(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1390928,      44546]*)
(*NotebookOutlinePosition[   1391680,      44572]*)
(*  CellTagsIndexPosition[   1391636,      44568]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Fourier series examples", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time Fourier series (CTFS)", "Section"],

Cell[CellGroupData[{

Cell["Example #1: triangle wave", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot triangle wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Triangle1[
          t_] := \((2  t + 1)\)\ \((u[t + 1/2]\  - \ 
                u[t])\)\  + \ \((\(-2\) t + 1)\) \((u[t] - 
                u[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Triangle1, {\(-1\)/2, 1/2}, {t, \(-2\), 
            2}];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[fnc1, {t, \(-2\), 2}, \ PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 2.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.206693 0.204647 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00205 -12 -4.5 ]
[-0.0125 .00205 0 4.5 ]
[-0.0125 .10437 -24 -4.5 ]
[-0.0125 .10437 0 4.5 ]
[-0.0125 .20669 -6 -4.5 ]
[-0.0125 .20669 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41134 -6 -4.5 ]
[-0.0125 .41134 0 4.5 ]
[-0.0125 .51366 -18 -4.5 ]
[-0.0125 .51366 0 4.5 ]
[-0.0125 .61599 -6 -4.5 ]
[-0.0125 .61599 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00205 m
.00625 .00205 L
s
[(-1)] -0.0125 .00205 1 0 Mshowa
0 .10437 m
.00625 .10437 L
s
[(-0.5)] -0.0125 .10437 1 0 Mshowa
0 .20669 m
.00625 .20669 L
s
[(0)] -0.0125 .20669 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.5)] -0.0125 .30902 1 0 Mshowa
0 .41134 m
.00625 .41134 L
s
[(1)] -0.0125 .41134 1 0 Mshowa
0 .51366 m
.00625 .51366 L
s
[(1.5)] -0.0125 .51366 1 0 Mshowa
0 .61599 m
.00625 .61599 L
s
[(2)] -0.0125 .61599 1 0 Mshowa
.125 Mabswid
0 .02251 m
.00375 .02251 L
s
0 .04298 m
.00375 .04298 L
s
0 .06344 m
.00375 .06344 L
s
0 .08391 m
.00375 .08391 L
s
0 .12483 m
.00375 .12483 L
s
0 .1453 m
.00375 .1453 L
s
0 .16576 m
.00375 .16576 L
s
0 .18623 m
.00375 .18623 L
s
0 .22716 m
.00375 .22716 L
s
0 .24762 m
.00375 .24762 L
s
0 .26809 m
.00375 .26809 L
s
0 .28855 m
.00375 .28855 L
s
0 .32948 m
.00375 .32948 L
s
0 .34995 m
.00375 .34995 L
s
0 .37041 m
.00375 .37041 L
s
0 .39088 m
.00375 .39088 L
s
0 .43181 m
.00375 .43181 L
s
0 .45227 m
.00375 .45227 L
s
0 .47273 m
.00375 .47273 L
s
0 .4932 m
.00375 .4932 L
s
0 .53413 m
.00375 .53413 L
s
0 .55459 m
.00375 .55459 L
s
0 .57506 m
.00375 .57506 L
s
0 .59552 m
.00375 .59552 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00205 m
1 .00205 L
s
.99375 .10437 m
1 .10437 L
s
.99375 .20669 m
1 .20669 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41134 m
1 .41134 L
s
.99375 .51366 m
1 .51366 L
s
.99375 .61599 m
1 .61599 L
s
.125 Mabswid
.99625 .02251 m
1 .02251 L
s
.99625 .04298 m
1 .04298 L
s
.99625 .06344 m
1 .06344 L
s
.99625 .08391 m
1 .08391 L
s
.99625 .12483 m
1 .12483 L
s
.99625 .1453 m
1 .1453 L
s
.99625 .16576 m
1 .16576 L
s
.99625 .18623 m
1 .18623 L
s
.99625 .22716 m
1 .22716 L
s
.99625 .24762 m
1 .24762 L
s
.99625 .26809 m
1 .26809 L
s
.99625 .28855 m
1 .28855 L
s
.99625 .32948 m
1 .32948 L
s
.99625 .34995 m
1 .34995 L
s
.99625 .37041 m
1 .37041 L
s
.99625 .39088 m
1 .39088 L
s
.99625 .43181 m
1 .43181 L
s
.99625 .45227 m
1 .45227 L
s
.99625 .47273 m
1 .47273 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .53413 m
1 .53413 L
s
.99625 .55459 m
1 .55459 L
s
.99625 .57506 m
1 .57506 L
s
.99625 .59552 m
1 .59552 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .20669 m
1 .20669 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .41134 m
.06244 .34493 L
.10458 .27249 L
.12507 .23728 L
.13506 .2201 L
.13735 .21615 L
.13979 .21197 L
.14079 .21025 L
.14186 .2084 L
.14305 .20702 L
.14415 .20892 L
.14868 .21671 L
.1536 .22517 L
.16254 .24053 L
.18221 .27434 L
.22343 .34521 L
.24402 .3806 L
.25405 .39784 L
.25635 .4018 L
.25878 .40598 L
.26086 .40955 L
.26204 .41111 L
.26314 .40922 L
.26771 .40135 L
.27266 .39285 L
.28163 .37744 L
.30133 .34356 L
.34024 .27668 L
.36005 .24262 L
.3705 .22466 L
.37623 .21481 L
.37759 .21247 L
.37903 .20999 L
.38026 .20788 L
.38096 .2067 L
.3816 .20781 L
.38634 .21595 L
.39144 .22472 L
.4023 .24339 L
.42145 .27631 L
.46049 .34343 L
.48041 .37766 L
.49089 .39568 L
.49618 .40477 L
.49763 .40726 L
.49842 .40863 L
.49918 .40993 L
.49988 .41114 L
.50065 .41022 L
.50135 .40903 L
Mistroke
.50199 .40792 L
.52279 .37216 L
.54197 .33919 L
.58116 .27183 L
.60117 .23743 L
.60665 .228 L
.61244 .21806 L
.61482 .21396 L
.61738 .20957 L
.61813 .20827 L
.61884 .20705 L
.61948 .20744 L
.62018 .20864 L
.62279 .21313 L
.66291 .28209 L
.70374 .35229 L
.71352 .36909 L
.72404 .38717 L
.72888 .39549 L
.73397 .40424 L
.73607 .40786 L
.73722 .40984 L
.73831 .41097 L
.7396 .40875 L
.74077 .40673 L
.74306 .4028 L
.78086 .33782 L
.81938 .2716 L
.83891 .23804 L
.84426 .22885 L
.84999 .21898 L
.85277 .2142 L
.85414 .21185 L
.85541 .20967 L
.85656 .2077 L
.85778 .20778 L
.859 .20989 L
.86035 .21221 L
.89981 .28004 L
.93998 .34909 L
.97619 .41134 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008Oooool5o`0003[ooooo0ol0000iooooo`;o0000>_ooool3o`0003[ooooo1Ol00006oooo
o`008_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Oooooo00Co0000oooo
oooooooo0000>_ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Kooooo000K
ooooo`Go00000oooool00ol0003oooooooooo`0cooooo`Go00000oooool00ol0003oooooooooo`0g
ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo00Co0000
oooooooooooo0000>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo000Q
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`0gooooo`04o`000?oo
ooooooooo`0003[ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000Ko
oooo000Qooooo`05o`000?ooooooooooooooool00000>_ooool2o`0003Wooooo00Co0000oooooooo
oooo0000>Oooool2o`0003_ooooo00Go0000ooooooooooooooooo`000006ooooo`008_ooool3o`00
03cooooo00?o0000ooooooooool0>?ooool2o`0003_ooooo00?o0000ooooooooool0>_ooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`005?ooool0
0ol0003oooooooooo`3oooooo`[ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`04oooo
oooo00001Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`7o00000Oooool001?ooooo0_l0
0006ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001_ooooo0_l00020ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool2o`00083o
oooo00?o0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo
0_l00020ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
00Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00020
ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020ooooo`03
o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo0Ol00001ooooo`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000
P?ooool00ol0003oooooooooo`1mooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020ooooo`03o`000?oooooooooo07gooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001
ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo9Ol000000ol00?oo0000o`00000jo`0000;o003o??l00002o`00
occo00000_l00?lTo`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool08Oooool2o`00occooooo0_l00?lNooooo`03o`000?oooooooooo01[ooooo00?o003ooooo
ool00?l0??ooool2o`00ob?ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo023ooooo00Co003ooooooooooooo003o>_ooool01?l00?ooooooooooool0
0?lMooooo`03o`000?oooooooooo01[ooooo00?o003oooooool00?l0>oooool00ol00?ooooooo`00
o`0Sooooo`7o00000Oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo023ooooo00Go003o
ooooooooooooooooo`00o`0iooooo`04o`00ooooooooooooo`00oagooooo00?o0000ooooooooool0
6_ooool01?l00?ooooooooooool00?liooooo`05o`00ooooooooooooooooool00?l08_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo023ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0eooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=_ooool01Ol00?oo
oooooooooooooooo003o02;ooooo0Ol00001ooooo`006oooool2o`00023ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool06_ooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool0=Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01kooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
<oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool0
6?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol0003oooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Mooooo`7o00000Oooool001_ooooo0_l0000Mooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Oo
oooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Kooooo`;o00000Oooool001_ooooo
00?o0000ooooooooool07?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool07?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01_ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01_ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool0:oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02cooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0Kooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool06_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool06_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool05?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool0:Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Wooooo0Ol00001ooooo`00
6oooool2o`0001[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Xooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo01Sooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo01?ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo02Oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Hooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool06?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`7o00000Oooool001_ooooo
0_l0000Gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0Eooooo`;o00000Oooool001_ooooo00?o0000ooooooooool05Oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo01Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool05?ooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo01?ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo01Cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Dooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Booooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool07Oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01;ooooo0Ol00001ooooo`001oooool01?l0
003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Booooo`7o00000Oooool0
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo017ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo017ooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo
013ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
017ooooo0Ol00001ooooo`006oooool2o`00017ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00oooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`0?ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0?ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03oooool00ol00?oooooooooo
o`0Sooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool09?ooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool09?ooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool03oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo00kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0>oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0Wooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo02Oooooo00?o003oooooooooool03Oooool1o`00007ooooo000Kooooo`;o0000
3Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
:?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
:?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0
2oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool0:Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0;ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`0;ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol0
0?ooooooooooo`0/ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0;?ooool00ol0
0?ooooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0;?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool02oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0/ooooo`03o`00oooooooooooo00[ooooo0Ol00001ooooo`006oooool2o`0000[ooooo
00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02kooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00Sooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool02?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool00oooool01Ol0003ooooooooooooooooo003o03Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`07ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0booooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0e
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`07
ooooo`7o00000Oooool001_ooooo0_l00008ooooo`03o`00oooooooooooo03?ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0cooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0dooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0<oooool0
0ol00?ooooooooooo`06ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`0eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0=?ooool01ol0
0?oooooooooooooooooo0000ooooool00?l0>?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo03Cooooo00?o003oooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00Gooooo00?o003oooooooooool0=oooool01Ol00?oooooooooooooooooo003o03Sooooo00Ko
003ooooooooooooo0000ooooool00?lhooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0=Oooool00ol00?ooooooooooo`06ooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool0=oooool01?l00?ooooooooooool00?ljooooo`04
o`00oooooooo0000o`00ocWooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0foooo
o`03o`00oooooooooooo00Gooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o003oooooooooool0>Oooool00ol00?ooooooo`00o`0kooooo`03
o`00ool0003o003o03[ooooo00Co003ooooooooooooo003o>_ooool00ol00?ooooooooooo`04oooo
o`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo03Wooooo0_l00?llooooo`;o003o??ooool2o`00oc_ooooo00?o003ooooooooo
ool01?ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`00
oooooooooooo03_ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0jooooo`03o`00
oooooooooooo03_ooooo00?o003oooooooooool00_ooool2o`00007ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001?ooooo0_l00006ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1
o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020ooooo`03o`000?oooooooooo07gooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`00
6oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003ooooooooo
o`1mooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o0000
0Oooool001_ooooo0_l00020ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`001oooool3o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o
00000Oooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000
P?ooool00ol0003oooooooooo`1mooooo`;o00000Oooool000Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool1o`00007ooooo0008ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo0007ooooo`;o00002Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00
007ooooo0008ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003ooooooooo
o`1mooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o0000
0Oooool001_ooooo0_l00020ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool2o`00083ooooo00?o
0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001;o
oooo1Ol00004ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00oooooooo`0000Go00000Ooo
ool001;ooooo00Go0000ooooooooooooooooo`00003oooooo`[ooooo000Booooo`05o`000?oooooo
ooooooooool00000ooooool:ooooo`004oooool3o`000?oooooo2oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.54077, -1.24296, \
0.0161771, 0.0188211}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Complex Fourier series", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[Triangle1[t], t, 5];\)\), "\[IndentingNewLine]", 
    \(series\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2 + \(2\ \[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \
\[Pi]\ t\)\)\/\[Pi]\^2 + \(2\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Pi]\ t\)\
\)\/\[Pi]\^2 + \(2\ \[ExponentialE]\^\(\(-6\)\ \[ImaginaryI]\ \[Pi]\ \
t\)\)\/\(9\ \[Pi]\^2\) + \(2\ \[ExponentialE]\^\(6\ \[ImaginaryI]\ \[Pi]\ t\)\
\)\/\(9\ \[Pi]\^2\) + \(2\ \[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ \[Pi]\ \
t\)\)\/\(25\ \[Pi]\^2\) + \(2\ \[ExponentialE]\^\(10\ \[ImaginaryI]\ \[Pi]\ t\
\)\)\/\(25\ \[Pi]\^2\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Real representation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(series2\  = series\  // \ ComplexExpand;\)\[IndentingNewLine]
    series2\  // TraditionalForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(4\ \(cos(2\ \[Pi]\ t)\)\)\/\[Pi]\^2 + \(4\ \(cos(6\ \
\[Pi]\ t)\)\)\/\(9\ \[Pi]\^2\) + \(4\ \(cos(10\ \[Pi]\ t)\)\)\/\(25\ \[Pi]\^2\
\) + 1\/2\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 2.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.206693 0.204647 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00205 -12 -4.5 ]
[-0.0125 .00205 0 4.5 ]
[-0.0125 .10437 -24 -4.5 ]
[-0.0125 .10437 0 4.5 ]
[-0.0125 .20669 -6 -4.5 ]
[-0.0125 .20669 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41134 -6 -4.5 ]
[-0.0125 .41134 0 4.5 ]
[-0.0125 .51366 -18 -4.5 ]
[-0.0125 .51366 0 4.5 ]
[-0.0125 .61599 -6 -4.5 ]
[-0.0125 .61599 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00205 m
.00625 .00205 L
s
[(-1)] -0.0125 .00205 1 0 Mshowa
0 .10437 m
.00625 .10437 L
s
[(-0.5)] -0.0125 .10437 1 0 Mshowa
0 .20669 m
.00625 .20669 L
s
[(0)] -0.0125 .20669 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.5)] -0.0125 .30902 1 0 Mshowa
0 .41134 m
.00625 .41134 L
s
[(1)] -0.0125 .41134 1 0 Mshowa
0 .51366 m
.00625 .51366 L
s
[(1.5)] -0.0125 .51366 1 0 Mshowa
0 .61599 m
.00625 .61599 L
s
[(2)] -0.0125 .61599 1 0 Mshowa
.125 Mabswid
0 .02251 m
.00375 .02251 L
s
0 .04298 m
.00375 .04298 L
s
0 .06344 m
.00375 .06344 L
s
0 .08391 m
.00375 .08391 L
s
0 .12483 m
.00375 .12483 L
s
0 .1453 m
.00375 .1453 L
s
0 .16576 m
.00375 .16576 L
s
0 .18623 m
.00375 .18623 L
s
0 .22716 m
.00375 .22716 L
s
0 .24762 m
.00375 .24762 L
s
0 .26809 m
.00375 .26809 L
s
0 .28855 m
.00375 .28855 L
s
0 .32948 m
.00375 .32948 L
s
0 .34995 m
.00375 .34995 L
s
0 .37041 m
.00375 .37041 L
s
0 .39088 m
.00375 .39088 L
s
0 .43181 m
.00375 .43181 L
s
0 .45227 m
.00375 .45227 L
s
0 .47273 m
.00375 .47273 L
s
0 .4932 m
.00375 .4932 L
s
0 .53413 m
.00375 .53413 L
s
0 .55459 m
.00375 .55459 L
s
0 .57506 m
.00375 .57506 L
s
0 .59552 m
.00375 .59552 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00205 m
1 .00205 L
s
.99375 .10437 m
1 .10437 L
s
.99375 .20669 m
1 .20669 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41134 m
1 .41134 L
s
.99375 .51366 m
1 .51366 L
s
.99375 .61599 m
1 .61599 L
s
.125 Mabswid
.99625 .02251 m
1 .02251 L
s
.99625 .04298 m
1 .04298 L
s
.99625 .06344 m
1 .06344 L
s
.99625 .08391 m
1 .08391 L
s
.99625 .12483 m
1 .12483 L
s
.99625 .1453 m
1 .1453 L
s
.99625 .16576 m
1 .16576 L
s
.99625 .18623 m
1 .18623 L
s
.99625 .22716 m
1 .22716 L
s
.99625 .24762 m
1 .24762 L
s
.99625 .26809 m
1 .26809 L
s
.99625 .28855 m
1 .28855 L
s
.99625 .32948 m
1 .32948 L
s
.99625 .34995 m
1 .34995 L
s
.99625 .37041 m
1 .37041 L
s
.99625 .39088 m
1 .39088 L
s
.99625 .43181 m
1 .43181 L
s
.99625 .45227 m
1 .45227 L
s
.99625 .47273 m
1 .47273 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .53413 m
1 .53413 L
s
.99625 .55459 m
1 .55459 L
s
.99625 .57506 m
1 .57506 L
s
.99625 .59552 m
1 .59552 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .20669 m
1 .20669 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .41134 m
.06244 .34493 L
.10458 .27249 L
.12507 .23728 L
.13506 .2201 L
.13735 .21615 L
.13979 .21197 L
.14079 .21025 L
.14186 .2084 L
.14305 .20702 L
.14415 .20892 L
.14868 .21671 L
.1536 .22517 L
.16254 .24053 L
.18221 .27434 L
.22343 .34521 L
.24402 .3806 L
.25405 .39784 L
.25635 .4018 L
.25878 .40598 L
.26086 .40955 L
.26204 .41111 L
.26314 .40922 L
.26771 .40135 L
.27266 .39285 L
.28163 .37744 L
.30133 .34356 L
.34024 .27668 L
.36005 .24262 L
.3705 .22466 L
.37623 .21481 L
.37759 .21247 L
.37903 .20999 L
.38026 .20788 L
.38096 .2067 L
.3816 .20781 L
.38634 .21595 L
.39144 .22472 L
.4023 .24339 L
.42145 .27631 L
.46049 .34343 L
.48041 .37766 L
.49089 .39568 L
.49618 .40477 L
.49763 .40726 L
.49842 .40863 L
.49918 .40993 L
.49988 .41114 L
.50065 .41022 L
.50135 .40903 L
Mistroke
.50199 .40792 L
.52279 .37216 L
.54197 .33919 L
.58116 .27183 L
.60117 .23743 L
.60665 .228 L
.61244 .21806 L
.61482 .21396 L
.61738 .20957 L
.61813 .20827 L
.61884 .20705 L
.61948 .20744 L
.62018 .20864 L
.62279 .21313 L
.66291 .28209 L
.70374 .35229 L
.71352 .36909 L
.72404 .38717 L
.72888 .39549 L
.73397 .40424 L
.73607 .40786 L
.73722 .40984 L
.73831 .41097 L
.7396 .40875 L
.74077 .40673 L
.74306 .4028 L
.78086 .33782 L
.81938 .2716 L
.83891 .23804 L
.84426 .22885 L
.84999 .21898 L
.85277 .2142 L
.85414 .21185 L
.85541 .20967 L
.85656 .2077 L
.85778 .20778 L
.859 .20989 L
.86035 .21221 L
.89981 .28004 L
.93998 .34909 L
.97619 .41134 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.206693 0.204647 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00205 -12 -4.5 ]
[-0.0125 .00205 0 4.5 ]
[-0.0125 .10437 -24 -4.5 ]
[-0.0125 .10437 0 4.5 ]
[-0.0125 .20669 -6 -4.5 ]
[-0.0125 .20669 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41134 -6 -4.5 ]
[-0.0125 .41134 0 4.5 ]
[-0.0125 .51366 -18 -4.5 ]
[-0.0125 .51366 0 4.5 ]
[-0.0125 .61599 -6 -4.5 ]
[-0.0125 .61599 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00205 m
.00625 .00205 L
s
[(-1)] -0.0125 .00205 1 0 Mshowa
0 .10437 m
.00625 .10437 L
s
[(-0.5)] -0.0125 .10437 1 0 Mshowa
0 .20669 m
.00625 .20669 L
s
[(0)] -0.0125 .20669 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.5)] -0.0125 .30902 1 0 Mshowa
0 .41134 m
.00625 .41134 L
s
[(1)] -0.0125 .41134 1 0 Mshowa
0 .51366 m
.00625 .51366 L
s
[(1.5)] -0.0125 .51366 1 0 Mshowa
0 .61599 m
.00625 .61599 L
s
[(2)] -0.0125 .61599 1 0 Mshowa
.125 Mabswid
0 .02251 m
.00375 .02251 L
s
0 .04298 m
.00375 .04298 L
s
0 .06344 m
.00375 .06344 L
s
0 .08391 m
.00375 .08391 L
s
0 .12483 m
.00375 .12483 L
s
0 .1453 m
.00375 .1453 L
s
0 .16576 m
.00375 .16576 L
s
0 .18623 m
.00375 .18623 L
s
0 .22716 m
.00375 .22716 L
s
0 .24762 m
.00375 .24762 L
s
0 .26809 m
.00375 .26809 L
s
0 .28855 m
.00375 .28855 L
s
0 .32948 m
.00375 .32948 L
s
0 .34995 m
.00375 .34995 L
s
0 .37041 m
.00375 .37041 L
s
0 .39088 m
.00375 .39088 L
s
0 .43181 m
.00375 .43181 L
s
0 .45227 m
.00375 .45227 L
s
0 .47273 m
.00375 .47273 L
s
0 .4932 m
.00375 .4932 L
s
0 .53413 m
.00375 .53413 L
s
0 .55459 m
.00375 .55459 L
s
0 .57506 m
.00375 .57506 L
s
0 .59552 m
.00375 .59552 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00205 m
1 .00205 L
s
.99375 .10437 m
1 .10437 L
s
.99375 .20669 m
1 .20669 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41134 m
1 .41134 L
s
.99375 .51366 m
1 .51366 L
s
.99375 .61599 m
1 .61599 L
s
.125 Mabswid
.99625 .02251 m
1 .02251 L
s
.99625 .04298 m
1 .04298 L
s
.99625 .06344 m
1 .06344 L
s
.99625 .08391 m
1 .08391 L
s
.99625 .12483 m
1 .12483 L
s
.99625 .1453 m
1 .1453 L
s
.99625 .16576 m
1 .16576 L
s
.99625 .18623 m
1 .18623 L
s
.99625 .22716 m
1 .22716 L
s
.99625 .24762 m
1 .24762 L
s
.99625 .26809 m
1 .26809 L
s
.99625 .28855 m
1 .28855 L
s
.99625 .32948 m
1 .32948 L
s
.99625 .34995 m
1 .34995 L
s
.99625 .37041 m
1 .37041 L
s
.99625 .39088 m
1 .39088 L
s
.99625 .43181 m
1 .43181 L
s
.99625 .45227 m
1 .45227 L
s
.99625 .47273 m
1 .47273 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .53413 m
1 .53413 L
s
.99625 .55459 m
1 .55459 L
s
.99625 .57506 m
1 .57506 L
s
.99625 .59552 m
1 .59552 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .20669 m
1 .20669 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .40449 m
.06244 .34452 L
.10458 .27297 L
.11448 .25677 L
.12507 .23589 L
.1302 .22602 L
.13273 .22184 L
.13506 .2186 L
.13718 .21628 L
.13824 .21536 L
.13942 .21456 L
.1406 .21398 L
.14186 .21363 L
.14306 .21355 L
.14415 .21369 L
.14538 .21409 L
.14649 .21468 L
.14778 .21561 L
.14899 .21672 L
.15115 .21923 L
.15348 .22261 L
.16366 .24203 L
.18221 .2746 L
.22321 .34443 L
.23307 .36044 L
.24363 .38117 L
.24875 .39113 L
.25127 .39541 L
.25361 .39879 L
.25572 .40126 L
.2568 .40227 L
.25796 .40316 L
.25912 .40382 L
.26021 .40424 L
.26151 .40448 L
.2627 .40444 L
.26386 .40416 L
.26491 .40371 L
.26613 .40296 L
.26728 .40204 L
.26932 .3999 L
.27153 .39694 L
.2812 .3791 L
.30067 .34432 L
.34159 .27462 L
.36195 .23836 L
.36705 .22828 L
.36957 .22385 L
.3719 .22027 L
.37418 .21739 L
Mistroke
.37625 .21543 L
.37743 .21461 L
.37855 .21404 L
.37972 .21367 L
.38099 .21354 L
.38214 .21366 L
.3832 .21398 L
.38437 .21455 L
.38562 .21541 L
.38694 .21657 L
.38818 .21792 L
.39051 .22099 L
.39926 .23693 L
.41888 .27244 L
.45726 .33827 L
.47668 .37093 L
.487 .39139 L
.48982 .39611 L
.49279 .40014 L
.49402 .40146 L
.49533 .40263 L
.49608 .40317 L
.49676 .40359 L
.4974 .40391 L
.4981 .40418 L
.49936 .40446 L
.50006 .40449 L
.50071 .40445 L
.50187 .40419 L
.50311 .40366 L
.50381 .40325 L
.50457 .40271 L
.50595 .4015 L
.50854 .39847 L
.51365 .39021 L
.51839 .38094 L
.53741 .34638 L
.57665 .27924 L
.59632 .24593 L
.60493 .22868 L
.60729 .22446 L
.60982 .22051 L
.612 .21771 L
.61437 .21541 L
.61568 .21452 L
.6169 .21394 L
.61806 .21363 L
.61929 .21355 L
.6204 .2137 L
.62143 .21403 L
Mistroke
.62256 .2146 L
.62378 .21545 L
.62505 .21659 L
.62643 .2181 L
.62895 .22151 L
.63369 .22968 L
.65454 .26868 L
.6952 .33803 L
.71401 .36941 L
.72391 .38921 L
.72889 .39755 L
.73025 .39938 L
.73171 .40106 L
.73309 .40235 L
.73435 .40329 L
.73505 .40369 L
.73579 .40403 L
.73653 .40428 L
.73735 .40444 L
.73806 .40449 L
.73882 .40445 L
.73954 .40431 L
.74019 .40411 L
.74143 .40353 L
.74213 .40309 L
.74279 .40261 L
.74551 .39989 L
.74812 .39635 L
.75048 .39249 L
.75578 .38236 L
.77595 .3457 L
.81596 .27739 L
.83429 .24618 L
.83931 .23597 L
.8447 .22564 L
.84732 .22139 L
.84979 .21806 L
.85202 .21578 L
.85328 .21483 L
.85444 .21417 L
.8557 .21372 L
.8564 .21359 L
.85705 .21354 L
.85824 .21365 L
.8595 .21402 L
.86063 .21459 L
.86169 .21531 L
.86408 .21758 L
.86667 .22095 L
.86903 .22469 L
Mistroke
.87433 .23468 L
.89538 .27291 L
.9353 .3411 L
.95394 .37306 L
.96334 .39166 L
.96592 .39597 L
.96869 .3998 L
.97003 .40129 L
.97131 .40246 L
.97245 .40329 L
.9737 .40396 L
.97499 .40437 L
.97619 .40449 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00;?ooool5
o`0002cooooo0ol0000Zooooo`;o0000;Oooool3o`0002cooooo1Ol0000iooooo`Go0000:oooool3
o`0002_ooooo0_l0000]ooooo`?o0000:oooool5o`0001;ooooo000]ooooo`04o`000?oooooooooo
o`0002gooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02cooooo00Co0000oooooooooooo0000>_ooool01?l0003oooooooooool0000/ooooo`03
o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`0[oooo
o`04o`000?ooooooooooo`0001;ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Uoooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0cooooo`Go00000oooool00ol0003oooooooooo`0T
ooooo`Go00000oooool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`0002gooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Yooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Aooooo`00;?ooool01Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooo
ooooooooo`00000iooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooo
oooooooo000001;ooooo000/ooooo`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002gooooo00Go0000ooooooooooooooooo`00000ioooo
o`05o`000?ooooooooooooooool00000:oooool2o`0002_ooooo00Co0000oooooooooooo0000;?oo
ool2o`0002cooooo00Go0000ooooooooooooooooo`00000Booooo`00;Oooool3o`0002kooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0;?ooool3o`0003_ooooo0ol0
000]ooooo`03o`000?oooooooooo02[ooooo0_l0000^ooooo`03o`000?oooooooooo02_ooooo0ol0
000Cooooo`00oooooooiooooo`00oooooooiooooo`008?ooool3o`000?Kooooo0ol0003Looooo`00
8Oooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo0=_ooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03oooool[o00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo9o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool03?ooool0023ooooo0_l00005ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Vooooo`;o00001_ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool0027ooooo
00?o0000ooooooooool00oooool2o`0006;ooooo00?o0000ooooooooool0HOooool2o`0002Wooooo
00?o0000ooooooooool01?ooool2o`0006;ooooo00?o0000ooooooooool0H?ooool2o`0000kooooo
000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo00cooooo000Wooooo`;o0000H_ooool00ol0003oooooooooo`1Qooooo`;o
0000<?ooool2o`0006;ooooo00?o0000ooooooooool0H?ooool2o`0000kooooo000Wooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Wooooo`;o0000H_ooool00ol0003oooooooooo`1Qooooo`;o0000<?ooool2o`00
06;ooooo00?o0000ooooooooool0H?ooool2o`0000kooooo000Wooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000W
ooooo`;o0000H_ooool00ol0003oooooooooo`1Qooooo`;o0000<?ooool2o`0006;ooooo00?o0000
ooooooooool0H?ooool2o`0000kooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0<ooooo`005Oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo01_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`00
5?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool000gooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00001Sooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool04oooool5o`0000;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool0000;ooooo`04
o`000?ooooooooooooooo`;o0000H_ooool00ol0003oooooooooo`1Pooooo`?o00007?ooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0001Rooooo`03o`000?oooooo
oooo063ooooo0_l0000>ooooo`005?ooool01?l0003oooooooooool00007ooooo`Co00001?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06_ooool0
1?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
3?ooool001Gooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool06oooool2o`0000Sooooo1Ol00004ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009oooool2
o`0006;ooooo00?o0000ooooooooool0HOooool2o`00033ooooo0_l0001Rooooo`03o`000?oooooo
oooo063ooooo0_l0000>ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009oooool2o`0006;ooooo00?o
0000ooooooooool0HOooool2o`00033ooooo0_l0001Rooooo`03o`000?oooooooooo063ooooo0_l0
000>ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0<ooooo`009oooool2o`0006;ooooo00?o0000ooooooooool0
HOooool2o`00033ooooo0_l0001Rooooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`009ooo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0<ooooo`009oooool2o`0006;ooooo00?o0000ooooooooool0HOooool2o`00033o
oooo0_l0001Rooooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`009oooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool0027ooooo0_l0
0004ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Wooooo`;o00001Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool09_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0<ooooo`008?ooool01?l0003oooooooooool00003oooooago000000?o003oo`000?l00000
;?l00002o`00obko000000?o003oo`000?l00000;Ol000000ol00?oo0000o`00000Ko`0002Sooooo
00Co0000oooooooooooo00001?ooooo9o`0000kooooo000Pooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool06Oooool2o`00obkooooo0_l00?lFooooo`03o`000?oooooooooo01Go
oooo0_l00?l]ooooo`?o003o6oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool06?ooool3ool002gooooo0_oo000Gooooo`03o`000?oooooooooo
01Cooooo0_oo000]ooooo`?oo`006oooool00ol0003oooooooooo`0<ooooo`008?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01Wooooo00?o003oooooool00?l0;Oooool00ol0
0?ooooooo`00o`0Eooooo`03o`000?oooooooooo01Cooooo00?o003oooooool00?l0;Oooool00ol0
0?ooooooo`00o`0Kooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Gooooo`Goo`00:oooool5ool001Gooooo00?o0000ooooooooool04_ooool5
ool002_ooooo1Ooo000Jooooo`03o`000?oooooooooo00cooooo000Pooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool06?ooool01?l00?ooooooooooool00?l/ooooo`04o`00oooo
ooooooooo`00oaGooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool00?l[ooooo`05
o`00ooooooooooooooooool00?l06_ooool00ol0003oooooooooo`0Vooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool05_ooool7ool002Wooooo1_oo000Eooooo`03o`000?oooooo
oooo01;ooooo1_oo000Zooooo`Goo`006_ooool00ol0003oooooooooo`0<ooooo`008Oooool2o`00
00Cooooo0_l0000Iooooo`05o`00ooooooooooooooooool00?l0:_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04oooool01Ol00?oooooooooooooo
oooo003o02_ooooo00Go003oooooooooooooooooo`00o`0Iooooo`;o0000:Oooool2o`0000Gooooo
0_l0000Gooooo`;oo`000_ooool3ool002Sooooo0ooo0002ooooo`;oo`005Oooool00ol0003ooooo
ooooo`0Aooooo`?oo`000_ooool2ool002Wooooo0ooo00001?ooooooo`00ool00?oo000Hooooo`;o
00003_ooool002Oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo02Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Kooooo0_oo0003ooooo`?oo`009oooool3ool000;ooooo0ooo000Dooooo`03o`00
0?oooooooooo017ooooo0ooo0002ooooo`?oo`00:?ooool2ool000?ooooo0_oo000Iooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Eooooo`?oo`001?ooool2ool002Kooooo0ooo0004ooooo`?oo`004ooo
ool00ol0003oooooooooo`0@ooooo`?oo`001?ooool2ool002Oooooo0ooo0003ooooo`?oo`006?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool05Oooool2ool000Gooooo0ooo000Uooooo`;oo`001_ooool2
ool001?ooooo00?o0000ooooooooool04?ooool2ool000Gooooo0ooo000Vooooo`;oo`001Oooool2
ool001Sooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Fooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
013ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Eooooo`;o0000<?ooool2o`00
01Gooooo0ooo0006ooooo`;oo`009?ooool3ool000Kooooo0ooo000Booooo`03o`000?oooooooooo
00oooooo0ooo0006ooooo`;oo`009Oooool3ool000Gooooo0ooo000Fooooo`;o00003_ooool002Oo
oooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo017o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Co
oooo0_oo0007ooooo`?oo`008oooool2ool000Sooooo0_oo000Booooo`03o`000?oooooooooo00oo
oooo0_oo0007ooooo`?oo`009?ooool2ool000Oooooo0_oo000Gooooo`03o`000?oooooooooo00co
oooo000Wooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Cooooo`?oo`002?ooool2ool002;ooooo0ooo0008ooooo`?oo`004Oooool00ol0003ooooo
ooooo`0>ooooo`?oo`002?ooool3ool002;ooooo0ooo0007ooooo`?oo`005_ooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool04oooool2ool000Wooooo0ooo000Qooooo`;oo`002_ooool3ool0013ooooo00?o
0000ooooooooool03_ooool2ool000[ooooo0_oo000Qooooo`?oo`002Oooool3ool001Gooooo00?o
0000ooooooooool03?ooool002Oooooo0_l0000Dooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00gooooo00?o0000
ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Cooooo`;o0000<?ooool2o`0001?ooooo0ooo000:
ooooo`;oo`008?ooool3ool000_ooooo0_oo000@ooooo`03o`000?oooooooooo00gooooo0ooo000:
ooooo`?oo`008?ooool2ool000_ooooo0_oo000Dooooo`;o00003_ooool002Oooooo00?o0000oooo
ooooool04_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool04oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo0ooo000;oooo
o`;oo`008?ooool2ool000cooooo0ooo000?ooooo`03o`000?oooooooooo00cooooo0ooo000<oooo
o`;oo`007oooool3ool000_ooooo0ooo000Dooooo`03o`000?oooooooooo00cooooo000Wooooo`03
o`000?oooooooooo01;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`;o
o`003?ooool3ool001kooooo0ooo000=ooooo`;oo`003oooool00ol0003oooooooooo`0<ooooo`;o
o`003Oooool3ool001gooooo0ooo000=ooooo`;oo`005?ooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
4?ooool3ool000gooooo0_oo000Nooooo`;oo`003_ooool3ool000kooooo00?o0000ooooooooool0
2oooool3ool000kooooo0_oo000Mooooo`;oo`003_ooool3ool001?ooooo00?o0000ooooooooool0
3?ooool002Oooooo0_l0000Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool03Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Aooooo`;o0000<?ooool2o`00013ooooo0ooo000>ooooo`?oo`007?oo
ool3ool000oooooo0_oo000>ooooo`03o`000?oooooooooo00_ooooo0_oo000?ooooo`?oo`006ooo
ool3ool000oooooo0_oo000Booooo`;o00003_ooool002Oooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo0_oo000@ooooo`?oo`006oooool2
ool0013ooooo0ooo000=ooooo`03o`000?oooooooooo00[ooooo0ooo000@ooooo`?oo`006_ooool2
ool0013ooooo0ooo000Booooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo
01_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
00kooooo0ooo000Aooooo`;oo`006_ooool3ool0017ooooo0_oo000=ooooo`03o`000?oooooooooo
00[ooooo0_oo000Booooo`;oo`006Oooool3ool0017ooooo0ooo000Aooooo`03o`000?oooooooooo
00cooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`;oo`00
4_ooool3ool001Sooooo0ooo000Booooo`?oo`003?ooool00ol0003oooooooooo`09ooooo`?oo`00
4_ooool3ool001Oooooo0ooo000Cooooo`;oo`004Oooool00ol0003oooooooooo`0<ooooo`005?oo
ool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000004Oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03oooool00ol0003o
ooooooooo`0Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`?oo`004oooool3ool001Oooooo0_oo000Dooooo`?oo`002oooool00ol0
003oooooooooo`09ooooo`;oo`005?ooool2ool001Oooooo0_oo000Dooooo`?oo`004?ooool00ol0
003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool0000;ooooo`04o`000?oooooooooo
ooooo`;o00003oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool03Oooool3o`0001cooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`02ooooo`;o00003Oooool3ool001Gooooo0_oo000Fooooo`?oo`005Oooool2ool000_ooooo00?o
0000ooooooooool02?ooool3ool001Cooooo0ooo000Eooooo`?oo`005Oooool2ool000oooooo0_l0
000>ooooo`005?ooool01?l0003oooooooooool00007ooooo`Co00001?ooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo
00?o0000ooooooooool03?ooool2ool001Kooooo0ooo000Eooooo`;oo`005_ooool3ool000[ooooo
00?o0000ooooooooool01oooool3ool001Kooooo0_oo000Eooooo`;oo`005_ooool3ool000oooooo
00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool06_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool3ool001Oo
oooo0_oo000Dooooo`?oo`005oooool2ool000[ooooo00?o0000ooooooooool01oooool2ool001Oo
oooo0ooo000Cooooo`?oo`005oooool2ool000oooooo00?o0000ooooooooool03?ooool001Gooooo
0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo
0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0;ooooo`;oo`006?ooool3ool001?ooooo
0_oo000Hooooo`?oo`002Oooool00ol0003oooooooooo`06ooooo`?oo`006?ooool3ool001;ooooo
0_oo000Hooooo`?oo`003_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`0000gooooo00?o
003oooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00cooooo0_l0
000`ooooo`;o00002oooool3ool001Wooooo0ooo000Aooooo`?oo`006Oooool2ool000Wooooo00?o
0000ooooooooool01_ooool2ool001[ooooo0_oo000Aooooo`?oo`006Oooool3ool000cooooo0_l0
000>ooooo`009oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02Oooool3ool001_ooooo0_oo000@ooooo`?oo`006_ooool3ool000Sooooo00?o0000
ooooooooool01Oooool3ool001[ooooo0ooo000?ooooo`?oo`006oooool2ool000gooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Wooooo0_oo000Looooo`?oo`003oooool2ool001cooooo0_oo0008oooo
o`03o`000?oooooooooo00Gooooo0_oo000Looooo`;oo`003oooool2ool001cooooo0ooo000<oooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00_ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`08ooooo`?oo`007Oooool3ool000gooooo0ooo000Looooo`?o
o`001oooool00ol0003oooooooooo`04ooooo`?oo`007?ooool3ool000gooooo0ooo000Mooooo`;o
o`003?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`0000_ooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Wooooo0_l0000`ooooo`;o0000
2Oooool2ool001oooooo0_oo000=ooooo`;oo`007_ooool2ool000Oooooo00?o0000ooooooooool0
1?ooool2ool001kooooo0_oo000=ooooo`;oo`007_ooool3ool000[ooooo0_l0000>ooooo`009ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01ooo
ool3ool001oooooo0ooo000;ooooo`?oo`007_ooool3ool000Kooooo00?o0000ooooooooool00ooo
ool3ool001kooooo0ooo000;ooooo`?oo`007oooool3ool000[ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo0_oo000Qooooo`?oo`002_ooool2ool0023ooooo0ooo0005ooooo`03o`000?oooooo
oooo00?ooooo0_oo000Pooooo`?oo`002_ooool2ool0027ooooo0_oo000:ooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`06ooooo`?oo`008_ooool2ool000Wooooo0ooo000Qooooo`;oo`001Oooool00ol0
003oooooooooo`02ooooo`?oo`008Oooool2ool000Wooooo0ooo000Qooooo`?oo`002Oooool00ol0
003oooooooooo`0<ooooo`009oooool2o`0000Sooooo00?o003oooooooooool08oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo0_l0000`ooooo`;o00001_ooool3ool002?o
oooo0ooo0007ooooo`?oo`008_ooool3ool000Cooooo00Co0000oooooooooooooooo0ooo000Roooo
o`?oo`001oooool3ool002?ooooo0ooo0007ooooo`;o00003_ooool002Oooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool09?ooool01Ol00?oooooooooooooooooo000000Cooooo00?o003oooooooooool08oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo0_oo000Uooooo`;oo`001oooool2ool0
02Cooooo0_oo0004ooooo`04o`000?ooooooooooooooo`;oo`009?ooool2ool000Oooooo0_oo000U
ooooo`;oo`002?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Toooo
o`05o`00ooooooooooooooooool000000oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool01?ooool3ool002Gooooo0ooo0005ooooo`?oo`009?ooool3
ool000?ooooo00?o0000ooooooooool00ooo000Tooooo`?oo`001Oooool3ool002Gooooo0ooo0007
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Kooooo00Co003ooooo
oooooooo00000oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool09_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01?ooool2ool002Oooooo0_oo0005ooooo`;oo`009_ooool2ool000?ooooo00?o0000
ooooooooool00_oo000Vooooo`;oo`001Oooool2ool002Oooooo0_oo0007ooooo`03o`000?oooooo
oooo00cooooo000Wooooo`;o00001_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool09oooool01?l00?ooooooooooool00002ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00Cooooo0_l0000`ooooo`;o00001?ooool3ool002Oooooo0ooo0003ooooo`?oo`009_ooool3
ool000;ooooo00?o0000oooooooo00000_oo000Vooooo`?oo`000oooool3ool002Oooooo0ooo0005
ooooo`;o00003_ooool002Oooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Yoooo
o`05o`00ooooooooooooooooool00?l0:_ooool01Ol00?ooooooo`000?oooooo003o02_ooooo00Go
003oooooooooooooooooo`00o`0[ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`02ooooo`?oo`00:Oooool2ool000;ooooo0ooo000Xooooo`?oo`00
00?oooooo`000?ooool00_oo000Xooooo`?oo`000_ooool2ool002Wooooo0_oo0006ooooo`03o`00
0?oooooooooo00cooooo000Pooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo02Wooooo00Co003ooooooooooooo003o;?ooool01?l00?oo0000ooooool00?l[ooooo`04
o`00ooooooooooooo`00obcooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Voooo
o`?o00001Oooool00ol0003oooooooooo`02ooooo`;oo`00:_ooool6ool002[ooooo1ooo000Yoooo
o`Koo`00:Oooool4ool000Cooooo00?o0000ooooooooool03?ooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02_ooooo00?o003oooooool0
0?l0;Oooool2o`00obgooooo0ol00?l]ooooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?oo`00:oooool5ool0
02_ooooo1Ooo000Zooooo`Goo`00:oooool3ool000Cooooo00?o0000ooooooooool03?ooool0027o
oooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o003oooooooooool0;?ooool2o`00obko
oooo0_l00?l^ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool00ol0000Yooooo`03
o`000?oooooooooo00Cooooo0_l00002ooooo`;oo`00;Oooool3ool002cooooo1?oo000/ooooo`?o
o`00;Oooool2ool000?ooooo0_l0000>ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?oo
ool0023ooooo0_l00005ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0Vooooo`;o00001_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool03?ooool0027ooooo00?o0000ooooooooool00oooool2o`00
06;ooooo00?o0000ooooooooool0HOooool2o`0002Wooooo00?o0000ooooooooool01?ooool2o`00
06;ooooo00?o0000ooooooooool0H?ooool2o`0000kooooo000Wooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000W
ooooo`;o0000H_ooool00ol0003oooooooooo`1Qooooo`;o0000<?ooool2o`0006;ooooo00?o0000
ooooooooool0H?ooool2o`0000kooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Wooooo`;o0000H_oo
ool00ol0003oooooooooo`1Qooooo`;o0000<?ooool2o`0006;ooooo00?o0000ooooooooool0H?oo
ool2o`0000kooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Wooooo`;o0000H_ooool00ol0003ooooo
ooooo`1Qooooo`;o0000<?ooool2o`0006;ooooo00?o0000ooooooooool0H?ooool2o`0000kooooo
000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0<ooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01[ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000006?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooooooool2o`0006;ooooo00?o0000ooooooooool0H?ooool3o`0001gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000H_ooool00ol0003ooooooooo
o`1Pooooo`;o00003_ooool001Gooooo00?o0000ooooooooool01oooool4o`0000Cooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo00cooooo000Dooooo`;o00002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Joooo
o`;o00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`07ooooo`Go
00000oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Rooooo`03o`00
0?oooooooooo067ooooo0_l0000`ooooo`;o0000H_ooool00ol0003oooooooooo`1Pooooo`;o0000
3_ooool002Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Rooooo`03o`000?oooooooooo067o
oooo0_l0000`ooooo`;o0000H_ooool00ol0003oooooooooo`1Pooooo`;o00003_ooool002Oooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool03?ooool002Oooooo0_l0001Rooooo`03o`000?oooooooooo067ooooo0_l0000`oooo
o`;o0000H_ooool00ol0003oooooooooo`1Pooooo`;o00003_ooool002Oooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03?oo
ool002Oooooo0_l0001Rooooo`03o`000?oooooooooo067ooooo0_l0000`ooooo`;o0000H_ooool0
0ol0003oooooooooo`1Pooooo`;o00003_ooool002Oooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Oooooo`Go00000oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool09Oooool5o`0000Co
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00co
oooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00?o
oooob_l0000Yooooo`03o`000?oooooooooo00CooooobOl0000>ooooo`008_ooool00ol0003ooooo
ooooo`3fooooo`03o`000?oooooooooo0=[ooooo000Oooooo`05o`000?ooooooooooooooool00000
m?ooool01Ol0003ooooooooooooooooo00000=_ooooo000Oooooo`05o`000?ooooooooooooooool0
0000m?ooool01Ol0003ooooooooooooooooo00000=_ooooo000Pooooo`?o0000m_ooool3o`000=co
oooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-2.93072, \
-1.38745, 0.0209614, 0.0243874}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-8.16452, -1.38745, 0.0209614, 0.0243874}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot error between truncated Fourier series and triangle wave\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[fnc1\  - \ series, \ {t, \(-2\), 2}, \ 
        PlotStyle \[Rule] {Green}, \ PlotPoints \[Rule] 250, 
        PlotRange \[Rule] {\(- .1\),  .1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 3.09017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -36 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -30 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -36 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -30 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -24 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -30 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(-0.075)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.05)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.025)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.025)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.05)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.075)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.02381 .41245 m
.02562 .36969 L
.02753 .33376 L
.02947 .30652 L
.03057 .29494 L
.03159 .2865 L
.03208 .28325 L
.03261 .28023 L
.03307 .278 L
.03356 .27607 L
.03401 .27467 L
.03424 .27407 L
.03449 .27351 L
.03473 .27309 L
.03494 .27278 L
.03515 .27253 L
.03535 .27236 L
.03547 .27228 L
.03554 .27225 L
.0356 .27222 L
.03572 .27219 L
.03584 .27217 L
.03595 .27217 L
.03605 .27219 L
.03616 .27222 L
.03628 .27227 L
.0364 .27235 L
.03654 .27245 L
.03679 .27269 L
.03726 .27334 L
.03771 .27418 L
.03818 .27528 L
.03903 .27775 L
.04091 .28495 L
.04267 .29309 L
.0464 .31085 L
.0483 .31852 L
.0493 .3219 L
.05037 .32492 L
.0514 .32719 L
.05235 .32869 L
.0528 .32921 L
.05304 .32943 L
.05329 .32963 L
.05351 .32977 L
.05376 .32989 L
.05386 .32993 L
.05398 .32997 L
.05409 .32999 L
.05419 .33001 L
Mistroke
.05431 .33002 L
.05443 .33003 L
.05453 .33003 L
.05465 .33002 L
.05477 .33 L
.05483 .32998 L
.0549 .32997 L
.05514 .32989 L
.05536 .32978 L
.05559 .32964 L
.05602 .32931 L
.05656 .32875 L
.05707 .32808 L
.05802 .3265 L
.05994 .32221 L
.06172 .31731 L
.06551 .30589 L
.06741 .30073 L
.06915 .29686 L
.07006 .29527 L
.07102 .29395 L
.07152 .29342 L
.07198 .29302 L
.07249 .29269 L
.07277 .29256 L
.07291 .29251 L
.07303 .29247 L
.07315 .29244 L
.07325 .29242 L
.07337 .2924 L
.0735 .29239 L
.07362 .29238 L
.07369 .29238 L
.07375 .29238 L
.07387 .29239 L
.074 .29241 L
.0741 .29242 L
.07421 .29245 L
.07442 .29251 L
.07466 .2926 L
.07488 .29271 L
.07535 .29301 L
.07586 .29345 L
.07689 .29465 L
.07788 .29617 L
.07878 .29784 L
.0808 .30239 L
.08465 .31252 L
.08641 .31695 L
.08835 .32108 L
Mistroke
.08927 .32266 L
.09027 .32401 L
.09081 .32459 L
.09131 .32502 L
.09155 .32518 L
.09181 .32534 L
.09206 .32545 L
.09229 .32554 L
.09241 .32557 L
.09254 .3256 L
.09267 .32563 L
.09274 .32564 L
.09281 .32564 L
.09293 .32565 L
.09304 .32565 L
.0931 .32565 L
.09317 .32565 L
.09329 .32563 L
.0934 .32562 L
.09352 .32559 L
.09376 .32552 L
.09398 .32544 L
.09419 .32534 L
.0947 .32501 L
.09516 .3246 L
.09621 .32335 L
.09716 .32183 L
.09804 .32012 L
.10003 .31529 L
.1038 .30417 L
.10572 .29852 L
.1078 .29326 L
.10878 .2913 L
.10931 .29039 L
.10981 .28967 L
.11027 .28911 L
.11069 .28869 L
.11115 .28834 L
.11141 .2882 L
.11166 .2881 L
.11178 .28806 L
.11184 .28805 L
.11191 .28804 L
.11203 .28802 L
.11214 .28801 L
.11225 .288 L
.11235 .28801 L
.11246 .28802 L
.11258 .28804 L
.11271 .28808 L
Mistroke
.11285 .28812 L
.1131 .28824 L
.11334 .28838 L
.11357 .28855 L
.11398 .28894 L
.11443 .28949 L
.11534 .291 L
.11632 .29317 L
.11721 .29565 L
.11923 .30279 L
.12305 .32036 L
.12498 .32961 L
.12673 .33708 L
.12764 .34031 L
.12863 .34311 L
.12917 .34428 L
.12941 .34469 L
.12967 .34509 L
.1299 .34537 L
.13014 .3456 L
.13028 .3457 L
.13041 .34577 L
.13053 .34582 L
.13065 .34585 L
.13076 .34586 L
.13088 .34586 L
.13099 .34584 L
.13109 .3458 L
.1312 .34575 L
.13133 .34566 L
.13158 .34544 L
.13183 .34512 L
.13209 .34468 L
.13257 .34361 L
.13304 .34217 L
.1335 .34046 L
.13434 .33626 L
.13528 .33001 L
.13627 .32144 L
.13805 .30062 L
.13993 .27035 L
.1417 .2339 L
.14218 .2226 L
.14243 .21639 L
.14257 .21291 L
.1427 .2096 L
.14283 .20639 L
.1429 .20659 L
.14296 .20825 L
.1432 .21421 L
Mistroke
.14365 .22542 L
.14544 .26393 L
.14726 .29479 L
.1483 .30887 L
.14925 .3195 L
.15015 .32777 L
.15113 .33482 L
.15167 .33789 L
.15217 .34025 L
.15264 .34208 L
.15315 .34362 L
.15339 .34419 L
.15364 .3447 L
.15387 .34509 L
.15408 .34537 L
.15428 .34558 L
.15438 .34566 L
.1545 .34574 L
.15462 .3458 L
.15473 .34584 L
.15485 .34586 L
.15495 .34586 L
.15507 .34585 L
.15519 .34582 L
.15531 .34577 L
.15541 .34571 L
.15567 .34551 L
.15592 .34525 L
.15641 .34453 L
.15694 .34346 L
.15784 .34104 L
.15884 .33762 L
.16086 .329 L
.16474 .31041 L
.16651 .30269 L
.16752 .29888 L
.16846 .29577 L
.16947 .29298 L
.17039 .29096 L
.17137 .28938 L
.17191 .28876 L
.17217 .28853 L
.17242 .28835 L
.17265 .28822 L
.17287 .28812 L
.17299 .28808 L
.1731 .28805 L
.17322 .28803 L
.17329 .28802 L
.17336 .28801 L
Mistroke
.17342 .28801 L
.17349 .288 L
.17361 .28801 L
.17373 .28802 L
.17384 .28804 L
.17395 .28807 L
.17408 .28811 L
.17435 .28822 L
.17458 .28835 L
.17479 .2885 L
.17527 .28892 L
.17612 .28997 L
.17708 .29156 L
.17796 .29337 L
.17997 .29843 L
.18375 .30976 L
.18565 .31521 L
.18739 .3195 L
.18828 .32133 L
.18926 .32299 L
.19024 .32428 L
.19077 .3248 L
.19127 .32518 L
.1915 .32532 L
.19175 .32545 L
.19188 .3255 L
.19203 .32555 L
.19216 .32558 L
.19228 .32561 L
.1924 .32563 L
.19252 .32564 L
.19264 .32565 L
.19271 .32565 L
.19278 .32565 L
.19289 .32565 L
.193 .32563 L
.19312 .32561 L
.19324 .32559 L
.19346 .32553 L
.19369 .32544 L
.1941 .32522 L
.19454 .32491 L
.19503 .32447 L
.19602 .32328 L
.19692 .32188 L
.19893 .31781 L
.20278 .30795 L
.20648 .29879 L
.20839 .29527 L
.20935 .29398 L
Mistroke
.2099 .2934 L
.21042 .29298 L
.21089 .29268 L
.21116 .29256 L
.21129 .29251 L
.21141 .29247 L
.21153 .29244 L
.21166 .29242 L
.21177 .2924 L
.21187 .29239 L
.21199 .29238 L
.21211 .29238 L
.21218 .29238 L
.21224 .29239 L
.21237 .2924 L
.21248 .29242 L
.21259 .29245 L
.21284 .29252 L
.21306 .29261 L
.2133 .29273 L
.2137 .293 L
.21415 .29337 L
.21512 .29449 L
.21601 .29586 L
.21802 .30004 L
.22184 .31078 L
.22551 .32154 L
.2274 .32593 L
.22846 .3278 L
.22892 .32846 L
.22942 .32904 L
.22987 .32946 L
.23012 .32964 L
.23038 .32979 L
.23062 .3299 L
.23084 .32997 L
.23094 .33 L
.23106 .33002 L
.23116 .33003 L
.23126 .33003 L
.23139 .33003 L
.23146 .33002 L
.23153 .33001 L
.23165 .32999 L
.23177 .32995 L
.23199 .32987 L
.23224 .32975 L
.23249 .32958 L
.23277 .32935 L
.23327 .32881 L
Mistroke
.23378 .3281 L
.23425 .3273 L
.23532 .32499 L
.23726 .3191 L
.24105 .3028 L
.24469 .28546 L
.24655 .27817 L
.24706 .27656 L
.2476 .2751 L
.24811 .27397 L
.24856 .27317 L
.24879 .27285 L
.24904 .27257 L
.24915 .27247 L
.24927 .27237 L
.24938 .2723 L
.24949 .27225 L
.2496 .27221 L
.24973 .27218 L
.24984 .27217 L
.24995 .27218 L
.25002 .27219 L
.25008 .27221 L
.2502 .27226 L
.25027 .2723 L
.25034 .27234 L
.25047 .27244 L
.25069 .27267 L
.25091 .27297 L
.25132 .27372 L
.25176 .27482 L
.25224 .27638 L
.25323 .28087 L
.25413 .28654 L
.25516 .29513 L
.25614 .30537 L
.25807 .33194 L
.25985 .36454 L
.26072 .38343 L
.26119 .39468 L
.26165 .40594 L
.26177 .4091 L
.26184 .41085 L
.26191 .4124 L
.26198 .41043 L
.26205 .40866 L
.26219 .40524 L
.26268 .39319 L
.26364 .37137 L
.26541 .33741 L
Mistroke
.26641 .32163 L
.26735 .30908 L
.26836 .29791 L
.26928 .28965 L
.27026 .28275 L
.27076 .27991 L
.27131 .27741 L
.27176 .27572 L
.27226 .27425 L
.27248 .27374 L
.27272 .27327 L
.27294 .27291 L
.27314 .27264 L
.27339 .2724 L
.27352 .27231 L
.27365 .27224 L
.27372 .27221 L
.2738 .27219 L
.27387 .27218 L
.27393 .27217 L
.27406 .27218 L
.27412 .27218 L
.27419 .2722 L
.27431 .27224 L
.27443 .2723 L
.27456 .27239 L
.27468 .27249 L
.2749 .27271 L
.27515 .27302 L
.27566 .27389 L
.27614 .27494 L
.27705 .27748 L
.27907 .28522 L
.28279 .30292 L
.28468 .31163 L
.28674 .31977 L
.2877 .32283 L
.28872 .32554 L
.28968 .32752 L
.29056 .32883 L
.29102 .32933 L
.29127 .32955 L
.29151 .32971 L
.29173 .32983 L
.29193 .32992 L
.29204 .32996 L
.29216 .32999 L
.29227 .33001 L
.2924 .33002 L
.29246 .33003 L
Mistroke
.29253 .33003 L
.2926 .33003 L
.29266 .33002 L
.29278 .33001 L
.2929 .32999 L
.29303 .32996 L
.29316 .32992 L
.29344 .32979 L
.29368 .32965 L
.2939 .32949 L
.2944 .32903 L
.29535 .32779 L
.29624 .32627 L
.29824 .3217 L
.30202 .31064 L
.30565 .30036 L
.30752 .29636 L
.30856 .29466 L
.30903 .29405 L
.30952 .2935 L
.31002 .29306 L
.31047 .29276 L
.31068 .29264 L
.31092 .29254 L
.31114 .29247 L
.31125 .29244 L
.31135 .29242 L
.31146 .2924 L
.31158 .29239 L
.3117 .29238 L
.31181 .29238 L
.31193 .29239 L
.31205 .2924 L
.31212 .29241 L
.31218 .29242 L
.31231 .29245 L
.31257 .29253 L
.31284 .29264 L
.31334 .29294 L
.31381 .29332 L
.31426 .29376 L
.31526 .29504 L
.31729 .29871 L
.32105 .30799 L
.32296 .31308 L
.32503 .31817 L
.326 .32023 L
.32703 .32211 L
.32799 .32355 L
.32888 .32456 L
Mistroke
.32932 .32495 L
.32978 .32526 L
.33 .32539 L
.33025 .32549 L
.33038 .32554 L
.33051 .32557 L
.33063 .3256 L
.33075 .32563 L
.33086 .32564 L
.33098 .32565 L
.33109 .32565 L
.33119 .32565 L
.33131 .32564 L
.33142 .32563 L
.33154 .32561 L
.33166 .32558 L
.33187 .32552 L
.33207 .32544 L
.33252 .3252 L
.33301 .32483 L
.33354 .32432 L
.3345 .32307 L
.33543 .3215 L
.33629 .31977 L
.34011 .30962 L
.34377 .29863 L
.34582 .29343 L
.34678 .29146 L
.34768 .28998 L
.34812 .28939 L
.3486 .28886 L
.34909 .28845 L
.34936 .28828 L
.34961 .28816 L
.34972 .28811 L
.34984 .28807 L
.34996 .28804 L
.35007 .28802 L
.35017 .28801 L
.35027 .28801 L
.35038 .28801 L
.35049 .28801 L
.3506 .28803 L
.35072 .28805 L
.35083 .28808 L
.35094 .28812 L
.3512 .28824 L
.35143 .28838 L
.35191 .28878 L
.35244 .28938 L
Mistroke
.35339 .29091 L
.35432 .29294 L
.35518 .29527 L
.35698 .30144 L
.35896 .3099 L
.36284 .3285 L
.36462 .33626 L
.36563 .33995 L
.36656 .34272 L
.36704 .34384 L
.3675 .34469 L
.36775 .34507 L
.36802 .3454 L
.36814 .34552 L
.36827 .34562 L
.36838 .3457 L
.3685 .34577 L
.36862 .34582 L
.36874 .34585 L
.36886 .34586 L
.36893 .34586 L
.369 .34585 L
.36911 .34583 L
.36922 .34579 L
.36935 .34572 L
.36946 .34563 L
.36973 .34537 L
.36998 .34504 L
.37024 .34457 L
.37053 .34395 L
.37101 .34261 L
.37144 .34106 L
.37242 .33633 L
.37333 .33032 L
.37419 .32309 L
.37611 .30104 L
.37789 .27289 L
.37883 .25478 L
.37984 .23274 L
.38031 .2217 L
.38056 .21545 L
.38069 .21234 L
.3808 .20948 L
.38091 .2068 L
.381 .20691 L
.38111 .20958 L
.38122 .21243 L
.38168 .22372 L
.38341 .26156 L
.38532 .29431 L
Mistroke
.38724 .31841 L
.38829 .32809 L
.38927 .33506 L
.38975 .3378 L
.39027 .34028 L
.39073 .34207 L
.39123 .34357 L
.39167 .34458 L
.39192 .34502 L
.39215 .34535 L
.39237 .34557 L
.39257 .34572 L
.39267 .34578 L
.39278 .34582 L
.3929 .34585 L
.39301 .34586 L
.39314 .34585 L
.3932 .34584 L
.39326 .34583 L
.39339 .34578 L
.3935 .34572 L
.39375 .34553 L
.39402 .34524 L
.39452 .34449 L
.39498 .34358 L
.3959 .34115 L
.39677 .33823 L
.40045 .32185 L
.40251 .31192 L
.40437 .30366 L
.40634 .29646 L
.4072 .29393 L
.40814 .29165 L
.40904 .28998 L
.40954 .28929 L
.41 .28877 L
.41026 .28854 L
.4105 .28836 L
.41073 .28823 L
.41097 .28812 L
.41109 .28808 L
.41123 .28804 L
.4113 .28803 L
.41137 .28802 L
.41144 .28801 L
.41151 .28801 L
.41162 .28801 L
.41175 .28801 L
.41181 .28802 L
.41188 .28803 L
Mistroke
.412 .28806 L
.41212 .28809 L
.41225 .28814 L
.41252 .28826 L
.41276 .28841 L
.41299 .28858 L
.41351 .28907 L
.41406 .28975 L
.41508 .29137 L
.416 .29325 L
.41984 .30365 L
.42352 .31461 L
.42558 .31971 L
.42655 .32166 L
.42745 .32313 L
.42838 .32433 L
.42887 .32481 L
.42939 .3252 L
.42961 .32533 L
.42984 .32544 L
.43007 .32553 L
.43027 .32559 L
.43039 .32561 L
.4305 .32563 L
.43063 .32565 L
.43069 .32565 L
.43076 .32565 L
.43087 .32565 L
.431 .32564 L
.43112 .32563 L
.43122 .32561 L
.43135 .32559 L
.43146 .32556 L
.43168 .32548 L
.43192 .32538 L
.43217 .32524 L
.43263 .32491 L
.43305 .32454 L
.43402 .3234 L
.43505 .32182 L
.43694 .31802 L
.43871 .31371 L
.44245 .3038 L
.44436 .29925 L
.44537 .29719 L
.44644 .29535 L
.44738 .29405 L
.44789 .29351 L
.44843 .29304 L
.44867 .29287 L
Mistroke
.44893 .29271 L
.44916 .2926 L
.44938 .29251 L
.44959 .29245 L
.4497 .29243 L
.44981 .29241 L
.44992 .29239 L
.45005 .29238 L
.45017 .29238 L
.45027 .29238 L
.45039 .2924 L
.45051 .29241 L
.45061 .29243 L
.45072 .29246 L
.45097 .29254 L
.45121 .29263 L
.45163 .29288 L
.45208 .29322 L
.45262 .29375 L
.45312 .29437 L
.45407 .2958 L
.45601 .29977 L
.45779 .30442 L
.4616 .31584 L
.46351 .32129 L
.46526 .32545 L
.46616 .32716 L
.46714 .32861 L
.46768 .3292 L
.46791 .32941 L
.46818 .32961 L
.4684 .32976 L
.46865 .32988 L
.46879 .32993 L
.46891 .32997 L
.46903 .33 L
.46916 .33002 L
.46928 .33003 L
.46934 .33003 L
.4694 .33003 L
.46952 .33002 L
.46964 .33001 L
.46975 .32999 L
.46985 .32996 L
.47008 .32988 L
.47032 .32975 L
.47055 .3296 L
.47106 .32916 L
.4715 .32865 L
.47197 .32795 L
Mistroke
.47283 .32634 L
.47383 .3239 L
.47473 .3212 L
.47676 .31365 L
.48063 .29557 L
.4824 .28715 L
.48341 .2828 L
.48435 .2792 L
.48536 .276 L
.4858 .27486 L
.48628 .27383 L
.48654 .27336 L
.48678 .27299 L
.48703 .27268 L
.48726 .27246 L
.48738 .27236 L
.4875 .27229 L
.48763 .27223 L
.4877 .27221 L
.48777 .27219 L
.48783 .27218 L
.4879 .27217 L
.48803 .27218 L
.4881 .27219 L
.48817 .27221 L
.48824 .27223 L
.48831 .27227 L
.48843 .27234 L
.48854 .27242 L
.48878 .27267 L
.48901 .27297 L
.48922 .27334 L
.4897 .27441 L
.49023 .276 L
.49074 .27801 L
.49128 .28065 L
.49226 .28682 L
.49316 .29423 L
.49413 .30418 L
.4959 .32771 L
.49783 .36221 L
.49881 .38342 L
.49935 .39615 L
.49962 .40268 L
.49973 .4056 L
.49986 .40886 L
.49998 .41195 L
.50009 .41005 L
.50021 .40702 L
.50034 .40381 L
Mistroke
.50086 .39116 L
.50176 .37075 L
.50353 .33694 L
.50451 .32165 L
.50557 .30758 L
.50659 .29657 L
.50751 .28855 L
.50849 .28193 L
.50941 .27737 L
.50992 .27551 L
.51038 .27419 L
.51089 .27313 L
.51115 .27275 L
.5113 .27258 L
.51143 .27245 L
.51155 .27236 L
.51168 .27228 L
.51174 .27225 L
.5118 .27222 L
.51187 .2722 L
.51194 .27218 L
.51206 .27217 L
.51212 .27217 L
.51219 .27218 L
.51231 .27221 L
.51242 .27225 L
.51254 .27231 L
.51265 .27238 L
.51285 .27256 L
.51307 .2728 L
.51332 .27313 L
.51383 .27403 L
.51437 .27526 L
.51533 .27811 L
.51722 .28548 L
.51899 .29369 L
.52273 .31148 L
.52464 .31908 L
.52565 .3224 L
.52672 .32531 L
.52766 .32732 L
.52817 .32817 L
.52871 .3289 L
.52921 .32941 L
.52942 .32959 L
.52966 .32974 L
.52989 .32986 L
.5301 .32994 L
.53021 .32998 L
.53032 .33 L
Mistroke
.53044 .33002 L
.53055 .33003 L
.53066 .33003 L
.53078 .33002 L
.5309 .33001 L
.531 .32999 L
.53112 .32996 L
.53125 .32992 L
.53149 .32981 L
.53174 .32967 L
.532 .32948 L
.53248 .32904 L
.53341 .32785 L
.53426 .32641 L
.53611 .32226 L
.53812 .31668 L
.54207 .30482 L
.54404 .29966 L
.545 .29753 L
.54588 .29588 L
.54673 .29457 L
.54765 .29348 L
.54815 .29303 L
.54838 .29287 L
.54862 .29272 L
.54884 .29262 L
.54907 .29252 L
.54919 .29248 L
.54931 .29245 L
.54942 .29242 L
.54954 .2924 L
.54966 .29239 L
.54978 .29238 L
.54989 .29238 L
.55 .29239 L
.55011 .2924 L
.55024 .29241 L
.55037 .29244 L
.55049 .29247 L
.55071 .29255 L
.55091 .29263 L
.55137 .29289 L
.55186 .29327 L
.55239 .2938 L
.55336 .29504 L
.55526 .29844 L
.55729 .30313 L
.5613 .31372 L
.56332 .31858 L
.5642 .32043 L
Mistroke
.56517 .32218 L
.56604 .32349 L
.56698 .32457 L
.5675 .32501 L
.56797 .32532 L
.56819 .32543 L
.56844 .32553 L
.56855 .32556 L
.56867 .32559 L
.56879 .32562 L
.56889 .32563 L
.569 .32564 L
.56913 .32565 L
.56924 .32565 L
.56936 .32565 L
.56948 .32563 L
.56959 .32562 L
.56969 .3256 L
.5698 .32557 L
.57004 .32549 L
.5703 .32538 L
.57077 .32509 L
.5712 .32474 L
.57161 .32434 L
.57253 .32316 L
.57354 .32148 L
.57449 .31954 L
.57628 .31514 L
.57997 .30422 L
.58184 .29871 L
.5839 .29345 L
.58484 .29153 L
.58585 .28987 L
.58632 .28927 L
.58681 .28875 L
.58723 .28842 L
.58746 .28827 L
.58769 .28816 L
.58781 .28811 L
.58794 .28807 L
.58805 .28804 L
.58817 .28802 L
.58824 .28801 L
.5883 .28801 L
.58837 .28801 L
.58844 .288 L
.58857 .28801 L
.58863 .28802 L
.5887 .28803 L
.58882 .28805 L
Mistroke
.58894 .28809 L
.58916 .28817 L
.5894 .2883 L
.58966 .28847 L
.59011 .28888 L
.59059 .28945 L
.59145 .29083 L
.59236 .2928 L
.59334 .29546 L
.59511 .30158 L
.5991 .31966 L
.6011 .32926 L
.60294 .33716 L
.60387 .34043 L
.60474 .34291 L
.60521 .34398 L
.60564 .34477 L
.60587 .3451 L
.60612 .3454 L
.60637 .34563 L
.60651 .34572 L
.60657 .34576 L
.60664 .34579 L
.60676 .34583 L
.60683 .34585 L
.60689 .34586 L
.60701 .34586 L
.60713 .34585 L
.6072 .34583 L
.60727 .34581 L
.6074 .34574 L
.60753 .34565 L
.60766 .34555 L
.6079 .34528 L
.60812 .34496 L
.60861 .34397 L
.60906 .34275 L
.60954 .34106 L
.61041 .33697 L
.61133 .33107 L
.61233 .32265 L
.61437 .29885 L
.61625 .26797 L
.6173 .24692 L
.61827 .22496 L
.61875 .21323 L
.61886 .21029 L
.61899 .20708 L
.61906 .20594 L
.61913 .20763 L
Mistroke
.61926 .21091 L
.62032 .23659 L
.62227 .27565 L
.62409 .30384 L
.62514 .31639 L
.62609 .32565 L
.62707 .33318 L
.62799 .33854 L
.62849 .34081 L
.62896 .34251 L
.62947 .34395 L
.62973 .34451 L
.63001 .34501 L
.63025 .34535 L
.63038 .34549 L
.63051 .34562 L
.63063 .3457 L
.6307 .34574 L
.63076 .34578 L
.63088 .34583 L
.63099 .34585 L
.6311 .34586 L
.63122 .34586 L
.63135 .34583 L
.63146 .34579 L
.63157 .34573 L
.63167 .34567 L
.63189 .34549 L
.63215 .3452 L
.63239 .34487 L
.63293 .3439 L
.63391 .34142 L
.63571 .33492 L
.6377 .32594 L
.64159 .3074 L
.64338 .30007 L
.64533 .29382 L
.64639 .29133 L
.64691 .29036 L
.64737 .28963 L
.64783 .28905 L
.64831 .28857 L
.64858 .28837 L
.64883 .28822 L
.64906 .28812 L
.64918 .28808 L
.64924 .28806 L
.64931 .28805 L
.64944 .28802 L
.64955 .28801 L
Mistroke
.64968 .288 L
.64975 .28801 L
.64982 .28801 L
.64994 .28802 L
.65005 .28805 L
.65017 .28808 L
.6503 .28812 L
.65052 .28821 L
.65073 .28833 L
.6512 .28867 L
.65171 .28919 L
.65217 .28977 L
.65321 .29145 L
.65507 .29553 L
.65707 .30107 L
.66102 .31293 L
.66299 .31813 L
.66395 .32028 L
.66482 .32197 L
.66567 .32332 L
.66659 .32445 L
.66709 .32491 L
.66756 .32525 L
.66779 .32537 L
.66801 .32547 L
.66823 .32555 L
.66835 .32558 L
.66848 .32561 L
.6686 .32563 L
.66871 .32564 L
.66884 .32565 L
.66896 .32565 L
.66907 .32565 L
.66917 .32564 L
.66928 .32562 L
.6694 .3256 L
.66965 .32553 L
.66988 .32544 L
.67014 .32531 L
.67041 .32515 L
.67095 .32472 L
.67147 .3242 L
.67244 .32294 L
.67435 .3195 L
.67612 .31542 L
.6799 .30548 L
.68182 .30067 L
.68284 .29843 L
.68391 .29638 L
.68487 .29485 L
Mistroke
.68538 .29418 L
.68592 .29357 L
.68642 .29312 L
.68688 .2928 L
.6871 .29267 L
.68734 .29256 L
.68756 .29248 L
.68777 .29243 L
.68789 .29241 L
.688 .29239 L
.68811 .29239 L
.68822 .29238 L
.68834 .29238 L
.68841 .29239 L
.68847 .29239 L
.68859 .29241 L
.6887 .29243 L
.68892 .29248 L
.68912 .29255 L
.68957 .29278 L
.69003 .2931 L
.69054 .29357 L
.69156 .29484 L
.69254 .29646 L
.69343 .29826 L
.69545 .30322 L
.69928 .3146 L
.70122 .32024 L
.70297 .32462 L
.70388 .3265 L
.70487 .32813 L
.70541 .32882 L
.70591 .32933 L
.70639 .32969 L
.70663 .32983 L
.70677 .32989 L
.70689 .32993 L
.70701 .32997 L
.70714 .33 L
.7072 .33001 L
.70727 .33002 L
.70733 .33002 L
.7074 .33003 L
.70746 .33003 L
.70753 .33003 L
.70765 .33002 L
.70777 .33 L
.70788 .32998 L
.708 .32994 L
.70811 .3299 L
Mistroke
.70832 .32981 L
.70854 .32968 L
.70878 .3295 L
.70929 .32901 L
.70983 .32831 L
.7108 .32661 L
.71171 .32448 L
.71269 .32165 L
.71446 .31528 L
.71844 .29693 L
.72044 .28744 L
.72228 .27979 L
.7232 .27672 L
.72407 .27445 L
.72451 .27358 L
.72497 .27286 L
.72523 .27257 L
.72537 .27245 L
.7255 .27235 L
.72562 .27228 L
.72572 .27223 L
.72584 .27219 L
.72591 .27218 L
.72597 .27217 L
.72608 .27217 L
.7262 .27219 L
.72632 .27223 L
.72642 .27228 L
.72654 .27235 L
.72667 .27245 L
.72691 .27271 L
.72716 .27306 L
.72742 .27354 L
.7279 .27468 L
.72838 .27621 L
.72883 .27801 L
.72968 .28236 L
.73062 .28884 L
.73162 .29767 L
.7334 .31898 L
.73529 .34996 L
.73706 .38704 L
.73755 .3986 L
.7378 .40493 L
.73794 .40848 L
.73801 .41023 L
.73807 .41185 L
.73819 .41012 L
.73831 .40699 L
.73857 .40047 L
Mistroke
.73903 .3894 L
.74082 .35145 L
.74264 .32108 L
.74369 .30733 L
.74464 .29702 L
.74555 .289 L
.74653 .28223 L
.74707 .27931 L
.74757 .2771 L
.74804 .27541 L
.74855 .27401 L
.7488 .27347 L
.74904 .27304 L
.74927 .27272 L
.74949 .27248 L
.74969 .27232 L
.74979 .27226 L
.74991 .27222 L
.75002 .27219 L
.75014 .27217 L
.75026 .27218 L
.75036 .2722 L
.75048 .27223 L
.7506 .27229 L
.75072 .27237 L
.75083 .27245 L
.75109 .2727 L
.75133 .27302 L
.75182 .27383 L
.75235 .275 L
.75326 .27757 L
.75427 .28113 L
.75629 .28992 L
.76018 .30856 L
.76196 .31619 L
.76391 .32291 L
.76497 .32569 L
.76595 .32766 L
.76644 .32842 L
.76689 .329 L
.76714 .32926 L
.76741 .32951 L
.76764 .32967 L
.76789 .32982 L
.76802 .32988 L
.76814 .32992 L
.76825 .32996 L
.76836 .32999 L
.76847 .33001 L
.76857 .33002 L
Mistroke
.76868 .33003 L
.76881 .33003 L
.76887 .33002 L
.76894 .33002 L
.76906 .33 L
.76912 .32998 L
.76918 .32997 L
.76932 .32992 L
.76956 .32982 L
.76981 .32968 L
.77036 .32926 L
.77088 .32871 L
.77184 .32732 L
.77278 .32557 L
.77377 .32335 L
.77555 .31862 L
.7792 .30763 L
.78123 .30191 L
.78309 .29755 L
.78401 .29582 L
.78501 .29431 L
.78547 .29376 L
.78596 .29327 L
.78642 .29291 L
.78683 .29266 L
.78706 .29256 L
.78731 .29247 L
.78743 .29244 L
.78756 .29241 L
.78769 .2924 L
.7878 .29239 L
.78792 .29238 L
.78802 .29238 L
.78814 .29239 L
.78826 .2924 L
.78837 .29242 L
.78847 .29244 L
.78869 .29251 L
.78894 .2926 L
.7892 .29273 L
.78966 .29303 L
.79016 .29346 L
.7907 .29404 L
.79169 .2954 L
.7926 .29694 L
.79462 .30126 L
.79848 .31131 L
.80024 .31586 L
.80219 .32022 L
.80311 .32193 L
Mistroke
.80411 .32345 L
.80466 .32413 L
.80516 .32465 L
.80566 .32506 L
.80591 .32523 L
.80614 .32536 L
.80637 .32546 L
.80658 .32554 L
.80669 .32557 L
.80681 .3256 L
.80694 .32562 L
.807 .32563 L
.80707 .32564 L
.80713 .32565 L
.8072 .32565 L
.80732 .32565 L
.80744 .32565 L
.80754 .32564 L
.80766 .32562 L
.80779 .3256 L
.80793 .32556 L
.80806 .32552 L
.80828 .32543 L
.8085 .32532 L
.80891 .32506 L
.80935 .3247 L
.80983 .3242 L
.81083 .32287 L
.81173 .32131 L
.81375 .31678 L
.81761 .30561 L
.82133 .29501 L
.82326 .29095 L
.82422 .2895 L
.82477 .28888 L
.82504 .28863 L
.82529 .28844 L
.82552 .2883 L
.82577 .28817 L
.82589 .28812 L
.82603 .28807 L
.8261 .28806 L
.82616 .28804 L
.82623 .28803 L
.8263 .28802 L
.82641 .28801 L
.82652 .288 L
.82665 .28801 L
.82676 .28802 L
.82688 .28805 L
Mistroke
.82701 .28808 L
.82714 .28812 L
.82725 .28817 L
.82766 .28841 L
.8279 .28859 L
.82812 .28879 L
.82904 .28997 L
.82952 .29079 L
.83004 .29185 L
.831 .2942 L
.83278 .29998 L
.83671 .3173 L
.84049 .33497 L
.84148 .33881 L
.84256 .3422 L
.84305 .34343 L
.84357 .34449 L
.84402 .34517 L
.84427 .34546 L
.8445 .34566 L
.84463 .34574 L
.84469 .34577 L
.84476 .3458 L
.84487 .34584 L
.84499 .34586 L
.84506 .34586 L
.84512 .34586 L
.84524 .34584 L
.84531 .34583 L
.84537 .3458 L
.84552 .34573 L
.84564 .34564 L
.84576 .34554 L
.84598 .3453 L
.84622 .34496 L
.84647 .34449 L
.84692 .34342 L
.8474 .34192 L
.84826 .33824 L
.84917 .33282 L
.85015 .32516 L
.85192 .3061 L
.85397 .2749 L
.85491 .25708 L
.85591 .23566 L
.85635 .22544 L
.85682 .21385 L
.85695 .21052 L
.85702 .20868 L
.85709 .20696 L
Mistroke
.85721 .20728 L
.85727 .20889 L
.85734 .2106 L
.85783 .22269 L
.8596 .26151 L
.86166 .29647 L
.8626 .30906 L
.8636 .32016 L
.86452 .32842 L
.86553 .3355 L
.86597 .33797 L
.86645 .34022 L
.86686 .34185 L
.86731 .34327 L
.86757 .34396 L
.86781 .34449 L
.86806 .34494 L
.86828 .34527 L
.86855 .34556 L
.86869 .34567 L
.86876 .34572 L
.86883 .34576 L
.86896 .34582 L
.86908 .34585 L
.86915 .34586 L
.86922 .34586 L
.86928 .34586 L
.86935 .34585 L
.86947 .34582 L
.86958 .34578 L
.8697 .34571 L
.86984 .34562 L
.87011 .34536 L
.87035 .34506 L
.87081 .34432 L
.87128 .34332 L
.87221 .34079 L
.87319 .33738 L
.87496 .32987 L
.87897 .31066 L
.88097 .30199 L
.88282 .29553 L
.88376 .29298 L
.88463 .29105 L
.88554 .28954 L
.88602 .28894 L
.88627 .28869 L
.88654 .28847 L
.88678 .28831 L
.88691 .28823 L
Mistroke
.88704 .28817 L
.88717 .28811 L
.88729 .28808 L
.8874 .28805 L
.88752 .28802 L
.88764 .28801 L
.88771 .28801 L
.88778 .288 L
.8879 .28801 L
.88802 .28802 L
.88809 .28803 L
.88816 .28805 L
.88829 .28808 L
.88843 .28813 L
.88858 .2882 L
.88906 .28849 L
.88933 .28871 L
.88958 .28895 L
.89052 .29013 L
.89147 .29175 L
.89235 .29359 L
.89435 .29871 L
.89812 .31002 L
.90005 .31551 L
.90106 .31808 L
.90213 .32046 L
.90309 .32226 L
.90414 .32383 L
.9046 .32437 L
.9051 .32484 L
.90557 .32519 L
.90599 .32543 L
.90621 .32551 L
.90646 .32559 L
.90658 .32561 L
.90664 .32562 L
.90671 .32563 L
.90684 .32565 L
.90695 .32565 L
.90706 .32565 L
.90717 .32565 L
.90727 .32564 L
.90737 .32562 L
.90749 .3256 L
.90761 .32557 L
.90783 .3255 L
.90807 .32539 L
.90834 .32525 L
.90888 .32487 L
.90937 .32441 L
Mistroke
.90984 .32389 L
.91179 .32081 L
.91358 .31698 L
.91741 .30702 L
.9211 .29809 L
.92208 .29624 L
.923 .2948 L
.92351 .29413 L
.92406 .29352 L
.92456 .29308 L
.92502 .29277 L
.92525 .29264 L
.92547 .29255 L
.92559 .29251 L
.92572 .29247 L
.92583 .29244 L
.92594 .29242 L
.92606 .2924 L
.92613 .29239 L
.9262 .29239 L
.92627 .29238 L
.92634 .29238 L
.9264 .29238 L
.92647 .29238 L
.92659 .2924 L
.92666 .2924 L
.92672 .29241 L
.92695 .29247 L
.92708 .2925 L
.92721 .29255 L
.92745 .29266 L
.928 .293 L
.92847 .2934 L
.92898 .29395 L
.92996 .29531 L
.93086 .29689 L
.93288 .30145 L
.93672 .31259 L
.94041 .32309 L
.94231 .3271 L
.94327 .32854 L
.94382 .32916 L
.94409 .3294 L
.94434 .32959 L
.94457 .32974 L
.94479 .32985 L
.94503 .32995 L
.94516 .32998 L
.94528 .33001 L
.9454 .33002 L
Mistroke
.94547 .33003 L
.94553 .33003 L
.94565 .33003 L
.94576 .33002 L
.94583 .33001 L
.94589 .33 L
.94601 .32997 L
.94614 .32993 L
.94628 .32987 L
.94652 .32975 L
.94673 .32961 L
.94721 .3292 L
.94765 .32869 L
.94806 .3281 L
.94901 .32637 L
.95 .32395 L
.95178 .31823 L
.95545 .30225 L
.95749 .29232 L
.95935 .28386 L
.96027 .28018 L
.96127 .27679 L
.96173 .2755 L
.96222 .27433 L
.96265 .27349 L
.9631 .27282 L
.96332 .27257 L
.96344 .27246 L
.96357 .27236 L
.96369 .27229 L
.9638 .27224 L
.9639 .2722 L
.964 .27218 L
.96412 .27217 L
.96425 .27218 L
.96435 .27221 L
.96447 .27225 L
.9646 .27232 L
.96473 .27243 L
.96498 .27267 L
.9652 .27298 L
.96545 .27341 L
.9659 .27442 L
.96634 .27572 L
.96674 .27721 L
.96767 .28173 L
.96854 .28746 L
.96949 .29552 L
.97052 .30643 L
.97245 .33347 L
Mistroke
.97448 .37189 L
.97619 .41245 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00;?ooool5o`0003Oooooo0ol0
000fooooo`;o0000>?ooool3o`0003Oooooo1Ol00006ooooo`00;Oooool01?l0003oooooooooool0
000hooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo0000>?ooool00ol0003ooooo
ooooo`0gooooo`04o`000?ooooooooooo`0000Kooooo000Vooooo`Go00000oooool00ol0003ooooo
ooooo`0`ooooo`Go00000oooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0003So
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`00;oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo0000>?ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Gooooo000/ooooo`05o`000?ooooooooooooooool0
0000>?ooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0003Sooooo00?o0000oooo
ooooool0=_ooool01Ol0003ooooooooooooooooo000000Kooooo000/ooooo`05o`000?oooooooooo
ooooool00000=oooool2o`0003Kooooo00Co0000oooooooooooo0000=oooool2o`0003Sooooo00Go
0000ooooooooooooooooo`000006ooooo`00;Oooool3o`0003Wooooo00?o0000ooooooooool0=Ooo
ool2o`0003Wooooo00?o0000ooooooooool0=oooool3o`0000Oooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000WooooooSo00000Oooool002Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool002Oooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo0_l0001iooooo`03o`00
0?oooooooooo07Sooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
07Wooooo0Ol00001ooooo`009oooool2o`0007Wooooo00?o0000ooooooooool0N?ooool2o`00007o
oooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo
000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000Woooo
o`;o0000NOooool00ol0003oooooooooo`1hooooo`;o00000Oooool002Oooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo0_l0001iooooo`03o`000?oooooo
oooo07Sooooo0_l00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`1iooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo0005
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0007Wooooo00?o0000ooooooooool0
N?ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo0008
ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo0_l0001i
ooooo`03o`000?oooooooooo07Sooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo07Wooooo0Ol00001ooooo`009oooool2o`0007Wooooo00?o0000ooooooooool0N?oo
ool2o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1
o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00
007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007o
oooo000Wooooo`;o0000NOooool00ol0003oooooooooo`1hooooo`;o00000Oooool002Oooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo0_l0001iooooo`03
o`000?oooooooooo07Sooooo0_l00001ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
NOooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`1iooooo`7o00000Oooool000Kooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000=ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000NOoo
ool00ol0003oooooooooo`1hooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo07Wooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
07Wooooo0Ol00001ooooo`003_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`0007Wo
oooo00?o0000ooooooooool0N?ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0NOooool1o`00007ooooo000Wooooo`;o0000NOooool00ol0003oooooooooo`1hoooo
o`;o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o
00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o0000
0Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Ooo
ool002Oooooo0_l0001iooooo`03o`000?oooooooooo07Sooooo0_l00001ooooo`009oooool00ol0
003oooooooooo`0Pooooo`03o`3o0?oooooooooo05Gooooo00?o0000ooooooooool06oooool00ol0
o`3oooooooooo`1Kooooo`7o00000Oooool002Oooooo00?o0000ooooooooool08?ooool00ol0o`3o
ooooooooo`0hooooo`03o`3o0?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0o`3o
ooooooooo`0hooooo`03o`3o0?oooooooooo023ooooo0Ol00001ooooo`009oooool00ol0003ooooo
ooooo`0Pooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool08?ooool1o`00007ooooo
000Wooooo`;o00008Oooool00ol0o`3oooooooooo`0hooooo`03o`3o0?oooooooooo01[ooooo00?o
0000ooooooooool06oooool00ol0o`3oooooooooo`0hooooo`03o`3o0?oooooooooo01oooooo0_l0
0001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002
ooooo`?o00001Oooool00ol0003oooooooooo`0Pooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0
ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0
ooooooooool08?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Pooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0oooooooo
ool08?ooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Pooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool06_ooool00ol0
003oooooooooo`0Kooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool08?ooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`03o`3o0?oooooo
oooo03Sooooo00?o0?l0ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooo
oooo03Sooooo00?o0?l0ooooooooool07oooool2o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o0000
1Oooool00ol0003oooooooooo`0Pooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool0
6_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo03Sooooo00?o0?l0ooooooooool0
8?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool08?ooool00ol0
o`3oooooooooo`0hooooo`03o`3o0?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0
o`3oooooooooo`0hooooo`03o`3o0?oooooooooo023ooooo0Ol00001ooooo`002?ooool2o`0000[o
oooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool08?ooool00ol0o`3o
ooooooooo`0gooooo`03o`3o0?oooooo0?l001_ooooo00?o0000ooooooooool06oooool00ol0o`3o
ooooooooo`0hooooo`;o0?l08Oooool1o`00007ooooo000Wooooo`;o00008Oooool2o`3o03Sooooo
00?o0?l0ooooool0o`006oooool00ol0003oooooooooo`0Kooooo`03o`3o0?oooooooooo03Oooooo
00?o0?l0ooooool0o`008?ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo01oooooo00?o
0?l0ooooool0o`00>?ooool00ol0o`3oooooo`3o000Kooooo`03o`000?oooooooooo01_ooooo00?o
0?l0ooooooooool0=oooool00ol0o`3oooooo`3o000Qooooo`7o00000Oooool002Oooooo00?o0000
ooooooooool07oooool00ol0o`3oooooo`3o000hooooo`03o`3o0?oooooo0?l001_ooooo00?o0000
ooooooooool06oooool00ol0o`3oooooooooo`0gooooo`03o`3o0?oooooo0?l0027ooooo0Ol00001
ooooo`009oooool2o`00023ooooo00?o0?l0ooooool0o`00>?ooool00ol0o`3oooooo`3o000Koooo
o`03o`000?oooooooooo01[ooooo00?o0?l0ooooool0o`00>?ooool00ol0o`3oooooo`3o000Poooo
o`;o00000Oooool002Oooooo00?o0000ooooooooool07oooool00ol0o`3oooooo`3o000hooooo`03
o`3o0?oooooo0?l001_ooooo00?o0000ooooooooool06_ooool00ol0o`3oooooo`3o000hooooo`03
o`3o0?oooooo0?l0027ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`06ooooo`03o`3o
0?oooooooooo01Kooooo00?o0?l0ooooool0o`006Oooool00ol0o`3oooooooooo`03ooooo`03o`3o
0?oooooooooo01Kooooo00?o0?l0ooooool0o`006Oooool00ol0o`3oooooo`000003ooooo`03o`3o
0?oooooooooo01Kooooo00?o0?l0ooooool0o`006Oooool00ol0o`3oooooooooo`03ooooo`03o`3o
0?oooooooooo01Kooooo00?o0?l0ooooool0o`006Oooool00ol0o`3oooooooooo`05ooooo`7o0000
0Oooool002Oooooo00?o0000ooooooooool01Oooool2o`3o01Sooooo00?o0?l0ooooool0o`006?oo
ool2o`3o00Cooooo0_l0o`0Hooooo`03o`3o0?oooooo0?l001Sooooo0_l0o`001?oooooo0000oooo
ooooool2o`3o01Sooooo00?o0?l0ooooool0o`006?ooool2o`3o00Cooooo0_l0o`0Hooooo`03o`3o
0?oooooo0?l001Sooooo0_l0o`07ooooo`7o00000Oooool002Oooooo0_l00006ooooo`;o0?l06?oo
ool00ol0o`3oooooo`3o000Hooooo`;o0?l01?ooool2o`3o01Sooooo00?o0?l0ooooool0o`006?oo
ool2o`3o0004ooooool0003oooooooooo`;o0?l06?ooool00ol0o`3oooooo`3o000Hooooo`;o0?l0
1?ooool2o`3o01Sooooo00?o0?l0ooooool0o`006?ooool2o`3o00Kooooo0_l00001ooooo`009ooo
ool00ol0003oooooooooo`05ooooo`;o0?l06?ooool00ol0o`3oooooo`3o000Hooooo`;o0?l01?oo
ool2o`3o01Sooooo00?o0?l0ooooool0o`005oooool01Ol0o`3oooooo`3o0?oooooo000000;ooooo
0_l0o`0Hooooo`03o`3o0?oooooo0?l001Sooooo0_l0o`04ooooo`;o0?l06?ooool00ol0o`3ooooo
o`3o000Hooooo`;o0?l01oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo00Co
0?l0oooooooooooo0?l04Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooo0?l000Kooooo
00?o0?l0ooooooooool03_ooool01?l0o`3oooooooooool0o`03ooooo`03o`3o0?oooooo0?l0017o
oooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o0006ooooo`03o`3o0?oooooooooo00ko
oooo00Go0?l0oooooooooooo0?l0o`000002ooooo`03o`3o0?oooooo0?l0013ooooo0_l0o`05oooo
o`03o`3o0?oooooo0?l000Kooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooo`3o0004oooo
o`;o0?l04Oooool2o`3o00Gooooo00?o0?l0ooooool0o`001_ooool00ol0o`3oooooooooo`0>oooo
o`04o`3o0?ooooooooooo`3o00Kooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`04oooo
o`04o`3o0?ooooooooooo`3o00Oooooo00?o0?l0ooooooooool01_ooool2o`3o00Gooooo00?o0?l0
ooooool0o`001Oooool2o`3o00Sooooo00?o0?l0ooooooooool01Oooool01?l0o`3oooooooooool0
o`02ooooo`04o`3o0?ooooooooooo`3o00Oooooo00?o0?l0ooooooooool01_ooool2o`3o00Gooooo
00?o0?l0ooooool0o`001Oooool2o`3o00Sooooo0_l0o`06ooooo`07o`3o0?ooooooooooo`3o0?l0
003oooooo`3o0002ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool01_ooool2o`3o
00Gooooo00?o0?l0ooooool0o`001Oooool2o`3o00Sooooo00?o0?l0ooooooooool01Oooool01?l0
o`3oooooooooool0o`02ooooo`04o`3o0?ooooooooooo`3o00Oooooo00?o0?l0ooooooooool01_oo
ool2o`3o00Gooooo00?o0?l0ooooool0o`001Oooool2o`3o00Sooooo0_l0o`06ooooo`04o`3o0?oo
ooooooooo`3o00Kooooo0Ol00001ooooo`009oooool2o`0000Gooooo00Co0?l0oooooooooooo0?l0
1_ooool3o`3o00Kooooo00?o0?l0ooooool0o`001Oooool00ol0o`3oooooo`3o0005ooooo`?o0?l0
1_ooool3o`3o00Kooooo00Co0?l0oooooooooooo0?l00_ooool01?l0o`3oooooooooool0o`06oooo
o`?o0?l01_ooool01?l0o`3oooooo`3o0?l0o`04ooooo`03o`3o0?oooooo0?l000Cooooo0_l0o`00
0ooooooo0?l0ooooo`05ooooo`?o0?l01_ooool01ol0o`3oooooooooool0o`3o0000ooooool0o`00
0_ooool00ol0o`3oooooooooo`04ooooo`?o0?l01_ooool01?l0o`3oooooo`3o0?l0o`04ooooo`03
o`3o0?oooooo0?l000Cooooo00Co0?l0oooooooooooo0?l01_ooool3o`3o00Kooooo00Co0?l0oooo
oooooooo0?l00_ooool01?l0o`3oooooooooool0o`06ooooo`?o0?l01_ooool01?l0o`3oooooo`3o
0?l0o`04ooooo`03o`3o0?oooooo0?l000Cooooo1?l0o`06ooooo`?o0?l01_ooool01?l0o`3ooooo
ooooool0o`05ooooo`;o00000Oooool0023ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
00Co0?l0oooooooooooo0?l01_ooool00ol0o`3oooooo`3o0006ooooo`04o`3o0?ooooooooooo`3o
00Cooooo00?o0?l0ooooool0o`001?ooool01?l0o`3oooooooooool0o`06ooooo`03o`3o0?oooooo
0?l000Gooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`05o`3o0?ooooooooooooooool0o`00
1Oooool00ol0o`3oooooo`3o0006ooooo`04o`3o0?ooooooooooo`3o00Cooooo00?o0?l0ooooool0
o`001?ooool01?l0o`3oooooooooool0o`06ooooo`03o`3o0?oooooo0?l000Kooooo00Oo0?l0oooo
oooooooo0?l0o`000?oooooo0?l000;ooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooo`3o
0006ooooo`04o`3o0?ooooooooooo`3o00Cooooo00?o0?l0ooooool0o`001?ooool01?l0o`3ooooo
ooooool0o`06ooooo`03o`3o0?oooooo0?l000Kooooo00Co0?l0oooooooooooo0?l00_ooool01?l0
o`3oooooooooool0o`06ooooo`03o`3o0?oooooo0?l000Kooooo00Co0?l0oooooooooooo0?l01?oo
ool00ol0o`3oooooo`3o0004ooooo`04o`3o0?ooooooooooo`3o00Kooooo00?o0?l0ooooool0o`00
1_ooool01?l0o`3oooooooooool0o`06ooooo`7o00000Oooool001oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Go0?l0oooo
ooooooooooooo`3o0005ooooo`04o`3o0?ooooooooooo`3o00Cooooo00?o0?l0ooooool0o`001?oo
ool01?l0o`3oooooooooool0o`06ooooo`04o`3o0?ooooooooooo`3o00Cooooo00Go0?l0oooooooo
ooooooooo`3o0002ooooo`05o`3o0?ooooooooooooooool0o`001?ooool01?l0o`3oooooooooool0
o`06ooooo`04o`3o0?ooooooooooo`3o00Cooooo00?o0?l0ooooool0o`001?ooool01Ol0o`3ooooo
oooooooooooo0?l000Gooooo00Co0?l0oooooooooooo0?l01Oooool01ol0o`3oooooooooool0o`3o
0000ooooool0o`000_ooool00ol0o`3oooooooooo`03ooooo`05o`3o0?ooooooooooooooool0o`00
1Oooool01?l0o`3oooooooooool0o`04ooooo`03o`3o0?oooooo0?l000Cooooo00Co0?l0oooooooo
oooo0?l01_ooool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?ooooooooooo`3o00;ooooo00Go
0?l0ooooooooooooooooo`3o0004ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Go0?l0oooooooo
ooooooooo`3o0004ooooo`03o`3o0?oooooo0?l000Cooooo00Co0?l0oooooooooooo0?l01_ooool0
1?l0o`3oooooooooool0o`04ooooo`05o`3o0?ooooooooooooooool0o`001_ooool1o`00007ooooo
000Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0o`3ooooo
oooooooooooo0?l000Cooooo00Go0?l0ooooooooooooooooo`3o0004ooooo`05o`3o0?oooooooooo
ooooool0o`001?ooool00ol0o`3oooooo`3o0004ooooo`05o`3o0?ooooooooooooooool0o`001?oo
ool01Ol0o`3ooooooooooooooooo0?l000Cooooo00Go0?l0ooooooooooooooooo`3o0002ooooo`05
o`3o0?ooooooooooooooool0o`001?ooool01Ol0o`3ooooooooooooooooo0?l000Cooooo00Go0?l0
ooooooooooooooooo`3o0004ooooo`03o`3o0?oooooo0?l000Cooooo00Go0?l0oooooooooooooooo
o`3o0004ooooo`05o`3o0?ooooooooooooooool0o`001?ooool02?l0o`3ooooooooooooooooo0?l0
o`000?oooooo0?l00oooool00ol0o`3oooooooooo`02ooooo`05o`3o0?ooooooooooooooool0o`00
1?ooool01Ol0o`3ooooooooooooooooo0?l000Cooooo00?o0?l0ooooool0o`001?ooool01?l0o`3o
ooooooooool0o`05ooooo`05o`3o0?ooooooooooooooool0o`001Oooool01?l0o`3oooooooooool0
o`02ooooo`05o`3o0?ooooooooooooooool0o`001?ooool01?l0o`3oooooooooool0o`05ooooo`05
o`3o0?ooooooooooooooool0o`001?ooool00ol0o`3oooooo`3o0004ooooo`05o`3o0?oooooooooo
ooooool0o`001?ooool01Ol0o`3ooooooooooooooooo0?l000Cooooo00Go0?l0oooooooooooooooo
o`3o0006ooooo`7o00000Oooool001oooooo00Co0000oooooooooooo00001?ooool7o`000005o`3o
0?l0003o0000o`000?l0o`001?l000000ol0o`3o0000o`000002o`000005o`3o0?l0003o0000o`00
0?l0o`000ol000000ol0o`3o0000o`000002o`000003o`3o0?l0003o0?l000?o000000?o0?l0o`00
0?l000000_l000000ol0o`3o0000o`000002o`000003o`3o0?l0003o000000;o000000Go0?l0o`00
0?l0003o0000o`3o0003o`000004o`3o0?l0003o0000o`3o00?o000000Go0?l0o`000?l0003o0000
o`3o0004o`000003o`3o0?l0003o000000;o000000?o0?l0o`000?l000000_l000001Ol0o`3o0000
o`000?l0003o0?l000;o000000Go0?l0o`000?l0003o0000o`3o0004o`000005o`3o0?l0003o0000
o`000?l0o`000ol000000ol0o`3o0000o`000002o`000005o`3o0?l0003o0000o`000?l0o`000_l0
00001Ol0o`3o0000o`000?l0003o0?l000Co000000?o0?l0o`000?l000000_l000001Ol0o`3o0000
o`000?l0003o0?l000?o000000?o0?l0o`000?l000000_l000000ol0o`3o0000o`3o0004o`000005
o`3o0?l0003o0000o`000?l0o`001?l000000ol0o`3o0000o`000002o`000005o`3o0?l0003o0000
o`000?l0o`000ol000001?l0o`3o0000o`000?l0o`03o`000003o`3o0?l0003o000000;o000000Go
0?l0o`000?l0003o0000o`3o0004o`000005o`3o0?l0003o0000o`000?l0o`001?l000000ol0o`3o
0000o`3o0003o`000003o`3o0?l0003o000000;o000000?o0?l0o`000?l000000_l000000ol0o`3o
0000o`000002o`000005o`3o0?l0003o0000o`000?l0o`000ol000000ol0o`3o0000o`000005o`00
007ooooo000Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0
o`3ooooooooooooooooo0?l000?ooooo00?o0?l0ooooooooool00oooool01?l0o`3oooooooooool0
o`05ooooo`04o`3o0?ooooooooooo`3o00;ooooo00Go0?l0ooooooooooooooooo`3o0005ooooo`05
o`3o0?ooooooooooooooool0o`001?ooool01?l0o`3oooooooooool0o`04ooooo`04o`3o0?oooooo
ooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o0005ooooo`05o`3o0?ooooooooooooooool0
o`001?ooool01?l0o`3oooooooooool0o`03ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Co0?l0
oooooooooooo0?l01Oooool01Ol0o`3ooooooooooooooooo0?l000?ooooo00Co0?l0o`000?oooooo
0?l00oooool01Ol0o`3ooooooooooooooooo0?l000Gooooo00Co0?l0oooooooooooo0?l01Oooool0
1?l0o`3oooooooooool0o`02ooooo`03o`3o0?oooooooooo00;ooooo00Go0?l0oooooooooooooooo
o`3o0003ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l0ooooooooooooooooo`3o0003ooooo`04
o`3o0?ooooooooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o0004ooooo`05o`3o0?oooooo
ooooooooool0o`001Oooool01ol0o`3ooooooooooooooooo0?l0ooooool0o`000oooool00ol0o`3o
ooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Co0?l0oooooooooooo0?l01?ooool0
0ol0o`3oooooooooo`04ooooo`7o00000Oooool001oooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l01Ooo
ool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Co0?l0oooooooo
oooo0?l01Oooool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?ooooooooooo`3o00Cooooo00Co
0?l0oooooooooooo0?l01?ooool00ol0o`3oooooo`3o0006ooooo`04o`3o0?ooooooooooo`3o00Go
oooo00Co0?l0oooooooooooo0?l00oooool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?oooooo
ooooo`3o00Gooooo00Go0?l0ooooooooooooooooo`3o0003ooooo`04o`3o0?l0003oooooo`3o00Co
oooo00Co0?l0oooooooooooo0?l01Oooool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?oooooo
ooooo`3o00;ooooo00Go0?l0ooooooooooooooooo`3o0005ooooo`04o`3o0?ooooooooooo`3o00Go
oooo00Go0?l0ooooooooooooooooo`3o0003ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0
ooooooooooooooooo`3o0005ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Co0?l0oooooooooooo
0?l00oooool01?l0o`3oooooooooool0o`05ooooo`04o`3o0?ooooooooooo`3o00Gooooo00Co0?l0
oooooooooooo0?l01?ooool00ol0o`3oooooooooo`04ooooo`7o00000Oooool0023ooooo0_l00005
ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooo`3o0006
ooooo`Co0?l01Oooool01?l0o`3oooooooooool0o`03ooooo`03o`3o0?oooooo0?l000Kooooo00?o
0?l0ooooool0o`001_ooool01?l0o`3oooooooooool0o`05ooooo`03o`3o0?oooooo0?l000Cooooo
00?o0?l0ooooool0o`001_ooool4o`3o00Kooooo00?o0?l0ooooool0o`000oooool01?l0o`3ooooo
ooooool0o`05ooooo`?o0?l01_ooool01?l0o`3oooooooooool0o`04ooooo`04o`3o0?l0003ooooo
o`3o00Cooooo00?o0?l0ooooool0o`001_ooool4o`3o00Gooooo00Co0?l0oooooooooooo0?l00_oo
ool01Ol0o`3ooooooooooooooooo0?l000Gooooo0ol0o`06ooooo`04o`3o0?ooooooooooo`3o00Co
oooo00Co0?l0oooooooooooo0?l01?ooool00ol0o`3oooooo`3o0006ooooo`;o0?l000?oooooo`3o
0?ooool01?ooool01?l0o`3oooooooooool0o`03ooooo`03o`3o0?oooooo0?l000Kooooo0_l0o`00
0ooooooo0?l0ooooo`05ooooo`03o`3o0?oooooo0?l000Gooooo00?o0?l0ooooooooool00oooool1
o`00007ooooo000Wooooo`;o00001?ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooo0?l0
00Oooooo0_l0o`06ooooo`04o`3o0?ooooooooooo`3o00?ooooo00?o0?l0ooooool0o`001oooool2
o`3o00Oooooo00?o0?l0ooooool0o`001Oooool00ol0o`3oooooo`3o0004ooooo`03o`3o0?oooooo
0?l000Oooooo0_l0o`07ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0oooooooooooo0?l01_oo
ool2o`3o00Oooooo00?o0?l0ooooool0o`001?ooool01?l0o`3o0000ooooool0o`04ooooo`03o`3o
0?oooooo0?l000Oooooo0_l0o`07ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0oooooooooooo
0?l01_ooool2o`3o00Oooooo00?o0?l0ooooool0o`001?ooool01?l0o`3oooooooooool0o`04oooo
o`03o`3o0?oooooo0?l000Oooooo0_l0o`06ooooo`04o`3o0?ooooooooooo`3o00?ooooo00?o0?l0
ooooool0o`001oooool2o`3o00Oooooo00?o0?l0ooooool0o`001Oooool00ol0o`3oooooooooo`02
ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`04oooo
o`;o0?l04?ooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooo0?l0013ooooo0ol0o`05oooo
o`03o`3o0?oooooo0?l000Gooooo0_l0o`0@ooooo`03o`3o0?oooooo0?l000?ooooo00Co0?l0oooo
oooooooo0?l03oooool3o`3o00Cooooo00Co0?l0o`000?oooooo0?l01?ooool3o`3o013ooooo00?o
0?l0ooooool0o`000oooool01?l0o`3oooooooooool0o`0?ooooo`;o0?l01Oooool01?l0o`3ooooo
ooooool0o`05ooooo`;o0?l04?ooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooo0?l0013o
oooo0ol0o`05ooooo`03o`3o0?oooooooooo00?ooooo0Ol00001ooooo`009oooool00ol0003ooooo
ooooo`03ooooo`03o`3o0?oooooooooo01Kooooo00?o0?l0ooooool0o`000oooool00ol0o`3ooooo
o`3o000Hooooo`;o0?l06?ooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooo0?l001Oooooo
00?o0?l0o`000?l0o`006?ooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooo0?l001Oooooo
00Co0?l0oooooooooooo0?l05oooool00ol0o`3oooooo`3o0003ooooo`03o`3o0?oooooo0?l001So
oooo00?o0?l0ooooooooool00oooool1o`00007ooooo000Wooooo`;o00001?ooool00ol0o`3ooooo
ooooo`0Fooooo`03o`3o0?oooooo0?l000?ooooo00?o0?l0ooooool0o`006?ooool2o`3o01Sooooo
00?o0?l0ooooool0o`000oooool00ol0o`3oooooo`3o000Gooooo`03o`3o0?l0003o0?l001Sooooo
00?o0?l0ooooool0o`000oooool00ol0o`3oooooo`3o000Hooooo`;o0?l06?ooool00ol0o`3ooooo
o`3o0003ooooo`03o`3o0?oooooo0?l001Sooooo00?o0?l0ooooooooool00_ooool2o`00007ooooo
000Wooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool05_ooool3o`3o00?ooooo0ol0
o`0Hooooo`;o0?l06?ooool3o`3o00?ooooo0ol0o`0Gooooo`03o`3o0?l0003o0?l001Sooooo0ol0
o`03ooooo`?o0?l06?ooool2o`3o01Sooooo0ol0o`03ooooo`?o0?l06?ooool00ol0o`3ooooooooo
o`03ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`0G
ooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool05oooool2o`3o01Wooooo00?o0?l0
ooooooooool00oooool00ol0o`3oooooooooo`0Gooooo`;o0?l06Oooool00ol0o`3oooooooooo`03
ooooo`03o`3o0?oooooooooo01Oooooo0_l0o`0Iooooo`03o`3o0?oooooooooo00?ooooo00?o0?l0
ooooooooool05oooool00ol0o`3oooooooooo`03ooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool00oooool00ol0o`3oooooooooo`0gooooo`;o0?l0>Oooool2o`3o03Wooooo0_l0o`0ioooo
o`03o`3o0?oooooooooo00?ooooo0Ol00001ooooo`009oooool2o`0000Cooooo00?o0?l0oooooooo
ool0=oooool2o`3o03Wooooo0_l0o`0iooooo`;o0?l0>Oooool00ol0o`3oooooooooo`02ooooo`;o
00000Oooool002Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`0gooooo`;o0?l0
>Oooool2o`3o03Wooooo0_l0o`0iooooo`03o`3o0?oooooooooo00?ooooo0Ol00001ooooo`009ooo
ool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo03Oooooo0_l0o`0iooooo`;o0?l0>Ooo
ool2o`3o03Wooooo00?o0?l0ooooooooool00oooool1o`00007ooooo000Wooooo`03o`000?oooooo
oooo00?ooooo00?o0?l0ooooooooool0=oooool2o`3o03Wooooo0_l0o`0iooooo`;o0?l0>Oooool0
0ol0o`3oooooooooo`03ooooo`7o00000Oooool002Oooooo0_l00004ooooo`03o`3o0?oooooooooo
03Oooooo0_l0o`0iooooo`;o0?l0>Oooool2o`3o03Wooooo00?o0?l0ooooooooool00_ooool2o`00
007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool0=oooool2o`3o03Wo
oooo0_l0o`0iooooo`;o0?l0>Oooool00ol0o`3oooooooooo`03ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0?l0ooooooooool0=oooool2o`3o03Wooooo0_l0o`0iooooo`;o0?l0>Oooool00ol0o`3ooooooooo
o`03ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`3o0?oooooooooo03Oooooo0_l0o`0iooooo`;o0?l0>Oooool2o`3o03Wooooo
00?o0?l0ooooooooool00oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`03o`3o0?oooooooooo03Oooooo0_l0o`0iooooo`;o0?l0>Oooool2o`3o03Wo
oooo00?o0?l0ooooooooool00_ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo03Oooooo0_l0o`0iooooo`;o0?l0>Oooool2
o`3o03Wooooo00?o0?l0ooooooooool00oooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`0hooooo`;o0?l0>Oooool2o`3o03Wooooo
0_l0o`0iooooo`03o`3o0?oooooooooo00?ooooo0Ol00001ooooo`002?ooool2o`0000[ooooo0_l0
0003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool00_ooool00ol0o`3ooooooooo
o`0hooooo`;o0?l0>Oooool2o`3o03Wooooo0_l0o`0iooooo`03o`3o0?oooooooooo00?ooooo0Ol0
0001ooooo`009oooool2o`0000?ooooo00?o0?l0ooooooooool0>?ooool2o`3o03Wooooo0_l0o`0i
ooooo`;o0?l0>Oooool00ol0o`3oooooooooo`02ooooo`;o00000Oooool002Oooooo00?o0000oooo
ooooool00_ooool00ol0o`3oooooooooo`0hooooo`;o0?l0>Oooool2o`3o03Wooooo0_l0o`0ioooo
o`03o`3o0?oooooooooo00?ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`02ooooo`03
o`3o0?oooooooooo03Sooooo0_l0o`0iooooo`;o0?l0>Oooool2o`3o03Wooooo00?o0?l0oooooooo
ool00oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
NOooool1o`00007ooooo000Wooooo`;o0000NOooool00ol0003oooooooooo`1hooooo`;o00000Ooo
ool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool0
02Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oo
oooo0_l0001iooooo`03o`000?oooooooooo07Sooooo0_l00001ooooo`009oooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool2o`0007Wooooo00?o0000oooo
ooooool0N?ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool1o`00007ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool3o`0000Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o0000
0Oooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
07Wooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool00_ooool2o`0007Wooooo00?o0000ooooooooool0N?ooool2
o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOoo
ool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000
ooooo`04o`0000Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o0000
0Oooool000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00Sooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool000ko
oooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0001iooooo`03o`000?oooooooooo07So
oooo0_l00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo
0Ol00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol0
0001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001
ooooo`009oooool2o`0007Wooooo00?o0000ooooooooool0N?ooool2o`00007ooooo000Wooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000Wooooo`;o0000NOooool0
0ol0003oooooooooo`1hooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`1iooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`1iooooo`7o00000Oooool002Oooooo0_l0001iooooo`03o`000?oooooooooo07Sooooo
0_l00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol0
0001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1i
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo0_l0001iooooo`03o`000?oooooooooo07Sooooo0_l00001ooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool0NOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`002?ooool2o`0000[ooooo0_l0
0002ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000NOooool00ol0003ooooooooo
o`1hooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1i
ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1ioooo
o`7o00000Oooool002Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o
00000Oooool002Oooooo0_l0001iooooo`03o`000?oooooooooo07Sooooo0_l00001ooooo`009ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo0Ol00001ooooo`009oooool2o`0007Wo
oooo00?o0000ooooooooool0N?ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0NOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0NOooool1o`00007ooooo000Wooooo`;o0000NOooool00ol0003oooooooooo`1hoooo
o`;o00000Oooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool1o`00007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooooSo
00000Oooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3mooooo`00
4oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?gooooo000Cooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003oooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool0
oOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.76275, -0.120506, \
0.0169509, 0.00130605}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency domain plots", "Subsubsection"],

Cell[BoxData[
    \(\(ftbl\  = \ 
        Table[{k, FourierCoefficient[Triangle1[t], t, k]}, {k, \(-10\), 
            10}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[ftbl, \ Red, \ Frame \[Rule] True, \ 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 1.17721 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.1)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.2)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.3)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.4)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03826 m
.00375 .03826 L
s
0 .0618 m
.00375 .0618 L
s
0 .08535 m
.00375 .08535 L
s
0 .10889 m
.00375 .10889 L
s
0 .15598 m
.00375 .15598 L
s
0 .17952 m
.00375 .17952 L
s
0 .20307 m
.00375 .20307 L
s
0 .22661 m
.00375 .22661 L
s
0 .2737 m
.00375 .2737 L
s
0 .29724 m
.00375 .29724 L
s
0 .32079 m
.00375 .32079 L
s
0 .34433 m
.00375 .34433 L
s
0 .39142 m
.00375 .39142 L
s
0 .41497 m
.00375 .41497 L
s
0 .43851 m
.00375 .43851 L
s
0 .46205 m
.00375 .46205 L
s
0 .50914 m
.00375 .50914 L
s
0 .53269 m
.00375 .53269 L
s
0 .55623 m
.00375 .55623 L
s
0 .57977 m
.00375 .57977 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03826 m
1 .03826 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .08535 m
1 .08535 L
s
.99625 .10889 m
1 .10889 L
s
.99625 .15598 m
1 .15598 L
s
.99625 .17952 m
1 .17952 L
s
.99625 .20307 m
1 .20307 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .2737 m
1 .2737 L
s
.99625 .29724 m
1 .29724 L
s
.99625 .32079 m
1 .32079 L
s
.99625 .34433 m
1 .34433 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .41497 m
1 .41497 L
s
.99625 .43851 m
1 .43851 L
s
.99625 .46205 m
1 .46205 L
s
.99625 .50914 m
1 .50914 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57977 m
1 .57977 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.07143 .01472 m
.07143 .01766 L
s
.11905 .01472 m
.11905 .01472 L
s
.16667 .01472 m
.16667 .01958 L
s
.21429 .01472 m
.21429 .01472 L
s
.2619 .01472 m
.2619 .02426 L
s
.30952 .01472 m
.30952 .01472 L
s
.35714 .01472 m
.35714 .04122 L
s
.40476 .01472 m
.40476 .01472 L
s
.45238 .01472 m
.45238 .25327 L
s
.5 .01472 m
.5 .60332 L
s
.54762 .01472 m
.54762 .25327 L
s
.59524 .01472 m
.59524 .01472 L
s
.64286 .01472 m
.64286 .04122 L
s
.69048 .01472 m
.69048 .01472 L
s
.7381 .01472 m
.7381 .02426 L
s
.78571 .01472 m
.78571 .01472 L
s
.83333 .01472 m
.83333 .01958 L
s
.88095 .01472 m
.88095 .01472 L
s
.92857 .01472 m
.92857 .01766 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.07143 .01766 Mdot
.11905 .01472 Mdot
.16667 .01958 Mdot
.21429 .01472 Mdot
.2619 .02426 Mdot
.30952 .01472 Mdot
.35714 .04122 Mdot
.40476 .01472 Mdot
.45238 .25327 Mdot
.5 .60332 Mdot
.54762 .25327 Mdot
.59524 .01472 Mdot
.64286 .04122 Mdot
.69048 .01472 Mdot
.7381 .02426 Mdot
.78571 .01472 Mdot
.83333 .01958 Mdot
.88095 .01472 Mdot
.92857 .01766 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Cooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00000oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00002ol00001
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000=ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo0ooo000Fooooo`?oo`005_ooool3ool001Oooooo0ooo000Foooo
o`?oo`00;oooool3ool001Oooooo0ooo000Fooooo`?oo`005_ooool3ool001Oooooo0ooo0004oooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool3o`0000;ooooo0ooo0009oooo
o`?oo`002_ooool3ool000_ooooo00?oo`00ooooooooool02?ooool3ool000_ooooo00?oo`00oooo
ooooool02Oooool3ool000_ooooo00?oo`00ooooooooool02?ooool3ool000_ooooo00?oo`00oooo
ooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo0ooo000<oooo
o`03ool00?oooooooooo00Sooooo0ooo000;ooooo`03ool00?oooooooooo00Sooooo0ooo000;oooo
o`03ool00?oooooooooo00Sooooo0ooo000:ooooo`?oo`002_ooool3ool000?ooooo0_l00001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ooo0009oooo
o`?oo`002_ooool3ool000[ooooo0ooo0009ooooo`?oo`002oooool00ooo003oooooooooo`09oooo
o`?oo`002oooool00ooo003oooooooooo`08ooooo`?oo`002oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool3ool000cooooo00?oo`00oooo
ooooool02?ooool3ool000_ooooo00?oo`00ooooooooool02?ooool3ool000[ooooo0ooo0009oooo
o`?oo`002_ooool3ool000[ooooo0ooo0004ooooo`7o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0>ooooo`?oo`005oooool3ool001Kooooo0ooo000Hoooo
o`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05?ooool3ool001Oooooo0ooo000Foooo
o`?oo`004Oooool1o`00007ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`0Xooooo`?o
o`005_ooool3ool001Sooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0:ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Dooooo`?o
o`005oooool3ool002[ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`11ooooo`?oo`00
6?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Cooooo0ooo0014ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`0Fooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo05_ooooo0Ol00001ooooo`005Oooool2o`0005_ooooo0ooo000Hooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Eooooo`?oo`00G?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo05[ooooo0ooo000Hooooo`03ool00?oooooooooo
00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Eooooo`?oo`00GOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo05[ooooo0ooo000Hooooo`03ool00?oooooooooo00[o
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Eooooo`?oo`00GOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo000Eoooo
o`;o0000M_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOoo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ooo003o
ooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007o
oooo000Eooooo`;o0000M_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1dooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
07Gooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[o
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool000;ooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo07Gooooo
00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo
0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool0MOooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Wooooo
00?o0000ooooooooool01?ooool3o`0007Gooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo07Cooooo0_l00001ooooo`0000Goooooo`000?oooooooooo
o`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0MOooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo
00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1eooooo`7o00000Oooool00005ooooool0003oooooooooool000002?ooool2o`0000Kooooo
00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool0MOooool1o`00007ooooo0002ooooo`;o00002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1e
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1e
ooooo`7o00000Oooool001Gooooo0_l0001fooooo`03ool00?oooooooooo00[ooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000oooooooo
ool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool0
0ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1dooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Ooo
ool2o`0007Kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Go
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo07Go
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1eooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_ooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0M?ooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1eooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0:ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo0002ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0MOooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0MOooool1o`00007ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1eooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`1eooooo`7o00000Oooool00005ooooool0003oooooooooool000002Oooool00ol0003o
ooooooooo`04ooooo`?o0000MOooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0M?ooool2o`00007ooooo00001Ooooooo0000oooooooooooo000000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1dooooo`?oo`002oooool00ooo003o
ooooooooo`08ooooo`?oo`00M_ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Cooooo0ooo000;oooo
o`03ool00?oooooooooo00Sooooo0ooo001fooooo`7o00000Oooool00005ooooool0003ooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0M?ooool3
ool000_ooooo00?oo`00ooooooooool02?ooool3ool007Kooooo0Ol00001ooooo`000_ooool2o`00
00Wooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo
000Eooooo`;o0000Poooool00ooo003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03ool00?oooooo
oooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo
087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001
ooooo`005Oooool2o`0008?ooooo00?oo`00ooooooooool0P?ooool2o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ooo003o
ooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21
ooooo`7o00000Oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo00001Ooooooo
0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo00001Ooooooo0000oooooooooooo
000000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`03ool00?oooooo
oooo087ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`;o00001Oooool3
o`0008;ooooo00?oo`00ooooooooool0P?ooool2o`00007ooooo00001Ooooooo0000oooooooooooo
000000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`03ool00?oooooo
oooo087ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol0
0001ooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?oo`00
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00oooooooo
ool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ooo003oooooooooo`20ooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l0
0023ooooo`03ool00?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03ool00?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
ool00?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool0
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?oo`00ooooooooool0P?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`;o
0000Poooool00ooo003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ooo003oooooooooo`21ooooo`7o00000Oooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0ol00004ooooo`03o`000?oooooooooo08;ooooo00?oo`00ooooooooool0POooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`22ooooo`03ool00?oooooo
oooo087ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Gooooo0ol00022ooooo`03ool00?oooooooooo083ooooo0_l00001ooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0P_oo
ool00ooo003oooooooooo`21ooooo`7o00000Oooool00005ooooool0003oooooooooool000002Ooo
ool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Ooo
ool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0P_ooool0
0ooo003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo
003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03ool00?oooooooooo083ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool2o`0008?ooooo00?oo`00ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?oo`00ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
o`00ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ooo003oooooooooo`20
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001Go
oooo0_l00023ooooo`03ool00?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21
ooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0P_ooool00ooo003oooooooooo`21ooooo`7o00000Ooo
ool00005ooooool0003oooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo083ooooo0ooo0023ooooo`7o00000Oooool00005ooooool0003oooooooooool000002ooo
ool00ol0003oooooooooo`02ooooo`?o0000P?ooool3ool008;ooooo0_l00001ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0003oooooooooo`20ooooo`?oo`00Pooo
ool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0002ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1
o`00007ooooo000Eoooooooo00002ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.1932, -0.0519277, \
0.0791273, 0.00320076}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example #2: sawtooth wave", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SawTooth1[t_] := \((t)\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          SawTooth1, {\(-1\)/2, 1/2}, {t, \(-2\), 
            2}];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[fnc1, {t, \(-2\), 2}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .32105 L
.04339 .33418 L
.05298 .34651 L
.06221 .35836 L
.07203 .37098 L
.08148 .38313 L
.09153 .39604 L
.10121 .40848 L
.11052 .42044 L
.12043 .43318 L
.12997 .44543 L
.13476 .45159 L
.13914 .45722 L
.14029 .4587 L
.14155 .46032 L
.14213 .46106 L
.14244 .46147 L
.14274 .46185 L
.14302 .15625 L
.14332 .15663 L
.14385 .15731 L
.14891 .16381 L
.15885 .17659 L
.16842 .18889 L
.17763 .20072 L
.18743 .21331 L
.19686 .22543 L
.20688 .23832 L
.21654 .25073 L
.22584 .26267 L
.23572 .27537 L
.24524 .28761 L
.25439 .29937 L
.26414 .31189 L
.27352 .32394 L
.28349 .33676 L
.2931 .3491 L
.30234 .36097 L
.31217 .37361 L
.32163 .38577 L
.33169 .3987 L
.34139 .41115 L
.35071 .42314 L
.36063 .43588 L
.37018 .44816 L
.37498 .45433 L
.37708 .45702 L
.37937 .45996 L
.37998 .46074 L
Mistroke
.38031 .46117 L
.38062 .46157 L
.38092 .46195 L
.38123 .1564 L
.38152 .15677 L
.38179 .15711 L
.38408 .16006 L
.38915 .16657 L
.39873 .17889 L
.40795 .19073 L
.41776 .20334 L
.42721 .21548 L
.43725 .22838 L
.44692 .24081 L
.45623 .25277 L
.46613 .26549 L
.47566 .27774 L
.48482 .28951 L
.49458 .30205 L
.50397 .31412 L
.51396 .32695 L
.52358 .33931 L
.53283 .3512 L
.54267 .36385 L
.55215 .37603 L
.56222 .38898 L
.57193 .40145 L
.58127 .41345 L
.5912 .42621 L
.60076 .4385 L
.60996 .45032 L
.61469 .45639 L
.61605 .45814 L
.61734 .4598 L
.6179 .46052 L
.61849 .46128 L
.6188 .46168 L
.61898 .46191 L
.61915 .15617 L
.61944 .15654 L
.61975 .15695 L
.62972 .16975 L
.63932 .18208 L
.64855 .19395 L
.65837 .20657 L
.66783 .21873 L
.67788 .23164 L
.68757 .24409 L
.69688 .25606 L
.7068 .2688 L
Mistroke
.71634 .28106 L
.72552 .29285 L
.73529 .30541 L
.74469 .3175 L
.75469 .33034 L
.76432 .34272 L
.77359 .35462 L
.78345 .36729 L
.79294 .37949 L
.80302 .39245 L
.81274 .40494 L
.82209 .41695 L
.83203 .42973 L
.84161 .44204 L
.85082 .45387 L
.85325 .457 L
.85556 .45996 L
.85617 .46075 L
.85651 .46118 L
.85683 .46159 L
.85699 .4618 L
.85717 .15607 L
.85736 .15632 L
.85755 .15656 L
.85821 .15741 L
.86063 .16052 L
.87024 .17287 L
.87948 .18474 L
.88932 .19739 L
.89879 .20955 L
.90885 .22249 L
.91855 .23495 L
.92788 .24694 L
.93781 .25969 L
.94736 .27197 L
.95655 .28378 L
.96634 .29636 L
.97575 .30846 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008Oooool5o`0003[ooooo0ol0000iooooo`;o0000>_ooool3o`0003[ooooo1Ol00006oooo
o`008_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Oooooo00Co0000oooo
oooooooo0000>_ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Kooooo000K
ooooo`Go00000oooool00ol0003oooooooooo`0cooooo`Go00000oooool00ol0003oooooooooo`0g
ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo00Co0000
oooooooooooo0000>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo000Q
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`0gooooo`04o`000?oo
ooooooooo`0003[ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000Ko
oooo000Qooooo`05o`000?ooooooooooooooool00000>_ooool2o`0003Wooooo00Co0000oooooooo
oooo0000>Oooool2o`0003_ooooo00Go0000ooooooooooooooooo`000006ooooo`008_ooool3o`00
03cooooo00?o0000ooooooooool0>?ooool2o`0003_ooooo00?o0000ooooooooool0>_ooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`005?ooool0
0ol0003oooooooooo`3oooooo`[ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`04oooo
oooo00001Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`004oooool2o`0000Kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool2
o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020oooo
o`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo0008ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Sooooo`03o`00
oooooooooooo03_ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0Kooooo`;o003o
??ooool2o`00ob;ooooo0_l00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co0000
1Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo03_ooooo0_l00?lMooooo`03o`00
0?oooooooooo01_ooooo0_l00?llooooo`;o003o8oooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`;o003o
??ooool00ol00?ooooooo`00o`0Looooo`03o`000?oooooooooo01_ooooo00?o003oooooool00?l0
>oooool00ol00?ooooooo`00o`0Rooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?oo
ool00ol0003oooooooooo`0Rooooo`03o`00oooooooo003o03_ooooo00?o003oooooool00?l07?oo
ool00ol0003oooooooooo`0Kooooo`04o`00ooooooooooooo`00oc[ooooo00Co003ooooooooooooo
003o8Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00Co003ooooooooooooo
003o>_ooool01?l00?ooooooooooool00?lKooooo`03o`000?oooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`0iooooo`05o`00ooooooooooooooooool00?l08?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo02;ooooo00Go003oooooooooooooooooo`00o`0iooooo`04o`00oooo
ooooooooo`00oa_ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo03Kooooo00Go003oooooooooooooooooo`00o`0Pooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool08_ooool01Ol00?oooooooooooooooooo003o03Wooooo00Go003ooooooooo
ooooooooo`00o`0Jooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0eooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0fooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0=Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01cooooo0Ol00001ooooo`006oooool2o`0002?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0=?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01[ooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0=?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Gooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Jooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool08_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool06Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool06oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Hooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
8_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
5oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04Ooo
ool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Oooooo0Ol00001ooooo`006oooool2
o`0002?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo01Gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
013ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02ko
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo01_o
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool05?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0;?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02_ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Cooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool08_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool04_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool0:_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo017ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool0:_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00_ooooo00?o0000oooooooo
ool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0@ooooo`7o00000Oooool001_ooooo0_l0000Sooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00_ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo02Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0>ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo02Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool03oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
02Kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool03Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0;ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool08_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool02_ooool1o`00007ooooo000Kooooo`;o00008oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo02?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo01_ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool02Oooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0Kooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`08ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo027ooooo00?o003oooooooooool06?ooool01Ol00?oooooooooooooooooo000001gooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool01oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00Go
003oooooooooooooooooo`00000Mooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00Kooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0Iooooo`04o`00ooooooooooooo`0001gooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
1Oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0Rooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooo
oooo000001gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool01Oooool1o`00007ooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooo
oooooooo01kooooo00?o003oooooooooool06_ooool00ol00?ooooooo`00000Mooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Cooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`Ko000000?o
003oo`000?l000007?l000000ol00?oo0000o`00000Ko`000003o`00ool0003o000001go000000?o
003oo`000?l000006ol000000ol00?oo0000o`00000Lo`000003o`00ool0003o000001co000000?o
003oo`000?l000007?l000000ol00?oo0000o`00000Lo`000003o`00ool0003o000000Co00000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool08_ooool1o`00007ooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`000?l0
0?oooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo02;ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool07?ooool00ol0003o003oooooo`0Kooooo`03o`00oooo
oooooooo01kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Rooooo`7o00000Ooo
ool001Cooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool06_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool07?ooool0
0ol0003oooooo`00o`0Kooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0Looooo`04o`000?ooooooooooo`00oa[ooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo01cooooo00Go0000ooooooooooooooooo`00o`0I
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0R
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Loooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`;o
00002_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool08Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
7?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool08_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool07?ooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool09_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0=ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool08_ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`0Wooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool07?ooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool2o`00013ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo027ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool0:Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01cooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
:oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool08_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0/ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07?ooool00ol0
003oooooooooo`0=ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0;Oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0Rooooo`7o00000Oooool001_ooooo0_l0000Fooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01cooooo
00?o0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool05_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o0000oooo
ooooool04_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool06?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
7?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0dooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08_ooool1
o`00007ooooo000Kooooo`;o00007?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
03Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo
01Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool08Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo01co
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02;o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0=_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01cooooo
00?o0000ooooooooool05oooool01Ol00?oooooooooooooooooo003o03Sooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
7Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03Oooooo00Go003ooooooooooooo
ooooo`00o`0Nooooo`03o`000?oooooooooo01Oooooo00Go003oooooooooooooooooo`00o`0ioooo
o`05o`00ooooooooooooooooool00?l09?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
01kooooo0_l00?l2ooooo`03o`00oooooooooooo03Sooooo00Co003ooooooooooooo003o7_ooool0
0ol0003oooooooooo`0Hooooo`04o`00ooooooooooooo`00oc[ooooo00Co003ooooooooooooo003o
9?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo023ooooo00?o003oooooool00?l0>_oo
ool01?l00?ooooooooooool00?lNooooo`03o`000?oooooooooo01Wooooo00?o003oooooool00?l0
>oooool00ol00?ooooooo`00o`0Tooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo023ooooo00?o003oooooool00?l0>ooo
ool00ol00?ooooooo`00o`0Nooooo`03o`000?oooooooooo01Wooooo00?o003oooooool00?l0??oo
ool2o`00obCooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0Qooooo`;o003o??ooool2o`00oakooooo
00?o0000ooooooooool06_ooool2o`00occooooo0_l00?lTooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00008_ooool2o`00occooooo
0_l00?lNooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0>oooool00ol00?oooooo
ooooo`0Qooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020oooo
o`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003o
ooooooooo`1mooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00000Oooool0
01Cooooo00?o0000ooooooooool01?ooooooo`0000Go00000Oooool001?ooooo0_l0003oooooo`co
oooo000Dooooo`03o`000?oooooooooo0?oooooo2_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.54077, -1.16749, \
0.0161771, 0.012589}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Complex Fourier series", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[SawTooth1[t], t, 5];\)\), "\[IndentingNewLine]", 
    \(\(series\  // \ Simplify\)\  // TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\(\(\[ImaginaryI]\ \[ExponentialE]\^\(\(-10\)\ \
\[ImaginaryI]\ \[Pi]\ t\)\ \((\(-12\) + 
                15\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Pi]\ t\) - 
                20\ \[ExponentialE]\^\(4\ \[ImaginaryI]\ \[Pi]\ t\) + 
                30\ \[ExponentialE]\^\(6\ \[ImaginaryI]\ \[Pi]\ t\) - 
                60\ \[ExponentialE]\^\(8\ \[ImaginaryI]\ \[Pi]\ t\) + 
                60\ \[ExponentialE]\^\(12\ \[ImaginaryI]\ \[Pi]\ t\) - 
                30\ \[ExponentialE]\^\(14\ \[ImaginaryI]\ \[Pi]\ t\) + 
                20\ \[ExponentialE]\^\(16\ \[ImaginaryI]\ \[Pi]\ t\) - 
                15\ \[ExponentialE]\^\(18\ \[ImaginaryI]\ \[Pi]\ t\) + 
                12\ \[ExponentialE]\^\(20\ \[ImaginaryI]\ \[Pi]\ \
t\))\)\)\/\(120\ \[Pi]\)\)\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Real representation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(series2\  = series\  // \ ComplexExpand;\)\[IndentingNewLine]
    series2\  // TraditionalForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(sin(2\ \[Pi]\ t)\)\/\[Pi] - \(sin(4\ \[Pi]\ \
t)\)\/\(2\ \[Pi]\) + \(sin(6\ \[Pi]\ t)\)\/\(3\ \[Pi]\) - \(sin(8\ \[Pi]\ \
t)\)\/\(4\ \[Pi]\) + \(sin(10\ \[Pi]\ t)\)\/\(5\ \[Pi]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .32105 L
.04339 .33418 L
.05298 .34651 L
.06221 .35836 L
.07203 .37098 L
.08148 .38313 L
.09153 .39604 L
.10121 .40848 L
.11052 .42044 L
.12043 .43318 L
.12997 .44543 L
.13476 .45159 L
.13914 .45722 L
.14029 .4587 L
.14155 .46032 L
.14213 .46106 L
.14244 .46147 L
.14274 .46185 L
.14302 .15625 L
.14332 .15663 L
.14385 .15731 L
.14891 .16381 L
.15885 .17659 L
.16842 .18889 L
.17763 .20072 L
.18743 .21331 L
.19686 .22543 L
.20688 .23832 L
.21654 .25073 L
.22584 .26267 L
.23572 .27537 L
.24524 .28761 L
.25439 .29937 L
.26414 .31189 L
.27352 .32394 L
.28349 .33676 L
.2931 .3491 L
.30234 .36097 L
.31217 .37361 L
.32163 .38577 L
.33169 .3987 L
.34139 .41115 L
.35071 .42314 L
.36063 .43588 L
.37018 .44816 L
.37498 .45433 L
.37708 .45702 L
.37937 .45996 L
.37998 .46074 L
Mistroke
.38031 .46117 L
.38062 .46157 L
.38092 .46195 L
.38123 .1564 L
.38152 .15677 L
.38179 .15711 L
.38408 .16006 L
.38915 .16657 L
.39873 .17889 L
.40795 .19073 L
.41776 .20334 L
.42721 .21548 L
.43725 .22838 L
.44692 .24081 L
.45623 .25277 L
.46613 .26549 L
.47566 .27774 L
.48482 .28951 L
.49458 .30205 L
.50397 .31412 L
.51396 .32695 L
.52358 .33931 L
.53283 .3512 L
.54267 .36385 L
.55215 .37603 L
.56222 .38898 L
.57193 .40145 L
.58127 .41345 L
.5912 .42621 L
.60076 .4385 L
.60996 .45032 L
.61469 .45639 L
.61605 .45814 L
.61734 .4598 L
.6179 .46052 L
.61849 .46128 L
.6188 .46168 L
.61898 .46191 L
.61915 .15617 L
.61944 .15654 L
.61975 .15695 L
.62972 .16975 L
.63932 .18208 L
.64855 .19395 L
.65837 .20657 L
.66783 .21873 L
.67788 .23164 L
.68757 .24409 L
.69688 .25606 L
.7068 .2688 L
Mistroke
.71634 .28106 L
.72552 .29285 L
.73529 .30541 L
.74469 .3175 L
.75469 .33034 L
.76432 .34272 L
.77359 .35462 L
.78345 .36729 L
.79294 .37949 L
.80302 .39245 L
.81274 .40494 L
.82209 .41695 L
.83203 .42973 L
.84161 .44204 L
.85082 .45387 L
.85325 .457 L
.85556 .45996 L
.85617 .46075 L
.85651 .46118 L
.85683 .46159 L
.85699 .4618 L
.85717 .15607 L
.85736 .15632 L
.85755 .15656 L
.85821 .15741 L
.86063 .16052 L
.87024 .17287 L
.87948 .18474 L
.88932 .19739 L
.89879 .20955 L
.90885 .22249 L
.91855 .23495 L
.92788 .24694 L
.93781 .25969 L
.94736 .27197 L
.95655 .28378 L
.96634 .29636 L
.97575 .30846 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.06244 .35278 L
.07216 .37894 L
.07496 .3852 L
.07633 .3877 L
.0776 .38963 L
.07873 .39101 L
.07998 .39217 L
.08123 .39294 L
.08191 .39321 L
.08255 .39336 L
.08326 .39342 L
.08402 .39337 L
.08475 .39323 L
.08542 .39301 L
.08669 .39243 L
.08805 .39162 L
.09109 .38958 L
.09182 .38914 L
.09258 .38873 L
.09329 .38842 L
.09396 .3882 L
.09523 .38802 L
.09591 .38808 L
.09663 .38827 L
.09741 .38863 L
.09815 .38915 L
.09881 .38975 L
.09953 .39058 L
.1008 .39248 L
.10215 .39513 L
.10458 .40153 L
.11363 .4381 L
.11611 .44826 L
.11746 .45308 L
.11872 .45689 L
.1198 .45954 L
.12095 .46163 L
.12223 .46294 L
.12339 .46312 L
.12406 .46275 L
.12476 .46197 L
.12603 .45952 L
.12674 .45756 L
.1274 .45533 L
.1289 .44881 L
.1314 .43345 L
.1341 .41106 L
.14415 .29242 L
.14906 .23315 L
Mistroke
.15175 .20573 L
.15428 .18477 L
.15573 .17521 L
.15729 .16695 L
.15798 .16399 L
.15871 .16133 L
.16001 .15774 L
.16132 .1556 L
.16255 .15487 L
.16325 .15498 L
.16389 .15539 L
.16463 .15622 L
.16533 .15733 L
.16648 .15981 L
.16776 .16337 L
.17033 .17262 L
.17496 .19265 L
.18006 .21305 L
.18263 .22068 L
.18408 .22399 L
.18543 .22639 L
.18675 .22812 L
.188 .22921 L
.18911 .22978 L
.19032 .23001 L
.19165 .22986 L
.19231 .22965 L
.19304 .22935 L
.19555 .22785 L
.19786 .22629 L
.19913 .22554 L
.20034 .225 L
.20146 .2247 L
.20268 .22462 L
.20379 .22482 L
.20481 .22526 L
.20601 .22609 L
.20729 .22737 L
.20851 .22896 L
.20962 .23074 L
.21493 .24262 L
.22013 .25703 L
.22298 .26455 L
.22568 .27067 L
.22814 .27509 L
.22944 .27692 L
.23081 .27849 L
.23196 .27953 L
.23323 .28038 L
.23439 .28092 L
Mistroke
.23547 .28125 L
.23665 .28145 L
.23776 .28152 L
.23877 .28151 L
.23986 .28146 L
.24105 .2814 L
.24231 .28138 L
.2435 .28145 L
.24458 .28162 L
.24588 .282 L
.24653 .28229 L
.24725 .28267 L
.24852 .28356 L
.2497 .28465 L
.25238 .28806 L
.25524 .29316 L
.26528 .31751 L
.26784 .32337 L
.27057 .32858 L
.27289 .332 L
.27422 .3335 L
.27546 .33461 L
.27681 .33551 L
.2775 .33585 L
.27824 .33614 L
.27956 .33648 L
.28079 .33663 L
.28154 .33666 L
.28224 .33665 L
.28357 .33659 L
.28426 .33656 L
.28499 .33653 L
.28579 .33651 L
.28653 .33653 L
.28778 .33667 L
.28892 .33694 L
.29024 .33747 L
.29148 .33824 L
.29264 .33919 L
.2937 .3403 L
.29612 .34367 L
.2988 .34877 L
.30122 .35448 L
.30666 .36934 L
.31155 .38202 L
.31402 .387 L
.31543 .38925 L
.31672 .39089 L
.3179 .39203 L
.31903 .39279 L
Mistroke
.32021 .39326 L
.3215 .39342 L
.32262 .39328 L
.32382 .3929 L
.32483 .39241 L
.32596 .39174 L
.32861 .38995 L
.32992 .38913 L
.33114 .38852 L
.33181 .38827 L
.33253 .3881 L
.33333 .38802 L
.33405 .38809 L
.33471 .38826 L
.33542 .38858 L
.33671 .38956 L
.33793 .39099 L
.33927 .39314 L
.34066 .39608 L
.34196 .39944 L
.3468 .41657 L
.3518 .4384 L
.35444 .44912 L
.35588 .45413 L
.35724 .458 L
.35842 .46058 L
.35968 .46242 L
.36037 .46296 L
.36109 .46317 L
.36238 .46254 L
.36356 .46079 L
.36465 .45811 L
.36585 .45394 L
.36714 .44807 L
.36954 .43319 L
.37214 .41159 L
.37686 .36052 L
.38569 .24984 L
.38805 .22353 L
.39058 .19915 L
.39276 .18204 L
.39515 .16805 L
.39585 .16491 L
.3966 .16204 L
.39724 .15996 L
.39794 .15812 L
.39866 .15667 L
.39933 .1557 L
.40059 .15488 L
.40185 .15528 L
Mistroke
.40248 .15591 L
.40318 .1569 L
.40441 .1594 L
.40556 .16248 L
.41074 .18238 L
.41637 .20652 L
.41895 .21563 L
.42036 .21974 L
.42168 .22296 L
.4229 .22537 L
.42402 .22711 L
.42526 .22854 L
.42591 .22908 L
.4266 .22951 L
.42788 .22995 L
.42904 .22998 L
.42968 .22987 L
.43038 .22966 L
.43165 .22909 L
.43409 .22754 L
.43634 .22605 L
.43753 .22539 L
.4388 .22488 L
.43953 .2247 L
.4402 .22462 L
.44151 .22473 L
.44221 .22493 L
.44285 .22523 L
.44356 .22567 L
.44432 .22627 L
.44558 .2276 L
.44698 .22953 L
.44938 .23391 L
.45158 .23893 L
.45655 .25236 L
.46126 .265 L
.46332 .26971 L
.46555 .27396 L
.46681 .27594 L
.46798 .27747 L
.46916 .27875 L
.47027 .27969 L
.47144 .28044 L
.47273 .28101 L
.47398 .28134 L
.47468 .28144 L
.47533 .2815 L
.47651 .28152 L
.47761 .28148 L
.47889 .28141 L
Mistroke
.48005 .28138 L
.48115 .28141 L
.48216 .28152 L
.48327 .28177 L
.48444 .2822 L
.48569 .28288 L
.48686 .28376 L
.48814 .285 L
.48951 .28668 L
.49241 .29135 L
.49504 .29681 L
.49993 .30885 L
.50513 .3216 L
.50739 .32631 L
.50984 .33044 L
.51124 .33232 L
.51252 .33371 L
.51375 .33476 L
.51504 .33558 L
.51614 .33607 L
.51731 .33641 L
.51842 .33659 L
.51942 .33665 L
.52061 .33664 L
.52189 .33658 L
.5231 .33653 L
.52422 .33652 L
.52541 .3366 L
.5267 .33685 L
.52791 .33727 L
.52902 .33786 L
.53032 .33882 L
.53173 .34022 L
.5343 .34382 L
.53699 .34898 L
.53984 .35582 L
.54498 .36997 L
.55 .3828 L
.55253 .38771 L
.55396 .38985 L
.55529 .3914 L
.55605 .39207 L
.55676 .39258 L
.5574 .39293 L
.5581 .39321 L
.55886 .39337 L
.55966 .39342 L
.56035 .39335 L
.5611 .39318 L
.56179 .39294 L
Mistroke
.56243 .39266 L
.56386 .39187 L
.56644 .39013 L
.56768 .38933 L
.56836 .38894 L
.569 .38862 L
.57025 .38818 L
.57138 .38802 L
.57204 .38807 L
.57273 .38824 L
.57397 .38887 L
.57467 .38943 L
.57531 .39009 L
.57678 .39213 L
.57806 .39452 L
.57926 .39732 L
.58153 .40394 L
.58662 .42397 L
.59159 .4455 L
.59403 .45429 L
.59509 .45738 L
.59626 .4601 L
.5974 .46199 L
.59861 .46303 L
.59991 .46298 L
.60113 .46171 L
.60183 .46042 L
.60249 .45882 L
.60373 .45479 L
.60507 .44892 L
.60651 .44077 L
.60873 .42476 L
.61116 .4026 L
.61609 .34661 L
.62493 .23674 L
.62742 .2107 L
.63013 .1873 L
.63137 .17861 L
.6327 .17083 L
.63394 .16495 L
.63508 .16076 L
.63628 .15757 L
.63758 .15553 L
.63873 .15487 L
.63994 .15528 L
.64103 .15652 L
.64205 .15837 L
.64316 .16108 L
.64436 .16467 L
.64962 .18585 L
Mistroke
.6525 .19851 L
.65521 .20934 L
.6577 .21762 L
.65998 .22339 L
.66121 .22574 L
.66251 .22762 L
.66382 .22893 L
.66455 .22944 L
.66524 .22976 L
.66588 .22993 L
.66657 .23001 L
.66782 .22986 L
.66904 .22943 L
.67017 .22885 L
.67289 .22706 L
.67422 .22618 L
.67543 .22549 L
.67666 .22496 L
.67735 .22476 L
.67799 .22465 L
.67869 .22461 L
.67934 .22467 L
.68005 .22485 L
.68081 .22516 L
.68155 .22559 L
.68235 .22622 L
.6838 .22775 L
.68521 .22974 L
.6865 .23198 L
.69692 .25868 L
.69953 .26543 L
.702 .27093 L
.70422 .27491 L
.70537 .27658 L
.70663 .27811 L
.70774 .27918 L
.70893 .28008 L
.71019 .28076 L
.71137 .28118 L
.71255 .28141 L
.71366 .28151 L
.71466 .28152 L
.71575 .28148 L
.71701 .28141 L
.7182 .28138 L
.71886 .28139 L
.71957 .28143 L
.72081 .28163 L
.722 .28198 L
.72326 .28257 L
Mistroke
.72433 .28327 L
.72551 .28427 L
.7269 .28577 L
.72821 .28753 L
.73067 .29167 L
.73621 .3042 L
.74096 .31627 L
.74348 .32217 L
.7462 .32761 L
.74746 .32973 L
.74879 .33163 L
.75003 .3331 L
.75117 .33422 L
.75225 .33505 L
.75341 .33572 L
.75469 .33623 L
.75585 .3365 L
.75716 .33664 L
.75838 .33665 L
.75901 .33663 L
.75971 .3366 L
.76045 .33656 L
.76112 .33653 L
.76236 .33652 L
.76305 .33656 L
.7637 .33663 L
.76485 .33686 L
.7661 .33732 L
.76735 .33801 L
.76853 .33892 L
.76959 .33996 L
.77073 .34133 L
.7733 .3454 L
.77566 .35026 L
.78452 .37395 L
.78923 .38518 L
.79059 .38766 L
.79188 .38961 L
.79303 .39102 L
.79428 .39218 L
.79537 .39287 L
.79658 .39331 L
.79783 .39342 L
.79901 .39323 L
.80011 .39285 L
.80111 .39236 L
.80338 .39092 L
.80571 .38937 L
.80701 .38866 L
.8082 .38822 L
Mistroke
.80887 .38807 L
.8096 .38803 L
.81029 .3881 L
.81092 .38827 L
.81216 .38893 L
.81346 .39015 L
.81472 .39187 L
.81607 .39435 L
.81851 .40046 L
.82141 .41029 L
.82406 .4211 L
.82885 .44208 L
.83148 .45218 L
.83277 .45623 L
.83395 .45924 L
.83497 .46122 L
.83605 .46259 L
.83712 .46316 L
.8383 .46278 L
.83951 .46124 L
.8408 .45824 L
.84201 .45408 L
.84311 .44915 L
.84578 .43284 L
.84823 .41248 L
.85378 .35157 L
.85864 .28982 L
.86387 .22748 L
.86646 .2019 L
.86892 .18229 L
.87113 .16909 L
.87238 .16355 L
.87354 .15965 L
.87473 .15688 L
.87584 .15537 L
.87684 .15487 L
.87793 .15519 L
.87911 .1565 L
.88036 .15885 L
.88143 .16156 L
.8826 .16517 L
.88814 .18776 L
.89087 .19968 L
.89339 .20968 L
.89563 .21715 L
.89811 .22346 L
.89939 .22587 L
.90059 .2276 L
.90186 .2289 L
.90258 .22939 L
Mistroke
.90323 .22972 L
.90437 .22999 L
.90559 .22993 L
.90673 .2296 L
.90777 .22912 L
.91036 .22749 L
.91274 .22592 L
.91394 .22529 L
.91521 .22482 L
.91649 .22462 L
.91721 .22464 L
.91789 .22477 L
.91912 .22527 L
.92024 .22604 L
.92153 .22731 L
.92275 .22891 L
.92527 .23329 L
.92795 .23936 L
.93276 .25242 L
.93553 .26006 L
.93845 .26737 L
.94115 .27294 L
.94367 .27685 L
.94553 .27891 L
.94657 .27977 L
.94752 .28038 L
.94855 .28087 L
.94968 .28123 L
.95074 .28143 L
.95173 .28151 L
.95275 .28152 L
.95372 .28148 L
.95484 .28142 L
.95587 .28138 L
.95699 .28139 L
.95822 .2815 L
.95937 .28174 L
.96043 .28211 L
.96143 .28261 L
.96237 .28322 L
.96413 .28479 L
.96603 .28713 L
.96808 .2904 L
.9723 .29928 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Eooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo00cooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`003Oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooo
oooooooo000006;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Cooooo`Go0000
0_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`00
0?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0_l0000Jooooo`;o003o;_ooool00ol0
0?ooooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0;?ooool00ol0
0?ooooooooooo`0Hooooo`?o00007?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Mooooo`?oo`00;Oooool2ool001;ooooo00?o0000ooooooooool06?ooool2
ool002gooooo0ooo000Eooooo`;o00003_ooool001Cooooo00Co0000oooooooooooo00001oooool4
o`0000Cooooo00?o0000ooooooooool06Oooool00ol00?ooooooo`00o`0]ooooo`03o`00oooooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0/ooooo`;o003o6oooool0
0ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oo
oooooooo01cooooo00?oo`00oooooooo0000;?ooool3ool001;ooooo00?o0000ooooooooool06?oo
ool2ool002gooooo00?oo`00oooooooo00005_ooool00ol0003oooooooooo`0<ooooo`005?ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Ooo
ool00ol00?ooooooo`00o`0]ooooo`;o003o5Oooool00ol0003oooooooooo`0Eooooo`;o003o;Ooo
ool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?oo`00oooooooo0000
;?ooool00ooo003oooooool0000Booooo`03o`000?oooooooooo01Sooooo00?oo`00oooooooo0000
;?ooool00ooo003oooooool0000Fooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00002?oo
ool5o`0000?ooooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l/ooooo`03o`00
oooooooo003o01Cooooo00?o0000ooooooooool05Oooool00ol00?ooooooo`00o`0/ooooo`04o`00
ooooooooooooo`00oaWooooo00?o0000ooooooooool06oooool2o`0000Sooooo1Ol00004ooooo`03
o`000?oooooooooo01cooooo00Coo`00ooooooooooooo`00:oooool00ooo003oooooool0000Boooo
o`03o`000?oooooooooo01Oooooo00Coo`00ooooooooooooo`00;?ooool00ooo003oooooool0000F
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00Go003ooooo
ooooooooooooo`00o`0[ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool05Ooo
ool01?l00?ooooooooooool00?l[ooooo`04o`00ooooooooooooo`00oaWooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool002_ooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0Gooooo`04ool00?ooooooooooool002_ooooo00Co
o`00ooooooooooooo`005_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`0Iooooo`05o`00ooooooooooooooooool00?l0:oooool01?l00?ooooooooooool00?lCooooo`03
o`000?oooooooooo01Gooooo00Go003oooooooooooooooooo`00o`0Zooooo`05o`00oooooooooooo
ooooool00?l06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01cooooo00Coo`00
ooooooooooooo`00:oooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo01Oooooo
00Goo`00ooooooooooooooooool0000Zooooo`05ool00?oooooooooooooooooo00005Oooool00ol0
003oooooooooo`0<ooooo`009oooool2o`0001[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Xooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01Cooooo0_l0000`ooooo`03o`000?oooooooooo01_ooooo00Goo`00oooo
ooooooooooooool0000[ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool05ooo
ool01Ooo003oooooooooooooooooo`0002[ooooo00Goo`00ooooooooooooooooool0000Eooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
3oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Kooooo`05ool00?oooooooooooooooooo0000:_ooool01Ooo003o
ooooooooooooooooo`00017ooooo00?o0000ooooooooool05oooool01Ooo003ooooooooooooooooo
o`0002[ooooo00Goo`00ooooooooooooooooool0000Eooooo`03o`000?oooooooooo00cooooo000W
ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0E
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0K
ooooo`05ool00?oooooooooooooooooo0000:_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00kooooo00?o0000ooooooooool05oooool01Ooo003oooooooooooooooooo`0002[ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Vooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Kooooo`05ool00?oooooooooooooooooo0000:_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool05_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00kooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo02Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooo
oooo00cooooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
01Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool04?ooool2o`00033ooooo00?o0000ooooooooool06oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Vooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04Oooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[o
oooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Ko
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo01Ko
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`0Iooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003ooooo
ooooo`05ooooo`Goo`008oooool00ooo003oooooooooo`04ooooo`Goo`002_ooool00ol0003ooooo
ooooo`0Fooooo`03ool00?oooooooooo00Cooooo1Ooo000Sooooo`03ool00?oooooooooo00Cooooo
1_oo000>ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo00Gooooo0_oo
0002ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000Wooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`05ooooo`05ool0
0?oooooooooooooooooo00008_ooool00ooo003oooooooooo`05ooooo`;oo`000_ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool08Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Oooooo
00?o0000ooooooooool05_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo023ooooo
00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Jooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool07oooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool2o`00033ooooo00?o0000
ooooooooool06_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo01oooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo01kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Ooooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o0000oooooooo
ool05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool06_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo01kooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`05ooooo`03o`00
0?oooooooooo01Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Mooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Ooo
ool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03?oo
ool2ool000Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0=ooooo`03ool00?oo
oooooooo01cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool07?ooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool05Oooool0
0ooo003oooooooooo`0=ooooo`;oo`007Oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06ooooo`;o0000<?ooool00ol0
003oooooooooo`0Iooooo`03ool00?oooooooooo00kooooo0_oo000Mooooo`03ool00?oooooooooo
00gooooo0_oo0005ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`0Kooooo`03ool00?oooooooooo00kooooo0_oo0009ooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`00000Goooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo00oooooo1?oo000Jooooo`03ool00?oooooooooo00kooooo1Ooo00000ooo
oooo0000ooooo`0Fooooo`03ool00?oooooooooo00kooooo1Ooo000Iooooo`03ool00?oooooooooo
00oooooo1?oo0006ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017o
oooo00Co003ooooooooooooo00005oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooo`00000Gooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04Oooool01?l00?oo
ooooooooool0000Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Iooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Booooo`03ool00?oooooo000001Oooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`008Oooool2o`0000Cooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool04_ooool00ol00?oo
ooooo`00000Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool09oooool2o`0000Go
oooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool04oooool00ooo003o0000ooooo`0Fooooo`03ool00?oooooooooo01?o
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Iooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00ool0003ooooo01Kooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003o0000ooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0023o
oooo00Co0000oooooooooooo00000oooool5o`000003o`00ool0003o000001Co000000?o003oo`00
0?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o000001Co000000?o003oo`00
0?l000005Ol000000ol00?oo0000o`00000Do`000003o`00ool0003o000001Go000000?o003oo`00
0?l000005Ol000000ol00?oo0000o`000003o`0002Sooooo00Co0000oooooooooooo00001?ooool4
o`000003ool00?l0003o000001Go000000?oo`00o`000?l000005?l000000ooo003o0000o`00000E
o`000003ool00?l0003o000001Go000000?oo`00o`000?l000005Ol000000ooo003o0000o`00000D
o`000003ool00?l0003o000001Go000000?oo`00o`000?l000005Ol000000ooo003o0000o`000002
o`0000kooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Dooooo`03o`000?l00?oooooo01Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool09_ooool0
1?l0003oooooooooool00004ooooo`05o`000?oooooooooooooooooo00005oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00cooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`000?l00?oooooo01Gooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool09_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool05Oooool00ol0003oo`00ooooo`0Eooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00co
oooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Dooooo`03o`000?oooooo003o01Gooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool09_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05Oooool00ol0
003oo`00ooooo`0Dooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Qooooo`;o00001?ooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01Cooooo00Co0000oooooooooooo003o5?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0Wooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01Cooooo00Go0000ooooooooooooooooo`00o`0Coooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Eoooo
o`04o`000?ooooooo`00ool001?ooooo00?oo`00ooooooooool05oooool2ool001?ooooo00?oo`00
ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`0000Oooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo0_l0000`oooo
o`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Ioooo
o`Coo`004?ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Coo`004?ooool00ooo
003oooooooooo`0Hooooo`Goo`003oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool07Oooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool01?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`09ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07_ooool00ooo003ooooooooo
o`0<ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03?ooool00ooo003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool07_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01gooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0<oooo
o`03ool00?oooooooooo01kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo000Wooooo`;o00002oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Dooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo01oooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Jooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo01oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Nooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02ooo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo01Cooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo023ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0
003oooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`02ool000Kooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`03ool0
00Kooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`07ooooo`;oo`0000Coooooool0
0?oo003oo`001_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00;oo`001_ooool0
0ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`?oo`000_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo02;ooooo0_oo0002ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`08ooooo`?oo`0000?oooooool0
0?ooool01Oooool00ooo003oooooooooo`0Qooooo`?oo`0000?oooooool00?oo00001Oooool00ooo
003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00004?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06Oooool2o`00033o
oooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Ko
oooo0_oo0005ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool09oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Kooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Kooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0:?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00?o0000
ooooooooool03Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Oooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Boooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Koooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0:?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00?o0000oooooooo
ool03_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0:?ooool01Ooo003oooooooooooooooooo`0001Wo
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Oo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00co
oooo000Wooooo`;o00005_ooool01Ol00?oooooooooooooooooo003o02_ooooo00Go003ooooooooo
ooooooooo`00o`0Fooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool2o`00
033ooooo00?o0000ooooooooool04oooool01Ooo003oooooooooooooooooo`0002_ooooo00Coo`00
ooooooooooooo`006Oooool00ol0003oooooooooo`0>ooooo`05ool00?oooooooooooooooooo0000
:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool05_ooool01?l00?ooooooooooool00?l[ooooo`05o`00
ooooooooooooooooool00?l05_ooool00ol0003oooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l0:_ooool01Ol00?oooooooooooooooooo003o01cooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Cooooo`05ool00?oooooooooooooooooo0000:oooool01?oo003ooooooooo
oooo000Iooooo`03o`000?oooooooooo00oooooo00Coo`00ooooooooooooo`00:oooool01Ooo003o
ooooooooooooooooo`0001gooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooooooo
ool05oooool00ol00?ooooooo`00o`0/ooooo`04o`00ooooooooooooo`00oaKooooo00?o0000oooo
ooooool04_ooool01?l00?ooooooooooool00?l[ooooo`04o`00ooooooooooooo`00oacooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`04ool00?ooooooooooool002cooooo
00Coo`00ooooooooooooo`006Oooool00ol0003oooooooooo`0?ooooo`04ool00?ooooooooooool0
02_ooooo00Coo`00ooooooooooooo`007_ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool05oooool00ol0
0?ooooooo`00o`0]ooooo`03o`00oooooooo003o01Kooooo00?o0000ooooooooool04oooool00ol0
0?ooooooo`00o`0/ooooo`03o`00oooooooo003o01cooooo00?o0000ooooooooool06oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool05?ooool00ooo
003oooooool0000/ooooo`04ool00?ooooooooooool001Wooooo00?o0000ooooooooool03oooool0
1?oo003ooooooooooooo000[ooooo`04ool00?ooooooooooool001kooooo00?o0000ooooooooool0
3?ooool001Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool06?ooool2o`00obgooooo00?o003oooooool00?l05_ooool00ol0003o
ooooooooo`0Cooooo`03o`00oooooooo003o02gooooo0_l00?lLooooo`03o`000?oooooooooo01[o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool05?ooool00ooo003oooooool0000/ooooo`03ool00?ooooooo`0001[ooooo00?o0000
ooooooooool04?ooool00ooo003oooooool0000/ooooo`03ool00?ooooooo`0001kooooo00?o0000
ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooo
oooo000001_ooooo00?o003oooooooooool0;?ooool2o`00oaKooooo00?o0000ooooooooool05?oo
ool2o`00obgooooo0_l00?lLooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo0ooo000]ooooo`;oo`00
6_ooool00ol0003oooooooooo`0@ooooo`;oo`00;Oooool3ool001kooooo00?o0000ooooooooool0
3?ooool001Cooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0001[o
oooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`0Hooooo`?o00007?ooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`;oo`00;Oooool2ool0
01[ooooo00?o0000ooooooooool04?ooool2ool002kooooo00?oo`00ooooooooool07?ooool2o`00
00kooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`005Oooool2
o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0Kooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000
ooooooooool0H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Pooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool09_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`05o`000?oooooo
ooooooooool000003_ooool0027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o0000:Oooool0
0ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_l0000>ooooo`008Oooool00ol0003oooooooooo`03oooo
olSo0000:Oooool00ol0003oooooooooo`04ooooolOo00003_ooool0023ooooo0_l0003eooooo`;o
0000foooool0027ooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`3Iooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["More terms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[SawTooth1[t], t, 10];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], 
        ImageSize \[Rule] 500];\)\), "\[IndentingNewLine]", 
    \(\(series\  // \ ComplexExpand\)\  // TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .32105 L
.04339 .33418 L
.05298 .34651 L
.06221 .35836 L
.07203 .37098 L
.08148 .38313 L
.09153 .39604 L
.10121 .40848 L
.11052 .42044 L
.12043 .43318 L
.12997 .44543 L
.13476 .45159 L
.13914 .45722 L
.14029 .4587 L
.14155 .46032 L
.14213 .46106 L
.14244 .46147 L
.14274 .46185 L
.14302 .15625 L
.14332 .15663 L
.14385 .15731 L
.14891 .16381 L
.15885 .17659 L
.16842 .18889 L
.17763 .20072 L
.18743 .21331 L
.19686 .22543 L
.20688 .23832 L
.21654 .25073 L
.22584 .26267 L
.23572 .27537 L
.24524 .28761 L
.25439 .29937 L
.26414 .31189 L
.27352 .32394 L
.28349 .33676 L
.2931 .3491 L
.30234 .36097 L
.31217 .37361 L
.32163 .38577 L
.33169 .3987 L
.34139 .41115 L
.35071 .42314 L
.36063 .43588 L
.37018 .44816 L
.37498 .45433 L
.37708 .45702 L
.37937 .45996 L
.37998 .46074 L
Mistroke
.38031 .46117 L
.38062 .46157 L
.38092 .46195 L
.38123 .1564 L
.38152 .15677 L
.38179 .15711 L
.38408 .16006 L
.38915 .16657 L
.39873 .17889 L
.40795 .19073 L
.41776 .20334 L
.42721 .21548 L
.43725 .22838 L
.44692 .24081 L
.45623 .25277 L
.46613 .26549 L
.47566 .27774 L
.48482 .28951 L
.49458 .30205 L
.50397 .31412 L
.51396 .32695 L
.52358 .33931 L
.53283 .3512 L
.54267 .36385 L
.55215 .37603 L
.56222 .38898 L
.57193 .40145 L
.58127 .41345 L
.5912 .42621 L
.60076 .4385 L
.60996 .45032 L
.61469 .45639 L
.61605 .45814 L
.61734 .4598 L
.6179 .46052 L
.61849 .46128 L
.6188 .46168 L
.61898 .46191 L
.61915 .15617 L
.61944 .15654 L
.61975 .15695 L
.62972 .16975 L
.63932 .18208 L
.64855 .19395 L
.65837 .20657 L
.66783 .21873 L
.67788 .23164 L
.68757 .24409 L
.69688 .25606 L
.7068 .2688 L
Mistroke
.71634 .28106 L
.72552 .29285 L
.73529 .30541 L
.74469 .3175 L
.75469 .33034 L
.76432 .34272 L
.77359 .35462 L
.78345 .36729 L
.79294 .37949 L
.80302 .39245 L
.81274 .40494 L
.82209 .41695 L
.83203 .42973 L
.84161 .44204 L
.85082 .45387 L
.85325 .457 L
.85556 .45996 L
.85617 .46075 L
.85651 .46118 L
.85683 .46159 L
.85699 .4618 L
.85717 .15607 L
.85736 .15632 L
.85755 .15656 L
.85821 .15741 L
.86063 .16052 L
.87024 .17287 L
.87948 .18474 L
.88932 .19739 L
.89879 .20955 L
.90885 .22249 L
.91855 .23495 L
.92788 .24694 L
.93781 .25969 L
.94736 .27197 L
.95655 .28378 L
.96634 .29636 L
.97575 .30846 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.06244 .36378 L
.08255 .38823 L
.10458 .41712 L
.10576 .42134 L
.10702 .42513 L
.10767 .42672 L
.1084 .42811 L
.10967 .42954 L
.11086 .42967 L
.11215 .42856 L
.11337 .42657 L
.11448 .42423 L
.11584 .4212 L
.11655 .41973 L
.11732 .41843 L
.11806 .41753 L
.11872 .4171 L
.12002 .41757 L
.12127 .41989 L
.12197 .42206 L
.12262 .42461 L
.12381 .43057 L
.12507 .43836 L
.12734 .4544 L
.12859 .46282 L
.12977 .46943 L
.13087 .47361 L
.13207 .47526 L
.13316 .47354 L
.13416 .46884 L
.13535 .45918 L
.13647 .44595 L
.13769 .42692 L
.13901 .40163 L
.14415 .27599 L
.14655 .21974 L
.14787 .19391 L
.14911 .174 L
.15027 .1598 L
.15153 .14933 L
.15267 .14416 L
.15372 .14278 L
.15497 .1448 L
.15614 .1496 L
.15743 .15715 L
.15881 .16671 L
.16016 .17635 L
.1616 .18571 L
.16296 .19284 L
Mistroke
.16419 .19744 L
.16486 .19914 L
.16559 .20034 L
.1669 .20096 L
.16765 .20052 L
.16844 .19955 L
.16911 .1984 L
.16985 .1969 L
.17118 .19393 L
.17244 .19128 L
.17314 .19008 L
.17389 .18907 L
.17458 .18849 L
.17522 .18828 L
.17642 .18877 L
.17711 .18959 L
.17775 .1907 L
.17904 .19386 L
.18043 .19835 L
.18298 .20799 L
.18529 .21606 L
.18653 .21941 L
.1877 .22172 L
.18893 .22322 L
.18963 .22366 L
.19027 .22383 L
.19134 .22368 L
.19251 .22306 L
.19373 .22214 L
.19489 .22129 L
.19554 .2209 L
.19625 .22062 L
.1975 .22058 L
.19821 .22087 L
.19896 .22145 L
.1996 .22219 L
.20031 .22324 L
.20156 .22573 L
.20292 .22913 L
.20537 .23637 L
.20671 .24035 L
.20815 .24418 L
.20948 .2471 L
.21073 .24916 L
.21141 .24997 L
.21214 .25062 L
.21343 .25124 L
.21417 .25134 L
.21496 .25129 L
.21564 .25116 L
Mistroke
.21638 .25097 L
.21769 .25065 L
.2189 .25057 L
.21956 .25068 L
.22028 .25096 L
.2216 .25197 L
.22283 .25354 L
.22413 .25587 L
.22648 .26142 L
.22907 .26836 L
.23149 .2741 L
.23271 .27633 L
.23401 .2781 L
.23476 .27883 L
.23546 .27933 L
.23678 .27986 L
.23748 .27997 L
.23822 .27999 L
.23886 .27997 L
.23956 .27993 L
.24031 .27991 L
.24112 .27996 L
.24188 .28012 L
.24258 .28039 L
.24382 .28124 L
.24452 .28196 L
.24518 .28279 L
.2465 .28493 L
.24791 .28784 L
.25052 .2943 L
.25335 .30125 L
.25465 .30389 L
.25602 .30609 L
.25719 .30744 L
.25848 .30839 L
.25973 .30885 L
.26088 .309 L
.26219 .30902 L
.26345 .30908 L
.2646 .30933 L
.26567 .30984 L
.26684 .31081 L
.26809 .31237 L
.30974 .3667 L
.33066 .39544 L
.34988 .429 L
.35229 .42484 L
.35458 .41987 L
.35584 .41786 L
.35655 .41722 L
Mistroke
.35721 .41705 L
.35838 .41789 L
.35961 .42057 L
.36068 .42447 L
.36184 .43019 L
.36392 .44361 L
.3662 .45967 L
.3674 .46702 L
.36868 .47273 L
.36999 .47523 L
.37121 .47367 L
.37247 .46745 L
.37362 .45743 L
.37473 .44354 L
.37594 .42411 L
.37814 .37885 L
.38072 .3149 L
.3835 .24549 L
.38484 .21561 L
.38611 .19122 L
.38727 .17307 L
.3885 .15841 L
.38962 .14932 L
.39086 .1439 L
.39199 .14284 L
.39305 .14475 L
.39429 .14988 L
.39543 .15656 L
.398 .17457 L
.39917 .18248 L
.40043 .18978 L
.40115 .19324 L
.4018 .19585 L
.40308 .19939 L
.4044 .20092 L
.40515 .20091 L
.40583 .20043 L
.40709 .1986 L
.40773 .19735 L
.40843 .19583 L
.40984 .1927 L
.41053 .1913 L
.41117 .19018 L
.41237 .18871 L
.41368 .1883 L
.41441 .18868 L
.41511 .18946 L
.4164 .19193 L
.41713 .19385 L
.4178 .19589 L
Mistroke
.41931 .20122 L
.42187 .21097 L
.42313 .21525 L
.42426 .21852 L
.42547 .22116 L
.42676 .22297 L
.42743 .22351 L
.42816 .2238 L
.42885 .22382 L
.42949 .22366 L
.43067 .22301 L
.43192 .22207 L
.43299 .22129 L
.43414 .22069 L
.43538 .22053 L
.43653 .22101 L
.43723 .22163 L
.4379 .22246 L
.43914 .22461 L
.44024 .2271 L
.4414 .23021 L
.44348 .23642 L
.44594 .24343 L
.44702 .24596 L
.44819 .24819 L
.44944 .2499 L
.45063 .25088 L
.4513 .25117 L
.452 .25132 L
.45326 .25125 L
.45442 .25098 L
.45552 .2507 L
.45671 .25056 L
.45801 .25079 L
.45931 .25161 L
.46006 .25237 L
.46075 .25328 L
.46214 .2557 L
.46363 .25902 L
.4688 .27239 L
.47013 .27516 L
.47138 .27719 L
.47268 .27868 L
.47337 .27922 L
.47411 .27962 L
.47543 .27996 L
.47668 .27998 L
.4778 .27992 L
.47902 .27994 L
.47977 .28006 L
Mistroke
.48048 .2803 L
.48112 .28064 L
.4818 .28115 L
.48256 .28189 L
.48335 .2829 L
.48477 .28527 L
.48732 .29097 L
.49011 .2981 L
.49135 .30103 L
.49269 .3038 L
.49396 .30588 L
.49514 .30729 L
.49579 .30787 L
.49651 .30835 L
.49725 .30869 L
.49796 .30888 L
.49919 .30901 L
.49989 .30902 L
.50053 .30902 L
.5017 .3091 L
.50279 .30936 L
.50399 .31 L
.50527 .31117 L
.50591 .31198 L
.50661 .31303 L
.50788 .31535 L
.51025 .32084 L
.51259 .32684 L
.51482 .33196 L
.51604 .33421 L
.51669 .33519 L
.51738 .33607 L
.51859 .3372 L
.51972 .33781 L
.52042 .33801 L
.52118 .33811 L
.52189 .33812 L
.52254 .33809 L
.52379 .33804 L
.5251 .33817 L
.52634 .33864 L
.5275 .33952 L
.52877 .34106 L
.53013 .34338 L
.55118 .36889 L
.57103 .39423 L
.5815 .41977 L
.5828 .424 L
.58404 .4271 L
.58472 .42833 L
Mistroke
.58547 .42925 L
.58678 .42974 L
.58753 .4294 L
.58834 .42857 L
.5891 .42742 L
.58978 .42612 L
.59115 .42314 L
.5926 .42002 L
.59387 .41794 L
.59459 .41725 L
.59527 .41705 L
.59645 .41787 L
.59773 .42064 L
.59844 .42309 L
.59922 .42647 L
.60063 .43431 L
.60328 .45261 L
.60458 .46158 L
.60581 .46868 L
.60709 .47368 L
.60777 .475 L
.6085 .47516 L
.60973 .47211 L
.61103 .46394 L
.61213 .45268 L
.61334 .43585 L
.61807 .33406 L
.62056 .27058 L
.6232 .21028 L
.62431 .18954 L
.6255 .17124 L
.62681 .15636 L
.62804 .14748 L
.62923 .14332 L
.63037 .14309 L
.63139 .14554 L
.6325 .15048 L
.63508 .16731 L
.6365 .17735 L
.63783 .18592 L
.63907 .19248 L
.63973 .19522 L
.64042 .19754 L
.64164 .20017 L
.64277 .20098 L
.64388 .20048 L
.64507 .19882 L
.64619 .19657 L
.64722 .19428 L
.64842 .1917 L
Mistroke
.64972 .18951 L
.65096 .1884 L
.6521 .18841 L
.6533 .18959 L
.65459 .19215 L
.65581 .19561 L
.65693 .19945 L
.65947 .20914 L
.66082 .21395 L
.66226 .21825 L
.66299 .22001 L
.66368 .22137 L
.66498 .2231 L
.66619 .22379 L
.66751 .22369 L
.66818 .22338 L
.66891 .22291 L
.67039 .22178 L
.67105 .22131 L
.67176 .22089 L
.67304 .22052 L
.67373 .22058 L
.67438 .22086 L
.67559 .22194 L
.6769 .22395 L
.67831 .22704 L
.68319 .24115 L
.68464 .2449 L
.68599 .24769 L
.68673 .24888 L
.6874 .24975 L
.68815 .25048 L
.68895 .25099 L
.69025 .25133 L
.69099 .25131 L
.69167 .25119 L
.6929 .25088 L
.69359 .25071 L
.69424 .2506 L
.69549 .25062 L
.69663 .25105 L
.69771 .25189 L
.69888 .25334 L
.70016 .25555 L
.70153 .25855 L
.704 .26496 L
.70679 .27216 L
.70816 .27504 L
.70942 .27712 L
.71057 .27849 L
Mistroke
.71179 .27941 L
.71301 .27987 L
.7137 .27997 L
.71434 .27999 L
.71561 .27994 L
.71624 .27991 L
.71694 .27992 L
.71818 .28015 L
.71935 .28073 L
.72002 .28125 L
.72072 .28196 L
.72197 .28369 L
.72332 .28616 L
.72479 .28946 L
.72958 .30134 L
.73096 .30411 L
.73226 .30615 L
.73343 .30748 L
.73469 .3084 L
.73585 .30883 L
.73712 .309 L
.73776 .30902 L
.73845 .30902 L
.73969 .30908 L
.74093 .30938 L
.7421 .31001 L
.74316 .31095 L
.74431 .31241 L
.74548 .31439 L
.74655 .31657 L
.74895 .32236 L
.75117 .32803 L
.75325 .33262 L
.75438 .33459 L
.75558 .33619 L
.75627 .33687 L
.75692 .33736 L
.75814 .33792 L
.75942 .33812 L
.76061 .33809 L
.76191 .33804 L
.76257 .33807 L
.7633 .33819 L
.76449 .33868 L
.76559 .33952 L
.7668 .34095 L
.76806 .34306 L
.7702 .3478 L
.77253 .35398 L
.77522 .36078 L
Mistroke
.77654 .36344 L
.77775 .36531 L
.77844 .3661 L
.77916 .36673 L
.77988 .36715 L
.78068 .36741 L
.78134 .36747 L
.78205 .36743 L
.78333 .36715 L
.78462 .36682 L
.78535 .36671 L
.78602 .36671 L
.78726 .36705 L
.78857 .36805 L
.78975 .36958 L
.79085 .37159 L
.79336 .3779 L
.79582 .38526 L
.79717 .38914 L
.79844 .39232 L
.79963 .39469 L
.80092 .39646 L
.80209 .39732 L
.80318 .39752 L
.80432 .3972 L
.80557 .39642 L
.8069 .3954 L
.80811 .3946 L
.8088 .39431 L
.80946 .39419 L
.81015 .39429 L
.8109 .39468 L
.81156 .3953 L
.81226 .39625 L
.81352 .39874 L
.81477 .40215 L
.81592 .40597 L
.81851 .41579 L
.82076 .42358 L
.82203 .42687 L
.82322 .42888 L
.8243 .4297 L
.82528 .42961 L
.82642 .42859 L
.8275 .42687 L
.82967 .42219 L
.83081 .41979 L
.83201 .41788 L
.83325 .41705 L
.83438 .41765 L
Mistroke
.83544 .4196 L
.83661 .42337 L
.83788 .42935 L
.83923 .43757 L
.84167 .45476 L
.843 .46362 L
.8437 .46763 L
.84444 .47113 L
.84509 .47341 L
.8458 .47491 L
.84705 .47454 L
.84827 .46993 L
.84957 .45981 L
.85081 .44519 L
.85193 .42763 L
.85653 .32465 L
.86086 .21921 L
.86203 .19618 L
.86326 .17599 L
.8639 .16729 L
.86461 .15928 L
.86585 .14913 L
.86697 .14411 L
.86818 .14284 L
.86932 .14499 L
.87036 .14924 L
.87279 .16455 L
.87544 .18293 L
.87665 .18993 L
.87793 .19563 L
.87903 .19888 L
.88024 .20071 L
.88143 .20087 L
.88251 .19985 L
.88377 .19766 L
.88496 .19506 L
.88599 .19278 L
.88708 .19064 L
.88828 .18897 L
.88939 .18829 L
.89007 .18836 L
.89079 .18885 L
.89208 .1908 L
.8928 .19243 L
.89347 .19427 L
.89499 .19934 L
.89775 .20982 L
.89896 .21409 L
.90027 .21803 L
.90154 .22094 L
Mistroke
.90271 .22272 L
.90384 .22363 L
.90503 .22383 L
.90628 .22338 L
.90745 .22258 L
.90875 .22159 L
.90946 .22111 L
.91013 .22076 L
.91141 .22052 L
.91256 .22091 L
.91365 .22189 L
.91482 .22364 L
.91612 .22636 L
.91749 .22994 L
.91996 .23728 L
.92233 .24393 L
.92364 .24686 L
.92488 .24897 L
.92558 .24985 L
.92635 .25056 L
.92704 .25099 L
.92768 .25123 L
.92895 .25132 L
.92966 .25121 L
.9303 .25106 L
.93146 .25076 L
.93269 .25056 L
.93374 .25065 L
.93488 .25114 L
.93612 .25222 L
.93681 .2531 L
.93745 .25407 L
.93983 .25905 L
.94419 .27048 L
.94638 .27527 L
.94763 .27728 L
.9488 .27862 L
.94964 .27927 L
.95052 .2797 L
.95127 .2799 L
.95209 .27999 L
.95297 .27998 L
.95392 .27993 L
.95481 .27991 L
.95562 .27999 L
.95643 .28021 L
.95718 .28056 L
.958 .28115 L
.95887 .28203 L
.96033 .28412 L
Mistroke
.96193 .28725 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Eooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0/ooooo`;o
o`005?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo02cooooo00?oo`00oooooooo
ool05oooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo02cooooo0_oo
000Dooooo`03o`000?oooooooooo01Kooooo0_oo000^ooooo`03ool00?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool000gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00Go
0000ooooooooooooooooo`00001Rooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
4oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01_ooooo0_oo000]ooooo`;oo`005?ooool00ol0003oooooooooo`0Fooooo`;o
o`00;_ooool2ool001Sooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo
00002oooool01?l0003oooooooooooooool2o`0001[ooooo0_l00?l^ooooo`03o`00oooooooooooo
01Cooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo
01Sooooo0ol0000Looooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2
o`0001cooooo0_oo000]ooooo`;oo`005?ooool00ol0003oooooooooo`0Fooooo`;oo`00;_ooool2
ool001Oooooo0_l0000>ooooo`005?ooool01?l0003oooooooooool00007ooooo`Co00001?ooool0
0ol0003oooooooooo`0Iooooo`03o`00oooooooo003o02gooooo00?o003oooooooooool05?ooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo02cooooo0_l00?lKooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool06ooo
ool2ool002gooooo0_oo000Dooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000;?oo
ool00ooo003oooooool0000Hooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00oooo
oooo003o02gooooo0_l00?lEooooo`03o`000?oooooooooo01Gooooo0_l00?l]ooooo`03o`00oooo
oooo003o01[ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06oooool2ool002gooooo0_oo000Dooooo`03o`00
0?oooooooooo01Kooooo00?oo`00oooooooo0000;?ooool00ooo003oooooool0000Hooooo`03o`00
0?oooooooooo00cooooo000Eooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool06Ooo
ool01?l00?ooooooooooool00?l/ooooo`03o`00oooooooo003o01Cooooo00?o0000ooooooooool0
5Oooool00ol00?ooooooo`00o`0/ooooo`04o`00ooooooooooooo`00oaWooooo00?o0000oooooooo
ool06oooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo01[ooooo00?oo`00oooooooo
0000;Oooool00ooo003oooooool0000Cooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo
0000;?ooool00ooo003oooooool0000Hooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Wooooo00Go003oooooooooooooooooo`00o`0[ooooo`04o`00ooooooooooooo`00
oa?ooooo00?o0000ooooooooool05Oooool01?l00?ooooooooooool00?l[ooooo`04o`00oooooooo
ooooo`00oaWooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`04ool00?oo
ooooooooool002cooooo00?oo`00oooooooo00004oooool00ol0003oooooooooo`0Fooooo`03ool0
0?ooooooo`0002cooooo00Coo`00ooooooooooooo`005oooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l0:oooool01?l00?oo
ooooooooool00?lCooooo`03o`000?oooooooooo01Gooooo00Go003oooooooooooooooooo`00o`0Z
ooooo`05o`00ooooooooooooooooool00?l06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01[ooooo00Coo`00ooooooooooooo`00;?ooool00ooo003oooooool0000Cooooo`03o`00
0?oooooooooo01Kooooo00?oo`00oooooooo0000;?ooool01?oo003ooooooooooooo000Gooooo`03
o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo02Sooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool05?ooool2o`00033ooooo00?o0000ooooooooool06_ooool01Ooo003o
oooooooooooo003ooooo00;oo`00:?ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
oooo00kooooo00?o0000ooooooooool05_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
oooo02Oooooo00Goo`00ooooooooooooo`00ooooo`02ool001Cooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01[ooooo00Goo`00ooooooooooooo`00ooooo`02ool002Sooooo00Goo`00ooooooooooooo`00
ooooo`03ool000oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`04ool002Sooooo
00Goo`00ooooooooooooo`00ooooo`02ool001Cooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool06Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool04oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo
00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0
0ooo00000oooooooo`00ooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0
0_oo00000oooooooo`00ooooo`0Wooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool0
4oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool06_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00?oo`00ooooooooool09Oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo
ool03Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00;oo`0000?oooooool00?oo
ool09oooool00ooo003oooooooooo`02ool00003oooooooo003ooooo01?ooooo00?o0000oooooooo
ool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00
0?oooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Uooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo017ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03?oo
ool002Oooooo0_l0000Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool05Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0@ooooo`;o0000<?ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo02Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol0
003oooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Jooooo`03ool00?oooooooooo00Gooooo0ooo000Tooooo`03ool00?oooooooooo
00Gooooo1?oo000;ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool01Oooool4ool0
02Cooooo00?oo`00ooooooooool01Oooool3ool0013ooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[o
oooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00go
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0Qooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool08Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00gooooo00?o
0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0P
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`09
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Joooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;oooo
o`;o0000<?ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo00Wooooo0_oo000Qoooo
o`03ool00?oooooooooo00Wooooo0_oo0009ooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool02_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0;ooooo`?o
o`007oooool00ooo003oooooooooo`0:ooooo`?oo`001oooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo00[ooooo0ooo000Pooooo`03ool00?oooooooooo00Wooooo1?oo000;ooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`0<ooooo`;oo`001_ooool00ol0003oooooooooo`0Eooooo`03ool0
0?oooooooooo00gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool07Ooo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Wooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Looooo`03ool00?oooooo
oooo00kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool03oooool00ooo
003oooooooooo`0Kooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0Eooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06oooool00ooo
003oooooooooo`0>ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03?ooool002Oo
oooo0_l0000Jooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`06ooooo`;o0000<?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00oo
oooo0ooo000Kooooo`03ool00?oooooooooo00kooooo0ooo0003ooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool03_ooool3ool001_ooooo00?oo`00ooooooooool03oooool2ool000So
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?ooool01Ol00?oooooo
oooooooooooo000001Oooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Wooooo00?oo`00ooooooooool04Oooool2ool001Wooooo00?oo`00oooooooo
ool04Oooool2ool000;ooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0@ooooo`;o
o`006_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool0000Gooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Booooo`04
ool00?ooooooooooo`0001Oooooo00?oo`00ooooooooool04Oooool2ool001Wooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo000Wooooo`03
o`000?oooooooooo01Wooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03
o`00oooooooooooo017ooooo00Co003ooooooooooooo00005oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool01?oo003oooooooooool0000G
ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0027ooooo0_l00004oooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01;ooooo00?o003oooooool000005oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo02Oooooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ool000005oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo000Pooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool04oooool00ol00?oo0000ooooo`0Foooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00?ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0F
ooooo`03ool00?oooooooooo01?ooooo0_oo00000ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool5
o`000003o`00ool0003o000001Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000E
o`000003o`00ool0003o000001Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000D
o`000003o`00ool0003o000001Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`000003
o`0002Sooooo00Co0000oooooooooooo00001?ooool4o`000003ool00?l0003o000001Go000000?o
o`00o`000?l000005?l00002ool001Ko000000?oo`00o`000?l000005?l00003ool001Go000000?o
o`00o`000?l000005?l00003ool001Ko000000?oo`00o`000?l000005Ol000000ooo003o0000o`00
0002o`0000kooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`000?l00?oooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool09_oo
ool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooooooo00005oooool00ooo003o
ooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05Oooool00ol0003o
o`00ooooo`0Dooooo`03ool00?oooooooooo01Kooooo0_oo000Eooooo`03ool00?oooooooooo01Wo
oooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00?o0000o`00ooooool05Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Eooooo`03o`000?ooooooo`0001Cooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0023o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01Cooooo00?o0000ooooool00?l05Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Vooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
o`0001Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooo
oooo01Wooooo00?o0000ooooooooool03?ooool0027ooooo0_l00004ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool05?ooool01?l0003oooooooooool00?lDooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo02Oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooool0000Dooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool05?ooool01Ol0003ooooooooooooooooo003o01?ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool06Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Gooooo00Co0000
ooooooooooooo`004oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool2o`0000Oooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo0_l0000`
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0I
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`03
ool0017ooooo00?oo`00ooooooooool06Oooool3ool0017ooooo00?oo`00ooooooooool06Oooool0
0ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
01_ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo
00oooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`0?ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`0Looooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06Oooool00ol0003o
ooooooooo`0<ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Cooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01cooooo
00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool00ooo003ooooooooo
o`0Looooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06Oooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01kooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool2o`0000_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool05?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Wooooo0_l0000`oooo
o`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Ooooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`07oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool07Oooool4ool000cooooo00?oo`00oooo
ooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0;ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01Cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Jooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Pooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
8?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0=ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01Cooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo027ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Wooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Qooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool02?ooool0
0ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
01Cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo
02?ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Rooooo`04ool00?ooooooo`00
ool000Oooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00
013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
01Wooooo0_l0000`ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`0Sooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool05Oooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool08oooool3ool0
00Oooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0Uooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o0000ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Cooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Fooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Vooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool06_ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool09_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Cooooo00?o0000
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool09_ooool0
1?oo003oooooool00?oo0002ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool03Ooo
ool01?oo003oooooool00?oo0002ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0
0_oo0002ooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01;ooooo1?oo
0002ooooo`03ool00?oooooooooo02Kooooo00Coo`00oooooooo003oo`000_ooool00ooo003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00gooooo00Ooo`00oooooooo003oooooool00?ooooooo`00
02Wooooo0_oo00001Oooooooo`00ooooooooooooo`0001cooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01;ooooo0_oo00001Oooooooo`00ooooooooooooo`0002Wooooo00Koo`00ooooooooooooo`00oooo
oooo000Hooooo`03o`000?oooooooooo00kooooo0_oo00001?ooooooo`00oooooooo000Yooooo`;o
o`0000Goooooool00?ooooooooooool0000Looooo`03o`000?oooooooooo00cooooo000Wooooo`;o
00005_ooool01Ol00?oooooooooooooooooo003o02_ooooo00Go003oooooooooooooooooo`00o`0F
ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000
ooooooooool05Oooool01?oo003ooooooooooooo000/ooooo`03ool00?ooooooo`0001Sooooo00?o
0000ooooooooool04Oooool00ooo003oooooool0000/ooooo`04ool00?ooooooooooool001cooooo
00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool05_ooool01?l00?oooooooooo
ool00?l[ooooo`05o`00ooooooooooooooooool00?l05_ooool00ol0003oooooooooo`0Aooooo`05
o`00ooooooooooooooooool00?l0:_ooool01Ol00?oooooooooooooooooo003o01cooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Fooooo`03ool00?ooooooo`0002cooooo00?oo`00
oooooooo00006?ooool00ol0003oooooooooo`0Aooooo`03ool00?ooooooo`0002cooooo00Coo`00
ooooooooooooo`007?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooo003o02cooooo00Co003ooooooooooooo003o5_ooool00ol0003ooooooooo
o`0Booooo`04o`00ooooooooooooo`00ob_ooooo00Co003ooooooooooooo003o7?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000;?ooool00ooo003o
ooooool0000Hooooo`03o`000?oooooooooo017ooooo00?oo`00oooooooo0000;?ooool01?oo003o
oooooooooooo000Looooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo003o02go
oooo00?o003oooooool00?l05_ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo003o02co
oooo00?o003oooooool00?l07?ooool00ol0003oooooooooo`0Kooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Fooooo`03ool00?ooooooo`0002co
oooo00?oo`00oooooooo00006?ooool00ol0003oooooooooo`0Aooooo`03ool00?ooooooo`0002go
oooo00?oo`00oooooooo00007?ooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Hoooo
o`;o003o;Oooool00ol00?ooooooo`00o`0Fooooo`03o`000?oooooooooo01?ooooo00?o003ooooo
ool00?l0;Oooool2o`00oacooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Fooooo`03ool00?oo
ooooo`0002cooooo00?oo`00oooooooo00006?ooool00ol0003oooooooooo`0Aooooo`03ool00?oo
ooooo`0002gooooo0_oo000Mooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?oooooo
ooooo`0000_ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`00oooooooooooo02cooooo
0_l00?lFooooo`03o`000?oooooooooo01Cooooo0_l00?l]ooooo`;o003o7?ooool00ol0003ooooo
ooooo`0Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Fooooo`03ool00?ooooooo`0002cooooo00?oo`00oooooooo00006?ooool00ol0003o
ooooooooo`0Aooooo`03ool00?ooooooo`0002gooooo0_oo000Mooooo`03o`000?oooooooooo00co
oooo000Dooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0_l0000Joooo
o`03o`00oooooooooooo02gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo02cooooo00?o003oooooooooool06?ooool3o`0001cooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00005oooool00ooo003oooooool0000/
ooooo`03ool00?ooooooo`0001Sooooo00?o0000ooooooooool04_ooool2ool002gooooo0_oo000L
ooooo`;o00003_ooool001Cooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co0000
oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool05_ooool2ool002kooooo0_oo
000Hooooo`03o`000?oooooooooo01;ooooo0_oo000]ooooo`;oo`007Oooool00ol0003ooooooooo
o`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo
0_oo000]ooooo`;oo`007Oooool00ol0003oooooooooo`0<ooooo`005Oooool2o`0000Sooooo1Ol0
0003ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0Kooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qooooo`03
o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00co
oooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000W
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<
ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0H?oo
ool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Q
ooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`?o0000
1?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
9_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool00000
3_ooool0027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o0000:Oooool00ol0003ooooooooo
o`04ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_l0000>ooooo`008Oooool00ol0003oooooooooo`03ooooolSo0000:Oooool0
0ol0003oooooooooo`04ooooolOo00003_ooool0023ooooo0_l0003eooooo`;o0000foooool0027o
oooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`3Iooooo`00oooooooeooooo`00oooo
oooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}],

Cell[BoxData[
    \(TraditionalForm\`\(sin(2\ \[Pi]\ t)\)\/\[Pi] - \(sin(4\ \[Pi]\ \
t)\)\/\(2\ \[Pi]\) + \(sin(6\ \[Pi]\ t)\)\/\(3\ \[Pi]\) - \(sin(8\ \[Pi]\ \
t)\)\/\(4\ \[Pi]\) + \(sin(10\ \[Pi]\ t)\)\/\(5\ \[Pi]\) - \(sin(12\ \[Pi]\ \
t)\)\/\(6\ \[Pi]\) + \(sin(14\ \[Pi]\ t)\)\/\(7\ \[Pi]\) - \(sin(16\ \[Pi]\ \
t)\)\/\(8\ \[Pi]\) + \(sin(18\ \[Pi]\ t)\)\/\(9\ \[Pi]\) - \(sin(20\ \[Pi]\ \
t)\)\/\(10\ \[Pi]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Even more terms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[SawTooth1[t], t, 100];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], 
        ImageSize \[Rule] 500];\)\), "\[IndentingNewLine]", 
    \(\(series\  // \ ComplexExpand\)\  // TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .32105 L
.04339 .33418 L
.05298 .34651 L
.06221 .35836 L
.07203 .37098 L
.08148 .38313 L
.09153 .39604 L
.10121 .40848 L
.11052 .42044 L
.12043 .43318 L
.12997 .44543 L
.13476 .45159 L
.13914 .45722 L
.14029 .4587 L
.14155 .46032 L
.14213 .46106 L
.14244 .46147 L
.14274 .46185 L
.14302 .15625 L
.14332 .15663 L
.14385 .15731 L
.14891 .16381 L
.15885 .17659 L
.16842 .18889 L
.17763 .20072 L
.18743 .21331 L
.19686 .22543 L
.20688 .23832 L
.21654 .25073 L
.22584 .26267 L
.23572 .27537 L
.24524 .28761 L
.25439 .29937 L
.26414 .31189 L
.27352 .32394 L
.28349 .33676 L
.2931 .3491 L
.30234 .36097 L
.31217 .37361 L
.32163 .38577 L
.33169 .3987 L
.34139 .41115 L
.35071 .42314 L
.36063 .43588 L
.37018 .44816 L
.37498 .45433 L
.37708 .45702 L
.37937 .45996 L
.37998 .46074 L
Mistroke
.38031 .46117 L
.38062 .46157 L
.38092 .46195 L
.38123 .1564 L
.38152 .15677 L
.38179 .15711 L
.38408 .16006 L
.38915 .16657 L
.39873 .17889 L
.40795 .19073 L
.41776 .20334 L
.42721 .21548 L
.43725 .22838 L
.44692 .24081 L
.45623 .25277 L
.46613 .26549 L
.47566 .27774 L
.48482 .28951 L
.49458 .30205 L
.50397 .31412 L
.51396 .32695 L
.52358 .33931 L
.53283 .3512 L
.54267 .36385 L
.55215 .37603 L
.56222 .38898 L
.57193 .40145 L
.58127 .41345 L
.5912 .42621 L
.60076 .4385 L
.60996 .45032 L
.61469 .45639 L
.61605 .45814 L
.61734 .4598 L
.6179 .46052 L
.61849 .46128 L
.6188 .46168 L
.61898 .46191 L
.61915 .15617 L
.61944 .15654 L
.61975 .15695 L
.62972 .16975 L
.63932 .18208 L
.64855 .19395 L
.65837 .20657 L
.66783 .21873 L
.67788 .23164 L
.68757 .24409 L
.69688 .25606 L
.7068 .2688 L
Mistroke
.71634 .28106 L
.72552 .29285 L
.73529 .30541 L
.74469 .3175 L
.75469 .33034 L
.76432 .34272 L
.77359 .35462 L
.78345 .36729 L
.79294 .37949 L
.80302 .39245 L
.81274 .40494 L
.82209 .41695 L
.83203 .42973 L
.84161 .44204 L
.85082 .45387 L
.85325 .457 L
.85556 .45996 L
.85617 .46075 L
.85651 .46118 L
.85683 .46159 L
.85699 .4618 L
.85717 .15607 L
.85736 .15632 L
.85755 .15656 L
.85821 .15741 L
.86063 .16052 L
.87024 .17287 L
.87948 .18474 L
.88932 .19739 L
.89879 .20955 L
.90885 .22249 L
.91855 .23495 L
.92788 .24694 L
.93781 .25969 L
.94736 .27197 L
.95655 .28378 L
.96634 .29636 L
.97575 .30846 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.06244 .35815 L
.08255 .38515 L
.10458 .41225 L
.11448 .42422 L
.12507 .44121 L
.1302 .44724 L
.13143 .44597 L
.13273 .44942 L
.13384 .44914 L
.13506 .45296 L
.13716 .45973 L
.13832 .44959 L
.13942 .46721 L
.1407 .44678 L
.14186 .48377 L
.14296 .28341 L
.14415 .13156 L
.1448 .16322 L
.14548 .1711 L
.1467 .15367 L
.14802 .16616 L
.14877 .15748 L
.14946 .16557 L
.15073 .16431 L
.15188 .16894 L
.15252 .17188 L
.15321 .16701 L
.15447 .17348 L
.15559 .17042 L
.15683 .17604 L
.15812 .17341 L
.15933 .17934 L
.16046 .17678 L
.16149 .18128 L
.16263 .18041 L
.16382 .184 L
.16514 .1833 L
.16633 .18753 L
.16699 .18766 L
.16771 .18648 L
.16901 .19104 L
.17023 .18992 L
.17153 .19394 L
.17263 .19313 L
.17384 .19693 L
.17457 .1959 L
.17527 .19718 L
.17657 .19951 L
.17797 .20163 L
Mistroke
.17877 .20278 L
.1795 .20211 L
.18019 .20407 L
.18085 .20584 L
.18207 .20549 L
.18338 .20887 L
.18412 .20825 L
.1848 .20966 L
.18607 .21164 L
.18726 .21307 L
.18951 .21569 L
.19456 .22281 L
.20366 .23382 L
.22434 .26031 L
.26272 .30966 L
.30355 .36281 L
.32385 .38805 L
.34287 .41216 L
.35175 .42506 L
.36108 .43787 L
.36344 .44111 L
.36597 .44382 L
.36671 .44111 L
.36742 .4453 L
.36873 .44456 L
.36997 .45017 L
.37067 .45062 L
.37131 .44611 L
.37251 .45522 L
.37382 .4477 L
.37506 .46056 L
.3762 .44823 L
.37723 .4664 L
.37837 .44607 L
.37956 .48342 L
.38067 .37833 L
.38177 .14661 L
.38293 .16487 L
.3842 .15352 L
.38536 .1665 L
.38661 .1587 L
.38776 .16839 L
.38904 .16268 L
.38975 .16619 L
.39039 .17203 L
.39156 .16626 L
.39263 .17386 L
.39381 .17002 L
.39506 .17667 L
.39615 .17351 L
Mistroke
.39716 .17808 L
.39828 .17752 L
.39948 .18064 L
.40014 .18229 L
.40085 .18013 L
.40212 .18484 L
.4029 .18412 L
.40364 .18371 L
.40429 .18698 L
.40501 .18785 L
.41026 .19282 L
.42013 .20543 L
.46115 .25943 L
.50066 .30939 L
.53865 .35818 L
.55981 .38519 L
.5791 .41003 L
.58868 .42245 L
.59909 .43798 L
.60386 .4445 L
.60502 .4417 L
.60627 .44778 L
.60699 .44388 L
.60764 .44617 L
.60893 .44934 L
.61004 .44926 L
.61122 .45323 L
.61336 .45964 L
.61451 .44957 L
.61559 .46735 L
.61687 .44629 L
.61802 .48498 L
.61918 .27531 L
.62042 .13383 L
.62159 .17263 L
.62266 .15067 L
.62391 .16953 L
.62462 .15965 L
.62527 .15973 L
.62648 .16901 L
.62776 .16517 L
.62845 .17193 L
.6291 .16929 L
.6298 .16651 L
.63054 .17263 L
.63179 .17038 L
.6325 .17207 L
.63316 .17668 L
.6344 .17339 L
.63552 .17935 L
Mistroke
.63682 .1768 L
.63805 .1824 L
.63912 .18001 L
.64029 .18503 L
.64151 .18326 L
.64265 .18791 L
.64372 .18645 L
.6447 .18967 L
.64583 .19 L
.6469 .19188 L
.65651 .20457 L
.69469 .25376 L
.73532 .30588 L
.77444 .35527 L
.79441 .38203 L
.81601 .40974 L
.82615 .4211 L
.83687 .43767 L
.84128 .44248 L
.84372 .44617 L
.84491 .44463 L
.84602 .44892 L
.84732 .44699 L
.84801 .4479 L
.84874 .45541 L
.84991 .44782 L
.85121 .46054 L
.85242 .44827 L
.85372 .46713 L
.85494 .44589 L
.85607 .48666 L
.85734 .25867 L
.85855 .13501 L
.85963 .17339 L
.8608 .151 L
.86208 .16902 L
.86273 .15951 L
.86343 .1606 L
.86586 .16531 L
.87057 .17189 L
.87498 .17691 L
.89568 .20547 L
.93449 .25509 L
.95423 .2813 L
.9654 .29498 L
.97041 .30177 L
.97321 .30568 L
.97452 .30641 L
.97575 .3089 L
.97619 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0I
ooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`18
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool0A?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo02cooooo00?oo`00oooo
ooooool06Oooool00ol0003oooooooooo`0<ooooo`005Oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo01_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo01Wooooo00?oo`00ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo02cooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`00
5?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`0Iooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool05?ooool00ol0003ooooooooo
o`0Eooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool06Oooool00ol0003ooooooooo
o`0<ooooo`003Oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooo
oooooooo000006;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Cooooo`Go0000
0_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06Oooool2ool002kooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo02cooooo0_oo000Jooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`00
0?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0_l0000Jooooo`;o003o;_ooool00ol0
0?ooooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0;?ooool00ol0
0?ooooooooooo`0Hooooo`?o00007?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Jooooo`;oo`00;_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Gooooo00?oo`00ooooooooool0;?ooool2ool001Wooooo0_l0000>ooooo`005?ooool01?l0
003oooooooooool00007ooooo`Co00001?ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
003o02gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooo
oooo02cooooo0_l00?lKooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001ooo
ool4o`0000Gooooo00?o0000ooooooooool06Oooool2ool002kooooo0_oo000Eooooo`03o`000?oo
oooooooo01Gooooo0_oo000]ooooo`;oo`006_ooool00ol0003oooooooooo`0<ooooo`005?ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Ooo
ool00ol00?ooooooo`00o`0]ooooo`;o003o5Oooool00ol0003oooooooooo`0Eooooo`;o003o;Ooo
ool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo0ooo000]ooooo`;oo`00
5Oooool00ol0003oooooooooo`0Eooooo`?oo`00;?ooool3ool001Wooooo00?o0000ooooooooool0
3?ooool001Gooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0Iooooo`04o`00oooo
ooooooooo`00obcooooo00?o003oooooool00?l05?ooool00ol0003oooooooooo`0Eooooo`03o`00
oooooooo003o02cooooo00Co003ooooooooooooo003o6Oooool00ol0003oooooooooo`0Kooooo`;o
00002?ooool5o`0000Cooooo00?o0000ooooooooool06Oooool4ool002cooooo0ooo000Dooooo`03
o`000?oooooooooo01Gooooo1?oo000[ooooo`04ool00?ooooooooooool001Sooooo00?o0000oooo
ooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool01Ol00?oooooooooooooooooo003o
02_ooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0Eooooo`04o`00oooooooo
ooooo`00ob_ooooo00Co003ooooooooooooo003o6Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Wooooo00?oo`00ooooooooool00_oo000[ooooo`04ool00?ooooooo`00ool001?o
oooo00?o0000ooooooooool05Oooool01?oo003oooooool00?oo000[ooooo`04ool00?oooooooooo
ool001Sooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool01Ol0
0?oooooooooooooooooo003o02_ooooo00Co003ooooooooooooo003o4oooool00ol0003ooooooooo
o`0Eooooo`05o`00ooooooooooooooooool00?l0:_ooool01Ol00?oooooooooooooooooo003o01So
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00?o
o`00:_ooool00ooo003oooooooooo`02ool001;ooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`02ool002[ooooo00Coo`00ooooooooooooo`006?ooool00ol0003oooooooooo`0<oooo
o`009oooool2o`0001[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`05
o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Cooooo0_l0000`ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0Xooooo`05ool00?oooooooooooooooooo00004_ooool00ol0003oooooooooo`0E
ooooo`04ool00?ooooooooooooooo`;oo`00:Oooool01Ooo003oooooooooooooooooo`0001Oooooo
00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0?ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Vooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool00_ooool2ool002Wooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0C
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`03
ooooo`;oo`00:?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00oooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo00Cooooo0_oo000Wooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool09_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01;ooooo00?o0000oooo
ooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Uooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo017ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
6Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0
1Oooool2ool002Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0=ooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Uooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`009ooo
ool2o`0001[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo013ooooo0_l0000`ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03?oo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09?oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ol0
003oooooooooo`0Eooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool08_ooool00ooo
003oooooooooo`07ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool03oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wo
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0Qooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool03Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool07oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool05Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0;ooooo`;o0000<?ooool00ol0003oooooooooo`0I
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0;
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool07oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01gooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000Wooooo`03
o`000?oooooooooo01Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo01gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0
5Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo01_ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Iooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06oooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool05Oooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool03_ooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool2o`00
033ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
01[ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo
00oooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`0@ooooo`05o`00ooooooooooooooooool000005oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04Oooool01Ooo003ooooooooooooooooo
000001Oooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooo
oooo013ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0
003oooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0Aooooo`04o`00ooooooooooooo`0001Oooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo00Goo`00ooooooooooooooooo`00
000Gooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06?ooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool04Oooool01?l00?ooooooooooool0000Gooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Booooo`04ool00?ooooooooooo`0001Oooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`008Oooool2o`0000Cooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool04_ooool00ol00?ooooooo`00000Gooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool09oooool2o`0000Gooooo00?o0000ooooooooool06Oooool00ooo003ooooooooo
o`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo003oooooo`00
000Gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0023ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0Cooooo`03o`00ool0003ooooo01Kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool00oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool05?ooool00ooo003o0000ooooo`0Fooooo`03ool00?oooooooooo01?ooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool5o`000003o`00
ool0003o000001Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00
ool0003o000001Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Do`000003o`00
ool0003o000001Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`000003o`0002Sooooo
00Co0000oooooooooooo00001?ooool4o`000003ool00?l0003o000001Go000000?oo`00o`000?l0
00005Ol000000ooo003o0000o`00000Do`000003ool00?l0003o000001Go000000?oo`00o`000?l0
00005Ol000000ooo003o0000o`00000Do`000003ool00?l0003o000001Go000000?oo`00o`000?l0
00005?l00002ool000Co00003_ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o0000o`00ooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooool0000G
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00?o0000
o`00ooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Kooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`0Eooooo`03o`000?oo003ooooo01Gooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Wooooo00?o
0000ooooooooool03?ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`0Cooooo`03o`00oooooooooooo01Cooooo00?o0000ooooool00?l05Oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06_ooool00ol0003ooooooooo
o`0Vooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`0Eooooo`03o`000?ooooooo`0001Gooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0027ooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05?ooool01?l0003ooooooooo
ool00?lDooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Jooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool05Oooool01?l0003ooooooooooooo000Dooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00co
oooo000Wooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05?ooool01Ol0003ooooo
oooooooooooo003o01?ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo01Gooooo00Go0000ooooooooooooooooool0000Cooooo`03ool00?oooooooooo
01Sooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o00001oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`0Aooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04?ooool00ooo003o
ooooooooo`0Eooooo`05o`000?oooooooooooooooooo00004oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Cooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01_ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01[ooooo00?oo`00oooooooo
ool03oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool04?ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo013ooooo00?oo`00oooooooo
ool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Jooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0?ooooo`03ool0
0?oooooooooo01[ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo00oooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?oo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06Ooo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooo
oooo01cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooo
oooo00kooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0
003oooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool03Oooool00ooo
003oooooooooo`0Looooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool06Oooool00ol0
003oooooooooo`0<ooooo`009oooool2o`0000_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Wooooo0_l0000`ooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01Wo
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool06_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`0Nooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool05Oooool00ol0003ooooo
ooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07Oooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool07_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo01Wooooo00?o
0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0P
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`09
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00Sooooo00?oo`00oooo
ooooool05Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooo
ooooool08Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool002Oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00kooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Qooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000@ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01Cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Iooooo`;o0000
<?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
8_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
2oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo013ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0?ooooo`03ool00?oo
oooooooo00Oooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Gooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo02Cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Iooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool03Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
02Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool09oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Oooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Xooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05?ooool00ol0003ooooooooo
o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Cooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00005_ooool01Ol00?oooooooooooooo
oooo003o02_ooooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool05?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo02Sooooo00Goo`00ooooooooooooooooool0000Gooooo`03
o`000?oooooooooo013ooooo00Goo`00ooooooooooooooooool0000Zooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`0Fooooo`04o`00ooooooooooooo`00ob_ooooo00Go003oooooooooooooooooo`00o`0F
ooooo`03o`000?oooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Zooooo`05o`00oooo
ooooooooooooool00?l07?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo
00Goo`00ooooooooooooooooool0000Zooooo`?oo`0000?oooooool00?ooool05_ooool00ol0003o
ooooooooo`0Aooooo`04ool00?ooooooooooool002_ooooo00Goo`00ooooooooooooooooool0000K
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Oooooo00?o003ooooo
ool00?l0;?ooool01?l00?ooooooooooool00?lFooooo`03o`000?oooooooooo01;ooooo00Co003o
oooooooooooo003o:oooool01?l00?ooooooooooool00?lLooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool05_ooool2ool00003oooooooo003ooooo02[ooooo0_oo00000oooooooo`00
ooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?oo`00oooooooo0000;?ooool01?oo003ooooo
ool00?oo000Kooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo003o02gooooo
00?o003oooooool00?l05_ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo003o02cooooo
00?o003oooooool00?l07?ooool00ol0003oooooooooo`0Kooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Gooooo`?oo`00;?ooool3ool001Oooooo
00?o0000ooooooooool04_ooool3ool002gooooo0ooo000Kooooo`03o`000?oooooooooo00cooooo
000Dooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo01Sooooo0_l00?l]ooooo`03o`00oooooooo003o01Kooooo00?o0000oooooooo
ool04oooool00ol00?ooooooo`00o`0]ooooo`;o003o7?ooool00ol0003oooooooooo`0Jooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo01Sooooo0_oo000]ooooo`;oo`005oooool00ol0003oooooooooo`0Cooooo`;oo`00;Oooool3
ool001_ooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00002oooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o003oooooooooool0;?ooool2o`00oaKooooo00?o
0000ooooooooool05?ooool2o`00obgooooo0_l00?lLooooo`03o`000?oooooooooo01[ooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
0_oo000]ooooo`;oo`005oooool00ol0003oooooooooo`0Cooooo`;oo`00;_ooool2ool001_ooooo
00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00002oooool01?l0003ooooo
ooooooooool2o`0001[ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0Dooooo`03
o`000?oooooooooo01Gooooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`0Hooooo`?o
00007?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Ioooo
o`;oo`00;_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?oo`00oooo
ooooool0;?ooool2ool001[ooooo0_l0000>ooooo`005?ooool01?l0003oooooooooool00007oooo
o`Co00001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0H
ooooo`;oo`00;_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool0;?ooool2ool001_ooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo02cooooo00?o
o`00ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`005Oooool2o`0000Sooooo1Ol00003
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0K
ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0/
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0]
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool06Oooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo01Gooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`14ooooo`03
ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qooooo`03o`00
0?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0H?ooool2
o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`?o00001?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09_oo
ool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo00cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool000003_oo
ool0027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o0000:Oooool00ol0003oooooooooo`04
ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_l0000>ooooo`008Oooool00ol0003oooooooooo`03ooooolSo0000:Oooool00ol0
003oooooooooo`04ooooolOo00003_ooool0023ooooo0_l0003eooooo`;o0000foooool0027ooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`3Iooooo`00oooooooeooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}],

Cell[BoxData[
    \(TraditionalForm\`\(sin(2\ \[Pi]\ t)\)\/\[Pi] - \(sin(4\ \[Pi]\ \
t)\)\/\(2\ \[Pi]\) + \(sin(6\ \[Pi]\ t)\)\/\(3\ \[Pi]\) - \(sin(8\ \[Pi]\ \
t)\)\/\(4\ \[Pi]\) + \(sin(10\ \[Pi]\ t)\)\/\(5\ \[Pi]\) - \(sin(12\ \[Pi]\ \
t)\)\/\(6\ \[Pi]\) + \(sin(14\ \[Pi]\ t)\)\/\(7\ \[Pi]\) - \(sin(16\ \[Pi]\ \
t)\)\/\(8\ \[Pi]\) + \(sin(18\ \[Pi]\ t)\)\/\(9\ \[Pi]\) - \(sin(20\ \[Pi]\ \
t)\)\/\(10\ \[Pi]\) + \(sin(22\ \[Pi]\ t)\)\/\(11\ \[Pi]\) - \(sin(24\ \[Pi]\ \
t)\)\/\(12\ \[Pi]\) + \(sin(26\ \[Pi]\ t)\)\/\(13\ \[Pi]\) - \(sin(28\ \[Pi]\ \
t)\)\/\(14\ \[Pi]\) + \(sin(30\ \[Pi]\ t)\)\/\(15\ \[Pi]\) - \(sin(32\ \[Pi]\ \
t)\)\/\(16\ \[Pi]\) + \(sin(34\ \[Pi]\ t)\)\/\(17\ \[Pi]\) - \(sin(36\ \[Pi]\ \
t)\)\/\(18\ \[Pi]\) + \(sin(38\ \[Pi]\ t)\)\/\(19\ \[Pi]\) - \(sin(40\ \[Pi]\ \
t)\)\/\(20\ \[Pi]\) + \(sin(42\ \[Pi]\ t)\)\/\(21\ \[Pi]\) - \(sin(44\ \[Pi]\ \
t)\)\/\(22\ \[Pi]\) + \(sin(46\ \[Pi]\ t)\)\/\(23\ \[Pi]\) - \(sin(48\ \[Pi]\ \
t)\)\/\(24\ \[Pi]\) + \(sin(50\ \[Pi]\ t)\)\/\(25\ \[Pi]\) - \(sin(52\ \[Pi]\ \
t)\)\/\(26\ \[Pi]\) + \(sin(54\ \[Pi]\ t)\)\/\(27\ \[Pi]\) - \(sin(56\ \[Pi]\ \
t)\)\/\(28\ \[Pi]\) + \(sin(58\ \[Pi]\ t)\)\/\(29\ \[Pi]\) - \(sin(60\ \[Pi]\ \
t)\)\/\(30\ \[Pi]\) + \(sin(62\ \[Pi]\ t)\)\/\(31\ \[Pi]\) - \(sin(64\ \[Pi]\ \
t)\)\/\(32\ \[Pi]\) + \(sin(66\ \[Pi]\ t)\)\/\(33\ \[Pi]\) - \(sin(68\ \[Pi]\ \
t)\)\/\(34\ \[Pi]\) + \(sin(70\ \[Pi]\ t)\)\/\(35\ \[Pi]\) - \(sin(72\ \[Pi]\ \
t)\)\/\(36\ \[Pi]\) + \(sin(74\ \[Pi]\ t)\)\/\(37\ \[Pi]\) - \(sin(76\ \[Pi]\ \
t)\)\/\(38\ \[Pi]\) + \(sin(78\ \[Pi]\ t)\)\/\(39\ \[Pi]\) - \(sin(80\ \[Pi]\ \
t)\)\/\(40\ \[Pi]\) + \(sin(82\ \[Pi]\ t)\)\/\(41\ \[Pi]\) - \(sin(84\ \[Pi]\ \
t)\)\/\(42\ \[Pi]\) + \(sin(86\ \[Pi]\ t)\)\/\(43\ \[Pi]\) - \(sin(88\ \[Pi]\ \
t)\)\/\(44\ \[Pi]\) + \(sin(90\ \[Pi]\ t)\)\/\(45\ \[Pi]\) - \(sin(92\ \[Pi]\ \
t)\)\/\(46\ \[Pi]\) + \(sin(94\ \[Pi]\ t)\)\/\(47\ \[Pi]\) - \(sin(96\ \[Pi]\ \
t)\)\/\(48\ \[Pi]\) + \(sin(98\ \[Pi]\ t)\)\/\(49\ \[Pi]\) - \(sin(100\ \[Pi]\
\ t)\)\/\(50\ \[Pi]\) + \(sin(102\ \[Pi]\ t)\)\/\(51\ \[Pi]\) - \(sin(104\ \
\[Pi]\ t)\)\/\(52\ \[Pi]\) + \(sin(106\ \[Pi]\ t)\)\/\(53\ \[Pi]\) - \
\(sin(108\ \[Pi]\ t)\)\/\(54\ \[Pi]\) + \(sin(110\ \[Pi]\ t)\)\/\(55\ \[Pi]\) \
- \(sin(112\ \[Pi]\ t)\)\/\(56\ \[Pi]\) + \(sin(114\ \[Pi]\ t)\)\/\(57\ \[Pi]\
\) - \(sin(116\ \[Pi]\ t)\)\/\(58\ \[Pi]\) + \(sin(118\ \[Pi]\ t)\)\/\(59\ \
\[Pi]\) - \(sin(120\ \[Pi]\ t)\)\/\(60\ \[Pi]\) + \(sin(122\ \[Pi]\ \
t)\)\/\(61\ \[Pi]\) - \(sin(124\ \[Pi]\ t)\)\/\(62\ \[Pi]\) + \(sin(126\ \
\[Pi]\ t)\)\/\(63\ \[Pi]\) - \(sin(128\ \[Pi]\ t)\)\/\(64\ \[Pi]\) + \
\(sin(130\ \[Pi]\ t)\)\/\(65\ \[Pi]\) - \(sin(132\ \[Pi]\ t)\)\/\(66\ \[Pi]\) \
+ \(sin(134\ \[Pi]\ t)\)\/\(67\ \[Pi]\) - \(sin(136\ \[Pi]\ t)\)\/\(68\ \[Pi]\
\) + \(sin(138\ \[Pi]\ t)\)\/\(69\ \[Pi]\) - \(sin(140\ \[Pi]\ t)\)\/\(70\ \
\[Pi]\) + \(sin(142\ \[Pi]\ t)\)\/\(71\ \[Pi]\) - \(sin(144\ \[Pi]\ \
t)\)\/\(72\ \[Pi]\) + \(sin(146\ \[Pi]\ t)\)\/\(73\ \[Pi]\) - \(sin(148\ \
\[Pi]\ t)\)\/\(74\ \[Pi]\) + \(sin(150\ \[Pi]\ t)\)\/\(75\ \[Pi]\) - \
\(sin(152\ \[Pi]\ t)\)\/\(76\ \[Pi]\) + \(sin(154\ \[Pi]\ t)\)\/\(77\ \[Pi]\) \
- \(sin(156\ \[Pi]\ t)\)\/\(78\ \[Pi]\) + \(sin(158\ \[Pi]\ t)\)\/\(79\ \[Pi]\
\) - \(sin(160\ \[Pi]\ t)\)\/\(80\ \[Pi]\) + \(sin(162\ \[Pi]\ t)\)\/\(81\ \
\[Pi]\) - \(sin(164\ \[Pi]\ t)\)\/\(82\ \[Pi]\) + \(sin(166\ \[Pi]\ \
t)\)\/\(83\ \[Pi]\) - \(sin(168\ \[Pi]\ t)\)\/\(84\ \[Pi]\) + \(sin(170\ \
\[Pi]\ t)\)\/\(85\ \[Pi]\) - \(sin(172\ \[Pi]\ t)\)\/\(86\ \[Pi]\) + \
\(sin(174\ \[Pi]\ t)\)\/\(87\ \[Pi]\) - \(sin(176\ \[Pi]\ t)\)\/\(88\ \[Pi]\) \
+ \(sin(178\ \[Pi]\ t)\)\/\(89\ \[Pi]\) - \(sin(180\ \[Pi]\ t)\)\/\(90\ \[Pi]\
\) + \(sin(182\ \[Pi]\ t)\)\/\(91\ \[Pi]\) - \(sin(184\ \[Pi]\ t)\)\/\(92\ \
\[Pi]\) + \(sin(186\ \[Pi]\ t)\)\/\(93\ \[Pi]\) - \(sin(188\ \[Pi]\ \
t)\)\/\(94\ \[Pi]\) + \(sin(190\ \[Pi]\ t)\)\/\(95\ \[Pi]\) - \(sin(192\ \
\[Pi]\ t)\)\/\(96\ \[Pi]\) + \(sin(194\ \[Pi]\ t)\)\/\(97\ \[Pi]\) - \
\(sin(196\ \[Pi]\ t)\)\/\(98\ \[Pi]\) + \(sin(198\ \[Pi]\ t)\)\/\(99\ \[Pi]\) \
- \(sin(200\ \[Pi]\ t)\)\/\(100\ \[Pi]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency domain plots", "Subsubsection"],

Cell[BoxData[
    \(\(ftbl\  = \ 
        Table[{k, 
            FourierCoefficient[SawTooth1[t], t, k, \ 
              FourierParameters \[Rule] {1, \(-1\)}]}, {k, \(-50\), 
            50}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[\({#[\([1]\)], Abs[#[\([2]\)]]} &\)\  /@ \ ftbl, \ 
        Red, \ Frame \[Rule] True, \ PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.0147151 3.69831 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10717 -30 -4.5 ]
[-0.0125 .10717 0 4.5 ]
[-0.0125 .19963 -24 -4.5 ]
[-0.0125 .19963 0 4.5 ]
[-0.0125 .29209 -30 -4.5 ]
[-0.0125 .29209 0 4.5 ]
[-0.0125 .38455 -18 -4.5 ]
[-0.0125 .38455 0 4.5 ]
[-0.0125 .477 -30 -4.5 ]
[-0.0125 .477 0 4.5 ]
[-0.0125 .56946 -24 -4.5 ]
[-0.0125 .56946 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-40)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-20)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(20)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(40)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10717 m
.00625 .10717 L
s
[(0.025)] -0.0125 .10717 1 0 Mshowa
0 .19963 m
.00625 .19963 L
s
[(0.05)] -0.0125 .19963 1 0 Mshowa
0 .29209 m
.00625 .29209 L
s
[(0.075)] -0.0125 .29209 1 0 Mshowa
0 .38455 m
.00625 .38455 L
s
[(0.1)] -0.0125 .38455 1 0 Mshowa
0 .477 m
.00625 .477 L
s
[(0.125)] -0.0125 .477 1 0 Mshowa
0 .56946 m
.00625 .56946 L
s
[(0.15)] -0.0125 .56946 1 0 Mshowa
.125 Mabswid
0 .03321 m
.00375 .03321 L
s
0 .0517 m
.00375 .0517 L
s
0 .07019 m
.00375 .07019 L
s
0 .08868 m
.00375 .08868 L
s
0 .12566 m
.00375 .12566 L
s
0 .14416 m
.00375 .14416 L
s
0 .16265 m
.00375 .16265 L
s
0 .18114 m
.00375 .18114 L
s
0 .21812 m
.00375 .21812 L
s
0 .23661 m
.00375 .23661 L
s
0 .25511 m
.00375 .25511 L
s
0 .2736 m
.00375 .2736 L
s
0 .31058 m
.00375 .31058 L
s
0 .32907 m
.00375 .32907 L
s
0 .34756 m
.00375 .34756 L
s
0 .36605 m
.00375 .36605 L
s
0 .40304 m
.00375 .40304 L
s
0 .42153 m
.00375 .42153 L
s
0 .44002 m
.00375 .44002 L
s
0 .45851 m
.00375 .45851 L
s
0 .49549 m
.00375 .49549 L
s
0 .51399 m
.00375 .51399 L
s
0 .53248 m
.00375 .53248 L
s
0 .55097 m
.00375 .55097 L
s
0 .58795 m
.00375 .58795 L
s
0 .60644 m
.00375 .60644 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10717 m
1 .10717 L
s
.99375 .19963 m
1 .19963 L
s
.99375 .29209 m
1 .29209 L
s
.99375 .38455 m
1 .38455 L
s
.99375 .477 m
1 .477 L
s
.99375 .56946 m
1 .56946 L
s
.125 Mabswid
.99625 .03321 m
1 .03321 L
s
.99625 .0517 m
1 .0517 L
s
.99625 .07019 m
1 .07019 L
s
.99625 .08868 m
1 .08868 L
s
.99625 .12566 m
1 .12566 L
s
.99625 .14416 m
1 .14416 L
s
.99625 .16265 m
1 .16265 L
s
.99625 .18114 m
1 .18114 L
s
.99625 .21812 m
1 .21812 L
s
.99625 .23661 m
1 .23661 L
s
.99625 .25511 m
1 .25511 L
s
.99625 .2736 m
1 .2736 L
s
.99625 .31058 m
1 .31058 L
s
.99625 .32907 m
1 .32907 L
s
.99625 .34756 m
1 .34756 L
s
.99625 .36605 m
1 .36605 L
s
.99625 .40304 m
1 .40304 L
s
.99625 .42153 m
1 .42153 L
s
.99625 .44002 m
1 .44002 L
s
.99625 .45851 m
1 .45851 L
s
.99625 .49549 m
1 .49549 L
s
.99625 .51399 m
1 .51399 L
s
.99625 .53248 m
1 .53248 L
s
.99625 .55097 m
1 .55097 L
s
.99625 .58795 m
1 .58795 L
s
.99625 .60644 m
1 .60644 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .02649 L
s
.03333 .01472 m
.03333 .02673 L
s
.04286 .01472 m
.04286 .02698 L
s
.05238 .01472 m
.05238 .02724 L
s
.0619 .01472 m
.0619 .02751 L
s
.07143 .01472 m
.07143 .0278 L
s
.08095 .01472 m
.08095 .02809 L
s
.09048 .01472 m
.09048 .0284 L
s
.1 .01472 m
.1 .02873 L
s
.10952 .01472 m
.10952 .02907 L
s
.11905 .01472 m
.11905 .02943 L
s
.12857 .01472 m
.12857 .02981 L
s
.1381 .01472 m
.1381 .0302 L
s
.14762 .01472 m
.14762 .03062 L
s
.15714 .01472 m
.15714 .03107 L
s
.16667 .01472 m
.16667 .03153 L
s
.17619 .01472 m
.17619 .03203 L
s
.18571 .01472 m
.18571 .03255 L
s
.19524 .01472 m
.19524 .03311 L
s
.20476 .01472 m
.20476 .0337 L
s
.21429 .01472 m
.21429 .03434 L
s
.22381 .01472 m
.22381 .03501 L
s
.23333 .01472 m
.23333 .03574 L
s
.24286 .01472 m
.24286 .03652 L
s
.25238 .01472 m
.25238 .03735 L
s
.2619 .01472 m
.2619 .03826 L
s
.27143 .01472 m
.27143 .03924 L
s
.28095 .01472 m
.28095 .04031 L
s
.29048 .01472 m
.29048 .04147 L
s
.3 .01472 m
.3 .04274 L
s
.30952 .01472 m
.30952 .04415 L
s
.31905 .01472 m
.31905 .04569 L
s
.32857 .01472 m
.32857 .04742 L
s
.3381 .01472 m
.3381 .04934 L
s
.34762 .01472 m
.34762 .0515 L
s
.35714 .01472 m
.35714 .05396 L
s
.36667 .01472 m
.36667 .05676 L
s
.37619 .01472 m
.37619 .05999 L
s
.38571 .01472 m
.38571 .06377 L
s
.39524 .01472 m
.39524 .06822 L
s
.40476 .01472 m
.40476 .07358 L
s
.41429 .01472 m
.41429 .08012 L
s
.42381 .01472 m
.42381 .08829 L
s
.43333 .01472 m
.43333 .0988 L
s
.44286 .01472 m
.44286 .11282 L
s
.45238 .01472 m
.45238 .13244 L
s
.4619 .01472 m
.4619 .16187 L
s
.47143 .01472 m
.47143 .21092 L
s
.48095 .01472 m
.48095 .30902 L
s
.49048 .01472 m
.49048 .60332 L
s
.5 .01472 m
.5 .01472 L
s
.50952 .01472 m
.50952 .60332 L
s
.51905 .01472 m
.51905 .30902 L
s
.52857 .01472 m
.52857 .21092 L
s
.5381 .01472 m
.5381 .16187 L
s
.54762 .01472 m
.54762 .13244 L
s
.55714 .01472 m
.55714 .11282 L
s
.56667 .01472 m
.56667 .0988 L
s
.57619 .01472 m
.57619 .08829 L
s
.58571 .01472 m
.58571 .08012 L
s
.59524 .01472 m
.59524 .07358 L
s
.60476 .01472 m
.60476 .06822 L
s
.61429 .01472 m
.61429 .06377 L
s
.62381 .01472 m
.62381 .05999 L
s
.63333 .01472 m
.63333 .05676 L
s
.64286 .01472 m
.64286 .05396 L
s
.65238 .01472 m
.65238 .0515 L
s
.6619 .01472 m
.6619 .04934 L
s
.67143 .01472 m
.67143 .04742 L
s
.68095 .01472 m
.68095 .04569 L
s
.69048 .01472 m
.69048 .04415 L
s
.7 .01472 m
.7 .04274 L
s
.70952 .01472 m
.70952 .04147 L
s
.71905 .01472 m
.71905 .04031 L
s
.72857 .01472 m
.72857 .03924 L
s
.7381 .01472 m
.7381 .03826 L
s
.74762 .01472 m
.74762 .03735 L
s
.75714 .01472 m
.75714 .03652 L
s
.76667 .01472 m
.76667 .03574 L
s
.77619 .01472 m
.77619 .03501 L
s
.78571 .01472 m
.78571 .03434 L
s
.79524 .01472 m
.79524 .0337 L
s
.80476 .01472 m
.80476 .03311 L
s
.81429 .01472 m
.81429 .03255 L
s
.82381 .01472 m
.82381 .03203 L
s
.83333 .01472 m
.83333 .03153 L
s
.84286 .01472 m
.84286 .03107 L
s
.85238 .01472 m
.85238 .03062 L
s
.8619 .01472 m
.8619 .0302 L
s
.87143 .01472 m
.87143 .02981 L
s
.88095 .01472 m
.88095 .02943 L
s
.89048 .01472 m
.89048 .02907 L
s
.9 .01472 m
.9 .02873 L
s
.90952 .01472 m
.90952 .0284 L
s
.91905 .01472 m
.91905 .02809 L
s
.92857 .01472 m
.92857 .0278 L
s
.9381 .01472 m
.9381 .02751 L
s
.94762 .01472 m
.94762 .02724 L
s
.95714 .01472 m
.95714 .02698 L
s
.96667 .01472 m
.96667 .02673 L
s
.97619 .01472 m
.97619 .02649 L
s
.015 w
.02381 .02649 Mdot
.03333 .02673 Mdot
.04286 .02698 Mdot
.05238 .02724 Mdot
.0619 .02751 Mdot
.07143 .0278 Mdot
.08095 .02809 Mdot
.09048 .0284 Mdot
.1 .02873 Mdot
.10952 .02907 Mdot
.11905 .02943 Mdot
.12857 .02981 Mdot
.1381 .0302 Mdot
.14762 .03062 Mdot
.15714 .03107 Mdot
.16667 .03153 Mdot
.17619 .03203 Mdot
.18571 .03255 Mdot
.19524 .03311 Mdot
.20476 .0337 Mdot
.21429 .03434 Mdot
.22381 .03501 Mdot
.23333 .03574 Mdot
.24286 .03652 Mdot
.25238 .03735 Mdot
.2619 .03826 Mdot
.27143 .03924 Mdot
.28095 .04031 Mdot
.29048 .04147 Mdot
.3 .04274 Mdot
.30952 .04415 Mdot
.31905 .04569 Mdot
.32857 .04742 Mdot
.3381 .04934 Mdot
.34762 .0515 Mdot
.35714 .05396 Mdot
.36667 .05676 Mdot
.37619 .05999 Mdot
.38571 .06377 Mdot
.39524 .06822 Mdot
.40476 .07358 Mdot
.41429 .08012 Mdot
.42381 .08829 Mdot
.43333 .0988 Mdot
.44286 .11282 Mdot
.45238 .13244 Mdot
.4619 .16187 Mdot
.47143 .21092 Mdot
.48095 .30902 Mdot
.49048 .60332 Mdot
.5 .01472 Mdot
.50952 .60332 Mdot
.51905 .30902 Mdot
.52857 .21092 Mdot
.5381 .16187 Mdot
.54762 .13244 Mdot
.55714 .11282 Mdot
.56667 .0988 Mdot
.57619 .08829 Mdot
.58571 .08012 Mdot
.59524 .07358 Mdot
.60476 .06822 Mdot
.61429 .06377 Mdot
.62381 .05999 Mdot
.63333 .05676 Mdot
.64286 .05396 Mdot
.65238 .0515 Mdot
.6619 .04934 Mdot
.67143 .04742 Mdot
.68095 .04569 Mdot
.69048 .04415 Mdot
.7 .04274 Mdot
.70952 .04147 Mdot
.71905 .04031 Mdot
.72857 .03924 Mdot
.7381 .03826 Mdot
.74762 .03735 Mdot
.75714 .03652 Mdot
.76667 .03574 Mdot
.77619 .03501 Mdot
.78571 .03434 Mdot
.79524 .0337 Mdot
.80476 .03311 Mdot
.81429 .03255 Mdot
.82381 .03203 Mdot
.83333 .03153 Mdot
.84286 .03107 Mdot
.85238 .03062 Mdot
.8619 .0302 Mdot
.87143 .02981 Mdot
.88095 .02943 Mdot
.89048 .02907 Mdot
.9 .02873 Mdot
.90952 .0284 Mdot
.91905 .02809 Mdot
.92857 .0278 Mdot
.9381 .02751 Mdot
.94762 .02724 Mdot
.95714 .02698 Mdot
.96667 .02673 Mdot
.97619 .02649 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00?_ooool3
o`0000?ooooo0_l0000Vooooo`Go00000oooool2o`0002Wooooo0_l0000Yooooo`Go00000oooool2
o`0002Sooooo0ol00003ooooo`;o00007?ooool003oooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Wooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Xooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Iooooo`00=_ooool5o`000003ooooool0003o000000?o00000_ooool01?l0003oooooooooool0
000Oooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo
00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0001_ooooo000looooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool09Oooool01?l0003oooooooooool0000[ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00006oooool003gooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
000Uooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Wooooo`04
o`000?ooooooooooo`0002Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0002Kooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Kooooo`00?_oo
ool2o`0000?ooooo00Co0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000Xooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Wooooo`;o00000oooool01?l0003ooooo
ooooool0000Kooooo`00?oooool00ol0003oooooooooo`02ooooo`;o00009oooool3o`0000Cooooo
0_l0000Yooooo`;o0000:_ooool3o`0000Cooooo0_l0000Yooooo`03o`000?oooooooooo00;ooooo
0_l0000Looooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
8Oooooono`00007ooooo000Jooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3jooooo`7o00000Ooo
ool001Wooooo00Co0000oooooooooooo00001?ooool2o`0000Cooooo00?oo`00oooooooo00000_oo
ool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05
ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00
oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00
oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003ooooo
ool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00003ool00004oooooooo003ooooo
ool000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00001?ooool2o`00007o
oooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ooo003o
ooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Go
o`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003o
ooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?oooooo
o`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000?oo`0000Co
ooooool00?ooooooo`000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002
ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?oo
ooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00005
ooooo`7o00000Oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oo
ooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo
003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002
ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oo
ooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo
00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000ooo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
1Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool0
0?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool0
0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool0
0?ooooooo`0000Gooooo0Ol00001ooooo`006Oooool01?l0003oooooooooool00004ooooo`04o`00
0?oooooooooooooooaWoo`0000Coooooool00?ooooooo`000_ooool00ooo003oooooool00002oooo
o`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?oooooo
o`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Go
o`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003o
ooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00006Ooo0004ooooo`7o00000Oooool001[ooooo0_l00005ooooo`04o`000?oooooo
ooooooooobooo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000;o
oooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool0
0?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
1Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01?oo003oooooool0
0?ooool`ool000Cooooo0Ol00001ooooo`008Oooool2o`0000;ooooo>ooo00001?ooooooo`00oooo
oooo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05
ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`00
00;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00
oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00001?oo
ool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003ooooo
ool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooo`00
oooooccoo`000oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo01[ooooo;Ooo0002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooobgoo`007?ooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo02oooooo7_oo00001_ooooooo`00oooooooo003o
ooooool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?oo
ooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo
00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo7ooo000booooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool0>ooooolHool000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool0
0?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo5ooo000noooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool0AOoooolAool00007oooooooo003ooooooooo
oooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool0
0?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo00Goo`00oooooooo003oooooool00002oooooa;oo`00B?ooool1o`00007ooooo000Qooooo`;o
0000COooool?ool00009oooooooo003ooooooooooooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000ooo`00C_ooool2o`00007ooooo000Qooooo`03o`00
0?oooooooooo057ooooo3Ooo00001_ooooooo`00oooooooo003oooooool000;ooooo00?oo`00oooo
oooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
1Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`goo`00E?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05Kooooo2_oo0000
1?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003ooooo
ool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00001?ooool00ooo003ooooo
ool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00002_oo001Iooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool0Foooool9ool000;ooooo00?oo`00oooooooo00000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool9ool005gooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`1Mooooo`Ooo`000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`Koo`00H?ooool1o`00007ooooo000Qooooo`;o0000HOooool5ool0
0004oooooooo003oooooool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oo
ooooo`0000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002ooooo`03ool00?oo
ooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000Koo`00
HOooool2o`00007ooooo000Qooooo`03o`000?oooooooooo06;ooooo1Ooo00002Oooooooo`00oooo
ooooooooo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00001?ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`Koo`00IOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
06;ooooo1Ooo00002Oooooooo`00ooooooooooooo`00oooooooo003oooooool00002ooooo`03ool0
0?ooooooo`0000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002ooooo`03ool0
0?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`Koo`00IOooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo06Cooooo1_oo00001_ooooooo`00oooooooo003oooooool0
00;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool01?oo003oooooool00?ooool7ool006Oooooo0Ol00001
ooooo`008Oooool2o`0006Sooooo0ooo00001_ooooooo`00oooooooo003oooooool000;ooooo00?o
o`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01?oo003oooooool00?ooool4ool006Wooooo0_l00001ooooo`008Ooo
ool00ol0003oooooooooo`1Wooooo`?oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo1?oo001Zooooo`7o00000Oooool000;o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Go
oooo00?o0000ooooooooool0JOooool3ool00004oooooooo003oooooool000;ooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooool00003ool006cooooo0Ol00001ooooo`0000Goooooo`000?oo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0JOooool3ool00004oooo
oooo003oooooool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00003ool006co
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Wooooo0ooo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00
oooooooo00001?ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00
oooooooo00000ooo001/ooooo`7o00000Oooool00005ooooool0003oooooooooool000002?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool2o`0006kooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oo
ooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oo
ooooo`0006kooooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000003o`0000Gooooo00?o0000oooooooo
ool0K?ooool4ool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00004ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool4ool006kooooo0Ol00001ooooo`00
00Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo06cooooo1?oo0002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo1?oo001^ooooo`7o00000Oooool000;ooooo0_l0000:ooooo`;o00000oooool3o`00
00;ooooo1Ol00004ooooo`03o`000?oooooooooo06cooooo1?oo0002ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`00
00;ooooo1?oo001^ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0Koooool01_oo003o
oooooooooooo003oooooool000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool00002
ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Qoooo
o`;o0000L?ooool01_oo003ooooooooooooo003oooooool000;ooooo00?oo`00oooooooo00001?oo
ool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0K_oo
ool2o`00007ooooo000Qooooo`03o`000?oooooooooo06kooooo0ooo00001?ooooooo`00oooooooo
0002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooool0
0003ool0077ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1^ooooo`?oo`0000Cooooo
ool00?ooooooo`000_ooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000ooo001aooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0K_ooool3
ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00001?ooool00ooo003oooooool0
0002ooooo`03ool00?ooooooo`0000?oo`00LOooool1o`00007ooooo000Qooooo`;o0000Loooool0
0ooo003oooooool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool0001cooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0L_ooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo
003oooooool0001dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0L_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool0001dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0L_ooool00ooo003ooooo
ool00002ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo00000_ooool00ooo003ooooo
ool0001dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0L?ooool3ool00007oooooooo
003ooooooooooooo003oooooool00004ooooo`03ool00?ooooooo`0000;ooooo1?oo001cooooo`7o
00000Oooool0027ooooo0_l0001aooooo`?oo`0000Ooooooool00?ooooooooooool00?ooooooo`00
00Cooooo00?oo`00oooooooo00000_ooool4ool007;ooooo0_l00001ooooo`008Oooool00ol0003o
ooooooooo`1`ooooo`?oo`0000Ooooooool00?ooooooooooool00?ooooooo`0000Cooooo00?oo`00
oooooooo00000_ooool4ool007?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1doooo
o`06ool00?ooooooooooool00?ooooooo`001?ooool00ooo003oooooool00002ooooo`03ool00?oo
oooooooo07Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`06ool00?oooooo
ooooool00?ooooooo`001?ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo07Cooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`06ool00?ooooooooooool00?oooooo
o`001?ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`00
8Oooool2o`0007Gooooo00Koo`00ooooooooooooo`00oooooooo0004ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00ooooooooool0Loooool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Co
oooo00Koo`00ooooooooooooo`00oooooooo0004ooooo`03ool00?ooooooo`0000;ooooo00?oo`00
ooooooooool0M?ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0M?ooool01_oo003ooooooooooooo003o
ooooool000Cooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`1dooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`06ool00?ooooooooooool0
0?ooooooo`001?ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo07Cooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00_ooool2o`0007Gooooo00Koo`00ooooooooooooo`00oooooooo0004ooooo`03
ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0Loooool2o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07Cooooo00Koo`00ooooooooooooo`00oooooooo0004ooooo`03ool00?oo
ooooo`0000;ooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0
M?ooool01_oo003ooooooooooooo003oooooool000Cooooo00?oo`00oooooooo00000_ooool00ooo
003oooooooooo`1dooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0Loooool3ool00004oooooooo
003oooooool000Cooooo00?oo`00oooooooo00000ooo001fooooo`7o00000Oooool000Sooooo0_l0
000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool0Loooool3ool00004oooooooo
003oooooool000Cooooo00?oo`00oooooooo00000ooo001fooooo`7o00000Oooool0027ooooo0_l0
001dooooo`?oo`0000Coooooool00?ooooooo`001?ooool00ooo003oooooool00003ool007Gooooo
0_l00001ooooo`008Oooool00ol0003oooooooooo`1gooooo`03ool00?ooooooo`0000Cooooo00?o
o`00oooooooo0000NOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?oo`00
oooooooo00001?ooool00ooo003oooooool0001iooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool0Moooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0007Wooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`1gooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo
0000NOooool1o`00007ooooo000Qooooo`;o0000N?ooool00ooo003oooooool00004ooooo`03ool0
0?ooooooo`0007Sooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1gooooo`03ool00?oo
ooooo`0000Cooooo00?oo`00oooooooo0000NOooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo07Oooooo00?oo`00oooooooo00001?ooool00ooo003oooooool0001iooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool0Moooool00ooo003oooooool00004ooooo`03ool00?ooooooo`00
07Wooooo0Ol00001ooooo`008Oooool2o`0007Sooooo00?oo`00oooooooo00001?ooool00ooo003o
ooooool0001hooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0Moooool00ooo003ooooo
ool00004ooooo`03ool00?ooooooo`0007Wooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`1gooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo0000NOooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo07Oooooo00?oo`00oooooooo00001?ooool00ooo003oooooool0001i
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0Moooool00ooo003oooooool00004oooo
o`03ool00?ooooooo`0007Wooooo0Ol00001ooooo`008Oooool2o`0007Sooooo00?oo`00oooooooo
00001?ooool00ooo003oooooool0001hooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0
Moooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0007Wooooo0Ol00001ooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0Moooool00ooo003oooooool00004ooooo`03ool00?oo
ooooo`0007Wooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Moooool00ooo003oooooool00004ooooo`03ool00?ooooooo`0007Wo
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07Oooooo00?oo`00oooooooo00001?ooool00ooo003oooooool0001iooooo`7o00000Oooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`0007Sooooo00?oo`00oooooooo00001?ooool0
0ooo003oooooool0001hooooo`;o00000Oooool00005ooooool0003oooooooooool000002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooooooo
o`1gooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooooooo0000NOooool1o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool0Moooool00ooo003oooooool00004ooooo`03
ool00?ooooooo`0007Wooooo0Ol00001ooooo`000_ooool2o`0000[ooooo0_l00002ooooo`Go0000
00?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo07Gooooo0ooo00000oooooooo`00
ooooo`03ooooo`Coo`00N?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Gooooo0ooo
00000oooooooo`00ooooo`03ooooo`Coo`00N?ooool1o`00007ooooo000Qooooo`;o0000M_ooool3
ool00003oooooooo003ooooo00?ooooo1?oo001gooooo`;o00000Oooool0027ooooo00?o0000oooo
ooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0NOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo0_l0001jooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0N?ooool2o`00007ooooo000Qooooo`03o`000?oooooo
oooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo0_l0
001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0N?ooool2o`00007ooooo000Q
ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1i
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o0000
0Oooool0027ooooo0_l0001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0N?oo
ool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1iooooo`7o00000Oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`1iooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`1iooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`04ooooo`;o0000N_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Sooooo0_l00001ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Wooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Wooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00008ooooo`;o00001_ooool00ol0
003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00
007ooooo000>ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo
0_l0001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0N?ooool2o`00007ooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1iooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1ioooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o
00000Oooool0027ooooo0_l0001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
N?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0NOooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00
007ooooo000Qooooo`;o0000N_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07So
oooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0NOooool1o`00007ooooo000Qooooo`;o0000N_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo07Sooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo0002ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oo
oooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Ooo
ool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool00005oooo
ool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0NOooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo0_l0001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0N?ooool2o`00007o
oooo00001Ooooooo0000oooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo00001Ooooooo0000oooooooooooo0000
00Sooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`03o`000?oo
oooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Ooo
ool000;ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00001?ooool0
0ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1
o`00007ooooo000Qooooo`;o0000N_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Sooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07Wooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0NOooool1o`00007ooooo000Qooooo`;o0000N_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07Sooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo07Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`;o0000N_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo07Sooooo0_l00001ooooo`008Oooool00ol0003o
ooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1iooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`008Oooool2o`0007[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1hooooo`;o00000Oooool0027ooooo00?o0000oooo
ooooool0NOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0NOooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0oooool3o`0000Gooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo07Wooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo0_l0001jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0N?ooool2o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1iooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool01?l0003o
ooooooooooooool4o`0000Gooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07Wooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008oooo
o`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Oooool000Sooooo0_l0000:ooooo`04
o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Qooooo`;o0000N_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo07Sooooo0_l00001ooooo`008Oooool00ol0003ooooo
ooooo`1iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1iooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0N?ooool3ool000;ooooo0ooo001j
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0N?ooool3ool000;ooooo0ooo001joooo
o`7o00000Oooool0027ooooo0_l0001iooooo`?oo`000_ooool3ool007Wooooo0_l00001ooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
6oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`008Oooooon
o`00007ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-66.2292, -0.0211989, \
0.413873, 0.0010658}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[\({#[\([1]\)], 
              Arg[#[\([2]\)] +  .000001]} &\)\  /@ \ ftbl, \ Red, \ 
        Frame \[Rule] True, \ PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.309017 0.187359 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02798 -24 -4.5 ]
[-0.0125 .02798 0 4.5 ]
[-0.0125 .12166 -12 -4.5 ]
[-0.0125 .12166 0 4.5 ]
[-0.0125 .21534 -24 -4.5 ]
[-0.0125 .21534 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .4027 -18 -4.5 ]
[-0.0125 .4027 0 4.5 ]
[-0.0125 .49638 -6 -4.5 ]
[-0.0125 .49638 0 4.5 ]
[-0.0125 .59006 -18 -4.5 ]
[-0.0125 .59006 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-40)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-20)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(20)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(40)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02798 m
.00625 .02798 L
s
[(-1.5)] -0.0125 .02798 1 0 Mshowa
0 .12166 m
.00625 .12166 L
s
[(-1)] -0.0125 .12166 1 0 Mshowa
0 .21534 m
.00625 .21534 L
s
[(-0.5)] -0.0125 .21534 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .4027 m
.00625 .4027 L
s
[(0.5)] -0.0125 .4027 1 0 Mshowa
0 .49638 m
.00625 .49638 L
s
[(1)] -0.0125 .49638 1 0 Mshowa
0 .59006 m
.00625 .59006 L
s
[(1.5)] -0.0125 .59006 1 0 Mshowa
.125 Mabswid
0 .04671 m
.00375 .04671 L
s
0 .06545 m
.00375 .06545 L
s
0 .08419 m
.00375 .08419 L
s
0 .10292 m
.00375 .10292 L
s
0 .14039 m
.00375 .14039 L
s
0 .15913 m
.00375 .15913 L
s
0 .17787 m
.00375 .17787 L
s
0 .1966 m
.00375 .1966 L
s
0 .23407 m
.00375 .23407 L
s
0 .25281 m
.00375 .25281 L
s
0 .27155 m
.00375 .27155 L
s
0 .29028 m
.00375 .29028 L
s
0 .32775 m
.00375 .32775 L
s
0 .34649 m
.00375 .34649 L
s
0 .36522 m
.00375 .36522 L
s
0 .38396 m
.00375 .38396 L
s
0 .42143 m
.00375 .42143 L
s
0 .44017 m
.00375 .44017 L
s
0 .4589 m
.00375 .4589 L
s
0 .47764 m
.00375 .47764 L
s
0 .51511 m
.00375 .51511 L
s
0 .53385 m
.00375 .53385 L
s
0 .55258 m
.00375 .55258 L
s
0 .57132 m
.00375 .57132 L
s
0 .00924 m
.00375 .00924 L
s
0 .60879 m
.00375 .60879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02798 m
1 .02798 L
s
.99375 .12166 m
1 .12166 L
s
.99375 .21534 m
1 .21534 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .4027 m
1 .4027 L
s
.99375 .49638 m
1 .49638 L
s
.99375 .59006 m
1 .59006 L
s
.125 Mabswid
.99625 .04671 m
1 .04671 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08419 m
1 .08419 L
s
.99625 .10292 m
1 .10292 L
s
.99625 .14039 m
1 .14039 L
s
.99625 .15913 m
1 .15913 L
s
.99625 .17787 m
1 .17787 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .23407 m
1 .23407 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .27155 m
1 .27155 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .32775 m
1 .32775 L
s
.99625 .34649 m
1 .34649 L
s
.99625 .36522 m
1 .36522 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .42143 m
1 .42143 L
s
.99625 .44017 m
1 .44017 L
s
.99625 .4589 m
1 .4589 L
s
.99625 .47764 m
1 .47764 L
s
.99625 .51511 m
1 .51511 L
s
.99625 .53385 m
1 .53385 L
s
.99625 .55258 m
1 .55258 L
s
.99625 .57132 m
1 .57132 L
s
.99625 .00924 m
1 .00924 L
s
.99625 .60879 m
1 .60879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .01477 L
s
.03333 .30902 m
.03333 .60326 L
s
.04286 .30902 m
.04286 .01477 L
s
.05238 .30902 m
.05238 .60326 L
s
.0619 .30902 m
.0619 .01477 L
s
.07143 .30902 m
.07143 .60327 L
s
.08095 .30902 m
.08095 .01477 L
s
.09048 .30902 m
.09048 .60327 L
s
.1 .30902 m
.1 .01476 L
s
.10952 .30902 m
.10952 .60327 L
s
.11905 .30902 m
.11905 .01476 L
s
.12857 .30902 m
.12857 .60327 L
s
.1381 .30902 m
.1381 .01476 L
s
.14762 .30902 m
.14762 .60328 L
s
.15714 .30902 m
.15714 .01476 L
s
.16667 .30902 m
.16667 .60328 L
s
.17619 .30902 m
.17619 .01475 L
s
.18571 .30902 m
.18571 .60328 L
s
.19524 .30902 m
.19524 .01475 L
s
.20476 .30902 m
.20476 .60328 L
s
.21429 .30902 m
.21429 .01475 L
s
.22381 .30902 m
.22381 .60329 L
s
.23333 .30902 m
.23333 .01475 L
s
.24286 .30902 m
.24286 .60329 L
s
.25238 .30902 m
.25238 .01474 L
s
.2619 .30902 m
.2619 .60329 L
s
.27143 .30902 m
.27143 .01474 L
s
.28095 .30902 m
.28095 .60329 L
s
.29048 .30902 m
.29048 .01474 L
s
.3 .30902 m
.3 .6033 L
s
.30952 .30902 m
.30952 .01474 L
s
.31905 .30902 m
.31905 .6033 L
s
.32857 .30902 m
.32857 .01474 L
s
.3381 .30902 m
.3381 .6033 L
s
.34762 .30902 m
.34762 .01473 L
s
.35714 .30902 m
.35714 .6033 L
s
.36667 .30902 m
.36667 .01473 L
s
.37619 .30902 m
.37619 .6033 L
s
.38571 .30902 m
.38571 .01473 L
s
.39524 .30902 m
.39524 .60331 L
s
.40476 .30902 m
.40476 .01473 L
s
.41429 .30902 m
.41429 .60331 L
s
.42381 .30902 m
.42381 .01472 L
s
.43333 .30902 m
.43333 .60331 L
s
.44286 .30902 m
.44286 .01472 L
s
.45238 .30902 m
.45238 .60331 L
s
.4619 .30902 m
.4619 .01472 L
s
.47143 .30902 m
.47143 .60332 L
s
.48095 .30902 m
.48095 .01472 L
s
.49048 .30902 m
.49048 .60332 L
s
.5 .30902 m
.5 .30902 L
s
.50952 .30902 m
.50952 .01472 L
s
.51905 .30902 m
.51905 .60332 L
s
.52857 .30902 m
.52857 .01472 L
s
.5381 .30902 m
.5381 .60332 L
s
.54762 .30902 m
.54762 .01472 L
s
.55714 .30902 m
.55714 .60331 L
s
.56667 .30902 m
.56667 .01472 L
s
.57619 .30902 m
.57619 .60331 L
s
.58571 .30902 m
.58571 .01472 L
s
.59524 .30902 m
.59524 .60331 L
s
.60476 .30902 m
.60476 .01473 L
s
.61429 .30902 m
.61429 .60331 L
s
.62381 .30902 m
.62381 .01473 L
s
.63333 .30902 m
.63333 .6033 L
s
.64286 .30902 m
.64286 .01473 L
s
.65238 .30902 m
.65238 .6033 L
s
.6619 .30902 m
.6619 .01473 L
s
.67143 .30902 m
.67143 .6033 L
s
.68095 .30902 m
.68095 .01474 L
s
.69048 .30902 m
.69048 .6033 L
s
.7 .30902 m
.7 .01474 L
s
.70952 .30902 m
.70952 .60329 L
s
.71905 .30902 m
.71905 .01474 L
s
.72857 .30902 m
.72857 .60329 L
s
.7381 .30902 m
.7381 .01474 L
s
.74762 .30902 m
.74762 .60329 L
s
.75714 .30902 m
.75714 .01475 L
s
.76667 .30902 m
.76667 .60329 L
s
.77619 .30902 m
.77619 .01475 L
s
.78571 .30902 m
.78571 .60328 L
s
.79524 .30902 m
.79524 .01475 L
s
.80476 .30902 m
.80476 .60328 L
s
.81429 .30902 m
.81429 .01475 L
s
.82381 .30902 m
.82381 .60328 L
s
.83333 .30902 m
.83333 .01476 L
s
.84286 .30902 m
.84286 .60328 L
s
.85238 .30902 m
.85238 .01476 L
s
.8619 .30902 m
.8619 .60328 L
s
.87143 .30902 m
.87143 .01476 L
s
.88095 .30902 m
.88095 .60327 L
s
.89048 .30902 m
.89048 .01476 L
s
.9 .30902 m
.9 .60327 L
s
.90952 .30902 m
.90952 .01476 L
s
.91905 .30902 m
.91905 .60327 L
s
.92857 .30902 m
.92857 .01477 L
s
.9381 .30902 m
.9381 .60327 L
s
.94762 .30902 m
.94762 .01477 L
s
.95714 .30902 m
.95714 .60326 L
s
.96667 .30902 m
.96667 .01477 L
s
.97619 .30902 m
.97619 .60326 L
s
.015 w
.02381 .01477 Mdot
.03333 .60326 Mdot
.04286 .01477 Mdot
.05238 .60326 Mdot
.0619 .01477 Mdot
.07143 .60327 Mdot
.08095 .01477 Mdot
.09048 .60327 Mdot
.1 .01476 Mdot
.10952 .60327 Mdot
.11905 .01476 Mdot
.12857 .60327 Mdot
.1381 .01476 Mdot
.14762 .60328 Mdot
.15714 .01476 Mdot
.16667 .60328 Mdot
.17619 .01475 Mdot
.18571 .60328 Mdot
.19524 .01475 Mdot
.20476 .60328 Mdot
.21429 .01475 Mdot
.22381 .60329 Mdot
.23333 .01475 Mdot
.24286 .60329 Mdot
.25238 .01474 Mdot
.2619 .60329 Mdot
.27143 .01474 Mdot
.28095 .60329 Mdot
.29048 .01474 Mdot
.3 .6033 Mdot
.30952 .01474 Mdot
.31905 .6033 Mdot
.32857 .01474 Mdot
.3381 .6033 Mdot
.34762 .01473 Mdot
.35714 .6033 Mdot
.36667 .01473 Mdot
.37619 .6033 Mdot
.38571 .01473 Mdot
.39524 .60331 Mdot
.40476 .01473 Mdot
.41429 .60331 Mdot
.42381 .01472 Mdot
.43333 .60331 Mdot
.44286 .01472 Mdot
.45238 .60331 Mdot
.4619 .01472 Mdot
.47143 .60332 Mdot
.48095 .01472 Mdot
.49048 .60332 Mdot
.5 .30902 Mdot
.50952 .01472 Mdot
.51905 .60332 Mdot
.52857 .01472 Mdot
.5381 .60332 Mdot
.54762 .01472 Mdot
.55714 .60331 Mdot
.56667 .01472 Mdot
.57619 .60331 Mdot
.58571 .01472 Mdot
.59524 .60331 Mdot
.60476 .01473 Mdot
.61429 .60331 Mdot
.62381 .01473 Mdot
.63333 .6033 Mdot
.64286 .01473 Mdot
.65238 .6033 Mdot
.6619 .01473 Mdot
.67143 .6033 Mdot
.68095 .01474 Mdot
.69048 .6033 Mdot
.7 .01474 Mdot
.70952 .60329 Mdot
.71905 .01474 Mdot
.72857 .60329 Mdot
.7381 .01474 Mdot
.74762 .60329 Mdot
.75714 .01475 Mdot
.76667 .60329 Mdot
.77619 .01475 Mdot
.78571 .60328 Mdot
.79524 .01475 Mdot
.80476 .60328 Mdot
.81429 .01475 Mdot
.82381 .60328 Mdot
.83333 .01476 Mdot
.84286 .60328 Mdot
.85238 .01476 Mdot
.8619 .60328 Mdot
.87143 .01476 Mdot
.88095 .60327 Mdot
.89048 .01476 Mdot
.9 .60327 Mdot
.90952 .01476 Mdot
.91905 .60327 Mdot
.92857 .01477 Mdot
.9381 .60327 Mdot
.94762 .01477 Mdot
.95714 .60326 Mdot
.96667 .01477 Mdot
.97619 .60326 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00>Oooool3o`0000?ooooo0_l0000Wooooo`Go0000
0oooool2o`0002[ooooo0_l0000Zooooo`Go00000oooool2o`0002Wooooo0ol00003ooooo`;o0000
7Oooool003[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Gooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`04o`000?oooooooooo
o`0002[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Yooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`00<Oooool5o`000003oooo
ool0003o000000?o00000_ooool01?l0003oooooooooool0000Pooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo0000:oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0001cooooo000gooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
0000:Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool09_ooool01?l0
003oooooooooool0000/ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Tooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007?ooool003Sooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Vooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Xooooo`04o`000?ooooooooooo`0002Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool0000Looooo`00>Oooool2o`0000?ooooo00Co0000oooooooo
oooo00009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?oo
ool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Xooooo`;o00000oooool01?l0003oooooooooool0000Looooo`00>_ooool00ol0
003oooooooooo`02ooooo`;o0000:?ooool3o`0000Cooooo0_l0000Zooooo`;o0000:oooool3o`00
00Cooooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooooooo`0000Go00000Oooool001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool1o`00007ooooo000Kooooo`;o00007Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01_ooooo0_l00001ooooo`006oooool01?l0003ooooooooo
ooooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`001Oooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo00001?oo
ooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0007ooooo`7o00000Oooool0
01_ooooo00Co0000oooooooooooooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_oo
ool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000Gooooo0ooo0002ooooo`?oo`0000Co
ooooool00?oo003oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo
0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo
0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo
0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3ool000;ooooo0ooo0002ooooo`?o
o`001oooool1o`00007ooooo0007ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool01?l0003oooooooooooooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`001Oooool3ool000;ooooo0ooo00001?oo
ooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0007ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`00
1Ol00003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`04ooooo`;o00000Oooool000Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool0
00Sooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo0Ol00001ooooo`001oooool2o`0000Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo0008ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o
00000Oooool001_ooooo0_l00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`7o00000Oooool001_ooooo0_l00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo0_l00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo
0_l00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`05ooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000<ooooo`Go00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o
00000Oooool001Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04oooo
o`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01Oooool1o`00007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006ooo
ool2o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`04ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo
0Ol00001ooooo`006oooool2o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o00000Oooool001_ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001oooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01Oooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool0
00Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Cooooo0_l00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co0000
1Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool1o`00007ooooo0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`;o00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`;o0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo
0Ol00001ooooo`006oooool2o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o00000Oooool001_ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Doooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Go
oooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`;o00001?ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000?oo`0000Woooooool00?ooooooooooool00?ooooooo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00001?ooool2o`00007ooooo000Cooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool4ool000Cooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool4ool000Cooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?ooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo0Ol00001ooooo`006oooool2o`0000Kooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`;o00000Oooool001_ooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool2o`0000Kooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Ooo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool2
o`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol0
0001ooooo`006oooool2o`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_oo
ool2o`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00?ooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`7o00000Oooool001_ooooo0_l00006ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_ooooo0_l00006oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool0
01_ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`7o00000Oooool001_ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
0_l00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Ooo
ool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_ooooo0_l00006oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool0
01_ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`;o00001_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007ooooo000Kooooo`;o0000
1_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool000Oooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`7o00000Ooo
ool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?ooooo0Ol00001ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool2o`00007ooooo0008ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool1o`00007o
oooo0008ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`7o00000Oooool000Oooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`001?ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`001?ooool1o`00007ooooo0008
ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00Cooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`000_oo
ool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_oo
ool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_oo
ool3ool000Cooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_oo
ool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`0000Co
ooooool00?oo003oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo
0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo
0ooo0002ooooo`?oo`000_ooool3ool000Cooooo0Ol00001ooooo`006oooool2o`0000Gooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000Cooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
00Coooooool00?oo003oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000?ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool001_oooooool00005o`00007ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-63.5193, -1.9446, 0.404426, \
0.0205577}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example #3: square wave", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[t_] := \((UnitStep[t]\  - 1/2)\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {\(-1\)/2, 1/2}, {t, \(-2\), 
            2}];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[fnc1, {t, \(-2\), 2}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .462 m
.03318 .462 L
.04339 .462 L
.05298 .462 L
.06221 .462 L
.07203 .462 L
.08148 .462 L
.09153 .462 L
.10121 .462 L
.11052 .462 L
.12043 .462 L
.12997 .462 L
.13476 .462 L
.13914 .462 L
.14029 .462 L
.14155 .462 L
.14213 .462 L
.14244 .462 L
.14274 .462 L
.14302 .15604 L
.14332 .15604 L
.14385 .15604 L
.14891 .15604 L
.15885 .15604 L
.16842 .15604 L
.17763 .15604 L
.18743 .15604 L
.19686 .15604 L
.20688 .15604 L
.21654 .15604 L
.22584 .15604 L
.23572 .15604 L
.24524 .15604 L
.25439 .15604 L
.25908 .15604 L
.26037 .15604 L
.26107 .15604 L
.26141 .15604 L
.26172 .15604 L
.26201 .462 L
.26228 .462 L
.26288 .462 L
.26414 .462 L
.27347 .462 L
.28338 .462 L
.29294 .462 L
.30212 .462 L
.3119 .462 L
.32131 .462 L
.33132 .462 L
Mistroke
.34096 .462 L
.35023 .462 L
.3601 .462 L
.36959 .462 L
.37445 .462 L
.377 .462 L
.37839 .462 L
.37969 .462 L
.38029 .462 L
.38058 .462 L
.38086 .462 L
.38117 .15604 L
.38133 .15604 L
.38151 .15604 L
.38211 .15604 L
.38476 .15604 L
.38941 .15604 L
.39858 .15604 L
.40834 .15604 L
.41773 .15604 L
.42771 .15604 L
.43733 .15604 L
.44658 .15604 L
.45643 .15604 L
.46591 .15604 L
.47598 .15604 L
.48569 .15604 L
.49502 .15604 L
.49752 .15604 L
.49874 .15604 L
.49927 .15604 L
.49955 .15604 L
.49985 .15604 L
.50016 .462 L
.50045 .462 L
.50102 .462 L
.50228 .462 L
.50496 .462 L
.5141 .462 L
.52384 .462 L
.53321 .462 L
.54317 .462 L
.55277 .462 L
.562 .462 L
.57183 .462 L
.58129 .462 L
.59134 .462 L
.60102 .462 L
.61034 .462 L
.61515 .462 L
Mistroke
.61758 .462 L
.61825 .462 L
.61861 .462 L
.61879 .462 L
.61896 .462 L
.61912 .15604 L
.61928 .15604 L
.61963 .15604 L
.62025 .15604 L
.63034 .15604 L
.64006 .15604 L
.64941 .15604 L
.65935 .15604 L
.66893 .15604 L
.67814 .15604 L
.68794 .15604 L
.69738 .15604 L
.70741 .15604 L
.71708 .15604 L
.72637 .15604 L
.73108 .15604 L
.73357 .15604 L
.73488 .15604 L
.73626 .15604 L
.73686 .15604 L
.73749 .15604 L
.73768 .15604 L
.73785 .15604 L
.73801 .15604 L
.73818 .462 L
.73835 .462 L
.73852 .462 L
.73883 .462 L
.74118 .462 L
.74579 .462 L
.75498 .462 L
.76476 .462 L
.77418 .462 L
.78419 .462 L
.79383 .462 L
.80311 .462 L
.81298 .462 L
.82249 .462 L
.83258 .462 L
.84231 .462 L
.85168 .462 L
.85419 .462 L
.85541 .462 L
.85652 .462 L
.85681 .462 L
Mistroke
.85713 .462 L
.85743 .15604 L
.8577 .15604 L
.85896 .15604 L
.86163 .15604 L
.87117 .15604 L
.88034 .15604 L
.8901 .15604 L
.8995 .15604 L
.90949 .15604 L
.91911 .15604 L
.92837 .15604 L
.93822 .15604 L
.9477 .15604 L
.95778 .15604 L
.96749 .15604 L
.97619 .15604 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008Oooool5o`0003[ooooo0ol0000iooooo`;o0000>_ooool3o`0003[ooooo1Ol00006oooo
o`008_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Oooooo00Co0000oooo
oooooooo0000>_ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Kooooo000K
ooooo`Go00000oooool00ol0003oooooooooo`0cooooo`Go00000oooool00ol0003oooooooooo`0g
ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo00Co0000
oooooooooooo0000>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo000Q
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`0gooooo`04o`000?oo
ooooooooo`0003[ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000Ko
oooo000Qooooo`05o`000?ooooooooooooooool00000>_ooool2o`0003Wooooo00Co0000oooooooo
oooo0000>Oooool2o`0003_ooooo00Go0000ooooooooooooooooo`000006ooooo`008_ooool3o`00
03cooooo00?o0000ooooooooool0>?ooool2o`0003_ooooo00?o0000ooooooooool0>_ooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`005?ooool0
0ol0003oooooooooo`3oooooo`[ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`04oooo
oooo00001Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`004oooool2o`0000Kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool2
o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020oooo
o`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo0008ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool0
>oooool00ol00?ooooooooooo`10ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`02ooooo`;o00008ooooolPo`00oakooooo8?l00?lMooooob3o003o
7_oooolPo`00o`Cooooo0_l00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co0000
1Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?oo
ool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool2o`0002?ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool08Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
8_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1
o`00007ooooo000Kooooo`;o00008oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Qooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
8_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo0_l0000Sooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo027ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001oooo
o`006oooool2o`0002?ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool08Oooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool08_ooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo9Ol000000ol00?oo0000o`00000Lo`000003o`00
ool0003o000001co000000?o003oo`000?l000007?l000000ol00?oo0000o`00000Ko`000003o`00
ool0003o000001co000000?o003oo`000?l000007?l000000ol00?oo0000o`00000So`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08_ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Rooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo
000Dooooo`;o00001Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`00
6oooool2o`0002?ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool08Oooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool08_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool08_ooool1o`00007ooooo000Kooooo`;o00008oooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Qoooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Rooooo`7o00000Oooool001_ooooo0_l0
000Sooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo027ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0R
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Roooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo02;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
02;ooooo0Ol00001ooooo`006oooool2o`0002?ooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08Oooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool1o`00007ooooo0008ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Rooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo02;ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02;o
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooob3o003o7_oooolPo`00oakooooo7ol00?lNooooob3o003o8oooool2o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool000Sooooo
0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001oooo
o`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000P?ooool00ol0003oooooooooo`1m
ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001_ooooo
0_l00020ooooo`03o`000?oooooooooo07gooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo0Ol00001ooooo`006oooool2o`00083ooooo00?o0000ooooooooool0OOooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool1o`00007ooooo000Coooo
o`?o00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001oooo
o`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`005?oo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool2o`00007ooooo000Dooooo`03o`000?oooooo
oooo00Coooooool00005o`00007ooooo000Cooooo`;o0000ooooool<ooooo`005?ooool00ol0003o
ooooooooo`3oooooo`[ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.54077, -1.16749, \
0.0161771, 0.012589}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Complex Fourier series", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[Pulse1[t], t, 5];\)\), "\[IndentingNewLine]", 
    \(series\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ImaginaryI]\ \[ExponentialE]\^\(\(-2\)\ \
\[ImaginaryI]\ \[Pi]\ t\)\)\/\[Pi] - \(\[ImaginaryI]\ \[ExponentialE]\^\(2\ \
\[ImaginaryI]\ \[Pi]\ t\)\)\/\[Pi] + \(\[ImaginaryI]\ \[ExponentialE]\^\(\(-6\
\)\ \[ImaginaryI]\ \[Pi]\ t\)\)\/\(3\ \[Pi]\) - \(\[ImaginaryI]\ \
\[ExponentialE]\^\(6\ \[ImaginaryI]\ \[Pi]\ t\)\)\/\(3\ \[Pi]\) + \(\
\[ImaginaryI]\ \[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ \[Pi]\ t\)\)\/\(5\ \
\[Pi]\) - \(\[ImaginaryI]\ \[ExponentialE]\^\(10\ \[ImaginaryI]\ \[Pi]\ t\)\)\
\/\(5\ \[Pi]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Real representation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(series2\  = series\  // \ ComplexExpand;\)\[IndentingNewLine]
    series2\  // TraditionalForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \(sin(2\ \[Pi]\ t)\)\)\/\[Pi] + \(2\ \(sin(6\ \
\[Pi]\ t)\)\)\/\(3\ \[Pi]\) + \(2\ \(sin(10\ \[Pi]\ t)\)\)\/\(5\ \[Pi]\)\)], \
"Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot result", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 500];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .462 m
.03318 .462 L
.04339 .462 L
.05298 .462 L
.06221 .462 L
.07203 .462 L
.08148 .462 L
.09153 .462 L
.10121 .462 L
.11052 .462 L
.12043 .462 L
.12997 .462 L
.13476 .462 L
.13914 .462 L
.14029 .462 L
.14155 .462 L
.14213 .462 L
.14244 .462 L
.14274 .462 L
.14302 .15604 L
.14332 .15604 L
.14385 .15604 L
.14891 .15604 L
.15885 .15604 L
.16842 .15604 L
.17763 .15604 L
.18743 .15604 L
.19686 .15604 L
.20688 .15604 L
.21654 .15604 L
.22584 .15604 L
.23572 .15604 L
.24524 .15604 L
.25439 .15604 L
.25908 .15604 L
.26037 .15604 L
.26107 .15604 L
.26141 .15604 L
.26172 .15604 L
.26201 .462 L
.26228 .462 L
.26288 .462 L
.26414 .462 L
.27347 .462 L
.28338 .462 L
.29294 .462 L
.30212 .462 L
.3119 .462 L
.32131 .462 L
.33132 .462 L
Mistroke
.34096 .462 L
.35023 .462 L
.3601 .462 L
.36959 .462 L
.37445 .462 L
.377 .462 L
.37839 .462 L
.37969 .462 L
.38029 .462 L
.38058 .462 L
.38086 .462 L
.38117 .15604 L
.38133 .15604 L
.38151 .15604 L
.38211 .15604 L
.38476 .15604 L
.38941 .15604 L
.39858 .15604 L
.40834 .15604 L
.41773 .15604 L
.42771 .15604 L
.43733 .15604 L
.44658 .15604 L
.45643 .15604 L
.46591 .15604 L
.47598 .15604 L
.48569 .15604 L
.49502 .15604 L
.49752 .15604 L
.49874 .15604 L
.49927 .15604 L
.49955 .15604 L
.49985 .15604 L
.50016 .462 L
.50045 .462 L
.50102 .462 L
.50228 .462 L
.50496 .462 L
.5141 .462 L
.52384 .462 L
.53321 .462 L
.54317 .462 L
.55277 .462 L
.562 .462 L
.57183 .462 L
.58129 .462 L
.59134 .462 L
.60102 .462 L
.61034 .462 L
.61515 .462 L
Mistroke
.61758 .462 L
.61825 .462 L
.61861 .462 L
.61879 .462 L
.61896 .462 L
.61912 .15604 L
.61928 .15604 L
.61963 .15604 L
.62025 .15604 L
.63034 .15604 L
.64006 .15604 L
.64941 .15604 L
.65935 .15604 L
.66893 .15604 L
.67814 .15604 L
.68794 .15604 L
.69738 .15604 L
.70741 .15604 L
.71708 .15604 L
.72637 .15604 L
.73108 .15604 L
.73357 .15604 L
.73488 .15604 L
.73626 .15604 L
.73686 .15604 L
.73749 .15604 L
.73768 .15604 L
.73785 .15604 L
.73801 .15604 L
.73818 .462 L
.73835 .462 L
.73852 .462 L
.73883 .462 L
.74118 .462 L
.74579 .462 L
.75498 .462 L
.76476 .462 L
.77418 .462 L
.78419 .462 L
.79383 .462 L
.80311 .462 L
.81298 .462 L
.82249 .462 L
.83258 .462 L
.84231 .462 L
.85168 .462 L
.85419 .462 L
.85541 .462 L
.85652 .462 L
.85681 .462 L
Mistroke
.85713 .462 L
.85743 .15604 L
.8577 .15604 L
.85896 .15604 L
.86163 .15604 L
.87117 .15604 L
.88034 .15604 L
.8901 .15604 L
.8995 .15604 L
.90949 .15604 L
.91911 .15604 L
.92837 .15604 L
.93822 .15604 L
.9477 .15604 L
.95778 .15604 L
.96749 .15604 L
.97619 .15604 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.02846 .37861 L
.03279 .43316 L
.03527 .4571 L
.03754 .47334 L
.03879 .47999 L
.03945 .48283 L
.04015 .48534 L
.04143 .48868 L
.04262 .49036 L
.04384 .4908 L
.04496 .49014 L
.04626 .48828 L
.04749 .48558 L
.04967 .47914 L
.05205 .47069 L
.05462 .46136 L
.05598 .45683 L
.0574 .4526 L
.05866 .44949 L
.05932 .4481 L
.06003 .44682 L
.06128 .44513 L
.06244 .44422 L
.06316 .44399 L
.06393 .44401 L
.06467 .44428 L
.06535 .44475 L
.06663 .44616 L
.06728 .44712 L
.06799 .44834 L
.07302 .46029 L
.07582 .46753 L
.07729 .4709 L
.07884 .47387 L
.0802 .47586 L
.08097 .4767 L
.08168 .47727 L
.08295 .47779 L
.08365 .4778 L
.08429 .47764 L
.08556 .47683 L
.0862 .47618 L
.0869 .4753 L
.0893 .47106 L
.09211 .46436 L
.09473 .45742 L
.09717 .45143 L
.09837 .44892 L
.09948 .44698 L
Mistroke
.10075 .44529 L
.10143 .44466 L
.10214 .44421 L
.10342 .44398 L
.10458 .44443 L
.10579 .44559 L
.10691 .44729 L
.10815 .4498 L
.10947 .45318 L
.11463 .47075 L
.11711 .47953 L
.11834 .48331 L
.11946 .48628 L
.12049 .48842 L
.12157 .49 L
.12266 .49076 L
.12386 .49051 L
.12518 .48878 L
.12584 .4873 L
.12657 .48518 L
.12785 .48012 L
.12904 .47386 L
.13174 .45414 L
.13462 .42494 L
.1447 .28075 L
.14969 .2101 L
.15242 .1787 L
.15497 .15574 L
.1563 .14644 L
.15773 .13856 L
.15854 .13504 L
.15931 .13233 L
.16 .13041 L
.16076 .12885 L
.16139 .12794 L
.1621 .12737 L
.16283 .12723 L
.16352 .12749 L
.16476 .12883 L
.16545 .13003 L
.16608 .13137 L
.17113 .14746 L
.17391 .15749 L
.17653 .16563 L
.17771 .16857 L
.17897 .17104 L
.17962 .17205 L
.18035 .17293 L
.18162 .17387 L
.18277 .17406 L
Mistroke
.18401 .17357 L
.18518 .1725 L
.18625 .17104 L
.19062 .16155 L
.19529 .14949 L
.19667 .14644 L
.19797 .14402 L
.19914 .1423 L
.2004 .141 L
.20161 .14033 L
.20287 .14026 L
.20396 .14071 L
.20515 .14174 L
.20586 .14262 L
.20654 .14361 L
.2078 .14585 L
.21064 .15235 L
.2133 .15935 L
.21576 .16557 L
.2181 .17036 L
.21928 .17213 L
.22059 .17346 L
.22189 .17405 L
.22263 .17403 L
.2233 .1738 L
.22454 .17279 L
.22584 .17096 L
.23539 .1411 L
.23672 .13673 L
.23815 .13265 L
.2388 .13109 L
.2395 .12968 L
.24074 .12791 L
.24194 .12723 L
.24305 .12763 L
.24428 .12935 L
.2456 .13279 L
.24682 .13756 L
.24795 .14338 L
.25052 .16163 L
.25279 .18337 L
.2552 .21172 L
.26397 .34066 L
.26899 .41114 L
.27174 .44207 L
.27429 .46437 L
.27563 .47333 L
.27706 .48081 L
.27788 .4841 L
.27865 .48659 L
Mistroke
.27935 .48831 L
.2801 .48966 L
.28074 .49039 L
.28145 .49077 L
.28218 .49073 L
.28287 .49031 L
.28411 .48871 L
.2848 .48739 L
.28544 .48595 L
.2905 .46939 L
.29328 .45942 L
.29465 .45505 L
.2959 .45153 L
.29707 .4488 L
.29835 .44646 L
.29964 .44487 L
.30034 .44433 L
.301 .44404 L
.30217 .44404 L
.30323 .44458 L
.30446 .44582 L
.30562 .44753 L
.3104 .45839 L
.31302 .46529 L
.31548 .4711 L
.31756 .47487 L
.31874 .47637 L
.31981 .4773 L
.32093 .47777 L
.32214 .47772 L
.32342 .47703 L
.3246 .47582 L
.32589 .47392 L
.32711 .47165 L
.3294 .46641 L
.33452 .45314 L
.33583 .45019 L
.33722 .44756 L
.3384 .44581 L
.3397 .44453 L
.34043 .44413 L
.3411 .44397 L
.34187 .44405 L
.3426 .44439 L
.3439 .44562 L
.34464 .44666 L
.34532 .44786 L
.35041 .4623 L
.35308 .47207 L
.35591 .48175 L
Mistroke
.3571 .48515 L
.35838 .48805 L
.35912 .4893 L
.35979 .49013 L
.3611 .49081 L
.36228 .49024 L
.36355 .48822 L
.36476 .48487 L
.36587 .48045 L
.36694 .47501 L
.36809 .46779 L
.37017 .45118 L
.3749 .39778 L
.38449 .2554 L
.38913 .19383 L
.39172 .16698 L
.39408 .14847 L
.39542 .14055 L
.39613 .13715 L
.39687 .13413 L
.39753 .13195 L
.39825 .13005 L
.39951 .12792 L
.40077 .12722 L
.40148 .12741 L
.40212 .12791 L
.40337 .1297 L
.40456 .13227 L
.40983 .14969 L
.41242 .15891 L
.41479 .16608 L
.41598 .16894 L
.41727 .17138 L
.41858 .17307 L
.41929 .17364 L
.41996 .17396 L
.4207 .17407 L
.4214 .17393 L
.42272 .17308 L
.42345 .17228 L
.42413 .17136 L
.42567 .16867 L
.43065 .15645 L
.43309 .1502 L
.43532 .14535 L
.43652 .1433 L
.43766 .1418 L
.43887 .14073 L
.44018 .14023 L
.44089 .14024 L
Mistroke
.44153 .14043 L
.44227 .14086 L
.44296 .14145 L
.4442 .14296 L
.44554 .14518 L
.45014 .15602 L
.45267 .16267 L
.45507 .16823 L
.45615 .17028 L
.45729 .17202 L
.45855 .17335 L
.45972 .17399 L
.46075 .17403 L
.46173 .1736 L
.4628 .1726 L
.46395 .17093 L
.46511 .16865 L
.46637 .16553 L
.46891 .15762 L
.47346 .1412 L
.47608 .13308 L
.47683 .13124 L
.47754 .12978 L
.47818 .12872 L
.47887 .12787 L
.48014 .12722 L
.48078 .12738 L
.48149 .12797 L
.48273 .13011 L
.4839 .13349 L
.4852 .1389 L
.48662 .14684 L
.48921 .16677 L
.49172 .19266 L
.49406 .22162 L
.4993 .29823 L
.50496 .38306 L
.50765 .41804 L
.51049 .44845 L
.51291 .46811 L
.51428 .4765 L
.51556 .48253 L
.51686 .48689 L
.51808 .48949 L
.51918 .49063 L
.52038 .49069 L
.52168 .48952 L
.52233 .48848 L
.52306 .48705 L
.52553 .48021 L
Mistroke
.53016 .46366 L
.53272 .45513 L
.53397 .45159 L
.53514 .44884 L
.53623 .4468 L
.53739 .44521 L
.53868 .4442 L
.53985 .44397 L
.54091 .44431 L
.54206 .44525 L
.54315 .44663 L
.54415 .44829 L
.54881 .45923 L
.55323 .47036 L
.55441 .47276 L
.55566 .47488 L
.55632 .47578 L
.55704 .47659 L
.55832 .47753 L
.55947 .47782 L
.56071 .47754 L
.56188 .4767 L
.56296 .47548 L
.56425 .47348 L
.56544 .47116 L
.56816 .46471 L
.57103 .45713 L
.57364 .4508 L
.57483 .44841 L
.57612 .44631 L
.57734 .4449 L
.57846 .44415 L
.57965 .44398 L
.58097 .44457 L
.58163 .44518 L
.58233 .44606 L
.58362 .44825 L
.58852 .46235 L
.59374 .48092 L
.59528 .48537 L
.59604 .48716 L
.59674 .48853 L
.59805 .49028 L
.59873 .49072 L
.59946 .49078 L
.60077 .48977 L
.60199 .4874 L
.6027 .48539 L
.60334 .48312 L
.60477 .47646 L
Mistroke
.60602 .46891 L
.60734 .45909 L
.60972 .43692 L
.6151 .36868 L
.6202 .29134 L
.62487 .22327 L
.62944 .17048 L
.63174 .15144 L
.63304 .14313 L
.63425 .13702 L
.63557 .13211 L
.63681 .12908 L
.63793 .12761 L
.63914 .12725 L
.64046 .12818 L
.64113 .12911 L
.64186 .13046 L
.64315 .13356 L
.64436 .13712 L
.64889 .1532 L
.65111 .16089 L
.65318 .16684 L
.65442 .16967 L
.65555 .17166 L
.6568 .17318 L
.65748 .1737 L
.65813 .17398 L
.65926 .174 L
.6603 .1735 L
.66144 .17241 L
.66265 .1707 L
.66754 .15966 L
.67216 .14792 L
.6734 .14537 L
.67472 .14314 L
.67541 .14221 L
.67616 .14138 L
.67685 .14081 L
.67749 .14044 L
.67871 .14021 L
.67983 .14053 L
.68112 .14151 L
.68235 .14303 L
.6873 .15357 L
.68973 .16 L
.69197 .16562 L
.69401 .16987 L
.69504 .17154 L
.69616 .17292 L
.69729 .17378 L
Mistroke
.69851 .17407 L
.69965 .1737 L
.7007 .17283 L
.70192 .17114 L
.70306 .16897 L
.70562 .16217 L
.71028 .14576 L
.71284 .13694 L
.71409 .13329 L
.71524 .13056 L
.71644 .12848 L
.71774 .12733 L
.71838 .12723 L
.71908 .12751 L
.71982 .12826 L
.7205 .12941 L
.72165 .13235 L
.7229 .13705 L
.72407 .14297 L
.72516 .14974 L
.72721 .16598 L
.72939 .18784 L
.73889 .32121 L
.74373 .3922 L
.74832 .44595 L
.75085 .46706 L
.75229 .47601 L
.75362 .48236 L
.75485 .4866 L
.75596 .48913 L
.75725 .49061 L
.75846 .4907 L
.75952 .48984 L
.76069 .488 L
.76191 .48525 L
.76304 .48205 L
.76726 .4673 L
.76962 .45893 L
.77185 .45217 L
.77309 .44917 L
.77374 .44784 L
.77443 .44664 L
.77564 .44505 L
.77677 .4442 L
.77791 .44397 L
.77916 .4444 L
.78046 .44559 L
.78167 .44729 L
.78384 .45156 L
.78616 .45726 L
Mistroke
.78866 .46388 L
.79137 .47045 L
.79261 .47296 L
.79392 .47512 L
.79504 .47649 L
.79628 .47746 L
.79753 .47782 L
.79867 .4776 L
.79998 .4767 L
.80123 .47523 L
.80238 .4734 L
.80345 .47135 L
.80587 .46571 L
.81457 .44584 L
.81575 .44463 L
.81702 .44401 L
.81822 .4441 L
.8193 .44477 L
.82053 .44621 L
.82169 .4482 L
.82294 .45101 L
.8243 .45473 L
.82977 .47387 L
.83216 .48194 L
.83343 .48549 L
.83413 .48714 L
.83479 .48846 L
.83609 .49023 L
.83727 .49081 L
.83838 .49032 L
.83959 .48854 L
.84087 .48514 L
.84158 .48252 L
.84223 .47969 L
.84468 .46497 L
.84693 .4458 L
.84937 .41944 L
.8538 .35984 L
.86335 .21814 L
.86567 .18978 L
.86816 .16475 L
.86959 .1532 L
.87089 .14455 L
.8722 .13767 L
.87344 .13282 L
.87448 .12996 L
.87562 .12801 L
.87682 .12723 L
.87794 .12758 L
.87898 .12875 L
Mistroke
.87994 .13044 L
.88099 .13288 L
.8821 .13601 L
.88694 .15305 L
.88932 .16123 L
.89151 .16743 L
.89268 .16999 L
.89391 .17205 L
.89515 .17341 L
.89586 .17385 L
.89652 .17405 L
.89766 .17391 L
.89871 .17326 L
.89992 .17193 L
.90106 .17016 L
.9036 .16484 L
.90594 .15884 L
.90869 .15166 L
.91126 .14582 L
.91236 .14386 L
.91351 .1422 L
.91477 .14093 L
.91593 .14032 L
.91698 .14023 L
.91795 .14054 L
.91902 .14132 L
.92016 .14264 L
.92138 .14455 L
.92271 .14714 L
.92512 .15286 L
.92963 .16459 L
.93198 .16964 L
.9333 .17177 L
.9345 .17315 L
.93562 .17389 L
.93684 .17404 L
.93799 .17355 L
.93907 .17251 L
.93972 .17162 L
.94042 .17043 L
.9417 .16772 L
.94409 .16098 L
.94946 .14188 L
.95079 .13741 L
.95221 .13322 L
.9529 .13151 L
.95355 .13011 L
.95478 .12817 L
.95607 .12726 L
.95679 .1273 L
Mistroke
.95746 .12774 L
.95814 .1286 L
.95889 .13004 L
.95967 .13212 L
.96041 .13464 L
.96164 .14012 L
.96294 .14763 L
.96525 .1655 L
.96775 .19082 L
.97048 .22481 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo01gooooo00?o
o`00ooooooooool03Oooool00ooo003oooooooooo`0Looooo`;oo`003_ooool01Ooo003ooooooooo
oooooooo000001[ooooo0_oo000>ooooo`;oo`007_ooool00ooo003oooooooooo`0<ooooo`;oo`00
1oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Looooo`03ool00?oo
ooooo`0000gooooo0_oo000Nooooo`;oo`003Oooool3ool000;ooooo00?o0000ooooooooool06?oo
ool2ool000gooooo0ooo000Mooooo`?oo`003Oooool2ool000Oooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool07?ooool00ooo003oooooool0000=ooooo`03ool00?oooooo
o`0001cooooo0ooo000=ooooo`03ool00?ooooooo`0000;ooooo00?o0000ooooooooool06?ooool0
0ooo003oooooool0000<ooooo`03ool00?ooooooo`0001gooooo00?oo`00oooooooo00003?ooool0
0ooo003oooooool00007ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool07?ooool01?oo003ooooooooooooo0004ooooo`?oo`001?ooool0
1?oo003ooooooooooooo000Looooo`03ool00?ooooooo`0000Gooooo0ooo0005ooooo`03ool00?oo
ooooo`0000;ooooo00?o0000ooooooooool05oooool01?oo003ooooooooooooo0005ooooo`;oo`00
1Oooool00ooo003oooooool0000Mooooo`03ool00?ooooooo`0000Gooooo0_oo0005ooooo`04ool0
0?ooooooooooool000Kooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07?ooool01?oo003ooooooooo
oooo0004ooooo`03ool00?ooooooo`0000Cooooo00Coo`00ooooooooooooo`007?ooool01?oo003o
oooooooooooo0004ooooo`03ool00?ooooooo`0000Gooooo00?oo`00oooooooo00000_ooool00ol0
003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooool00005
ooooo`03ool00?ooooooo`0001gooooo00Coo`00ooooooooooooo`001?ooool00ooo003oooooool0
0004ooooo`04ool00?ooooooooooool000Kooooo00?o0000ooooooooool03?ooool000gooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00001Rooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool04oooool5o`0000;ooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00Coo`00oooo
ooooooooo`001?ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool001cooooo
00Coo`00ooooooooooooo`001?ooool00ooo003oooooool00004ooooo`04ool00?ooooooooooool0
00;ooooo00?o0000ooooooooool05oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00
ooooooooooooo`001?ooool01?oo003ooooooooooooo000Kooooo`05ool00?oooooooooooooooooo
00000oooool01?oo003ooooooooooooo0004ooooo`04ool00?ooooooooooool000Kooooo00?o0000
ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00002oooool01?l0003ooooooooooooo
ool2o`0001[ooooo6Ol00?lGoooooaSo003o5ooooolIo`00oaKooooo6Ol00?l2ooooo`?o00007?oo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`05ool0
0?oooooooooooooooooo00001?ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool001cooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo0000
0oooool01?oo003ooooooooooooo0002ooooo`03o`000?oooooooooo01Oooooo00Goo`00oooooooo
ooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0001_ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooooooool00005ooooo`;o00003_ooool001Cooooo00Co0000oooooooo
oooo00001oooool4o`0000Cooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000
ooooooooool06oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00002ooooo`05ool00?oooooooooooooooooo00006oooool00ooo003oooooooooo`02ooooo`04
ool00?ooooooooooool000Cooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooo`00000I
ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02ooooo`04ool00?oo
ooooooooool000?ooooo00?oo`00ooooooooool06Oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00001_ooool0
0ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01_ooooo00?oo`00ooooooooool00_ooool01?oo003ooooooooooooo0004ooooo`03ool0
0?ooooooo`0000?ooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`02ooooo`03ool0
0?ooooooo`0000Gooooo00?oo`00oooooooo00001?ooool00ooo003oooooo`00000Iooooo`05ool0
0?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02ooooo`03ool00?ooooooo`0000Co
oooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`02ooooo`03ool00?ooooooo`0000Co
oooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo000Eooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo0_l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`0Kooooo`03ool00?oooooooooo00;ooooo0ooo0005ooooo`?oo`000oooool00ooo003o
ooooooooo`0Iooooo`03ool00?oooooooooo00?ooooo0_oo0005ooooo`?oo`001?ooool00ooo003o
ooooo`00000Iooooo`03ool00?oooooooooo00;ooooo0_oo0006ooooo`;oo`001?ooool00ooo003o
ooooooooo`0Iooooo`03ool00?oooooooooo00;ooooo0ooo0005ooooo`;oo`001?ooool00ooo003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01_ooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooool000006Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Wooooo
00?oo`00ooooooooool04?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00ooooool000006Oooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0I
ooooo`;o0000<?ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo000001Wooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Koooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooo000001Wooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool06?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo000001Wooooo00?oo`00oooooooo
ool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool0
0?oooooooooo01;ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Aooooo`03ool0
0?oooooo000001Sooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo017ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool06?oo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooo000001Sooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Booooo`03ool00?l0003o
oooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0<ooooo`009oooool2o`00
01[ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool06_ooool00ooo
003oooooooooo`0Booooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04_ooool00ooo
003o0000ooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01So
oooo00?oo`00ooooooooool04_ooool00ooo003o0000ooooo`0Gooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003o0000
ooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool06_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool04oooool00ooo003o0000ooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0J
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003o0000ooooo`0G
ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0B
ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool06_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Oooooo00?oo`00oooo
ooooool04oooool00ooo003o0000ooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0000`ooooo`03
o`000?oooooooooo01[ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03
ool00?oooooooooo01?ooooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
6_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00o`000?ooool0
5oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
4oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Wooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oo
oooooooo01?ooooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Wooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Iooooo`;o0000<?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Iooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooo`00000>ooooo`008Oooool2o`00
00Cooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02Oooooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo
003ooooooooooooooooo000000kooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02Kooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00Go
o`00ooooooooooooooooo`00000>ooooo`008?ooool01?l0003oooooooooool00003oooooaco0000
00?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o000001Co0000
00?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o000001Co0000
00?o003oo`000?l000006ol0000Xooooo`04o`000?ooooooooooo`0000Cooooo1?l000000ooo003o
0000o`00000Eo`000003ool00?l0003o000001Co000000?oo`00o`000?l000005Ol000000ooo003o
0000o`00000Eo`000003ool00?l0003o000001Go000000?oo`00o`000?l000005?l000000ooo003o
0000o`00000Eo`000003ool00?l0003o000001Go000000?oo`00o`000?l000000_l0000>ooooo`00
8?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool06_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooool0000Gooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0
023ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01[ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00004ooooo`05o`000?oo
oooooooooooooooo00005oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo
000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Jooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001?ooool01Ol0003o
ooooooooooooooooo`0001Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<oooo
o`008Oooool2o`0000Cooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03
o`000?oooooooooo02Oooooo0_l00005ooooo`05o`000?oooooooooooooooooo00005_ooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`05o`000?oooooooooooooo
oooo00005_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`;o
00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool01Ol0003oooooooooooooooooo`00
01Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003o
ooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool01Ol0003o
ooooooooooooooooo`0001Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o0000ool00?oo
ool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool0
0?oooooooooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_oo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o0000ool00?ooool05?oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00
01[ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03o`000?oo003ooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03o`000?oo003ooooo01Co
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01[o
oooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo003ooooo
ooooo`0Fooooo`03o`000?oo003ooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool04_ooool00ooo003oooooooooo`0Fooooo`03o`000?oo003ooooo01Cooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0J
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0C
ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0F
ooooo`03o`000?oo003ooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0C
ooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool00_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Sooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`0Fooooo`03o`000?oo003ooooo01Cooooo00?oo`00oooo
ooooool05_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01_ooooo00?o0000oooo
ooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0000`ooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool05_ooool00ol0003oo`00ooooo`0Dooooo`03
ool00?oooooooooo01Kooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Kooooo`03
o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
6_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooool0000Dooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool05_ooool00ol0003oooooool0000Cooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Kooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05_ooool0
0ol0003oooooool0000Cooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool05_ooool00ol0003oooooool0000Cooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool04Oooool00ooo003o
ooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05_ooool00ol0003o
ooooool0000Cooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04Oooool00ooo003o
ooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool05oooool00ol0003oooooool0000Cooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo
000Wooooo`;o00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06Oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo01Oooooo00?o0000oooooooo00004oooool00ooo003ooooooooo
o`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06oooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool06Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Oooooo00?o0000
oooooooo00004oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool06oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo0_oo0006ooooo`;oo`001?ooool00ooo003oooooooooo`0Ioooo
o`03ool00?oooooooooo00;ooooo0_oo0006ooooo`;oo`001?ooool00ooo003oooooooooo`0Goooo
o`03o`000?ooooooo`0000Cooooo0_oo0006ooooo`;oo`001Oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo00?ooooo0_oo0005ooooo`?oo`001?ooool00ooo003oooooooooo`0Koooo
o`03o`000?oooooooooo00cooooo000Eooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool06oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool01?ooool01?oo003oooooooooooooool3ool000Gooooo00?oo`00oooooooo00001?ooool00ooo
003oooooooooo`0Iooooo`03ool00?oooooooooo00;ooooo0_oo0005ooooo`?oo`001?ooool00ooo
003oooooooooo`0Gooooo`03o`000?ooooooo`0000Cooooo00?oo`00oooooooo00001Oooool00ooo
003oooooool00004ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool00_ooool00ooo
003oooooool00005ooooo`03ool00?ooooooo`0000Cooooo00?oo`00ooooooooool06oooool00ol0
003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool06_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`07ool00?oooooooooooooooooo003oooooool00005oooo
o`03ool00?ooooooo`0000Cooooo00?oo`00ooooooooool06Oooool01ooo003ooooooooooooooooo
o`00oooooooo00001Oooool00ooo003oooooool00004ooooo`03ool00?oooooooooo01Oooooo00?o
0000oooooooo00000oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00oooooooo00000ooo
ool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00001Ooo
ool00ooo003oooooool00004ooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool03?oo
ool001Cooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000001_ooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool06_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05ool00?oooooooooooooo
oooo00000_ooool00ooo003oooooooooo`02ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooo
ooooool06Oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_ooool0
1?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo01Oooooo00?o0000oooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03
ool00?oooooooooo01[ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01Ooo003oooooooooooooooooo`0001kooooo00?o0000ooooooooool03?oo
ool001Cooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0000?ooooo
6?l00?lGoooooaWo003o5_oooolIo`00oaOooooo6?l00?lJooooo`?o00007?ooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`05ool00?oooooooooooooo
oooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
000Kooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05
ool00?oooooooooooooooooo00006Oooool01?l0003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
6_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`05ool00?oooooooooooooooooo00007Oooool2o`0000kooooo000Dooooo`04o`000?oooooooooo
o`0000Oooooo1?l00004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oo
oooooooo00Cooooo00Coo`00ooooooooooooo`001?ooool00ooo003oooooool00004ooooo`04ool0
0?ooooooooooool001cooooo00Coo`00ooooooooooooo`001?ooool01?oo003ooooooooooooo0003
ooooo`05ool00?oooooooooooooooooo00006Oooool01?l0003ooooooooooooo0002ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00oooooooo00001?ooool01?oo003ooooooooooooo000Looooo`04
ool00?ooooooooooool000Cooooo00?oo`00oooooooo00001?ooool01?oo003ooooooooooooo000N
ooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool06_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool01?oo003ooooooooooooo0004ooooo`?oo`001?ooool01?oo003ooooo
oooooooo000Looooo`04ool00?ooooooooooool000Gooooo0ooo0004ooooo`04ool00?oooooooooo
ool001Wooooo00Ko0000ooooooooooooo`00oooooooo0005ooooo`?oo`001Oooool00ooo003ooooo
ool0000Looooo`04ool00?ooooooooooool000Cooooo00?oo`00oooooooo00001?ooool01?oo003o
oooooooooooo000Nooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00002?ooool5o`0000?o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01_o
oooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`04ooooo`04ool00?ooooooooooool0
00Gooooo0_oo0005ooooo`03ool00?ooooooo`0001gooooo0_oo0006ooooo`;oo`001Oooool00ooo
003oooooool0000Jooooo`06o`000?ooooooooooool00?ooooooo`001Oooool2ool000Kooooo00?o
o`00oooooooo00007?ooool00ooo003oooooool00006ooooo`;oo`001?ooool01?oo003ooooooooo
oooo000Nooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo0_oo
000=ooooo`03ool00?ooooooo`0001gooooo0_oo000=ooooo`?oo`006_ooool01_l0003ooooooooo
oooo003oooooool000gooooo0ooo000Looooo`03ool00?ooooooo`0000gooooo00?oo`00oooooooo
00007_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`;oo`00
3_ooool2ool001gooooo0_oo000>ooooo`;oo`006_ooool00ol0003oooooooooo`03ool000gooooo
0_oo000Nooooo`;oo`003Oooool2ool001oooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000oooo
ooooool0H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oo
oooo0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000P
ooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool09_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool03?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`05o`000?oooooooooo
ooooool000003_ooool0027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o0000:Oooool00ol0
003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_l0000>ooooo`008Oooool00ol0003oooooooooo`03ooooolSo
0000:Oooool00ol0003oooooooooo`04ooooolOo00003_ooool0023ooooo0_l0003eooooo`;o0000
foooool0027ooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`3Iooooo`00oooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["More terms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[Pulse1[t], t, 10];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], 
        ImageSize \[Rule] 500];\)\), "\[IndentingNewLine]", 
    \(\(series\  // \ ComplexExpand\)\  // TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .462 m
.03318 .462 L
.04339 .462 L
.05298 .462 L
.06221 .462 L
.07203 .462 L
.08148 .462 L
.09153 .462 L
.10121 .462 L
.11052 .462 L
.12043 .462 L
.12997 .462 L
.13476 .462 L
.13914 .462 L
.14029 .462 L
.14155 .462 L
.14213 .462 L
.14244 .462 L
.14274 .462 L
.14302 .15604 L
.14332 .15604 L
.14385 .15604 L
.14891 .15604 L
.15885 .15604 L
.16842 .15604 L
.17763 .15604 L
.18743 .15604 L
.19686 .15604 L
.20688 .15604 L
.21654 .15604 L
.22584 .15604 L
.23572 .15604 L
.24524 .15604 L
.25439 .15604 L
.25908 .15604 L
.26037 .15604 L
.26107 .15604 L
.26141 .15604 L
.26172 .15604 L
.26201 .462 L
.26228 .462 L
.26288 .462 L
.26414 .462 L
.27347 .462 L
.28338 .462 L
.29294 .462 L
.30212 .462 L
.3119 .462 L
.32131 .462 L
.33132 .462 L
Mistroke
.34096 .462 L
.35023 .462 L
.3601 .462 L
.36959 .462 L
.37445 .462 L
.377 .462 L
.37839 .462 L
.37969 .462 L
.38029 .462 L
.38058 .462 L
.38086 .462 L
.38117 .15604 L
.38133 .15604 L
.38151 .15604 L
.38211 .15604 L
.38476 .15604 L
.38941 .15604 L
.39858 .15604 L
.40834 .15604 L
.41773 .15604 L
.42771 .15604 L
.43733 .15604 L
.44658 .15604 L
.45643 .15604 L
.46591 .15604 L
.47598 .15604 L
.48569 .15604 L
.49502 .15604 L
.49752 .15604 L
.49874 .15604 L
.49927 .15604 L
.49955 .15604 L
.49985 .15604 L
.50016 .462 L
.50045 .462 L
.50102 .462 L
.50228 .462 L
.50496 .462 L
.5141 .462 L
.52384 .462 L
.53321 .462 L
.54317 .462 L
.55277 .462 L
.562 .462 L
.57183 .462 L
.58129 .462 L
.59134 .462 L
.60102 .462 L
.61034 .462 L
.61515 .462 L
Mistroke
.61758 .462 L
.61825 .462 L
.61861 .462 L
.61879 .462 L
.61896 .462 L
.61912 .15604 L
.61928 .15604 L
.61963 .15604 L
.62025 .15604 L
.63034 .15604 L
.64006 .15604 L
.64941 .15604 L
.65935 .15604 L
.66893 .15604 L
.67814 .15604 L
.68794 .15604 L
.69738 .15604 L
.70741 .15604 L
.71708 .15604 L
.72637 .15604 L
.73108 .15604 L
.73357 .15604 L
.73488 .15604 L
.73626 .15604 L
.73686 .15604 L
.73749 .15604 L
.73768 .15604 L
.73785 .15604 L
.73801 .15604 L
.73818 .462 L
.73835 .462 L
.73852 .462 L
.73883 .462 L
.74118 .462 L
.74579 .462 L
.75498 .462 L
.76476 .462 L
.77418 .462 L
.78419 .462 L
.79383 .462 L
.80311 .462 L
.81298 .462 L
.82249 .462 L
.83258 .462 L
.84231 .462 L
.85168 .462 L
.85419 .462 L
.85541 .462 L
.85652 .462 L
.85681 .462 L
Mistroke
.85713 .462 L
.85743 .15604 L
.8577 .15604 L
.85896 .15604 L
.86163 .15604 L
.87117 .15604 L
.88034 .15604 L
.8901 .15604 L
.8995 .15604 L
.90949 .15604 L
.91911 .15604 L
.92837 .15604 L
.93822 .15604 L
.9477 .15604 L
.95778 .15604 L
.96749 .15604 L
.97619 .15604 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.02605 .36562 L
.02846 .41899 L
.02962 .44035 L
.03072 .45718 L
.03171 .46931 L
.03279 .4792 L
.03397 .48624 L
.03527 .48966 L
.03592 .48984 L
.03663 .48902 L
.0379 .48532 L
.03916 .47956 L
.04036 .47298 L
.04262 .46028 L
.04384 .45442 L
.045 .45014 L
.04564 .4484 L
.04633 .44705 L
.04753 .44607 L
.04869 .44671 L
.04991 .44886 L
.05095 .45165 L
.0521 .45541 L
.05468 .46465 L
.0561 .46901 L
.0568 .47072 L
.05745 .472 L
.0587 .47352 L
.05936 .4738 L
.06006 .47369 L
.06119 .47268 L
.06244 .47052 L
.06508 .46365 L
.06754 .45693 L
.06878 .45432 L
.06947 .45322 L
.0701 .4525 L
.07079 .45202 L
.07154 .45188 L
.07225 .45211 L
.0729 .45263 L
.07361 .4535 L
.07426 .45457 L
.07576 .45774 L
.07878 .46541 L
.08012 .46834 L
.08138 .47038 L
.08208 .47112 L
.08284 .47156 L
Mistroke
.08354 .47163 L
.08418 .4714 L
.08546 .47014 L
.08618 .46901 L
.08685 .46773 L
.08936 .46165 L
.09054 .45864 L
.09179 .45575 L
.09298 .45362 L
.09406 .45236 L
.09531 .45187 L
.0965 .45244 L
.09778 .45413 L
.09851 .45553 L
.09918 .45706 L
.102 .46485 L
.10323 .46821 L
.10388 .46978 L
.10458 .47124 L
.10575 .47303 L
.10685 .47377 L
.10809 .47343 L
.10923 .47198 L
.11046 .46927 L
.1118 .46527 L
.11423 .4566 L
.11542 .45257 L
.11652 .44942 L
.11768 .44711 L
.11894 .44608 L
.12004 .44665 L
.12104 .44841 L
.12219 .4519 L
.12328 .45647 L
.12577 .46988 L
.12713 .47757 L
.12841 .48385 L
.12949 .48774 L
.13066 .4898 L
.13196 .48871 L
.13315 .48401 L
.13445 .47442 L
.13565 .46107 L
.13697 .44157 L
.13838 .4155 L
.1439 .28237 L
.14648 .22045 L
.14789 .19152 L
.14922 .16889 L
.15034 .15349 L
Mistroke
.15155 .14109 L
.15224 .13595 L
.1529 .13232 L
.15412 .12861 L
.15482 .12815 L
.15546 .12866 L
.15619 .1302 L
.15688 .13245 L
.1581 .13793 L
.15943 .14518 L
.16219 .16041 L
.16295 .16386 L
.16376 .16696 L
.16452 .16924 L
.16522 .17073 L
.16648 .17194 L
.16718 .17181 L
.16784 .1712 L
.16905 .16897 L
.17032 .16538 L
.1731 .15555 L
.17447 .15099 L
.17571 .14762 L
.17679 .14556 L
.17792 .1444 L
.17906 .14432 L
.1803 .14543 L
.18157 .14767 L
.18292 .15099 L
.18536 .1579 L
.1867 .16138 L
.18796 .16395 L
.18926 .16564 L
.18996 .16606 L
.1907 .16614 L
.19202 .16533 L
.19327 .16354 L
.19439 .16126 L
.19562 .15829 L
.19841 .15128 L
.19921 .14961 L
.19997 .1483 L
.20065 .14739 L
.20138 .14673 L
.20203 .14643 L
.20274 .14644 L
.20348 .1468 L
.20417 .14746 L
.2054 .14933 L
.20673 .15214 L
Mistroke
.20933 .15875 L
.2107 .16198 L
.21145 .16346 L
.21215 .16459 L
.21342 .1659 L
.21409 .16615 L
.21482 .16606 L
.2161 .165 L
.21728 .16308 L
.21987 .15657 L
.22231 .14974 L
.22338 .14728 L
.22451 .14537 L
.22574 .14431 L
.22688 .14442 L
.22806 .14569 L
.22915 .14786 L
.23035 .15117 L
.23164 .1555 L
.23289 .16003 L
.23425 .16477 L
.23542 .16825 L
.23672 .17092 L
.23792 .17195 L
.2392 .17124 L
.24039 .16885 L
.2415 .16514 L
.24259 .1603 L
.2436 .15507 L
.24586 .1422 L
.24706 .13595 L
.24835 .13084 L
.24957 .12834 L
.25068 .12867 L
.25198 .13285 L
.25271 .13724 L
.25339 .14266 L
.25463 .15613 L
.25595 .17531 L
.25856 .22674 L
.26101 .28609 L
.2639 .35949 L
.26658 .41951 L
.26782 .44205 L
.26899 .45945 L
.26963 .46739 L
.27033 .47458 L
.27155 .48369 L
.27221 .48685 L
.27293 .489 L
Mistroke
.27368 .48987 L
.27438 .48954 L
.27563 .48662 L
.27634 .48392 L
.27698 .48096 L
.27927 .46827 L
.28171 .45541 L
.28298 .45049 L
.28371 .44846 L
.28438 .44711 L
.28557 .44608 L
.28686 .44679 L
.28801 .44887 L
.28928 .45236 L
.29183 .46131 L
.29305 .46558 L
.29421 .46905 L
.29525 .47146 L
.29638 .47316 L
.29755 .47381 L
.29864 .47338 L
.29981 .47191 L
.30105 .46939 L
.30313 .46381 L
.30539 .45753 L
.30671 .45462 L
.30793 .45278 L
.30909 .45194 L
.31033 .4521 L
.31144 .45314 L
.31248 .45478 L
.31362 .45718 L
.31485 .46021 L
.31742 .46667 L
.31872 .46925 L
.31945 .47035 L
.32014 .47108 L
.32137 .47164 L
.32248 .47127 L
.32377 .46983 L
.32499 .46763 L
.32926 .45714 L
.3303 .45494 L
.33141 .45315 L
.33263 .45205 L
.33378 .45194 L
.33442 .45229 L
.33511 .45299 L
.33637 .45505 L
.3376 .45787 L
Mistroke
.33874 .46096 L
.34097 .46726 L
.34218 .47023 L
.34332 .47233 L
.34458 .47363 L
.34525 .47381 L
.34596 .47359 L
.34723 .47213 L
.3484 .4697 L
.34975 .46577 L
.35122 .46064 L
.35249 .45604 L
.35389 .45141 L
.35518 .44814 L
.3564 .44638 L
.35768 .44624 L
.3584 .447 L
.35906 .44825 L
.36017 .4515 L
.36139 .45654 L
.36384 .46978 L
.365 .47633 L
.36624 .4827 L
.36742 .48726 L
.36851 .48958 L
.36977 .48929 L
.37041 .4877 L
.37112 .48472 L
.37234 .47623 L
.37349 .46431 L
.37465 .44833 L
.37575 .42968 L
.37781 .38679 L
.38245 .27076 L
.38505 .21015 L
.38633 .18525 L
.3875 .16606 L
.38855 .15218 L
.3897 .14068 L
.39085 .13299 L
.39207 .12885 L
.39276 .12816 L
.39341 .12847 L
.39463 .13124 L
.39594 .13666 L
.39737 .14427 L
.39972 .15752 L
.40096 .16352 L
.40165 .16625 L
.40231 .16839 L
Mistroke
.40356 .17111 L
.4047 .17196 L
.40577 .17139 L
.40695 .16942 L
.40818 .16612 L
.4095 .16171 L
.41187 .15322 L
.41302 .14965 L
.41426 .14666 L
.41543 .14487 L
.4165 .14423 L
.41748 .14449 L
.41855 .14564 L
.41966 .14767 L
.42071 .15016 L
.42313 .15698 L
.42446 .16055 L
.4257 .16332 L
.42635 .16443 L
.42705 .16534 L
.42782 .16596 L
.42853 .16616 L
.4298 .16563 L
.43044 .16495 L
.43115 .16392 L
.43593 .15263 L
.4373 .14961 L
.43861 .14756 L
.43977 .14656 L
.44104 .1465 L
.44219 .14738 L
.44347 .14927 L
.44479 .15208 L
.44604 .15517 L
.44845 .16121 L
.44959 .16354 L
.45065 .16512 L
.4517 .166 L
.45286 .16608 L
.45387 .16537 L
.45496 .16385 L
.45621 .16125 L
.45739 .15819 L
.45959 .15192 L
.46076 .14888 L
.462 .14628 L
.46318 .14472 L
.46425 .14422 L
.46551 .14486 L
.46622 .1458 L
Mistroke
.46688 .14703 L
.46809 .15008 L
.46937 .1542 L
.47173 .16269 L
.47297 .16673 L
.47428 .16998 L
.47497 .17114 L
.47573 .17185 L
.47643 .17193 L
.47707 .17151 L
.47834 .16923 L
.47905 .16714 L
.47969 .16477 L
.48425 .14055 L
.4855 .13438 L
.48619 .1317 L
.48683 .12978 L
.48796 .12817 L
.4892 .12956 L
.49036 .13438 L
.49146 .14244 L
.49245 .1527 L
.49352 .16714 L
.49594 .21094 L
.49817 .26256 L
.50327 .3897 L
.50467 .41941 L
.50614 .44574 L
.5074 .4635 L
.50811 .47147 L
.50878 .47763 L
.51008 .48592 L
.51127 .48944 L
.51255 .48944 L
.51327 .48799 L
.51394 .48588 L
.51505 .48107 L
.51628 .47454 L
.51875 .46057 L
.51999 .45459 L
.52117 .45019 L
.52223 .44754 L
.52339 .44617 L
.52464 .44645 L
.52534 .44735 L
.52597 .44856 L
.5272 .45183 L
.52837 .45569 L
.53047 .46328 L
.53162 .46708 L
Mistroke
.5327 .47004 L
.53386 .47236 L
.53513 .47367 L
.53622 .47371 L
.53738 .47269 L
.5386 .47061 L
.53994 .46739 L
.54266 .4597 L
.54387 .45659 L
.54518 .45395 L
.54642 .45239 L
.54755 .45187 L
.54819 .45199 L
.54888 .45243 L
.55012 .454 L
.55088 .45538 L
.5516 .45692 L
.55294 .46021 L
.5557 .46707 L
.55637 .46845 L
.55709 .46969 L
.55788 .47073 L
.55861 .47136 L
.55926 .47162 L
.55996 .47158 L
.56124 .47066 L
.56248 .46882 L
.56364 .46643 L
.56602 .46043 L
.56719 .45751 L
.56827 .45518 L
.56955 .4531 L
.57022 .45239 L
.57093 .45196 L
.57208 .45202 L
.57334 .45316 L
.57404 .45425 L
.57469 .4555 L
.57613 .45901 L
.57873 .46638 L
.57984 .46924 L
.58103 .47171 L
.58233 .4734 L
.58356 .47379 L
.58486 .47283 L
.58551 .47182 L
.58623 .47034 L
.58749 .46687 L
.58867 .46294 L
.59096 .45472 L
Mistroke
.59208 .45113 L
.59311 .44848 L
.59431 .44656 L
.5956 .44614 L
.5967 .44732 L
.59785 .45013 L
.59914 .45498 L
.60032 .46072 L
.60297 .47567 L
.60415 .4818 L
.60543 .48697 L
.60663 .48961 L
.60775 .48947 L
.60904 .48555 L
.61026 .47774 L
.61095 .47135 L
.61159 .46424 L
.61302 .44386 L
.61575 .39027 L
.61863 .31981 L
.62098 .26014 L
.62353 .20242 L
.62469 .18051 L
.62593 .16125 L
.62699 .1483 L
.62815 .13786 L
.62885 .13351 L
.62948 .1307 L
.63021 .12877 L
.63091 .12815 L
.63214 .1296 L
.63284 .13163 L
.63349 .13415 L
.63599 .14729 L
.63834 .16021 L
.63943 .16505 L
.64058 .16889 L
.64184 .17136 L
.643 .17195 L
.64405 .17118 L
.64502 .16947 L
.64608 .1667 L
.64723 .163 L
.64977 .15387 L
.65103 .1499 L
.65218 .147 L
.65323 .14521 L
.65435 .1443 L
.65546 .14443 L
.6567 .14573 L
Mistroke
.65792 .14802 L
.65905 .15081 L
.66162 .15809 L
.66291 .16141 L
.66412 .16391 L
.6648 .16493 L
.66553 .1657 L
.6668 .16616 L
.66791 .16562 L
.66914 .16408 L
.67042 .16162 L
.67162 .15877 L
.67374 .15331 L
.67486 .1507 L
.67606 .14846 L
.67679 .14745 L
.67746 .14681 L
.67875 .1464 L
.68007 .14715 L
.68131 .14884 L
.68252 .15123 L
.68362 .15387 L
.68612 .16022 L
.68733 .16288 L
.68862 .16497 L
.68937 .16573 L
.69005 .1661 L
.69073 .16614 L
.69137 .16587 L
.69204 .16529 L
.69275 .16434 L
.69403 .16188 L
.69692 .1541 L
.69812 .15074 L
.69943 .14757 L
.70067 .1454 L
.70183 .14435 L
.70297 .14437 L
.704 .14533 L
.7052 .14751 L
.70632 .15049 L
.70868 .15857 L
.71118 .16706 L
.71249 .1702 L
.71323 .17134 L
.71392 .17189 L
.71513 .17154 L
.71644 .16921 L
.71766 .16526 L
.71879 .16026 L
Mistroke
.72135 .14615 L
.72252 .13966 L
.72361 .13434 L
.72475 .13024 L
.72601 .12818 L
.72707 .12904 L
.7282 .133 L
.72916 .13912 L
.73021 .14888 L
.73134 .16307 L
.73255 .18231 L
.73474 .22632 L
.73971 .34999 L
.74242 .41259 L
.74375 .43774 L
.74497 .45663 L
.74629 .47238 L
.74702 .47884 L
.74772 .48355 L
.74847 .48712 L
.74916 .48909 L
.74993 .48988 L
.75074 .48931 L
.75143 .48782 L
.75218 .48533 L
.75354 .4791 L
.75607 .46483 L
.75724 .45854 L
.7585 .45288 L
.75923 .45032 L
.75989 .44848 L
.76118 .44638 L
.76186 .44607 L
.7625 .44627 L
.7632 .447 L
.76394 .4483 L
.76519 .45151 L
.76657 .45606 L
.76896 .46465 L
.77022 .46856 L
.77091 .47032 L
.77155 .47166 L
.77271 .4733 L
.77398 .4738 L
.77506 .47317 L
.77622 .47153 L
.7812 .4585 L
.78241 .45559 L
.78371 .45328 L
.78446 .45243 L
Mistroke
.78514 .45199 L
.78583 .45188 L
.78648 .45208 L
.78717 .45262 L
.78791 .45353 L
.78855 .45456 L
.78925 .45593 L
.79226 .46338 L
.79358 .4666 L
.79428 .46808 L
.79501 .46942 L
.79565 .47036 L
.79635 .4711 L
.79759 .47164 L
.79824 .47151 L
.79895 .47105 L
.80023 .46942 L
.80148 .467 L
.80263 .46426 L
.8052 .45773 L
.80656 .4548 L
.80733 .45353 L
.80803 .45266 L
.80928 .45189 L
.81046 .45219 L
.81155 .45333 L
.81275 .45543 L
.814 .45841 L
.81534 .46213 L
.81775 .46879 L
.81899 .47148 L
.8197 .4726 L
.82035 .47334 L
.82105 .47375 L
.82168 .47378 L
.82241 .4734 L
.82311 .47262 L
.82433 .47031 L
.82547 .46724 L
.82804 .45835 L
.82927 .45398 L
.8306 .44995 L
.83136 .44816 L
.83206 .44697 L
.83273 .44628 L
.83343 .44607 L
.83412 .44643 L
.83485 .44743 L
.83617 .45083 L
.83698 .45385 L
Mistroke
.83774 .45728 L
.83916 .46479 L
.84161 .47861 L
.84284 .48448 L
.84354 .48704 L
.8442 .48877 L
.84537 .48987 L
.84644 .48821 L
.84767 .48264 L
.84884 .47337 L
.8501 .45887 L
.85145 .43837 L
.85386 .38993 L
.85933 .25373 L
.86195 .19591 L
.86338 .17083 L
.86471 .15253 L
.86585 .14102 L
.86707 .13288 L
.86776 .13009 L
.86842 .1286 L
.86965 .12853 L
.87029 .12972 L
.87099 .13183 L
.87173 .13479 L
.87242 .13811 L
.87499 .15248 L
.87635 .15979 L
.87778 .16603 L
.87853 .16849 L
.87935 .17045 L
.8801 .17153 L
.88079 .17195 L
.88205 .17129 L
.88277 .17018 L
.88342 .16875 L
.88463 .16531 L
.88591 .16092 L
.88815 .15292 L
.88938 .14916 L
.89055 .14645 L
.8912 .14539 L
.8919 .14461 L
.89312 .14425 L
.89437 .14515 L
.89552 .14698 L
.89677 .14984 L
.89816 .15364 L
.89962 .15781 L
.90097 .16134 L
Mistroke
.9021 .1637 L
.90331 .16542 L
.90401 .16596 L
.90466 .16616 L
.90588 .16572 L
.90717 .16419 L
.90836 .16196 L
.91105 .15532 L
.91217 .15251 L
.91337 .14986 L
.9145 .14794 L
.91554 .14682 L
.9167 .14639 L
.9178 .14683 L
.919 .14818 L
.9203 .15054 L
.92299 .15716 L
.92432 .16047 L
.92553 .16309 L
.9262 .16425 L
.92694 .16523 L
.92768 .16588 L
.92846 .16616 L
.92912 .16605 L
.92983 .1656 L
.93111 .16391 L
.9324 .16124 L
.93381 .15756 L
.93636 .15035 L
.93757 .14749 L
.93885 .1453 L
.93994 .14434 L
.94115 .14441 L
.94221 .14549 L
.94319 .1473 L
.94428 .15009 L
.94543 .15377 L
.94776 .16211 L
.9489 .16593 L
.94995 .16884 L
.95093 .17081 L
.95198 .17187 L
.95302 .17172 L
.95418 .17006 L
.95513 .16748 L
.95616 .1636 L
.95802 .15434 L
.96035 .14108 L
.96158 .13489 L
.96289 .13011 L
Mistroke
.96415 .12817 L
.96529 .12931 L
.96644 .13375 L
.96752 .14126 L
.96857 .15194 L
.96969 .16676 L
.97169 .20189 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo01_ooooo0_oo
000Aooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool04?ooool00ooo003oooooo`00
000Iooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool06Oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool06oooool2ool0017ooooo0_oo000Jooooo`;oo`004Oooool2ool00003ooooool0003o
oooo01Sooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Iooooo`;oo`004Oooool2
ool000Gooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06oooool2ool0
017ooooo0_oo000Jooooo`;oo`004Oooool2ool00003ooooool0003ooooo01Oooooo0_oo000Aoooo
o`;oo`006oooool2ool0017ooooo0_oo0005ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool06oooool2ool0017ooooo0_oo000Jooooo`;o
o`004Oooool2ool00003ooooool0003ooooo01Oooooo0_oo000Aooooo`;oo`006oooool2ool0013o
oooo00?oo`00oooooooo00001Oooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Kooooo`;oo`000ooo
ool2ool000;ooooo0_oo0003ooooo`;oo`000oooool2ool001[ooooo00?oo`00oooooooo00000_oo
ool2ool000?ooooo0_oo0002ooooo`;oo`000oooool2ool00003ooooool0003ooooo01Oooooo00?o
o`00oooooooo00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`000_ooool00ooo003oooooool0
000Jooooo`;oo`000oooool2ool000;ooooo0_oo0003ooooo`;oo`000_ooool00ooo003oooooool0
0005ooooo`03o`000?oooooooooo00cooooo000=ooooo`Go00000_ooool01?l0003oooooooooool0
000;ooooo`05o`000?ooooooooooooooool00000H_ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo01?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Kooooo`;oo`000_ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0002ooooo`03ool00?ooooooo`0001[ooooo00Coo`00oooooooo
003ooooo0ooo0002ooooo`?oo`000_ooool00ooo003oooooool00002ooooo`;oo`0000?oooooo`00
0?ooool05oooool00ooo003oooooool00002ooooo`04ool00?ooooooo`00ooooo`?oo`000_ooool0
0ooo003oooooool00002ooooo`03ool00?ooooooo`0001Wooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`;oo`000oooool2ool000;ooooo00?oo`00oooooooo00001Oooool0
0ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool0000;ooooo`04o`000?oooooo
ooooooooo`;o00006_oooolIo`00oaOooooo6?l00?lGoooooaWo003o5_oooolIo`00o`;ooooo0ol0
000Looooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0001cooooo
00Goo`00oooooooo003oooooool00002ooooo`07ool00?ooooooo`00oooooooo003oooooool00002
ooooo`05ool00?ooooooo`00oooooooo00006_ooool01Ooo003oooooool00?ooooooo`0000;ooooo
00Goo`00oooooooo003oooooool00002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?oo
oooo000001Sooooo00?oo`00oooooooo00000_ooool01ooo003oooooool00?ooooooo`00oooooooo
00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool05oooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Ooo`00oooooooo003oooooool00?oo
ooooo`0000;ooooo00?oo`00oooooooo00001?ooool2o`0000kooooo000Dooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00004ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`00
0?oooooooooo01[ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`;oo`000oooool2ool0
00;ooooo00Goo`00oooooooo003oooooool0000Jooooo`05ool00?ooooooo`00oooooooo00000_oo
ool2ool000?ooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00o`000?ooool05ooo
ool01Ooo003oooooool00?ooooooo`0000;ooooo0ooo0002ooooo`07ool00?ooooooo`00oooooooo
003oooooool00002ooooo`03ool00?oooooooooo01Oooooo00Koo`00ooooooooooooo`00oooooooo
0002ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo0000
1Oooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01[ooooo00?oo`00ooooooooool00ooo0002ooooo`;oo`000oooool2ool000;o
oooo0ooo00000oooooooo`00ooooo`0Iooooo`03ool00?ooooooo`0000;oo`000_ooool2ool000?o
oooo0_oo0003ooooo`;oo`000_ooool00ooo003o0000ooooo`0Gooooo`03ool00?oooooooooo00;o
o`000oooool01?oo003oooooooooooooool2ool000?ooooo0_oo0002ooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool00_oo0003ooooo`;oo`000oooool01?oo003oooooooooooooool2
ool000;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00
00Sooooo1Ol00003ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0Kooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool06_ooool00ooo
003oooooooooo`02ool000gooooo00Goo`00ooooooooooooooooool0000Iooooo`03ool00?oooooo
oooo00;oo`003?ooool2ool000;ooooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`02
ool000cooooo0_oo0002ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool00_oo000=
ooooo`04ool00?ooooooooooool000Gooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool06_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool04_ooool00ooo003o0000ooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo003o0000ooooo`0Goooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Wooooo0_l0000`ooooo`03o`000?oooooooooo01[ooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00o`000?oo
ool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01[ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool0
0?oooooooooo01?ooooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00o`000?ooool05ooo
ool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01[ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooo
oooo01?ooooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00o`000?ooool05oooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[o
oooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?o
oooo00?oo`00o`000?ooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool00ol0003ooooo
ooooo`0Jooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?l0003ooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003ooooo
ooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?l0003ooooo01Oooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0J
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0C
ooooo`03ool00?l0003ooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?l0003ooooo01Oooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Jooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03
ool00?l0003ooooo01Kooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
5_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`0001[ooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06Ooo
ool2o`00033ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Kooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`05ool00?oooooooooo
ooooool000003_ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eoooo
o`05ool00?ooooooooooooooool000003_ooool002Oooooo00?o0000ooooooooool06Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Eooooo`05ool00?ooooooooooooooool000003_ooool002Oooooo00?o0000oooo
ooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool06Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Eooooo`05ool00?ooooooooooooooool000003_ooool0
02Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0000`ooooo`03o`000?oooooooooo
01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooooooooooo000000kooooo000Woooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooooooooooo
000000kooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo
003ooooooooooooooooo000000kooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool05Oooool01Ooo003ooooooooooooooooo000000kooooo000Qooooo`;o00001?ooool00ol0
003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool09oooool2o`00
00Gooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`05ool00?oooooooooo
ooooool000003_ooool0023ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooo
oooooooo000000kooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo7?l000000ol00?oo0000
o`00000Eo`000003o`00ool0003o000001Go000000?o003oo`000?l000005?l000000ol00?oo0000
o`00000Eo`000003o`00ool0003o000001Go000000?o003oo`000?l000005?l000000ol00?oo0000
o`00000Ko`0002Sooooo00Co0000oooooooooooo00001?ooool4o`000003ool00?l0003o000001Go
000000?oo`00o`000?l000005Ol000000ooo003o0000o`00000Eo`000003ool00?l0003o000001Co
000000?oo`00o`000?l000005Ol000000ooo003o0000o`00000Eo`000003ool00?l0003o000001Co
000000?oo`00o`000?l000005Ol000000ooo003o0000o`000002o`0000kooooo000Pooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03
o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo
o`0001Oooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`008?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool0
0ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
ool0000Gooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0023ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool09_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
oooo00005oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Qooooo`;o
00001?ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo00Go0000ooooooooooooooooool0000Gooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03o`000?oo003ooooo
01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooool0000Goooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03o`000?oo003ooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Wooooo0_l0000`ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooooooo
ool05Oooool00ol0003oo`00ooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ol0003oo`00ooooo`0Eooooo`03ool0
0?oooooooooo01Gooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Jooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Ooo
ool00ol0003oo`00ooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05Oooool00ol0003oo`00ooooo`0Eooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ol0
003oo`00ooooo`0Dooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool05Oooool00ol0003oo`00ooooo`0Dooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00co
oooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003ooooo
ooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o
0000ool00?ooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0F
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o0000ool0
0?ooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo01Gooooo00?o0000ool00?ooool05?ooool00ooo003oooooooooo`0Fooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
5oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Gooooo00?o0000ool00?ooool0
5?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`009oooool2o`0001[ooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06Ooo
ool2o`00033ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Eooooo`03o`000?oo
003ooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04oooool0
0ooo003oooooooooo`0Eooooo`03o`000?oo003ooooo01Cooooo00?oo`00ooooooooool05_ooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Eooooo`03o`000?oo003ooooo
01Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003o
ooooooooo`0Fooooo`03o`000?oo003ooooo01Cooooo00?oo`00ooooooooool05_ooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Fooooo`03o`000?oo003ooooo01?ooooo
00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003ooooooooo
o`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`0Fooooo`03o`000?oo003ooooo01?ooooo00?oo`00ooooooooool05oooool00ooo003ooooooooo
o`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool00_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`0Fooooo`03o`000?oo003ooooo01?ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01[ooooo00?o0000
ooooooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0000`oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05_ooool00ol0003oo`00ooooo`0Coooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool04_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool05_ooool00ol0003oo`00ooooo`0Cooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00?ooooo00Coo`00ooooooooooooo`003Oooool01Ooo003oooooooooooooooooo`00
01Wooooo00Coo`00ooooooooooooo`004Oooool00ooo003oooooooooo`0Fooooo`03o`000?oo003o
oooo00;ooooo00?oo`00ooooooooool02oooool01?oo003ooooooooooooo000Iooooo`05ool00?oo
oooooooooooooooo00003Oooool01Ooo003oooooooooooooooooo`0001cooooo00?o0000oooooooo
ool03?ooool001Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Kooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo00;oo`003?ooool2ool000;ooooo00?oo`00ooooooooool05oooool00ooo003ooooo
ooooo`02ool000cooooo0_oo0002ooooo`03ool00?oooooooooo01Kooooo00Co0000ool00?oooooo
oooo0_oo000<ooooo`;oo`000_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00;o
o`003Oooool2ool000;ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`00
5?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool06_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`00
0_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00;oo`000oooool2ool000;ooooo
0ooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Fooooo`04o`000?oo003oooooooooo`?o
o`000_ooool2ool000?ooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00006_ooool01Ooo
003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`;oo`000_ooool01Ooo003oooooool00?oo
ooooo`0001gooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00002ooo
ool01Ol0003ooooooooooooooooo000001_ooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`;oo`000_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo01Oooooo00[oo`00oooo
ooooooooo`00oooooooo003oooooool00?ooooooo`000_ooool01ooo003oooooool00?ooooooo`00
oooooooo00000_ooool00ooo003oooooooooo`0Fooooo`08o`000?oo003ooooooooooooo003ooooo
ool00?ooool4ool00004oooooooo003oooooool000;ooooo00Goo`00oooooooo003oooooool0000J
ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo0_oo0002ooooo`05ool00?oo
ooooo`00oooooooo00007Oooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003ooooooooo
ool0000;ooooo`04o`000?ooooooooooooooo`;o00000ooooolHo`00oaOooooo6Ol00?lFoooooaWo
003o5ooooolHo`00oa[ooooo0ol0000Looooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo00?oo`00oooooooo00000_ooool01ooo003oooooool00?oooooo
o`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool0
5oooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool01ooo003o
ooooool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`0Fooooo`09o`000?oo003o
oooooooooooo003oooooool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`05ool00?ooooooo`00oooooooo00006_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00Go
o`00oooooooo003oooooool00002ooooo`07ool00?ooooooo`00oooooooo003oooooool0000Loooo
o`;o00003_ooool001Cooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co0000oooo
oooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooool00002
ooooo`;oo`000oooool2ool000;ooooo00?oo`00oooooooo00000_ooool2ool001[ooooo00?oo`00
oooooooo00000_ooool2ool000?ooooo0_oo0002ooooo`?oo`000_ooool00ooo003oooooool0000H
ooooo`04o`000?oo003oooooool000;ooooo00?oo`00oooooooo00000_ooool3ool000;ooooo0_oo
0002ooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo00000_ooool2ool000;ooooo0ooo
0002ooooo`?oo`0000Coooooool00?ooooooo`007Oooool00ol0003oooooooooo`0<ooooo`005?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
00000_ooool2ool000?ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool0
01[ooooo00?oo`00oooooooo00000_ooool2ool000Cooooo00Coo`00oooooooooooooooo0_oo0002
ooooo`03ool00?ooooooo`0001Sooooo00Co0000oooooooo003oo`000oooool00ooo003ooooooooo
o`02ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooool0000Jooooo`;oo`00
0oooool2ool000?ooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`007Oooool00ol0003o
ooooooooo`0<ooooo`005Oooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Kooooo`;o00002?ooool5o`0000Cooooo
00?o0000ooooooooool00oooool00ooo003oooooool0000@ooooo`;oo`006_ooool00ooo003ooooo
ool0000@ooooo`03ool00?ooooooo`0001Sooooo00Co0000oooooooo003oo`004?ooool00ooo003o
ooooool0000Jooooo`;oo`004Oooool2ool001gooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00oooool2ool0017ooooo0_oo000Kooooo`;oo`004?ooool2ool001Wooooo
00Co0000oooooooo003oo`004Oooool2ool001[ooooo0_oo000Aooooo`;oo`007Oooool00ol0003o
ooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo
0_oo000Kooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool05oooool01?l0003ooooo
ool00?oo000Aooooo`03ool00?oooooooooo01Wooooo0_oo000Aooooo`;oo`007Oooool00ol0003o
ooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0H?ooool2o`00033ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qooooo`03o`000?oo
oooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000W
ooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`00
9oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0H?ooool2o`00
033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool03?ooool0023ooooo0ol00004ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0Vooooo`?o00001Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000002oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo02gooooo00Go0000ooooooooooooooooo`00000>ooooo`008Oooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ol0000Yooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000kooooo000Qoooo
o`03o`000?oooooooooo00?ooooob?l0000Yooooo`03o`000?oooooooooo00Coooooaol0000>oooo
o`008?ooool2o`000?Gooooo0_l0003Kooooo`008Oooool00ol0003oooooooooo`3dooooo`03o`00
0?oooooooooo0=Wooooo003oooooooGooooo003oooooooGooooo003oooooooGooooo003oooooooGo
oooo003oooooooGooooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \(sin(2\ \[Pi]\ t)\)\)\/\[Pi] + \(2\ \(sin(6\ \
\[Pi]\ t)\)\)\/\(3\ \[Pi]\) + \(2\ \(sin(10\ \[Pi]\ t)\)\)\/\(5\ \[Pi]\) + \
\(2\ \(sin(14\ \[Pi]\ t)\)\)\/\(7\ \[Pi]\) + \(2\ \(sin(18\ \[Pi]\ \
t)\)\)\/\(9\ \[Pi]\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Even more terms", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(series\  = \ 
        FourierSeries[Pulse1[t], t, 100];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[series, {t, \(-2\), 2}, 
          PlotStyle \[Rule] {Red, \ Thickness[ .01]}, 
          PlotRange \[Rule] {\(-1.01\), 1.01}, \ 
          DisplayFunction \[Rule] Identity, \ 
          PlotPoints \[Rule] 1000];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], 
        ImageSize \[Rule] 500];\)\), "\[IndentingNewLine]", 
    \(\(series\  // \ ComplexExpand\)\  // TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 500 147.151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .462 m
.03318 .462 L
.04339 .462 L
.05298 .462 L
.06221 .462 L
.07203 .462 L
.08148 .462 L
.09153 .462 L
.10121 .462 L
.11052 .462 L
.12043 .462 L
.12997 .462 L
.13476 .462 L
.13914 .462 L
.14029 .462 L
.14155 .462 L
.14213 .462 L
.14244 .462 L
.14274 .462 L
.14302 .15604 L
.14332 .15604 L
.14385 .15604 L
.14891 .15604 L
.15885 .15604 L
.16842 .15604 L
.17763 .15604 L
.18743 .15604 L
.19686 .15604 L
.20688 .15604 L
.21654 .15604 L
.22584 .15604 L
.23572 .15604 L
.24524 .15604 L
.25439 .15604 L
.25908 .15604 L
.26037 .15604 L
.26107 .15604 L
.26141 .15604 L
.26172 .15604 L
.26201 .462 L
.26228 .462 L
.26288 .462 L
.26414 .462 L
.27347 .462 L
.28338 .462 L
.29294 .462 L
.30212 .462 L
.3119 .462 L
.32131 .462 L
.33132 .462 L
Mistroke
.34096 .462 L
.35023 .462 L
.3601 .462 L
.36959 .462 L
.37445 .462 L
.377 .462 L
.37839 .462 L
.37969 .462 L
.38029 .462 L
.38058 .462 L
.38086 .462 L
.38117 .15604 L
.38133 .15604 L
.38151 .15604 L
.38211 .15604 L
.38476 .15604 L
.38941 .15604 L
.39858 .15604 L
.40834 .15604 L
.41773 .15604 L
.42771 .15604 L
.43733 .15604 L
.44658 .15604 L
.45643 .15604 L
.46591 .15604 L
.47598 .15604 L
.48569 .15604 L
.49502 .15604 L
.49752 .15604 L
.49874 .15604 L
.49927 .15604 L
.49955 .15604 L
.49985 .15604 L
.50016 .462 L
.50045 .462 L
.50102 .462 L
.50228 .462 L
.50496 .462 L
.5141 .462 L
.52384 .462 L
.53321 .462 L
.54317 .462 L
.55277 .462 L
.562 .462 L
.57183 .462 L
.58129 .462 L
.59134 .462 L
.60102 .462 L
.61034 .462 L
.61515 .462 L
Mistroke
.61758 .462 L
.61825 .462 L
.61861 .462 L
.61879 .462 L
.61896 .462 L
.61912 .15604 L
.61928 .15604 L
.61963 .15604 L
.62025 .15604 L
.63034 .15604 L
.64006 .15604 L
.64941 .15604 L
.65935 .15604 L
.66893 .15604 L
.67814 .15604 L
.68794 .15604 L
.69738 .15604 L
.70741 .15604 L
.71708 .15604 L
.72637 .15604 L
.73108 .15604 L
.73357 .15604 L
.73488 .15604 L
.73626 .15604 L
.73686 .15604 L
.73749 .15604 L
.73768 .15604 L
.73785 .15604 L
.73801 .15604 L
.73818 .462 L
.73835 .462 L
.73852 .462 L
.73883 .462 L
.74118 .462 L
.74579 .462 L
.75498 .462 L
.76476 .462 L
.77418 .462 L
.78419 .462 L
.79383 .462 L
.80311 .462 L
.81298 .462 L
.82249 .462 L
.83258 .462 L
.84231 .462 L
.85168 .462 L
.85419 .462 L
.85541 .462 L
.85652 .462 L
.85681 .462 L
Mistroke
.85713 .462 L
.85743 .15604 L
.8577 .15604 L
.85896 .15604 L
.86163 .15604 L
.87117 .15604 L
.88034 .15604 L
.8901 .15604 L
.8995 .15604 L
.90949 .15604 L
.91911 .15604 L
.92837 .15604 L
.93822 .15604 L
.9477 .15604 L
.95778 .15604 L
.96749 .15604 L
.97619 .15604 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.305957 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -12 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -24 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -18 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(-1)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(-0.5)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(0.5)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(1)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .30902 m
.02403 .36345 L
.02426 .41635 L
.02438 .43847 L
.02451 .4579 L
.02463 .47193 L
.02468 .47668 L
.02474 .481 L
.0248 .48466 L
.02484 .4862 L
.02487 .48735 L
.0249 .48819 L
.02493 .48875 L
.02494 .48898 L
.02496 .48918 L
.02499 .48936 L
.02501 .48938 L
.02502 .48933 L
.02504 .48923 L
.02506 .48906 L
.02507 .48882 L
.02509 .4885 L
.02513 .48775 L
.02519 .48593 L
.02526 .48332 L
.02552 .47008 L
.02575 .45778 L
.02587 .45303 L
.02593 .45104 L
.02599 .44935 L
.02605 .44827 L
.02608 .44781 L
.02611 .44748 L
.02614 .44728 L
.02616 .44716 L
.02619 .44712 L
.02622 .44716 L
.02625 .44731 L
.02628 .44753 L
.02631 .44788 L
.02634 .44831 L
.0264 .44927 L
.02646 .45059 L
.02672 .45841 L
.02684 .4623 L
.02697 .46611 L
.02709 .46903 L
.02715 .47011 L
.0272 .47092 L
.02726 .47158 L
Mistroke
.02729 .47183 L
.02731 .47193 L
.02732 .47201 L
.02735 .4721 L
.02738 .47214 L
.02741 .4721 L
.02744 .47201 L
.02745 .47194 L
.02747 .47185 L
.0275 .47163 L
.02757 .47094 L
.02764 .46993 L
.0277 .46879 L
.02795 .46348 L
.02808 .46043 L
.0282 .4579 L
.02831 .45619 L
.02837 .45545 L
.02842 .45493 L
.02845 .45472 L
.02848 .45456 L
.02851 .45443 L
.02854 .45435 L
.02855 .45432 L
.02857 .45432 L
.0286 .45435 L
.02863 .45442 L
.02866 .45454 L
.02869 .45469 L
.02872 .45486 L
.02877 .45536 L
.02888 .4566 L
.02911 .4605 L
.02923 .46267 L
.02936 .46479 L
.02947 .46641 L
.02953 .46703 L
.02958 .46749 L
.02964 .46783 L
.02966 .46795 L
.02969 .46806 L
.02972 .46813 L
.02975 .46817 L
.02978 .46817 L
.0298 .46814 L
.02983 .46806 L
.02986 .46796 L
.02989 .46781 L
.02993 .46761 L
.02998 .46718 L
Mistroke
.03004 .46659 L
.0303 .46317 L
.03054 .45971 L
.03066 .45833 L
.03073 .45773 L
.03076 .45749 L
.03079 .4573 L
.03082 .45715 L
.03085 .45701 L
.03088 .45692 L
.03091 .45687 L
.03093 .45683 L
.03097 .45683 L
.03098 .45684 L
.031 .45686 L
.03103 .45693 L
.03106 .45702 L
.03109 .45714 L
.03115 .45749 L
.0312 .45789 L
.03126 .45841 L
.03147 .46082 L
.0317 .46361 L
.03182 .46485 L
.03188 .4654 L
.03194 .46582 L
.03199 .4661 L
.03202 .46622 L
.03205 .46631 L
.03208 .46638 L
.0321 .46641 L
.03211 .46643 L
.03214 .46644 L
.03217 .46643 L
.0322 .4664 L
.03222 .46635 L
.03225 .46627 L
.03227 .46619 L
.03233 .46593 L
.03238 .46561 L
.03263 .46336 L
.03286 .46083 L
.03297 .45984 L
.03307 .459 L
.03313 .45865 L
.03316 .4585 L
.03319 .45837 L
.03322 .45826 L
.03325 .45819 L
.03327 .45814 L
Mistroke
.0333 .45811 L
.03333 .45809 L
.03336 .4581 L
.03339 .45813 L
.03342 .45819 L
.03345 .45826 L
.03347 .45834 L
.03353 .45859 L
.03359 .45893 L
.03365 .45938 L
.03377 .46038 L
.03404 .46291 L
.03416 .46398 L
.03428 .46476 L
.03433 .46505 L
.03439 .46528 L
.03443 .46536 L
.03446 .46542 L
.03447 .46545 L
.03449 .46546 L
.0345 .46547 L
.03452 .46548 L
.03455 .46547 L
.03458 .46544 L
.0346 .4654 L
.03463 .46534 L
.03466 .46525 L
.03469 .46514 L
.03475 .46488 L
.03488 .46409 L
.03501 .46302 L
.03525 .46095 L
.03537 .46007 L
.03548 .45942 L
.03554 .45916 L
.03558 .45905 L
.03561 .45897 L
.03564 .45891 L
.03567 .45887 L
.0357 .45885 L
.03573 .45885 L
.03576 .45887 L
.03579 .45891 L
.03581 .45896 L
.03584 .45902 L
.03589 .45917 L
.03594 .45939 L
.03606 .46006 L
.03617 .46082 L
.03639 .46258 L
Mistroke
.03652 .46347 L
.03663 .46415 L
.03669 .46442 L
.03676 .46465 L
.03679 .46474 L
.03681 .46478 L
.03683 .46481 L
.03686 .46485 L
.03688 .46486 L
.03689 .46486 L
.03692 .46486 L
.03695 .46484 L
.03698 .46481 L
.03701 .46476 L
.03704 .4647 L
.03707 .4646 L
.03713 .46437 L
.0374 .46282 L
.03764 .46105 L
.03775 .46038 L
.03787 .45982 L
.03793 .45961 L
.03796 .45952 L
.03799 .45945 L
.03802 .4594 L
.03805 .45937 L
.03808 .45936 L
.03811 .45936 L
.03814 .45937 L
.03816 .45939 L
.03819 .45944 L
.03822 .4595 L
.03828 .45967 L
.03834 .45989 L
.03845 .4604 L
.03856 .46106 L
.03879 .46262 L
.03892 .4634 L
.03899 .46372 L
.03905 .46397 L
.03911 .46417 L
.03913 .46425 L
.03917 .46432 L
.0392 .46438 L
.03923 .46442 L
.03925 .46443 L
.03926 .46444 L
.03928 .46444 L
.0393 .46444 L
.03932 .46443 L
Mistroke
.03935 .46441 L
.03938 .46437 L
.03941 .46431 L
.03946 .46418 L
.03952 .46399 L
.03963 .4635 L
.03975 .46285 L
.03996 .46155 L
.04008 .46087 L
.04019 .46034 L
.04025 .46011 L
.04028 .46 L
.04032 .45991 L
.04035 .45985 L
.04038 .45979 L
.04041 .45975 L
.04043 .45973 L
.04046 .45971 L
.04049 .45971 L
.04052 .45972 L
.04054 .45975 L
.04057 .45978 L
.04059 .45982 L
.04065 .45993 L
.0407 .4601 L
.04076 .46033 L
.04087 .46084 L
.04112 .46224 L
.04124 .46291 L
.04135 .46343 L
.04141 .46365 L
.04147 .46385 L
.0415 .46394 L
.04153 .464 L
.04156 .46406 L
.04159 .4641 L
.04161 .46412 L
.04163 .46413 L
.04165 .46414 L
.04166 .46414 L
.04168 .46414 L
.0417 .46413 L
.04171 .46412 L
.04173 .46411 L
.04175 .46409 L
.04177 .46407 L
.0418 .46401 L
.04186 .46387 L
.04191 .4637 L
.04197 .46348 L
Mistroke
.04208 .46298 L
.04233 .46164 L
.04247 .46096 L
.04254 .46067 L
.0426 .46044 L
.04266 .46025 L
.04271 .46012 L
.04274 .46007 L
.04277 .46002 L
.0428 .46 L
.04282 .45998 L
.04284 .45998 L
.04287 .45998 L
.0429 .45999 L
.04292 .46001 L
.04295 .46004 L
.04298 .46008 L
.04301 .46015 L
.04307 .46029 L
.04318 .46064 L
.04329 .46114 L
.04355 .46246 L
.04366 .46299 L
.04372 .46324 L
.04379 .46347 L
.04385 .46365 L
.0439 .46377 L
.04393 .46382 L
.04396 .46386 L
.04399 .46388 L
.04401 .4639 L
.04404 .46391 L
.04407 .4639 L
.0441 .46389 L
.04413 .46386 L
.04414 .46385 L
.04416 .46382 L
.04419 .46377 L
.04425 .46364 L
.04432 .46345 L
.04438 .46324 L
.04451 .46266 L
.04475 .4615 L
.04487 .46098 L
.04493 .46074 L
.04499 .46055 L
.04505 .4604 L
.0451 .4603 L
.04513 .46026 L
.04515 .46022 L
Mistroke
.04518 .4602 L
.04521 .46018 L
.04525 .46018 L
.04527 .46019 L
.04529 .4602 L
.04531 .46021 L
.04534 .46025 L
.04537 .46029 L
.04541 .46035 L
.04547 .46052 L
.0456 .46094 L
.04572 .46142 L
.04597 .46259 L
.04609 .46308 L
.04615 .46327 L
.04621 .46344 L
.04626 .46356 L
.04631 .46364 L
.04634 .46368 L
.04636 .4637 L
.04639 .46372 L
.04642 .46373 L
.04645 .46372 L
.04648 .46371 L
.04651 .46369 L
.04653 .46366 L
.04656 .46362 L
.0466 .46356 L
.04665 .46343 L
.04712 .46157 L
.04725 .46106 L
.04732 .46082 L
.04739 .46063 L
.04745 .46049 L
.04749 .46044 L
.04752 .46039 L
.04755 .46037 L
.04758 .46035 L
.04761 .46034 L
.04764 .46034 L
.04767 .46036 L
.0477 .46038 L
.04773 .46041 L
.04776 .46046 L
.04782 .46058 L
.04788 .46071 L
.0481 .46149 L
.04836 .46256 L
.04847 .46298 L
.04853 .46316 L
Mistroke
.04859 .46333 L
.04865 .46345 L
.04868 .46349 L
.04871 .46353 L
.04873 .46355 L
.04876 .46357 L
.04879 .46358 L
.04882 .46358 L
.04884 .46358 L
.04887 .46356 L
.0489 .46354 L
.04893 .46351 L
.04899 .46341 L
.04905 .46327 L
.04918 .4629 L
.04929 .46247 L
.04955 .46142 L
.04968 .461 L
.04974 .46082 L
.04981 .46066 L
.04987 .46056 L
.0499 .46052 L
.04993 .46049 L
.04996 .46048 L
.04999 .46047 L
.05002 .46047 L
.05005 .46048 L
.05007 .4605 L
.0501 .46052 L
.05013 .46055 L
.05016 .4606 L
.05026 .46081 L
.05037 .46114 L
.05049 .46157 L
.05074 .46254 L
.05086 .46294 L
.05097 .46323 L
.05103 .46334 L
.05106 .46338 L
.05109 .46341 L
.05112 .46344 L
.05115 .46346 L
.05118 .46347 L
.0512 .46347 L
.05121 .46347 L
.05123 .46346 L
.05125 .46345 L
.05126 .46344 L
.05128 .46343 L
.05131 .4634 L
Mistroke
.05134 .46335 L
.05141 .46322 L
.05148 .46307 L
.05172 .46226 L
.05198 .46131 L
.05208 .46099 L
.05214 .46085 L
.0522 .46074 L
.05223 .46069 L
.05226 .46064 L
.05229 .46061 L
.05232 .46059 L
.05235 .46058 L
.05238 .46057 L
.05241 .46058 L
.05244 .46059 L
.05247 .46061 L
.05249 .46064 L
.05255 .46072 L
.05261 .46082 L
.05267 .46097 L
.05288 .46165 L
.05313 .46255 L
.05324 .46289 L
.05331 .46305 L
.05336 .46317 L
.05342 .46327 L
.05345 .46331 L
.05348 .46334 L
.05352 .46336 L
.05353 .46337 L
.05355 .46337 L
.05358 .46337 L
.05361 .46337 L
.05363 .46336 L
.05365 .46335 L
.05368 .46331 L
.05372 .46327 L
.05375 .46322 L
.05381 .46311 L
.05388 .46295 L
.05413 .46214 L
.05436 .46135 L
.05448 .46102 L
.05454 .46088 L
.0546 .46078 L
.05463 .46074 L
.05465 .46071 L
.05468 .46069 L
.05471 .46067 L
Mistroke
.05474 .46066 L
.05477 .46066 L
.0548 .46067 L
.05483 .46068 L
.05485 .46069 L
.05486 .46071 L
.0549 .46074 L
.05496 .46083 L
.05503 .46097 L
.05509 .46113 L
.05533 .4619 L
.05555 .46262 L
.05567 .46295 L
.05573 .46308 L
.05578 .46317 L
.05582 .46321 L
.05585 .46324 L
.05588 .46327 L
.0559 .46328 L
.05591 .46329 L
.05595 .46329 L
.05597 .46329 L
.05601 .46328 L
.05602 .46327 L
.05604 .46326 L
.05607 .46323 L
.0561 .4632 L
.05616 .4631 L
.05622 .46298 L
.05628 .46284 L
.05672 .46145 L
.05684 .46112 L
.0569 .46097 L
.05697 .46086 L
.057 .46083 L
.05703 .46079 L
.05704 .46078 L
.05706 .46076 L
.05709 .46074 L
.05712 .46073 L
.05715 .46073 L
.05718 .46074 L
.0572 .46075 L
.05723 .46076 L
.05726 .46079 L
.05731 .46086 L
.05738 .46096 L
.05743 .46108 L
.05768 .46179 L
.05781 .46221 L
Mistroke
.05794 .46262 L
.05806 .46291 L
.05812 .46304 L
.05815 .46309 L
.05818 .46313 L
.05821 .46316 L
.05824 .46319 L
.05827 .46321 L
.0583 .46322 L
.05833 .46323 L
.05835 .46323 L
.05838 .46322 L
.0584 .46321 L
.05843 .46319 L
.05846 .46316 L
.05853 .46307 L
.05859 .46296 L
.05864 .46284 L
.0589 .46211 L
.05902 .4617 L
.05914 .46136 L
.05925 .46109 L
.05932 .46097 L
.05937 .46089 L
.05941 .46085 L
.05944 .46082 L
.05945 .46081 L
.05947 .4608 L
.05949 .4608 L
.0595 .46079 L
.05954 .46079 L
.05956 .4608 L
.05958 .4608 L
.0596 .46081 L
.05963 .46084 L
.05965 .46086 L
.05968 .46089 L
.05974 .46098 L
.05986 .46123 L
.06007 .46184 L
.06031 .46256 L
.06043 .46285 L
.0605 .46298 L
.06053 .46303 L
.06056 .46307 L
.06059 .46311 L
.06062 .46313 L
.06064 .46315 L
.06067 .46317 L
.0607 .46317 L
Mistroke
.06072 .46317 L
.06075 .46317 L
.06077 .46316 L
.0608 .46314 L
.06083 .46311 L
.06089 .46304 L
.06095 .46295 L
.061 .46285 L
.06124 .46223 L
.06149 .46147 L
.0616 .46119 L
.06167 .46106 L
.06173 .46097 L
.06178 .46091 L
.0618 .46088 L
.06183 .46086 L
.06186 .46085 L
.06189 .46084 L
.06192 .46084 L
.06194 .46085 L
.06197 .46086 L
.062 .46088 L
.06203 .4609 L
.06205 .46093 L
.0621 .46099 L
.06215 .46108 L
.06227 .46134 L
.06238 .46165 L
.06261 .46231 L
.06273 .46263 L
.06285 .4629 L
.06291 .463 L
.06295 .46304 L
.06298 .46308 L
.063 .46309 L
.06302 .4631 L
.06305 .46312 L
.06307 .46313 L
.0631 .46313 L
.06313 .46312 L
.06316 .46311 L
.06318 .4631 L
.0632 .46309 L
.06323 .46306 L
.06329 .46298 L
.06334 .46289 L
.06345 .46267 L
.06356 .46238 L
.06379 .46171 L
.06392 .46137 L
Mistroke
.06398 .46123 L
.06404 .46112 L
.06409 .46103 L
.06415 .46096 L
.06417 .46093 L
.0642 .46091 L
.06423 .4609 L
.06426 .46089 L
.06428 .46088 L
.0643 .46088 L
.06433 .46089 L
.06435 .4609 L
.06436 .46091 L
.0644 .46093 L
.06443 .46096 L
.06446 .461 L
.06452 .4611 L
.06464 .46134 L
.06477 .46166 L
.06499 .46231 L
.06512 .46264 L
.06518 .46277 L
.06524 .46288 L
.06529 .46296 L
.06535 .46303 L
.06538 .46305 L
.06541 .46307 L
.06544 .46308 L
.06545 .46309 L
.06547 .46309 L
.06549 .46309 L
.06552 .46308 L
.06554 .46307 L
.06557 .46305 L
.0656 .46303 L
.06563 .463 L
.06568 .46294 L
.06579 .46274 L
.06591 .46244 L
.06616 .46175 L
.06627 .46146 L
.06639 .46119 L
.06645 .4611 L
.0665 .46102 L
.06655 .46097 L
.06658 .46095 L
.0666 .46093 L
.06663 .46092 L
.06666 .46092 L
.06669 .46092 L
Mistroke
.06672 .46093 L
.06675 .46094 L
.06676 .46095 L
.06678 .46096 L
.06684 .46102 L
.06689 .4611 L
.06695 .4612 L
.06705 .46143 L
.06729 .46206 L
.06741 .4624 L
.06755 .46272 L
.06761 .46284 L
.06768 .46294 L
.06773 .463 L
.06776 .46302 L
.06779 .46304 L
.06782 .46305 L
.06785 .46306 L
.06788 .46306 L
.0679 .46305 L
.06793 .46303 L
.06795 .46303 L
.06797 .46301 L
.06802 .46296 L
.06809 .46286 L
.06815 .46276 L
.06829 .46245 L
.06853 .46179 L
.06864 .46149 L
.06877 .46122 L
.06882 .46114 L
.06887 .46106 L
.0689 .46102 L
.06893 .461 L
.06896 .46098 L
.06899 .46096 L
.06902 .46095 L
.06905 .46095 L
.06906 .46095 L
.06908 .46095 L
.06911 .46096 L
.06914 .46098 L
.06917 .461 L
.06923 .46106 L
.06929 .46116 L
.06935 .46126 L
.06949 .46157 L
.06974 .46225 L
.06986 .46256 L
.06997 .46279 L
Mistroke
.07003 .46288 L
.07008 .46294 L
.07011 .46297 L
.07014 .46299 L
.07016 .46301 L
.07019 .46302 L
.07022 .46303 L
.07024 .46303 L
.07027 .46303 L
.0703 .46302 L
.07032 .46301 L
.07033 .463 L
.07036 .46297 L
.07042 .46291 L
.07048 .46283 L
.07054 .46273 L
.07065 .46249 L
.0709 .46183 L
.07103 .46149 L
.0711 .46134 L
.07116 .46122 L
.07122 .46112 L
.07128 .46105 L
.07131 .46102 L
.07134 .461 L
.07137 .46098 L
.07139 .46098 L
.0714 .46097 L
.07143 .46097 L
.07146 .46098 L
.07149 .46098 L
.07151 .461 L
.07154 .46102 L
.07158 .46105 L
.07164 .46112 L
.07174 .4613 L
.07185 .46155 L
.07211 .46223 L
.07223 .46251 L
.07229 .46264 L
.07235 .46276 L
.07241 .46286 L
.07247 .46293 L
.07249 .46296 L
.07252 .46298 L
.07255 .46299 L
.07258 .463 L
.0726 .46301 L
.07263 .46301 L
.07266 .463 L
Mistroke
.07269 .46299 L
.07271 .46298 L
.07272 .46297 L
.07276 .46294 L
.07281 .46288 L
.07288 .46278 L
.07294 .46267 L
.07307 .46236 L
.07332 .46173 L
.07343 .46145 L
.0735 .46131 L
.07356 .46121 L
.07361 .46112 L
.07366 .46106 L
.07369 .46104 L
.07372 .46102 L
.07375 .461 L
.07378 .46099 L
.07381 .46099 L
.07384 .46099 L
.07386 .461 L
.07387 .461 L
.07389 .46101 L
.07391 .46102 L
.07394 .46105 L
.07397 .46108 L
.07404 .46117 L
.07416 .46138 L
.07428 .46167 L
.07453 .46231 L
.07466 .46261 L
.07473 .46274 L
.07479 .46285 L
.07485 .46292 L
.07488 .46295 L
.07491 .46297 L
.07493 .46298 L
.07495 .46298 L
.07496 .46299 L
.07498 .46299 L
.07501 .46299 L
.07503 .46299 L
.07505 .46299 L
.07507 .46297 L
.0751 .46296 L
.07513 .46294 L
.07516 .46291 L
.07522 .46283 L
.07528 .46274 L
.07573 .46166 L
Mistroke
.07585 .46138 L
.07592 .46125 L
.07598 .46115 L
.07603 .46109 L
.07606 .46106 L
.07609 .46104 L
.07611 .46103 L
.07612 .46102 L
.07616 .46101 L
.07618 .461 L
.07621 .46101 L
.07623 .46101 L
.07625 .46102 L
.07626 .46102 L
.07628 .46103 L
.07632 .46106 L
.07635 .46109 L
.07642 .46117 L
.07648 .46128 L
.07673 .46184 L
.07685 .46216 L
.07698 .46247 L
.0771 .46272 L
.07716 .46281 L
.07721 .46288 L
.07727 .46294 L
.0773 .46296 L
.07733 .46297 L
.07736 .46298 L
.07739 .46298 L
.0774 .46298 L
.07742 .46298 L
.07744 .46297 L
.07745 .46296 L
.07749 .46294 L
.07752 .46291 L
.07758 .46285 L
.07765 .46275 L
.07772 .46261 L
.07797 .462 L
.0782 .46144 L
.07832 .46122 L
.07838 .46113 L
.07841 .4611 L
.07844 .46107 L
.07847 .46105 L
.0785 .46103 L
.07853 .46102 L
.07855 .46102 L
.07858 .46101 L
Mistroke
.07861 .46102 L
.07864 .46103 L
.07867 .46105 L
.0787 .46107 L
.07874 .46111 L
.0788 .46119 L
.07891 .46139 L
.07917 .46201 L
.07929 .46231 L
.07942 .4626 L
.07948 .46272 L
.07954 .46281 L
.07959 .46288 L
.07962 .46291 L
.07965 .46293 L
.07968 .46295 L
.07971 .46296 L
.07974 .46297 L
.07976 .46297 L
.07977 .46297 L
.0798 .46297 L
.07983 .46296 L
.07986 .46294 L
.07989 .46292 L
.07996 .46285 L
.08002 .46276 L
.08015 .46249 L
.0804 .4619 L
.08053 .46157 L
.08065 .46131 L
.0807 .46122 L
.08076 .46115 L
.08078 .46111 L
.08082 .46108 L
.08084 .46106 L
.08087 .46104 L
.0809 .46103 L
.08093 .46102 L
.08096 .46102 L
.08098 .46102 L
.081 .46103 L
.08102 .46104 L
.08105 .46105 L
.08108 .46108 L
.08111 .4611 L
.08117 .46117 L
.08123 .46127 L
.08134 .46149 L
.08156 .46201 L
.08168 .46234 L
Mistroke
.08181 .46261 L
.08191 .4628 L
.08198 .46288 L
.08203 .46293 L
.08206 .46295 L
.08209 .46296 L
.08212 .46297 L
.08214 .46297 L
.08217 .46297 L
.08219 .46296 L
.0822 .46296 L
.08223 .46294 L
.08226 .46292 L
.08232 .46286 L
.08238 .46279 L
.0825 .46256 L
.08275 .46196 L
.08288 .46163 L
.08301 .46136 L
.08312 .46117 L
.08315 .46113 L
.08318 .4611 L
.08321 .46107 L
.08324 .46105 L
.08327 .46103 L
.08329 .46103 L
.0833 .46102 L
.08333 .46102 L
.08336 .46102 L
.08338 .46103 L
.0834 .46104 L
.08342 .46104 L
.08343 .46105 L
.08346 .46108 L
.08349 .46111 L
.08355 .46118 L
.08361 .46127 L
.08371 .46146 L
.08394 .46202 L
.08406 .46233 L
.08419 .46261 L
.08425 .46273 L
.08431 .46282 L
.08436 .46288 L
.08439 .46291 L
.08442 .46293 L
.08445 .46295 L
.08446 .46296 L
.08448 .46296 L
.0845 .46297 L
Mistroke
.08451 .46297 L
.08455 .46297 L
.08457 .46296 L
.0846 .46295 L
.08463 .46293 L
.08466 .46291 L
.08473 .46283 L
.0848 .46272 L
.08493 .46247 L
.08514 .46194 L
.08537 .4614 L
.08544 .46127 L
.0855 .46117 L
.08556 .4611 L
.08559 .46107 L
.08562 .46105 L
.08565 .46104 L
.08567 .46103 L
.0857 .46102 L
.08573 .46102 L
.08576 .46103 L
.08578 .46103 L
.08579 .46104 L
.08582 .46106 L
.08585 .46108 L
.08591 .46115 L
.08597 .46124 L
.08608 .46145 L
.08633 .46205 L
.08658 .46263 L
.08664 .46274 L
.0867 .46284 L
.08674 .46288 L
.08677 .46291 L
.08681 .46294 L
.08682 .46295 L
.08684 .46296 L
.08687 .46297 L
.0869 .46297 L
.08692 .46297 L
.08694 .46297 L
.08696 .46296 L
.08698 .46295 L
.08701 .46294 L
.08704 .46291 L
.08707 .46289 L
.08713 .4628 L
.08719 .46271 L
.08732 .46245 L
.08753 .46191 L
Mistroke
.08776 .46137 L
.08787 .46118 L
.08791 .46113 L
.08794 .4611 L
.08797 .46107 L
.088 .46104 L
.08803 .46103 L
.08806 .46102 L
.08808 .46101 L
.08812 .46102 L
.08814 .46102 L
.08817 .46103 L
.08819 .46105 L
.08822 .46107 L
.08828 .46113 L
.08835 .46122 L
.08848 .46148 L
.08872 .46207 L
.08883 .46236 L
.08896 .46264 L
.08902 .46274 L
.08908 .46284 L
.08913 .4629 L
.08916 .46293 L
.08919 .46295 L
.0892 .46296 L
.08922 .46297 L
.08925 .46298 L
.08927 .46298 L
.08929 .46298 L
.08931 .46298 L
.08932 .46298 L
.08935 .46297 L
.08937 .46296 L
.08939 .46295 L
.08945 .46289 L
.08951 .46282 L
.08957 .46272 L
.08969 .46247 L
.08993 .46187 L
.09005 .46157 L
.09016 .46134 L
.09022 .46122 L
.09028 .46113 L
.09031 .46109 L
.09035 .46106 L
.09037 .46105 L
.09038 .46103 L
.0904 .46102 L
.09042 .46102 L
Mistroke
.09045 .46101 L
.09047 .461 L
.09049 .46101 L
.09051 .46101 L
.09054 .46102 L
.09057 .46103 L
.09059 .46105 L
.09063 .46108 L
.09066 .46112 L
.09078 .4613 L
.09088 .46153 L
.09113 .46214 L
.09134 .46264 L
.0914 .46276 L
.09146 .46285 L
.09151 .46291 L
.09154 .46294 L
.09157 .46296 L
.09159 .46298 L
.09163 .46299 L
.09166 .46299 L
.09167 .46299 L
.09169 .46299 L
.09172 .46298 L
.09175 .46297 L
.09178 .46295 L
.0918 .46293 L
.09186 .46287 L
.09191 .4628 L
.09202 .46259 L
.09228 .46195 L
.09239 .46165 L
.09252 .46137 L
.09257 .46126 L
.09264 .46116 L
.09269 .46108 L
.09274 .46103 L
.09277 .46101 L
.0928 .461 L
.09283 .46099 L
.09285 .46099 L
.09287 .46099 L
.09289 .461 L
.09293 .46101 L
.09296 .46102 L
.09298 .46104 L
.09305 .46111 L
.0931 .4612 L
.09324 .46146 L
.09348 .46208 L
Mistroke
.0936 .46239 L
.09374 .46269 L
.0938 .4628 L
.09386 .46289 L
.09392 .46295 L
.09395 .46297 L
.09398 .46299 L
.094 .463 L
.09403 .46301 L
.09406 .46301 L
.09409 .463 L
.09411 .463 L
.09414 .46298 L
.09417 .46296 L
.09419 .46294 L
.09425 .46287 L
.0943 .46279 L
.09442 .46255 L
.09466 .46195 L
.09479 .4616 L
.09492 .46132 L
.09497 .46122 L
.09503 .46112 L
.09506 .46108 L
.0951 .46104 L
.09513 .46102 L
.09516 .461 L
.09518 .46098 L
.09521 .46097 L
.09524 .46097 L
.09527 .46098 L
.09529 .46098 L
.09532 .461 L
.09535 .46102 L
.09537 .46104 L
.09543 .4611 L
.09549 .46119 L
.0956 .46141 L
.09585 .46203 L
.09596 .46235 L
.09608 .46262 L
.09618 .46281 L
.09624 .4629 L
.09626 .46293 L
.09629 .46296 L
.09632 .46299 L
.09634 .463 L
.09637 .46302 L
.0964 .46303 L
.09643 .46303 L
Mistroke
.09646 .46303 L
.09649 .46302 L
.09652 .463 L
.09655 .46298 L
.09658 .46295 L
.09664 .46288 L
.0967 .46278 L
.09676 .46266 L
.0972 .46152 L
.09731 .46127 L
.09737 .46116 L
.09743 .46108 L
.09746 .46104 L
.0975 .461 L
.09753 .46098 L
.09756 .46096 L
.09759 .46095 L
.09762 .46095 L
.09763 .46095 L
.09765 .46095 L
.09768 .46096 L
.09771 .46098 L
.09774 .461 L
.09777 .46103 L
.09781 .46108 L
.09788 .46119 L
.09794 .46131 L
.09819 .46192 L
.09841 .46252 L
.09852 .46277 L
.09859 .46288 L
.09865 .46296 L
.09868 .46299 L
.09871 .46302 L
.09873 .46303 L
.09874 .46304 L
.09876 .46305 L
.09878 .46305 L
.0988 .46306 L
.09881 .46306 L
.09883 .46306 L
.09885 .46305 L
.09888 .46304 L
.09891 .46302 L
.09893 .463 L
.09896 .46297 L
.09902 .4629 L
.09915 .46267 L
.09938 .46207 L
.09962 .46141 L
Mistroke
.09975 .46115 L
.09978 .46109 L
.09982 .46104 L
.09985 .461 L
.09989 .46096 L
.09991 .46095 L
.09992 .46094 L
.09995 .46093 L
.09997 .46092 L
.09999 .46092 L
.10002 .46092 L
.10005 .46093 L
.10008 .46094 L
.10011 .46096 L
.10014 .46099 L
.1002 .46106 L
.10025 .46115 L
.10037 .46141 L
.1006 .462 L
.10072 .46236 L
.10086 .46269 L
.10092 .46282 L
.10098 .46293 L
.10104 .463 L
.10107 .46303 L
.1011 .46306 L
.10112 .46307 L
.10115 .46308 L
.10118 .46309 L
.1012 .46309 L
.10123 .46308 L
.10126 .46307 L
.10129 .46305 L
.10132 .46303 L
.10137 .46296 L
.10143 .46287 L
.10155 .46262 L
.10181 .46191 L
.10193 .46159 L
.10205 .46128 L
.10211 .46116 L
.10217 .46105 L
.10223 .46097 L
.10225 .46095 L
.10228 .46092 L
.10231 .4609 L
.10234 .46089 L
.10237 .46089 L
.10239 .46088 L
.1024 .46089 L
Mistroke
.10243 .46089 L
.10246 .46091 L
.10249 .46093 L
.10252 .46096 L
.10258 .46103 L
.10264 .46114 L
.10276 .46139 L
.10302 .46213 L
.10324 .46273 L
.10331 .46286 L
.10337 .46297 L
.10343 .46304 L
.10346 .46308 L
.10349 .4631 L
.10351 .46311 L
.10354 .46312 L
.10357 .46313 L
.1036 .46312 L
.10362 .46312 L
.10365 .4631 L
.10367 .46309 L
.1037 .46306 L
.10376 .463 L
.10381 .46291 L
.10393 .46267 L
.10417 .46199 L
.1043 .4616 L
.10442 .46128 L
.10454 .46104 L
.10457 .46099 L
.1046 .46094 L
.10463 .46091 L
.10466 .46088 L
.10469 .46086 L
.10472 .46085 L
.10474 .46084 L
.10477 .46084 L
.10479 .46085 L
.10482 .46086 L
.10485 .46087 L
.10488 .4609 L
.10494 .46096 L
.10499 .46104 L
.10511 .46129 L
.10532 .46188 L
.10544 .46225 L
.10557 .46262 L
.10563 .46277 L
.10569 .4629 L
.10574 .46299 L
Mistroke
.1058 .46308 L
.10582 .46311 L
.10585 .46313 L
.10588 .46315 L
.10591 .46317 L
.10594 .46317 L
.10597 .46317 L
.10599 .46317 L
.10602 .46316 L
.10605 .46314 L
.10608 .46311 L
.10614 .46303 L
.1062 .46293 L
.10625 .46282 L
.1065 .46215 L
.10663 .46174 L
.10675 .46138 L
.10687 .46109 L
.10692 .46099 L
.10698 .4609 L
.10701 .46086 L
.10704 .46083 L
.10707 .46081 L
.1071 .4608 L
.10712 .46079 L
.10714 .46079 L
.10717 .46079 L
.10718 .4608 L
.1072 .46081 L
.10722 .46082 L
.10723 .46083 L
.10726 .46085 L
.10729 .46089 L
.10735 .46096 L
.10746 .4612 L
.10768 .46182 L
.10791 .46255 L
.10804 .46288 L
.1081 .46301 L
.10816 .4631 L
.10819 .46314 L
.10821 .46317 L
.10824 .46319 L
.10826 .46321 L
.10829 .46322 L
.10832 .46323 L
.10835 .46323 L
.10837 .46322 L
.1084 .46321 L
.10843 .46319 L
Mistroke
.10846 .46316 L
.10848 .46313 L
.10855 .46304 L
.1086 .46292 L
.10905 .46158 L
.10918 .46122 L
.10925 .46106 L
.10931 .46093 L
.10936 .46084 L
.10939 .46081 L
.10942 .46078 L
.10944 .46076 L
.10945 .46075 L
.10948 .46074 L
.10951 .46073 L
.10954 .46073 L
.10956 .46074 L
.10958 .46074 L
.10959 .46075 L
.10961 .46076 L
.10965 .4608 L
.10968 .46084 L
.10974 .46094 L
.10981 .46108 L
.11006 .46179 L
.11031 .46262 L
.11042 .46292 L
.11048 .46306 L
.11054 .46316 L
.1106 .46323 L
.11061 .46325 L
.11063 .46326 L
.11066 .46328 L
.11069 .46329 L
.11072 .46329 L
.11074 .46329 L
.11075 .46329 L
.11077 .46328 L
.11078 .46327 L
.11082 .46325 L
.11085 .46321 L
.11091 .46312 L
.11098 .46299 L
.11105 .46281 L
.1113 .462 L
.11153 .46125 L
.11165 .46095 L
.11171 .46082 L
.11175 .46078 L
.11177 .46074 L
Mistroke
.1118 .46071 L
.11183 .46069 L
.11185 .46067 L
.11188 .46066 L
.11191 .46066 L
.11194 .46067 L
.11197 .46068 L
.112 .4607 L
.11203 .46074 L
.11207 .46078 L
.11213 .46089 L
.11224 .46117 L
.1125 .46202 L
.11262 .46244 L
.11275 .46284 L
.11281 .46301 L
.11287 .46314 L
.11292 .46323 L
.11295 .46328 L
.11298 .46331 L
.11301 .46334 L
.11304 .46336 L
.11307 .46337 L
.11309 .46337 L
.11311 .46337 L
.11313 .46337 L
.11316 .46335 L
.11319 .46333 L
.11322 .4633 L
.11329 .4632 L
.11335 .46307 L
.11349 .4627 L
.11373 .46184 L
.11386 .46137 L
.11398 .461 L
.11404 .46087 L
.11409 .46076 L
.11412 .46071 L
.11415 .46067 L
.11418 .46063 L
.1142 .46061 L
.11423 .46059 L
.11426 .46058 L
.11429 .46057 L
.11431 .46058 L
.11433 .46058 L
.11435 .4606 L
.11438 .46062 L
.11442 .46066 L
.11444 .4607 L
Mistroke
.1145 .4608 L
.11456 .46094 L
.11468 .46127 L
.11489 .46204 L
.11502 .46252 L
.11514 .46292 L
.11525 .46321 L
.11531 .46333 L
.11537 .46341 L
.11539 .46343 L
.11542 .46345 L
.11545 .46346 L
.11548 .46347 L
.11551 .46346 L
.11552 .46346 L
.11554 .46345 L
.11557 .46343 L
.1156 .46339 L
.11566 .46331 L
.11571 .46319 L
.11584 .46284 L
.1161 .46187 L
.11622 .46139 L
.11634 .46099 L
.11646 .4607 L
.11649 .46063 L
.11652 .46058 L
.11655 .46055 L
.11658 .46051 L
.11661 .46049 L
.11662 .46048 L
.11664 .46047 L
.11667 .46047 L
.1167 .46047 L
.11671 .46048 L
.11673 .46049 L
.11675 .46051 L
.11677 .46052 L
.11683 .46061 L
.11688 .46071 L
.11693 .46083 L
.11705 .46117 L
.11727 .46207 L
.11751 .46297 L
.11763 .46331 L
.11766 .46338 L
.1177 .46344 L
.11773 .46349 L
.11776 .46353 L
.11779 .46356 L
Mistroke
.11782 .46357 L
.11785 .46358 L
.11786 .46358 L
.11788 .46358 L
.11791 .46357 L
.11793 .46355 L
.11796 .46352 L
.11799 .46348 L
.11804 .46339 L
.11809 .46328 L
.1182 .46296 L
.11842 .4621 L
.11866 .46114 L
.11878 .46074 L
.11885 .46057 L
.11888 .4605 L
.11891 .46045 L
.11894 .46041 L
.11897 .46037 L
.119 .46035 L
.11902 .46034 L
.11905 .46034 L
.11908 .46035 L
.1191 .46035 L
.11911 .46036 L
.11914 .46039 L
.11918 .46043 L
.11921 .46048 L
.11928 .46063 L
.11934 .46082 L
.11941 .46106 L
.11966 .46209 L
.11978 .46263 L
.11991 .46313 L
.12002 .46346 L
.12005 .46352 L
.12009 .46359 L
.12012 .46364 L
.12014 .46367 L
.12018 .4637 L
.12019 .46371 L
.12021 .46372 L
.12024 .46373 L
.12026 .46373 L
.12027 .46372 L
.1203 .4637 L
.12033 .46368 L
.12036 .46364 L
.12039 .46359 L
.12046 .46345 L
Mistroke
.12052 .46327 L
.12066 .46276 L
.12089 .46171 L
.12101 .46116 L
.12114 .46067 L
.1212 .46049 L
.12124 .4604 L
.12127 .46033 L
.12131 .46027 L
.12134 .46023 L
.12137 .4602 L
.12139 .46019 L
.12142 .46018 L
.12145 .46018 L
.12148 .4602 L
.12151 .46022 L
.12154 .46026 L
.12157 .46031 L
.12163 .46044 L
.12169 .46059 L
.12175 .46078 L
.12186 .46127 L
.12208 .46229 L
.1222 .46288 L
.12232 .46336 L
.12238 .46353 L
.12243 .46368 L
.12246 .46374 L
.12249 .4638 L
.12252 .46384 L
.12255 .46387 L
.12258 .4639 L
.1226 .4639 L
.12261 .46391 L
.12264 .4639 L
.12267 .46389 L
.12269 .46387 L
.12271 .46385 L
.12274 .46381 L
.12278 .46375 L
.12281 .46368 L
.12292 .46331 L
.12305 .46279 L
.12328 .46164 L
.1234 .46103 L
.12352 .46053 L
.12357 .46035 L
.12363 .4602 L
.12366 .46013 L
.12369 .46007 L
Mistroke
.12372 .46003 L
.12375 .46 L
.12378 .45998 L
.1238 .45998 L
.12383 .45998 L
.12385 .45999 L
.12388 .46001 L
.12391 .46004 L
.12393 .46009 L
.12396 .46013 L
.12401 .46027 L
.12408 .46046 L
.1242 .46096 L
.12442 .46211 L
.12455 .4628 L
.12468 .46343 L
.12474 .46364 L
.12479 .46383 L
.12483 .46392 L
.12486 .46399 L
.12489 .46405 L
.12492 .46409 L
.12495 .46412 L
.12498 .46414 L
.12501 .46414 L
.12503 .46413 L
.12506 .46411 L
.12509 .46407 L
.12513 .46402 L
.12516 .46395 L
.12521 .4638 L
.12527 .46363 L
.12538 .46311 L
.12564 .46167 L
.12577 .46096 L
.12589 .4604 L
.12599 .46002 L
.12604 .45988 L
.12607 .45982 L
.1261 .45977 L
.12613 .45974 L
.12616 .45972 L
.12619 .45971 L
.12621 .45971 L
.12624 .45973 L
.12626 .45975 L
.12628 .45977 L
.12631 .45982 L
.12633 .45987 L
.1264 .46005 L
Mistroke
.12646 .46026 L
.12657 .46079 L
.12683 .46231 L
.12695 .46303 L
.12706 .46362 L
.12712 .46389 L
.12719 .46413 L
.12722 .46422 L
.12725 .4643 L
.12728 .46435 L
.1273 .4644 L
.12733 .46442 L
.12736 .46444 L
.12738 .46445 L
.12741 .46444 L
.12744 .46442 L
.12747 .46438 L
.12749 .46434 L
.12752 .46429 L
.12757 .46414 L
.12763 .46391 L
.12775 .46338 L
.12797 .46195 L
.12822 .4604 L
.12829 .46004 L
.12836 .45976 L
.12842 .45956 L
.12845 .45948 L
.12849 .45942 L
.12852 .45938 L
.12854 .45936 L
.12857 .45935 L
.12859 .45936 L
.12861 .45937 L
.12864 .4594 L
.12866 .45942 L
.12867 .45945 L
.12871 .45952 L
.12874 .4596 L
.1288 .45981 L
.12886 .46009 L
.12898 .46076 L
.1292 .46228 L
.12932 .46315 L
.12945 .46396 L
.12951 .46428 L
.12957 .46453 L
.12963 .46469 L
.12966 .46476 L
.12969 .46481 L
Mistroke
.12971 .46484 L
.12974 .46486 L
.12977 .46487 L
.12979 .46486 L
.12982 .46483 L
.12985 .46479 L
.12988 .46473 L
.12991 .46465 L
.12997 .46445 L
.13002 .46421 L
.13014 .46352 L
.1304 .46157 L
.13051 .4607 L
.13064 .45986 L
.13069 .45955 L
.13075 .45927 L
.13078 .45916 L
.13081 .45907 L
.13084 .459 L
.13086 .45894 L
.13089 .45889 L
.13092 .45886 L
.13095 .45885 L
.13098 .45886 L
.13101 .45888 L
.13104 .45893 L
.13107 .45899 L
.1311 .45909 L
.13116 .45932 L
.13122 .45964 L
.13134 .46038 L
.1316 .46256 L
.13172 .46357 L
.13185 .46448 L
.13191 .46486 L
.13195 .46503 L
.13198 .46518 L
.13202 .4653 L
.13205 .46538 L
.13208 .46543 L
.13211 .46547 L
.13214 .46548 L
.13217 .46547 L
.13219 .46546 L
.1322 .46543 L
.13223 .46538 L
.13226 .46531 L
.13229 .46521 L
.13234 .46499 L
.13241 .46465 L
Mistroke
.13246 .46427 L
.1326 .4632 L
.13285 .4608 L
.13297 .4597 L
.13303 .45928 L
.13309 .45888 L
.13314 .4586 L
.13319 .45836 L
.13322 .45826 L
.13325 .45819 L
.13327 .45814 L
.1333 .45811 L
.13333 .45809 L
.13336 .4581 L
.13339 .45813 L
.13341 .45817 L
.13344 .45825 L
.13347 .45836 L
.13353 .45863 L
.13359 .45897 L
.13365 .45941 L
.13376 .46039 L
.13401 .46307 L
.13415 .46446 L
.13421 .46506 L
.13428 .46553 L
.13433 .46588 L
.13439 .46617 L
.13442 .46628 L
.13445 .46636 L
.13448 .46642 L
.1345 .46643 L
.13452 .46644 L
.13455 .46643 L
.13458 .4664 L
.1346 .46635 L
.13463 .46627 L
.13466 .46615 L
.13469 .466 L
.13475 .46565 L
.13486 .46479 L
.13497 .46359 L
.13523 .46037 L
.13535 .45894 L
.13547 .45787 L
.13552 .45746 L
.13558 .45714 L
.13562 .457 L
.13565 .45691 L
.13568 .45685 L
Mistroke
.13571 .45683 L
.13573 .45683 L
.13576 .45687 L
.1358 .45695 L
.13582 .45705 L
.13588 .45731 L
.13593 .45769 L
.136 .45826 L
.13607 .45901 L
.1362 .46066 L
.13644 .46418 L
.13654 .46566 L
.13666 .46697 L
.13673 .46752 L
.13676 .46772 L
.13679 .46789 L
.13682 .46802 L
.13685 .46811 L
.13688 .46816 L
.1369 .46817 L
.13691 .46817 L
.13694 .46814 L
.13696 .46811 L
.13698 .46806 L
.13701 .46795 L
.13704 .4678 L
.1371 .46734 L
.13717 .46666 L
.1373 .46497 L
.13742 .46304 L
.13764 .45905 L
.13776 .45706 L
.13787 .45558 L
.13794 .45496 L
.13797 .4547 L
.13801 .45452 L
.13804 .45441 L
.13807 .45434 L
.13808 .45432 L
.1381 .45432 L
.13813 .45435 L
.13816 .45444 L
.13818 .45451 L
.1382 .45459 L
.13822 .45477 L
.13826 .45503 L
.13831 .45559 L
.13837 .45636 L
.13863 .46136 L
.13888 .46703 L
Mistroke
.13898 .46917 L
.13904 .47015 L
.1391 .47092 L
.13913 .47128 L
.13916 .47161 L
.13919 .47184 L
.13922 .47199 L
.13925 .47209 L
.13928 .47213 L
.13931 .47212 L
.13934 .47204 L
.13937 .47189 L
.1394 .47169 L
.13943 .47141 L
.13946 .47104 L
.13951 .47025 L
.13957 .46914 L
.13979 .46353 L
.14004 .45539 L
.14015 .45211 L
.14021 .45062 L
.14027 .44926 L
.1403 .44868 L
.14033 .44821 L
.14036 .44783 L
.14039 .44754 L
.14041 .44734 L
.14044 .4472 L
.14047 .44713 L
.1405 .44714 L
.14053 .44726 L
.14055 .44746 L
.14057 .44761 L
.14059 .4478 L
.14062 .44824 L
.14068 .4494 L
.14073 .45083 L
.14086 .45532 L
.14098 .46064 L
.14123 .47469 L
.14135 .48075 L
.14142 .48362 L
.14148 .48589 L
.14153 .48744 L
.14155 .48807 L
.14158 .48863 L
.14161 .48907 L
.14164 .48932 L
.14167 .48938 L
.1417 .48928 L
Mistroke
.14173 .48899 L
.14176 .48846 L
.14179 .48775 L
.14181 .4869 L
.14187 .48422 L
.14194 .48024 L
.142 .47518 L
.14206 .4694 L
.1422 .45245 L
.14232 .4327 L
.14245 .407 L
.14269 .3516 L
.14314 .23939 L
.14338 .18745 L
.1435 .16742 L
.14361 .15274 L
.14373 .14114 L
.14379 .13643 L
.14386 .13304 L
.14389 .13166 L
.14392 .1305 L
.14395 .12967 L
.14398 .12913 L
.144 .12891 L
.14402 .12876 L
.14403 .12867 L
.14405 .12866 L
.14407 .12871 L
.14409 .1288 L
.1441 .12896 L
.14412 .1292 L
.14415 .12971 L
.14418 .13045 L
.14425 .13246 L
.14437 .13742 L
.14463 .15178 L
.14475 .15809 L
.14488 .16384 L
.14494 .16608 L
.145 .16784 L
.14506 .16909 L
.14509 .16962 L
.14512 .17008 L
.14515 .17046 L
.14518 .17071 L
.14521 .17087 L
.14523 .17091 L
.14524 .17091 L
.14527 .17085 L
.1453 .1707 L
Mistroke
.14532 .17059 L
.14533 .17044 L
.14536 .1701 L
.14542 .16924 L
.14548 .16805 L
.14559 .16529 L
.14583 .15758 L
.14596 .15356 L
.14609 .14997 L
.14615 .14875 L
.14621 .14767 L
.14624 .14716 L
.14627 .14677 L
.14631 .14644 L
.14634 .14621 L
.14636 .14605 L
.14639 .14595 L
.14642 .1459 L
.14645 .14592 L
.14648 .14599 L
.14651 .14612 L
.14653 .14629 L
.14656 .1465 L
.14662 .14709 L
.14667 .1478 L
.14679 .14989 L
.147 .15468 L
.14712 .1575 L
.14725 .16019 L
.14731 .16123 L
.14738 .16215 L
.14743 .16277 L
.14746 .16306 L
.14749 .16328 L
.14752 .16345 L
.14755 .16359 L
.14758 .16367 L
.1476 .16371 L
.14763 .16371 L
.14766 .16367 L
.14768 .16362 L
.14769 .16357 L
.14772 .16342 L
.14775 .16326 L
.14778 .16305 L
.14784 .1625 L
.14794 .1612 L
.1482 .15671 L
.14833 .15441 L
.14845 .15254 L
Mistroke
.14856 .1512 L
.14861 .15069 L
.14867 .15026 L
.14871 .15009 L
.14873 .14998 L
.14875 .14994 L
.14877 .1499 L
.1488 .14986 L
.14883 .14987 L
.14886 .14991 L
.14889 .14999 L
.14892 .1501 L
.14894 .15024 L
.14897 .15043 L
.14904 .15092 L
.14915 .15211 L
.1494 .15565 L
.14951 .15729 L
.14963 .15889 L
.14969 .15951 L
.14975 .16008 L
.1498 .16049 L
.14985 .16083 L
.14989 .16097 L
.14992 .16108 L
.14994 .16115 L
.14997 .16119 L
.14999 .1612 L
.15 .16121 L
.15003 .16119 L
.15005 .16116 L
.15007 .16112 L
.1501 .16102 L
.15013 .16091 L
.15016 .16077 L
.15021 .16045 L
.15033 .15946 L
.15057 .15661 L
.1507 .15494 L
.15083 .15353 L
.15095 .1525 L
.15101 .15208 L
.15105 .15192 L
.15108 .1518 L
.1511 .15172 L
.15113 .15165 L
.15116 .15161 L
.15118 .15159 L
.15121 .1516 L
.15124 .15163 L
Mistroke
.15127 .15169 L
.1513 .15178 L
.15133 .15188 L
.15136 .15202 L
.15141 .15232 L
.15151 .15308 L
.15174 .15538 L
.15186 .15668 L
.15199 .15797 L
.15205 .15851 L
.15211 .15896 L
.15216 .1593 L
.15222 .15959 L
.15225 .15971 L
.15228 .1598 L
.15231 .15987 L
.15233 .15991 L
.15237 .15994 L
.15239 .15994 L
.15243 .15991 L
.15244 .15989 L
.15246 .15986 L
.15249 .15977 L
.15253 .15966 L
.1526 .15933 L
.15266 .15893 L
.15272 .15847 L
.15294 .15656 L
.15316 .15444 L
.15323 .15391 L
.15329 .15347 L
.15336 .15311 L
.15341 .15286 L
.15344 .15276 L
.15347 .15269 L
.1535 .15262 L
.15352 .15258 L
.15356 .15256 L
.15358 .15256 L
.15361 .15258 L
.15363 .1526 L
.15365 .15262 L
.15368 .15269 L
.15371 .15278 L
.15377 .153 L
.15383 .15331 L
.15389 .15372 L
.15412 .15555 L
.15436 .15756 L
.15443 .15802 L
Mistroke
.1545 .15845 L
.15457 .15877 L
.1546 .15889 L
.15463 .15899 L
.15466 .15907 L
.15469 .15912 L
.15471 .15916 L
.15474 .15918 L
.15477 .15918 L
.1548 .15917 L
.15483 .15914 L
.15484 .15911 L
.15486 .15908 L
.15492 .15891 L
.15495 .15879 L
.15499 .15866 L
.1551 .15801 L
.15536 .15606 L
.15549 .15508 L
.15561 .1543 L
.15566 .15398 L
.15572 .15369 L
.15577 .15349 L
.15583 .15332 L
.15586 .15325 L
.15589 .15321 L
.15592 .15318 L
.15594 .15317 L
.15595 .15317 L
.15598 .15318 L
.15601 .1532 L
.15604 .15324 L
.15606 .15329 L
.15612 .15345 L
.15618 .15366 L
.15631 .15431 L
.15656 .15607 L
.1568 .15765 L
.15692 .15822 L
.15695 .15834 L
.15699 .15845 L
.15702 .15854 L
.15705 .1586 L
.15708 .15864 L
.15711 .15867 L
.15714 .15868 L
.15715 .15868 L
.15717 .15867 L
.1572 .15865 L
.15722 .15862 L
Mistroke
.15725 .15857 L
.15728 .15851 L
.15733 .15835 L
.15738 .15817 L
.15749 .15765 L
.15773 .15618 L
.15785 .15537 L
.15798 .1546 L
.15809 .15407 L
.15816 .15385 L
.15819 .15377 L
.15822 .1537 L
.15824 .15366 L
.15827 .15362 L
.1583 .1536 L
.15832 .15359 L
.15835 .15359 L
.15838 .15361 L
.15841 .15363 L
.15844 .15368 L
.15846 .15373 L
.15849 .1538 L
.15855 .15398 L
.15866 .15445 L
.15887 .15563 L
.1591 .157 L
.15922 .1576 L
.15928 .15786 L
.15934 .15806 L
.15937 .15815 L
.1594 .15821 L
.15944 .15826 L
.15946 .15829 L
.15947 .1583 L
.1595 .15832 L
.15953 .15832 L
.15956 .15831 L
.15958 .1583 L
.15959 .15828 L
.15963 .15824 L
.15965 .15819 L
.15972 .15803 L
.15977 .15784 L
.15983 .15761 L
.16028 .15517 L
.1604 .1546 L
.16046 .15438 L
.16051 .1542 L
.16057 .15405 L
.1606 .15398 L
Mistroke
.16062 .15396 L
.16064 .15394 L
.16067 .15391 L
.16069 .1539 L
.16071 .1539 L
.16073 .1539 L
.16076 .15391 L
.16078 .15393 L
.16081 .15396 L
.16084 .15401 L
.16086 .15406 L
.16091 .15418 L
.16097 .15435 L
.16109 .15484 L
.1612 .15539 L
.16142 .15657 L
.16154 .15716 L
.16165 .15761 L
.16171 .15781 L
.16175 .15789 L
.16178 .15796 L
.16181 .158 L
.16183 .15802 L
.16185 .15804 L
.16188 .15805 L
.16191 .15806 L
.16194 .15805 L
.16195 .15804 L
.16197 .15803 L
.162 .158 L
.16203 .15795 L
.16209 .15782 L
.16215 .15766 L
.16239 .15664 L
.16265 .15533 L
.16275 .15486 L
.16287 .15446 L
.1629 .15437 L
.16293 .1543 L
.16296 .15424 L
.16299 .1542 L
.16302 .15417 L
.16305 .15414 L
.16308 .15413 L
.16309 .15413 L
.16311 .15413 L
.16314 .15414 L
.16316 .15416 L
.16319 .15419 L
.16322 .15423 L
Mistroke
.16328 .15436 L
.16334 .15451 L
.16345 .1549 L
.16355 .15535 L
.16378 .15645 L
.16391 .15703 L
.16398 .15728 L
.16403 .15747 L
.16409 .15761 L
.16415 .15773 L
.16418 .15778 L
.16421 .15782 L
.16424 .15784 L
.16427 .15785 L
.16428 .15785 L
.1643 .15785 L
.16432 .15785 L
.16433 .15784 L
.16436 .15782 L
.16438 .1578 L
.1644 .15778 L
.16445 .15768 L
.16451 .15754 L
.16463 .15715 L
.16475 .15668 L
.16496 .15571 L
.16508 .15519 L
.16519 .15478 L
.16525 .15461 L
.16531 .15448 L
.16534 .15442 L
.16537 .15438 L
.1654 .15434 L
.16542 .15433 L
.16544 .15432 L
.16546 .15431 L
.16549 .15431 L
.16552 .15432 L
.16555 .15434 L
.16557 .15436 L
.1656 .15439 L
.16565 .15449 L
.16571 .15462 L
.16577 .15479 L
.16588 .15519 L
.16612 .15624 L
.16625 .15678 L
.16632 .15705 L
.16639 .15726 L
.16645 .15743 L
Mistroke
.16648 .15751 L
.16652 .15757 L
.16655 .15762 L
.16656 .15763 L
.16658 .15765 L
.16661 .15768 L
.16664 .15769 L
.16667 .15769 L
.16669 .15769 L
.1667 .15769 L
.16673 .15767 L
.16676 .15764 L
.16679 .15761 L
.16681 .15757 L
.16687 .15746 L
.16693 .1573 L
.16699 .15713 L
.16712 .15665 L
.16736 .15566 L
.16747 .15522 L
.16757 .15488 L
.16763 .15473 L
.16769 .1546 L
.16772 .15455 L
.16775 .15451 L
.16777 .15449 L
.1678 .15447 L
.16783 .15445 L
.16786 .15445 L
.16788 .15445 L
.16789 .15446 L
.16791 .15447 L
.16793 .15448 L
.16796 .15451 L
.16799 .15454 L
.16805 .15465 L
.1681 .15476 L
.16816 .15492 L
.16827 .1553 L
.16853 .15635 L
.16866 .15682 L
.16877 .15718 L
.16883 .15732 L
.16889 .15743 L
.16892 .15748 L
.16895 .15751 L
.16897 .15753 L
.16898 .15754 L
.169 .15755 L
.16902 .15756 L
Mistroke
.16904 .15757 L
.16907 .15756 L
.1691 .15755 L
.16912 .15753 L
.16915 .15751 L
.16919 .15746 L
.16924 .15737 L
.16931 .15723 L
.16937 .15704 L
.16951 .15659 L
.16975 .15565 L
.16987 .1552 L
.16994 .15501 L
.16999 .15486 L
.17004 .15476 L
.1701 .15466 L
.17013 .15463 L
.17016 .1546 L
.17019 .15458 L
.17022 .15457 L
.17025 .15457 L
.17028 .15457 L
.17029 .15458 L
.17031 .15459 L
.17034 .15462 L
.17038 .15467 L
.17041 .15472 L
.17048 .15485 L
.1706 .1552 L
.17072 .15559 L
.17094 .15641 L
.17106 .15683 L
.17117 .15714 L
.17124 .15728 L
.17127 .15734 L
.17131 .15739 L
.17134 .15742 L
.17135 .15743 L
.17137 .15744 L
.1714 .15746 L
.17143 .15746 L
.17146 .15746 L
.17147 .15745 L
.17149 .15744 L
.17152 .15742 L
.17155 .15739 L
.17161 .1573 L
.17167 .15719 L
.17191 .15647 L
.17217 .15554 L
Mistroke
.17227 .1552 L
.17239 .15492 L
.17245 .1548 L
.17248 .15475 L
.17251 .15472 L
.17254 .15469 L
.17257 .15467 L
.1726 .15466 L
.17263 .15466 L
.17266 .15467 L
.17267 .15468 L
.17269 .15468 L
.17272 .15471 L
.17275 .15474 L
.17281 .15483 L
.17288 .15497 L
.173 .15529 L
.17311 .15566 L
.17332 .15641 L
.17344 .15679 L
.17355 .15707 L
.1736 .15718 L
.17366 .15728 L
.1737 .15731 L
.17371 .15733 L
.17373 .15734 L
.17376 .15736 L
.17379 .15737 L
.17382 .15737 L
.17384 .15737 L
.17387 .15736 L
.17389 .15734 L
.17392 .15731 L
.17395 .15728 L
.17401 .15719 L
.17407 .15708 L
.17413 .15692 L
.17425 .15659 L
.17451 .1557 L
.17463 .15533 L
.17475 .15501 L
.17479 .15494 L
.17482 .15488 L
.17486 .15483 L
.17489 .1548 L
.17492 .15477 L
.17495 .15475 L
.17498 .15474 L
.175 .15474 L
.17502 .15474 L
Mistroke
.17505 .15475 L
.17506 .15476 L
.17508 .15477 L
.17511 .15479 L
.17514 .15483 L
.17519 .1549 L
.17525 .15501 L
.17538 .15533 L
.1755 .15571 L
.17575 .15653 L
.17587 .15688 L
.17593 .15702 L
.17599 .15712 L
.17604 .1572 L
.17606 .15723 L
.17609 .15726 L
.17612 .15728 L
.17614 .15729 L
.17617 .1573 L
.1762 .1573 L
.17623 .1573 L
.17626 .15728 L
.17627 .15727 L
.17629 .15726 L
.17632 .15723 L
.17638 .15715 L
.17643 .15706 L
.17666 .15644 L
.17692 .15563 L
.17703 .15529 L
.1771 .15514 L
.17715 .15502 L
.17721 .15493 L
.17726 .15487 L
.17729 .15484 L
.17731 .15483 L
.17734 .15481 L
.17737 .15481 L
.1774 .15481 L
.17743 .15482 L
.17746 .15483 L
.17748 .15485 L
.17751 .15488 L
.17754 .15492 L
.1776 .15501 L
.17773 .15529 L
.17784 .15561 L
.17805 .15628 L
.17816 .15661 L
.17828 .1569 L
Mistroke
.17834 .15703 L
.17838 .15709 L
.17841 .15714 L
.17845 .15718 L
.17848 .1572 L
.17851 .15722 L
.17853 .15724 L
.17856 .15724 L
.17859 .15724 L
.17862 .15723 L
.17865 .15722 L
.17868 .15719 L
.17871 .15716 L
.17877 .15708 L
.17883 .15698 L
.17889 .15685 L
.17901 .15654 L
.17922 .15588 L
.17935 .1555 L
.17947 .1552 L
.17952 .15509 L
.17958 .155 L
.1796 .15496 L
.17964 .15493 L
.17967 .1549 L
.17969 .15488 L
.17972 .15487 L
.17974 .15486 L
.17976 .15486 L
.17979 .15486 L
.1798 .15487 L
.17982 .15487 L
.17985 .15489 L
.17988 .15492 L
.17994 .15498 L
.18 .15509 L
.18007 .15523 L
.1802 .15555 L
.18042 .15624 L
.18055 .1566 L
.18067 .15688 L
.18072 .15699 L
.18078 .15707 L
.18081 .15711 L
.18084 .15714 L
.18087 .15717 L
.1809 .15718 L
.18093 .15719 L
.18095 .15719 L
.18098 .15719 L
Mistroke
.181 .15718 L
.18103 .15717 L
.18106 .15715 L
.18109 .15712 L
.18111 .15709 L
.18117 .15701 L
.18123 .1569 L
.18135 .15661 L
.18157 .15597 L
.18171 .15558 L
.18183 .15526 L
.18189 .15515 L
.18195 .15505 L
.18198 .15501 L
.18201 .15497 L
.18204 .15495 L
.18207 .15493 L
.1821 .15491 L
.18213 .15491 L
.18216 .15491 L
.18219 .15492 L
.18222 .15493 L
.18224 .15495 L
.18227 .15497 L
.1823 .155 L
.18236 .15509 L
.18241 .15519 L
.18254 .15547 L
.1828 .15622 L
.18293 .15657 L
.18304 .15684 L
.1831 .15694 L
.18316 .15703 L
.18318 .15706 L
.18321 .15709 L
.18324 .15711 L
.18326 .15713 L
.18329 .15714 L
.18331 .15715 L
.18332 .15715 L
.18335 .15715 L
.18338 .15714 L
.18341 .15713 L
.18344 .15711 L
.18347 .15708 L
.18349 .15705 L
.18356 .15696 L
.18362 .15685 L
.18375 .15655 L
.18399 .15587 L
Mistroke
.1841 .15556 L
.18422 .15527 L
.18428 .15517 L
.18434 .15508 L
.18439 .15502 L
.18441 .15499 L
.18444 .15497 L
.18447 .15496 L
.18449 .15495 L
.1845 .15495 L
.18453 .15495 L
.18457 .15495 L
.18459 .15496 L
.18462 .15498 L
.18465 .155 L
.18468 .15504 L
.18475 .15513 L
.18481 .15525 L
.18493 .15553 L
.18515 .15611 L
.18537 .1567 L
.18544 .15683 L
.1855 .15695 L
.18556 .15702 L
.18559 .15706 L
.18562 .15708 L
.18565 .1571 L
.18568 .15711 L
.18571 .15711 L
.18573 .15711 L
.18576 .15711 L
.18578 .1571 L
.1858 .15709 L
.18583 .15707 L
.18585 .15704 L
.18592 .15697 L
.18597 .15687 L
.18608 .15664 L
.18633 .15599 L
.18646 .15564 L
.18657 .15536 L
.18664 .15523 L
.18671 .15511 L
.18674 .15507 L
.18677 .15504 L
.1868 .15502 L
.18683 .155 L
.18685 .15499 L
.18687 .15498 L
.1869 .15498 L
Mistroke
.18693 .15498 L
.18695 .15499 L
.18698 .155 L
.187 .15501 L
.18701 .15502 L
.18708 .15509 L
.18714 .15517 L
.18719 .15526 L
.18731 .15553 L
.18752 .1561 L
.18775 .15668 L
.18782 .15681 L
.18788 .15691 L
.18793 .15699 L
.18796 .15702 L
.18799 .15704 L
.18802 .15706 L
.18804 .15708 L
.18807 .15708 L
.1881 .15709 L
.18813 .15708 L
.18816 .15707 L
.18818 .15706 L
.18821 .15704 L
.18824 .15701 L
.18827 .15697 L
.18833 .15689 L
.18846 .15663 L
.1887 .156 L
.18894 .15541 L
.18906 .15518 L
.18909 .15514 L
.18913 .15509 L
.18916 .15506 L
.18919 .15504 L
.18922 .15502 L
.18925 .15501 L
.18927 .155 L
.18929 .155 L
.18931 .15501 L
.18934 .15501 L
.18936 .15502 L
.18939 .15504 L
.18942 .15507 L
.18947 .15513 L
.18952 .1552 L
.18963 .15541 L
.18985 .15595 L
.19008 .15656 L
.1902 .15681 L
Mistroke
.19027 .15692 L
.19031 .15696 L
.19034 .15699 L
.19037 .15702 L
.1904 .15704 L
.19042 .15705 L
.19045 .15706 L
.19048 .15706 L
.19051 .15706 L
.19052 .15705 L
.19054 .15705 L
.19057 .15703 L
.1906 .157 L
.19063 .15697 L
.1907 .15689 L
.19077 .15677 L
.19084 .15663 L
.19109 .156 L
.19121 .15568 L
.19134 .15538 L
.19145 .15519 L
.19148 .15515 L
.19151 .15511 L
.19154 .15508 L
.19157 .15506 L
.1916 .15504 L
.19162 .15503 L
.19164 .15503 L
.19165 .15502 L
.19167 .15502 L
.1917 .15503 L
.19173 .15504 L
.19176 .15505 L
.19179 .15507 L
.19182 .1551 L
.19188 .15518 L
.19194 .15528 L
.19208 .15558 L
.19232 .15618 L
.19245 .15651 L
.19257 .15676 L
.19263 .15687 L
.19269 .15695 L
.19272 .15698 L
.19275 .157 L
.19278 .15702 L
.1928 .15703 L
.19282 .15704 L
.19285 .15704 L
.19288 .15704 L
Mistroke
.19291 .15704 L
.19293 .15702 L
.19296 .157 L
.193 .15698 L
.19306 .15691 L
.19311 .15683 L
.19317 .15672 L
.19329 .15646 L
.1935 .15591 L
.19363 .15559 L
.19375 .15534 L
.1938 .15525 L
.19385 .15517 L
.19388 .15513 L
.19391 .1551 L
.19394 .15508 L
.19397 .15506 L
.194 .15505 L
.19402 .15504 L
.19404 .15504 L
.19406 .15504 L
.1941 .15505 L
.19411 .15506 L
.19413 .15506 L
.19417 .15509 L
.1942 .15512 L
.19423 .15515 L
.19435 .15534 L
.19447 .1556 L
.1947 .15618 L
.19482 .15649 L
.19494 .15674 L
.195 .15683 L
.19505 .15691 L
.19508 .15695 L
.19511 .15698 L
.19514 .157 L
.19517 .15701 L
.1952 .15702 L
.19522 .15703 L
.19525 .15703 L
.19527 .15703 L
.1953 .15702 L
.19533 .157 L
.19536 .15698 L
.19538 .15696 L
.19544 .1569 L
.1955 .15681 L
.19562 .15657 L
.19584 .15602 L
Mistroke
.19597 .1557 L
.1961 .1554 L
.19621 .15521 L
.19625 .15516 L
.19628 .15513 L
.19631 .1551 L
.19634 .15508 L
.19637 .15506 L
.1964 .15506 L
.19643 .15505 L
.19645 .15505 L
.19646 .15506 L
.19649 .15507 L
.19652 .15508 L
.19655 .15511 L
.19658 .15513 L
.19664 .1552 L
.19669 .15528 L
.1968 .1555 L
.19706 .15614 L
.19719 .15645 L
.19731 .1567 L
.19737 .15681 L
.19742 .15689 L
.19748 .15695 L
.19751 .15698 L
.19754 .157 L
.19756 .15701 L
.19758 .15701 L
.19759 .15702 L
.19761 .15702 L
.19764 .15702 L
.19766 .15701 L
.19768 .15701 L
.19771 .15699 L
.19774 .15697 L
.19777 .15694 L
.1978 .15691 L
.19791 .15674 L
.19801 .15654 L
.19825 .15596 L
.19837 .15565 L
.1985 .15537 L
.19856 .15526 L
.19862 .15517 L
.19868 .15512 L
.19871 .15509 L
.19874 .15508 L
.19877 .15507 L
.1988 .15506 L
Mistroke
.19883 .15506 L
.19885 .15507 L
.19888 .15508 L
.1989 .15509 L
.19893 .15511 L
.19896 .15513 L
.19901 .1552 L
.19907 .15528 L
.19919 .1555 L
.19942 .15609 L
.19956 .15642 L
.19968 .15668 L
.19973 .15678 L
.19979 .15687 L
.19983 .15691 L
.19986 .15695 L
.19989 .15697 L
.19992 .15699 L
.19995 .157 L
.19997 .15701 L
.2 .15701 L
.20003 .15701 L
.20006 .157 L
.20009 .15699 L
.20011 .15697 L
.20014 .15695 L
.2002 .15689 L
.20026 .1568 L
.20036 .1566 L
.20061 .156 L
.20073 .1557 L
.20084 .15545 L
.20094 .15527 L
.201 .15519 L
.20103 .15515 L
.20105 .15513 L
.20108 .15511 L
.20111 .15509 L
.20113 .15508 L
.20116 .15507 L
.20119 .15506 L
.20122 .15507 L
.20125 .15508 L
.20128 .15509 L
.20131 .15511 L
.20134 .15514 L
.2014 .15521 L
.20146 .1553 L
.20152 .15542 L
.20197 .15648 L
Mistroke
.20208 .15671 L
.20214 .15682 L
.20219 .15689 L
.20223 .15693 L
.20226 .15696 L
.20229 .15699 L
.20232 .157 L
.20235 .15701 L
.20238 .15701 L
.2024 .15701 L
.20241 .15701 L
.20244 .157 L
.20248 .15698 L
.2025 .15696 L
.20257 .15689 L
.20264 .1568 L
.20271 .15667 L
.20295 .15611 L
.20319 .15551 L
.20326 .15537 L
.20333 .15525 L
.20339 .15517 L
.20343 .15513 L
.20346 .15511 L
.20349 .15509 L
.20351 .15508 L
.20352 .15507 L
.20355 .15507 L
.20358 .15506 L
.2036 .15507 L
.20362 .15507 L
.20363 .15508 L
.20365 .15508 L
.20368 .1551 L
.20371 .15513 L
.20377 .15519 L
.20382 .15527 L
.20394 .1555 L
.20416 .15603 L
.20439 .15659 L
.20451 .15681 L
.20458 .1569 L
.20461 .15694 L
.20465 .15697 L
.20467 .15699 L
.2047 .157 L
.20473 .15701 L
.20476 .15701 L
.20479 .15701 L
.20482 .157 L
Mistroke
.20483 .157 L
.20485 .15699 L
.20488 .15697 L
.20491 .15694 L
.20494 .15691 L
.20501 .15682 L
.20514 .15656 L
.20539 .15595 L
.20562 .15541 L
.20568 .1553 L
.20575 .15519 L
.20578 .15515 L
.20582 .15512 L
.20584 .1551 L
.20587 .15508 L
.2059 .15507 L
.20592 .15506 L
.20594 .15506 L
.20596 .15506 L
.20599 .15507 L
.20601 .15507 L
.20603 .15508 L
.20606 .1551 L
.20609 .15513 L
.20612 .15516 L
.20624 .15533 L
.20636 .15557 L
.20659 .15616 L
.20681 .15666 L
.20692 .15685 L
.20697 .15692 L
.207 .15695 L
.20703 .15698 L
.20705 .15699 L
.20706 .157 L
.20709 .15701 L
.20711 .15702 L
.20713 .15702 L
.20716 .15702 L
.20719 .15701 L
.20721 .157 L
.20724 .15699 L
.20727 .15696 L
.20733 .1569 L
.20739 .15682 L
.2075 .15661 L
.20771 .1561 L
.20783 .1558 L
.20796 .1555 L
.20802 .15538 L
Mistroke
.20808 .15527 L
.20813 .15519 L
.20819 .15512 L
.20822 .1551 L
.20825 .15508 L
.20828 .15506 L
.2083 .15506 L
.20833 .15505 L
.20836 .15506 L
.20839 .15506 L
.20841 .15507 L
.20843 .15508 L
.20846 .15511 L
.20849 .15514 L
.20856 .15523 L
.20869 .15546 L
.20893 .15605 L
.20906 .15638 L
.20919 .15666 L
.2093 .15687 L
.20933 .15691 L
.20937 .15695 L
.2094 .15697 L
.20943 .157 L
.20946 .15701 L
.20948 .15702 L
.20951 .15703 L
.20953 .15703 L
.20956 .15702 L
.20959 .15702 L
.20962 .157 L
.20965 .15698 L
.2097 .15692 L
.20975 .15685 L
.20987 .15664 L
.21008 .15613 L
.2102 .15582 L
.21033 .1555 L
.21039 .15537 L
.21045 .15527 L
.21051 .15519 L
.21054 .15515 L
.21056 .15512 L
.21059 .15509 L
.21062 .15507 L
.21065 .15506 L
.21068 .15505 L
.2107 .15504 L
.21073 .15504 L
.21076 .15505 L
Mistroke
.21078 .15506 L
.21081 .15507 L
.21084 .1551 L
.2109 .15515 L
.21096 .15524 L
.21102 .15535 L
.21126 .1559 L
.21138 .15623 L
.21152 .15656 L
.21158 .1567 L
.21165 .15682 L
.21171 .15691 L
.21174 .15695 L
.21177 .15698 L
.21179 .157 L
.21182 .15702 L
.21185 .15703 L
.21188 .15704 L
.21189 .15704 L
.21191 .15704 L
.21194 .15704 L
.21197 .15703 L
.212 .15701 L
.21203 .15699 L
.21206 .15696 L
.21213 .15688 L
.21224 .15667 L
.2125 .15603 L
.21262 .15571 L
.21275 .15541 L
.21281 .15529 L
.21287 .1552 L
.21292 .15513 L
.21298 .15507 L
.21301 .15505 L
.21303 .15504 L
.21304 .15503 L
.21307 .15503 L
.21309 .15502 L
.21311 .15502 L
.21313 .15503 L
.21316 .15504 L
.21319 .15506 L
.21322 .15508 L
.21329 .15516 L
.21335 .15525 L
.21349 .15552 L
.21373 .15615 L
.21386 .15649 L
.21399 .15676 L
Mistroke
.21404 .15686 L
.21409 .15693 L
.21412 .15697 L
.21415 .157 L
.21418 .15702 L
.21421 .15704 L
.21422 .15705 L
.21424 .15705 L
.21427 .15706 L
.21428 .15706 L
.2143 .15706 L
.21433 .15705 L
.21436 .15704 L
.21439 .15703 L
.21442 .157 L
.21445 .15697 L
.21451 .15689 L
.21457 .15679 L
.2147 .15652 L
.21493 .1559 L
.21514 .15538 L
.2152 .15526 L
.21526 .15516 L
.21531 .1551 L
.21534 .15507 L
.21537 .15504 L
.2154 .15502 L
.21543 .15501 L
.21546 .155 L
.21548 .155 L
.21549 .155 L
.21552 .15501 L
.21555 .15502 L
.21558 .15504 L
.2156 .15506 L
.21566 .15512 L
.21571 .15519 L
.21582 .1554 L
.21608 .15606 L
.21619 .15637 L
.21632 .15667 L
.21637 .15678 L
.21643 .15689 L
.21648 .15696 L
.21654 .15703 L
.21657 .15705 L
.2166 .15707 L
.21663 .15708 L
.21665 .15708 L
.21666 .15709 L
Mistroke
.21669 .15708 L
.21672 .15708 L
.21675 .15706 L
.21677 .15704 L
.2168 .15702 L
.21683 .15699 L
.21689 .15691 L
.21702 .15667 L
.21727 .15601 L
.21751 .15538 L
.21758 .15525 L
.21765 .15513 L
.21769 .15508 L
.21772 .15505 L
.21775 .15502 L
.21778 .155 L
.21781 .15499 L
.21784 .15498 L
.21787 .15498 L
.21789 .15498 L
.2179 .15498 L
.21793 .155 L
.21796 .15501 L
.21799 .15504 L
.21801 .15506 L
.21807 .15514 L
.21813 .15525 L
.21826 .15553 L
.21849 .15615 L
.21861 .15648 L
.21873 .15675 L
.21879 .15688 L
.21885 .15697 L
.21888 .15702 L
.21892 .15705 L
.21894 .15707 L
.21895 .15708 L
.21897 .15709 L
.21899 .1571 L
.21902 .15711 L
.21904 .15711 L
.21906 .15711 L
.21908 .15711 L
.21911 .1571 L
.21914 .15709 L
.21916 .15706 L
.2192 .15703 L
.21923 .15699 L
.21929 .1569 L
.21936 .15677 L
Mistroke
.21948 .15649 L
.21974 .15575 L
.21986 .15546 L
.21998 .1552 L
.22004 .15509 L
.22011 .15501 L
.22014 .15498 L
.22015 .15497 L
.22017 .15496 L
.2202 .15495 L
.22023 .15495 L
.22026 .15495 L
.22029 .15495 L
.22032 .15497 L
.22035 .15499 L
.2204 .15504 L
.22045 .15512 L
.22058 .15537 L
.2207 .15566 L
.22091 .15627 L
.22103 .15659 L
.22114 .15684 L
.2212 .15695 L
.22125 .15703 L
.22128 .15707 L
.22131 .1571 L
.22133 .15711 L
.22135 .15712 L
.22138 .15714 L
.2214 .15715 L
.22143 .15715 L
.22146 .15715 L
.22148 .15714 L
.22151 .15712 L
.22154 .1571 L
.2216 .15704 L
.22166 .15695 L
.22172 .15683 L
.22184 .15656 L
.2221 .15581 L
.22222 .15548 L
.22234 .15519 L
.22241 .15507 L
.22245 .15502 L
.22248 .15498 L
.22252 .15495 L
.22255 .15493 L
.22258 .15491 L
.22261 .15491 L
.22264 .15491 L
Mistroke
.22267 .15492 L
.22268 .15492 L
.2227 .15493 L
.22273 .15496 L
.22276 .15498 L
.22279 .15502 L
.22284 .1551 L
.22296 .15534 L
.22309 .15569 L
.22334 .15641 L
.22345 .15672 L
.22356 .15696 L
.22363 .15706 L
.22366 .1571 L
.22369 .15713 L
.22371 .15715 L
.22372 .15716 L
.22376 .15718 L
.22377 .15719 L
.22379 .15719 L
.22381 .15719 L
.22383 .15719 L
.22386 .15718 L
.22389 .15717 L
.22391 .15715 L
.22394 .15712 L
.22401 .15704 L
.22407 .15694 L
.2243 .15634 L
.22456 .15558 L
.22468 .15526 L
.22474 .15513 L
.2248 .15503 L
.22485 .15496 L
.22487 .15493 L
.2249 .1549 L
.22493 .15488 L
.22496 .15487 L
.22499 .15486 L
.22501 .15486 L
.22504 .15487 L
.22507 .15488 L
.2251 .1549 L
.22512 .15492 L
.22517 .15498 L
.22523 .15506 L
.22535 .15532 L
.22546 .15562 L
.2257 .15637 L
.22582 .1567 L
Mistroke
.22592 .15696 L
.22598 .15706 L
.22604 .15714 L
.22606 .15717 L
.22609 .1572 L
.22612 .15722 L
.22614 .15723 L
.22617 .15724 L
.2262 .15724 L
.22623 .15724 L
.22624 .15723 L
.22626 .15722 L
.22629 .1572 L
.22632 .15717 L
.22637 .1571 L
.22644 .15699 L
.22651 .15684 L
.22663 .15651 L
.22687 .15576 L
.22698 .15544 L
.2271 .15514 L
.22716 .155 L
.22719 .15496 L
.22722 .15491 L
.22725 .15488 L
.22728 .15485 L
.2273 .15483 L
.22731 .15482 L
.22734 .15481 L
.22738 .15481 L
.22739 .15481 L
.22741 .15481 L
.22744 .15482 L
.22747 .15484 L
.2275 .15487 L
.22753 .15491 L
.2276 .15501 L
.22766 .15514 L
.22773 .15529 L
.22785 .15564 L
.22809 .15643 L
.22821 .15678 L
.22832 .15704 L
.22838 .15715 L
.22842 .1572 L
.22845 .15724 L
.22847 .15725 L
.22848 .15727 L
.22852 .15729 L
.22853 .1573 L
Mistroke
.22855 .1573 L
.22857 .1573 L
.22859 .1573 L
.22862 .15729 L
.22864 .15728 L
.22867 .15726 L
.2287 .15723 L
.22877 .15714 L
.22883 .15702 L
.22907 .15636 L
.22932 .15552 L
.22944 .15517 L
.22951 .15503 L
.22956 .15492 L
.22961 .15484 L
.22964 .15481 L
.22967 .15478 L
.22969 .15476 L
.22972 .15475 L
.22975 .15474 L
.22978 .15474 L
.22981 .15475 L
.22984 .15477 L
.22987 .15479 L
.2299 .15482 L
.22995 .1549 L
.23 .155 L
.23013 .15532 L
.23025 .15568 L
.23047 .15642 L
.23058 .15679 L
.2307 .15708 L
.23076 .1572 L
.23079 .15725 L
.23082 .15729 L
.23085 .15732 L
.23088 .15735 L
.23091 .15736 L
.23093 .15737 L
.23096 .15737 L
.23099 .15737 L
.23101 .15736 L
.23104 .15734 L
.23107 .15732 L
.2311 .15728 L
.23115 .1572 L
.23121 .15707 L
.23128 .15689 L
.23141 .1565 L
.23165 .15567 L
Mistroke
.23176 .15531 L
.23188 .15499 L
.23194 .15485 L
.23201 .15475 L
.23203 .15472 L
.23205 .1547 L
.23207 .15469 L
.2321 .15467 L
.23213 .15466 L
.23216 .15466 L
.23219 .15467 L
.23222 .15469 L
.23223 .1547 L
.23225 .15472 L
.23231 .15479 L
.23237 .1549 L
.2325 .15522 L
.23263 .15567 L
.23288 .15656 L
.23301 .15697 L
.23308 .15715 L
.23315 .15729 L
.2332 .15738 L
.23324 .15741 L
.23327 .15744 L
.23328 .15745 L
.2333 .15745 L
.23331 .15746 L
.23333 .15746 L
.23335 .15746 L
.23337 .15745 L
.2334 .15744 L
.23343 .15742 L
.23346 .15739 L
.23351 .15731 L
.23357 .1572 L
.23363 .15705 L
.23389 .15617 L
.23402 .15568 L
.23414 .15526 L
.23424 .15495 L
.2343 .15481 L
.23436 .1547 L
.23439 .15465 L
.23442 .15462 L
.23445 .15459 L
.23448 .15458 L
.23451 .15457 L
.23454 .15457 L
.23457 .15458 L
Mistroke
.23459 .15459 L
.2346 .1546 L
.23463 .15462 L
.23466 .15466 L
.23472 .15477 L
.23478 .15489 L
.23483 .15503 L
.23508 .15592 L
.2353 .15675 L
.23542 .15712 L
.23548 .15728 L
.23554 .1574 L
.23557 .15746 L
.2356 .1575 L
.23563 .15753 L
.23565 .15754 L
.23567 .15755 L
.2357 .15756 L
.23573 .15756 L
.23576 .15756 L
.23577 .15755 L
.23579 .15754 L
.23582 .15751 L
.23585 .15747 L
.23591 .15736 L
.23597 .15724 L
.23603 .15707 L
.23647 .15537 L
.23659 .15497 L
.2367 .15468 L
.23676 .15456 L
.23679 .15452 L
.23681 .1545 L
.23683 .15448 L
.23686 .15446 L
.23688 .15445 L
.23691 .15445 L
.23694 .15446 L
.23697 .15447 L
.237 .1545 L
.23702 .15453 L
.23705 .15457 L
.23712 .15469 L
.23717 .15483 L
.23738 .15556 L
.2376 .1565 L
.23773 .15698 L
.23784 .15734 L
.2379 .15748 L
.23796 .1576 L
Mistroke
.238 .15764 L
.23802 .15766 L
.23804 .15767 L
.23805 .15768 L
.23807 .15769 L
.2381 .15769 L
.23813 .15769 L
.23815 .15768 L
.23817 .15767 L
.23819 .15764 L
.23823 .1576 L
.23828 .1575 L
.23834 .15736 L
.2386 .15641 L
.23885 .15533 L
.23895 .15492 L
.23907 .15458 L
.2391 .1545 L
.23913 .15444 L
.23917 .15439 L
.23919 .15436 L
.23922 .15433 L
.23925 .15431 L
.23928 .15431 L
.23931 .15431 L
.23934 .15432 L
.23936 .15434 L
.23937 .15435 L
.2394 .15439 L
.23943 .15444 L
.23949 .15454 L
.23954 .15469 L
.23967 .15514 L
.23979 .15566 L
.24001 .15665 L
.24012 .15712 L
.24024 .15752 L
.24028 .15761 L
.24031 .15769 L
.24034 .15774 L
.24037 .15779 L
.2404 .15782 L
.24043 .15784 L
.24046 .15785 L
.24048 .15785 L
.24049 .15785 L
.24052 .15784 L
.24055 .15782 L
.24058 .15779 L
.24061 .15775 L
Mistroke
.24067 .15762 L
.24073 .15746 L
.24083 .1571 L
.24095 .15661 L
.24117 .1555 L
.24129 .15497 L
.24136 .15472 L
.24142 .15452 L
.24147 .15437 L
.24152 .15426 L
.24155 .15421 L
.24158 .15418 L
.24161 .15415 L
.24164 .15413 L
.24167 .15413 L
.2417 .15413 L
.24172 .15414 L
.24173 .15415 L
.24175 .15417 L
.24177 .15419 L
.2418 .15424 L
.24183 .1543 L
.2419 .15448 L
.24202 .15489 L
.24214 .15546 L
.24239 .15672 L
.24252 .15731 L
.24259 .15758 L
.24266 .15778 L
.24271 .15792 L
.24275 .15797 L
.24278 .15801 L
.24279 .15803 L
.24281 .15804 L
.24283 .15805 L
.24284 .15806 L
.24287 .15806 L
.24289 .15805 L
.24291 .15804 L
.24294 .15801 L
.24297 .15797 L
.24299 .15793 L
.24302 .15787 L
.24308 .15771 L
.24314 .15751 L
.24359 .15525 L
.24372 .15466 L
.24378 .15439 L
.24385 .15419 L
.2439 .15406 L
Mistroke
.24393 .154 L
.24396 .15396 L
.24399 .15392 L
.244 .15391 L
.24402 .1539 L
.24405 .15389 L
.24408 .1539 L
.24411 .15393 L
.24414 .15396 L
.24417 .15401 L
.24421 .15408 L
.24426 .15423 L
.24432 .15445 L
.24446 .15508 L
.24459 .1558 L
.24483 .15712 L
.24489 .15743 L
.24496 .15773 L
.24502 .15796 L
.24508 .15812 L
.24511 .15819 L
.24514 .15824 L
.24515 .15826 L
.24517 .15829 L
.2452 .15831 L
.24522 .15832 L
.24523 .15832 L
.24525 .15832 L
.24527 .15832 L
.2453 .1583 L
.24531 .15828 L
.24533 .15826 L
.24539 .15815 L
.24542 .15807 L
.24545 .15798 L
.24557 .1575 L
.24578 .15629 L
.24602 .15489 L
.24613 .15429 L
.2462 .15402 L
.24626 .15383 L
.24629 .15375 L
.24633 .15368 L
.24634 .15365 L
.24636 .15362 L
.24638 .15361 L
.2464 .1536 L
.24641 .15359 L
.24643 .15359 L
.24645 .15359 L
Mistroke
.24646 .1536 L
.24649 .15363 L
.24651 .15365 L
.24653 .15367 L
.24658 .15379 L
.24664 .15396 L
.24676 .15448 L
.24688 .15517 L
.24701 .156 L
.24725 .15756 L
.24732 .15791 L
.24739 .15822 L
.24743 .15834 L
.24746 .15845 L
.24749 .15852 L
.24752 .15859 L
.24755 .15864 L
.24758 .15866 L
.24761 .15868 L
.24762 .15868 L
.24764 .15868 L
.24767 .15866 L
.2477 .15862 L
.24772 .15858 L
.24775 .15852 L
.24781 .15835 L
.24787 .1581 L
.248 .15742 L
.24826 .15563 L
.24839 .15474 L
.24851 .15403 L
.24856 .15375 L
.24861 .15354 L
.24864 .15344 L
.24867 .15335 L
.2487 .15328 L
.24873 .15323 L
.24876 .1532 L
.24877 .15318 L
.24879 .15317 L
.24881 .15317 L
.24882 .15317 L
.24885 .15319 L
.24888 .15322 L
.24891 .15327 L
.24894 .15333 L
.24897 .15342 L
.24903 .15363 L
.24908 .15387 L
.2492 .15457 L
Mistroke
.24941 .15618 L
.24953 .15713 L
.24966 .15805 L
.24973 .15842 L
.24979 .15871 L
.24984 .15892 L
.24987 .15901 L
.2499 .15908 L
.24993 .15912 L
.24995 .15916 L
.24999 .15918 L
.25001 .15918 L
.25004 .15916 L
.25006 .15914 L
.25008 .15912 L
.25011 .15906 L
.25014 .15898 L
.2502 .15877 L
.25025 .15851 L
.25035 .15788 L
.2506 .15592 L
.25073 .15478 L
.25085 .15384 L
.25096 .15316 L
.25103 .15288 L
.25105 .15278 L
.25108 .1527 L
.2511 .15266 L
.25111 .15263 L
.25114 .15258 L
.25116 .15257 L
.25118 .15256 L
.2512 .15256 L
.25121 .15256 L
.25124 .15259 L
.25127 .15264 L
.25129 .15267 L
.2513 .15271 L
.25133 .15281 L
.25139 .15305 L
.25145 .15338 L
.25157 .15418 L
.25178 .1561 L
.2519 .15725 L
.25203 .15838 L
.25209 .15885 L
.25215 .15923 L
.2522 .15951 L
.25226 .15974 L
.25229 .15982 L
Mistroke
.25232 .15989 L
.25235 .15993 L
.25237 .15994 L
.2524 .15994 L
.25243 .15991 L
.25246 .15985 L
.25248 .15981 L
.2525 .15976 L
.25256 .15949 L
.2526 .15929 L
.25263 .15908 L
.25276 .15807 L
.253 .15555 L
.25314 .15413 L
.25326 .15297 L
.25337 .15222 L
.2534 .15205 L
.25343 .15191 L
.25345 .1518 L
.25348 .15172 L
.25351 .15165 L
.25354 .15161 L
.25357 .15159 L
.2536 .1516 L
.25363 .15164 L
.25366 .1517 L
.25367 .15175 L
.25369 .1518 L
.25372 .15194 L
.25378 .15229 L
.25384 .15271 L
.25395 .15373 L
.2542 .15668 L
.25441 .1592 L
.25447 .15977 L
.25453 .1603 L
.25459 .1607 L
.25462 .16085 L
.25465 .16096 L
.25467 .16106 L
.2547 .16114 L
.25473 .16119 L
.25476 .16121 L
.25479 .1612 L
.2548 .16118 L
.25482 .16115 L
.25485 .16108 L
.25488 .16097 L
.25491 .16083 L
.25494 .16065 L
Mistroke
.25499 .16024 L
.25512 .15894 L
.25557 .15271 L
.25568 .15132 L
.25575 .15071 L
.25581 .15029 L
.25584 .15011 L
.25586 .15004 L
.25588 .14997 L
.2559 .14993 L
.25592 .14989 L
.25593 .14987 L
.25595 .14986 L
.25596 .14986 L
.25598 .14988 L
.25601 .14993 L
.25604 .15003 L
.25606 .15011 L
.25607 .15019 L
.25613 .15056 L
.25619 .15104 L
.25631 .15253 L
.25656 .15669 L
.25679 .1608 L
.25691 .16238 L
.25695 .16272 L
.25698 .16303 L
.25701 .16328 L
.25704 .16346 L
.25707 .16358 L
.2571 .16367 L
.25713 .16371 L
.25715 .16372 L
.25716 .16371 L
.25719 .16365 L
.25722 .16356 L
.25725 .16341 L
.25728 .16323 L
.25733 .16277 L
.25738 .16222 L
.25749 .16055 L
.25772 .15564 L
.25785 .15276 L
.25797 .14994 L
.25809 .1479 L
.25815 .14701 L
.25818 .14667 L
.25821 .14641 L
.25824 .14621 L
.25827 .14605 L
Mistroke
.25829 .14595 L
.25832 .14591 L
.25834 .1459 L
.25837 .14596 L
.2584 .14608 L
.25843 .14625 L
.25846 .14649 L
.25849 .14676 L
.25855 .14758 L
.2586 .14852 L
.25866 .14973 L
.25887 .15554 L
.25911 .16347 L
.25922 .16655 L
.25928 .16793 L
.25934 .16917 L
.25937 .16971 L
.2594 .17012 L
.25943 .17045 L
.25946 .17068 L
.25949 .17085 L
.25952 .17091 L
.25953 .17091 L
.25955 .17087 L
.25957 .17081 L
.25958 .17071 L
.2596 .17059 L
.25962 .17043 L
.25965 .17 L
.25968 .16949 L
.25971 .1689 L
.25978 .16722 L
.25985 .16489 L
.25998 .15938 L
.26011 .15307 L
.26034 .14041 L
.26046 .13464 L
.26052 .13236 L
.26057 .13069 L
.2606 .13001 L
.26063 .12942 L
.26066 .12897 L
.26069 .12872 L
.26071 .12866 L
.26072 .12866 L
.26074 .12872 L
.26076 .12885 L
.26079 .12923 L
.2608 .12954 L
.26082 .12989 L
Mistroke
.26084 .1306 L
.26087 .13155 L
.26092 .13377 L
.26098 .13729 L
.26103 .14137 L
.26115 .15317 L
.26126 .16802 L
.26149 .21023 L
.26174 .26749 L
.26218 .37876 L
.26241 .42679 L
.26254 .44809 L
.26265 .4643 L
.26276 .47564 L
.26283 .48049 L
.26288 .48401 L
.26294 .48644 L
.26296 .48732 L
.26298 .48799 L
.26301 .48859 L
.26304 .48905 L
.26307 .48929 L
.26309 .48938 L
.26312 .4893 L
.26314 .48918 L
.26315 .48902 L
.26318 .4886 L
.26321 .488 L
.26326 .48662 L
.26332 .48463 L
.26356 .47263 L
.26378 .46096 L
.2639 .45552 L
.26401 .45152 L
.26406 .44994 L
.26412 .44863 L
.26416 .44807 L
.26419 .44765 L
.26422 .44738 L
.26425 .4472 L
.26427 .44713 L
.2643 .44714 L
.26433 .44725 L
.26436 .44744 L
.26439 .44769 L
.26441 .44798 L
.26447 .44883 L
.26453 .45012 L
.26459 .45157 L
.26473 .4555 L
Mistroke
.26497 .46342 L
.26509 .46692 L
.26516 .46847 L
.26523 .46984 L
.26528 .4708 L
.26532 .4712 L
.26535 .47156 L
.26538 .47181 L
.26541 .47197 L
.26544 .47208 L
.26546 .47213 L
.26549 .47213 L
.26552 .47207 L
.26555 .47195 L
.26558 .47178 L
.26563 .47136 L
.26568 .47074 L
.2658 .46877 L
.26591 .46646 L
.26613 .46135 L
.26625 .45875 L
.26637 .45671 L
.26643 .4558 L
.26647 .45541 L
.2665 .45505 L
.26653 .4548 L
.26657 .45459 L
.2666 .45445 L
.26663 .45436 L
.26666 .45432 L
.26669 .45433 L
.26671 .45437 L
.26674 .45446 L
.26677 .45461 L
.26681 .45482 L
.26687 .45533 L
.26692 .45596 L
.26698 .45675 L
.26709 .45844 L
.26733 .46279 L
.26743 .4645 L
.26754 .46606 L
.2676 .4668 L
.26766 .46734 L
.26769 .46755 L
.26772 .46775 L
.26774 .4679 L
.26777 .46801 L
.2678 .4681 L
.26783 .46815 L
Mistroke
.26786 .46817 L
.26789 .46815 L
.26792 .4681 L
.26795 .46801 L
.26797 .46789 L
.268 .46775 L
.26806 .46732 L
.26813 .46671 L
.26825 .46527 L
.26849 .46177 L
.26862 .45997 L
.26869 .45909 L
.26875 .45836 L
.26882 .45779 L
.26885 .45754 L
.26888 .45732 L
.26891 .45716 L
.26894 .45702 L
.26897 .45693 L
.269 .45687 L
.26903 .45683 L
.26906 .45683 L
.26908 .45685 L
.26911 .4569 L
.26914 .45699 L
.26917 .45711 L
.26923 .45742 L
.2693 .4579 L
.26937 .45854 L
.2695 .45995 L
.26974 .46296 L
.26985 .46421 L
.26997 .46532 L
.27003 .4658 L
.2701 .46613 L
.27013 .46624 L
.27014 .46629 L
.27016 .46634 L
.27019 .4664 L
.27022 .46643 L
.27023 .46644 L
.27025 .46644 L
.27028 .46641 L
.2703 .46638 L
.27032 .46635 L
.27035 .46624 L
.27039 .46611 L
.27042 .46597 L
.27048 .46557 L
.27061 .46456 L
Mistroke
.27072 .46338 L
.27095 .46086 L
.27108 .45966 L
.27114 .45916 L
.2712 .45879 L
.27125 .45852 L
.2713 .45831 L
.27133 .45822 L
.27136 .45816 L
.27138 .45812 L
.27141 .4581 L
.27144 .45809 L
.27146 .4581 L
.27147 .45812 L
.2715 .45817 L
.27153 .45824 L
.27156 .45833 L
.27159 .45842 L
.27164 .4587 L
.27176 .4595 L
.2719 .46062 L
.27213 .4629 L
.27225 .46388 L
.27231 .46434 L
.27236 .46471 L
.27242 .46499 L
.27247 .46519 L
.27249 .46528 L
.27252 .46536 L
.27255 .46542 L
.27258 .46546 L
.27261 .46548 L
.27264 .46547 L
.27265 .46546 L
.27267 .46544 L
.27269 .46542 L
.27271 .46539 L
.27274 .46532 L
.27276 .46523 L
.27283 .46498 L
.27288 .46469 L
.27294 .46432 L
.27305 .46351 L
.27331 .46125 L
.27344 .46028 L
.27355 .45956 L
.27361 .45928 L
.27367 .45906 L
.2737 .45898 L
.27373 .45892 L
Mistroke
.27375 .45889 L
.27376 .45888 L
.27378 .45886 L
.2738 .45885 L
.27382 .45885 L
.27385 .45887 L
.27388 .4589 L
.27391 .45895 L
.27394 .45902 L
.27397 .45912 L
.27403 .45934 L
.27415 .46004 L
.27429 .461 L
.27453 .46288 L
.27465 .46369 L
.27476 .4643 L
.27482 .46455 L
.27485 .46465 L
.27489 .46474 L
.27492 .4648 L
.27493 .46482 L
.27495 .46484 L
.27498 .46486 L
.275 .46487 L
.27503 .46485 L
.27506 .46483 L
.27509 .46478 L
.27512 .46472 L
.27518 .46456 L
.27524 .46434 L
.27534 .46378 L
.27545 .46313 L
.27568 .46145 L
.27581 .4606 L
.27587 .46024 L
.27593 .45996 L
.27598 .45976 L
.27603 .45958 L
.27606 .45951 L
.27609 .45945 L
.27611 .45941 L
.27614 .45938 L
.27617 .45936 L
.2762 .45935 L
.27623 .45937 L
.27625 .45939 L
.27628 .45943 L
.27631 .45949 L
.27637 .45966 L
.27644 .45988 L
Mistroke
.2765 .46019 L
.27662 .46086 L
.27685 .46234 L
.27697 .46314 L
.27704 .46353 L
.27711 .46383 L
.27717 .46407 L
.27722 .46424 L
.27726 .46431 L
.27729 .46437 L
.27732 .46441 L
.27733 .46443 L
.27735 .46444 L
.27738 .46445 L
.27741 .46444 L
.27743 .46442 L
.27746 .46439 L
.27749 .46434 L
.27752 .46427 L
.27758 .46411 L
.27764 .4639 L
.2777 .46366 L
.2778 .46312 L
.27804 .46165 L
.27817 .46089 L
.27829 .4603 L
.27835 .46009 L
.2784 .45993 L
.27843 .45986 L
.27847 .4598 L
.2785 .45976 L
.27852 .45973 L
.27854 .45972 L
.27856 .45971 L
.27859 .45971 L
.27862 .45973 L
.27865 .45975 L
.27868 .4598 L
.27871 .45986 L
.27877 .46003 L
.27883 .46023 L
.27889 .46044 L
.279 .46103 L
.27922 .46225 L
.27933 .46289 L
.27946 .46347 L
.27951 .46367 L
.27956 .46385 L
.27959 .46393 L
.27962 .46399 L
Mistroke
.27965 .46405 L
.27968 .46409 L
.27971 .46412 L
.27974 .46413 L
.27977 .46414 L
.27979 .46413 L
.27983 .46411 L
.27985 .46407 L
.27989 .46402 L
.27992 .46395 L
.27998 .46378 L
.28004 .46358 L
.28018 .46299 L
.28043 .46165 L
.28055 .46102 L
.28067 .46053 L
.28072 .46035 L
.28077 .46021 L
.28082 .4601 L
.28085 .46005 L
.28088 .46001 L
.28091 .45999 L
.28094 .45998 L
.28095 .45998 L
.28097 .45998 L
.281 .45999 L
.28103 .46002 L
.28106 .46005 L
.28108 .46009 L
.28111 .46015 L
.28117 .46029 L
.28123 .46048 L
.28134 .46092 L
.28159 .46217 L
.28172 .46284 L
.28185 .46337 L
.28191 .46355 L
.28197 .4637 L
.282 .46378 L
.28203 .46383 L
.28206 .46387 L
.28209 .46389 L
.28212 .4639 L
.28215 .46391 L
.28218 .4639 L
.2822 .46388 L
.28224 .46385 L
.28227 .4638 L
.28233 .46369 L
.28239 .46352 L
Mistroke
.28246 .46329 L
.28258 .4628 L
.28281 .46169 L
.28302 .46077 L
.28313 .46044 L
.28318 .46032 L
.28322 .46027 L
.28324 .46023 L
.28328 .4602 L
.28331 .46018 L
.28333 .46018 L
.28336 .46018 L
.28339 .4602 L
.28341 .46022 L
.28343 .46024 L
.28346 .46028 L
.28349 .46033 L
.28354 .46045 L
.2836 .4606 L
.2837 .46096 L
.28393 .46196 L
.28416 .46297 L
.28422 .46321 L
.28429 .4634 L
.28434 .46353 L
.28437 .46359 L
.2844 .46364 L
.28443 .46367 L
.28446 .4637 L
.28449 .46372 L
.28452 .46373 L
.28455 .46372 L
.28458 .46371 L
.28461 .46369 L
.28463 .46365 L
.28468 .46358 L
.28474 .46346 L
.28485 .46314 L
.28511 .46208 L
.28523 .46152 L
.28535 .46105 L
.28546 .46071 L
.28552 .46056 L
.28557 .46045 L
.2856 .46041 L
.28563 .46038 L
.28566 .46035 L
.28568 .46035 L
.2857 .46034 L
.28573 .46034 L
Mistroke
.28576 .46035 L
.28579 .46037 L
.28581 .4604 L
.28584 .46043 L
.28587 .46048 L
.28593 .46061 L
.28604 .46092 L
.28629 .4619 L
.28651 .4628 L
.28662 .46316 L
.28669 .46333 L
.28675 .46344 L
.28678 .46349 L
.28681 .46353 L
.28684 .46356 L
.28685 .46357 L
.28687 .46358 L
.2869 .46358 L
.28693 .46358 L
.28696 .46357 L
.28699 .46355 L
.28702 .46352 L
.28704 .46348 L
.28709 .46339 L
.28715 .46327 L
.28721 .4631 L
.28747 .46213 L
.28771 .4612 L
.28783 .46084 L
.28789 .46068 L
.28793 .46062 L
.28795 .46057 L
.28798 .46054 L
.28801 .46051 L
.28804 .46049 L
.28807 .46047 L
.2881 .46047 L
.28813 .46047 L
.28816 .46049 L
.28818 .46051 L
.28821 .46054 L
.28824 .46058 L
.2883 .46069 L
.28837 .46084 L
.28843 .46102 L
.28869 .46197 L
.28891 .46279 L
.28897 .46299 L
.28903 .46315 L
.28909 .46327 L
Mistroke
.28914 .46336 L
.28917 .4634 L
.28919 .46342 L
.28921 .46344 L
.28924 .46346 L
.28927 .46347 L
.28928 .46347 L
.2893 .46347 L
.28932 .46346 L
.28934 .46345 L
.28937 .46343 L
.28938 .46342 L
.2894 .4634 L
.28946 .46331 L
.28952 .46319 L
.28964 .46287 L
.28987 .46206 L
.29011 .46119 L
.29018 .46098 L
.29025 .46082 L
.29031 .4607 L
.29035 .46065 L
.29038 .46062 L
.29041 .4606 L
.29044 .46058 L
.29047 .46057 L
.29048 .46057 L
.2905 .46058 L
.29053 .46059 L
.29055 .4606 L
.29057 .46061 L
.2906 .46064 L
.29063 .46069 L
.29069 .4608 L
.29075 .46093 L
.29089 .46132 L
.29113 .46219 L
.29124 .46258 L
.29135 .4629 L
.2914 .46305 L
.29147 .46319 L
.2915 .46323 L
.29153 .46328 L
.29155 .46331 L
.29158 .46334 L
.29161 .46336 L
.29164 .46337 L
.29166 .46337 L
.29169 .46337 L
.29172 .46336 L
Mistroke
.29175 .46334 L
.29178 .46331 L
.29181 .46327 L
.29187 .46318 L
.29193 .46306 L
.29203 .46279 L
.29227 .46197 L
.2924 .46151 L
.29253 .46114 L
.29264 .46088 L
.29267 .46082 L
.2927 .46077 L
.29273 .46073 L
.29276 .46071 L
.29279 .46068 L
.2928 .46067 L
.29282 .46067 L
.29285 .46066 L
.29288 .46066 L
.29289 .46067 L
.29291 .46067 L
.29293 .46068 L
.29295 .4607 L
.29298 .46073 L
.29301 .46077 L
.29307 .46086 L
.29313 .46099 L
.29324 .46128 L
.29345 .46198 L
.29357 .46239 L
.2937 .46278 L
.29376 .46293 L
.29382 .46306 L
.29387 .46315 L
.29393 .46323 L
.29396 .46326 L
.29399 .46328 L
.294 .46329 L
.29402 .46329 L
.29405 .46329 L
.29408 .46329 L
.29411 .46327 L
.29414 .46326 L
.29417 .46323 L
.2942 .46319 L
.29423 .46314 L
.29431 .46301 L
.29443 .46268 L
.29467 .4619 L
.29481 .46147 L
Mistroke
.29493 .46113 L
.29504 .46091 L
.29506 .46086 L
.29509 .46082 L
.29512 .46079 L
.29515 .46077 L
.29518 .46075 L
.29521 .46074 L
.29524 .46073 L
.29526 .46073 L
.2953 .46075 L
.29532 .46076 L
.29536 .46079 L
.29539 .46083 L
.29545 .46092 L
.2955 .46102 L
.29562 .46131 L
.29583 .46197 L
.29595 .46236 L
.29608 .46274 L
.29614 .46289 L
.2962 .46301 L
.29625 .4631 L
.29628 .46314 L
.29631 .46317 L
.29634 .46319 L
.29637 .46321 L
.2964 .46322 L
.29643 .46323 L
.29646 .46322 L
.29647 .46322 L
.29649 .46321 L
.29652 .46319 L
.29655 .46317 L
.2966 .4631 L
.29665 .46302 L
.29677 .46277 L
.29701 .46205 L
.29714 .46163 L
.29726 .46128 L
.29738 .46103 L
.29744 .46092 L
.2975 .46085 L
.29753 .46083 L
.29756 .46081 L
.29758 .4608 L
.29759 .4608 L
.29761 .46079 L
.29763 .46079 L
.29766 .4608 L
Mistroke
.29769 .46081 L
.2977 .46082 L
.29772 .46083 L
.29775 .46086 L
.29781 .46094 L
.29786 .46103 L
.29798 .4613 L
.2982 .46193 L
.29842 .4626 L
.29853 .46288 L
.2986 .463 L
.29866 .46308 L
.29869 .46312 L
.29871 .46313 L
.29872 .46314 L
.29875 .46316 L
.29878 .46317 L
.29882 .46317 L
.29883 .46317 L
.29885 .46317 L
.29887 .46316 L
.29888 .46315 L
.29892 .46312 L
.29895 .46309 L
.29898 .46306 L
.29904 .46296 L
.29916 .46271 L
.29938 .46208 L
.29961 .4614 L
.29973 .46112 L
.2998 .461 L
.29983 .46095 L
.29987 .46091 L
.29989 .46089 L
.29992 .46087 L
.29995 .46085 L
.29998 .46084 L
.30001 .46084 L
.30004 .46085 L
.30005 .46085 L
.30007 .46086 L
.3001 .46088 L
.30013 .46091 L
.30016 .46095 L
.30023 .46105 L
.3003 .46118 L
.30037 .46134 L
.30061 .46204 L
.30074 .4624 L
.30087 .46274 L
Mistroke
.30098 .46295 L
.30101 .463 L
.30104 .46304 L
.30107 .46307 L
.3011 .46309 L
.30113 .46311 L
.30115 .46312 L
.30116 .46312 L
.30118 .46313 L
.3012 .46313 L
.30123 .46312 L
.30126 .46311 L
.30128 .46309 L
.30131 .46307 L
.30134 .46304 L
.30141 .46294 L
.30147 .46283 L
.30161 .4625 L
.30184 .46183 L
.30197 .46147 L
.3021 .46119 L
.30216 .46107 L
.30222 .46099 L
.30225 .46095 L
.30228 .46092 L
.3023 .46091 L
.30231 .4609 L
.30233 .46089 L
.30235 .46089 L
.30238 .46088 L
.30241 .46089 L
.30242 .46089 L
.30244 .4609 L
.30247 .46092 L
.3025 .46094 L
.30253 .46097 L
.30259 .46104 L
.30269 .46124 L
.3028 .46149 L
.30303 .46215 L
.30315 .46248 L
.30321 .46264 L
.30328 .46278 L
.30334 .46289 L
.30341 .46298 L
.30343 .46302 L
.30346 .46304 L
.30349 .46307 L
.30352 .46308 L
.30355 .46309 L
Mistroke
.30357 .46309 L
.3036 .46309 L
.30362 .46308 L
.30365 .46306 L
.30368 .46304 L
.30371 .46302 L
.30374 .46299 L
.30385 .46281 L
.30396 .46255 L
.30421 .46188 L
.30433 .46155 L
.30444 .46129 L
.30454 .4611 L
.3046 .46102 L
.30465 .46097 L
.30468 .46095 L
.3047 .46093 L
.30473 .46092 L
.30476 .46092 L
.30479 .46092 L
.30482 .46093 L
.30484 .46095 L
.30487 .46097 L
.30491 .461 L
.30493 .46103 L
.305 .46112 L
.30512 .46136 L
.30534 .46194 L
.30547 .46229 L
.3056 .46263 L
.30566 .46276 L
.30573 .46287 L
.30578 .46295 L
.30581 .46299 L
.30584 .46301 L
.30587 .46303 L
.3059 .46305 L
.30593 .46305 L
.30595 .46306 L
.30598 .46305 L
.30601 .46304 L
.30603 .46304 L
.30605 .46303 L
.30608 .463 L
.30613 .46294 L
.30619 .46286 L
.30629 .46266 L
.30653 .46205 L
.30666 .46169 L
.30679 .46138 L
Mistroke
.30691 .46115 L
.30694 .4611 L
.30697 .46105 L
.307 .46102 L
.30704 .46099 L
.30707 .46097 L
.30709 .46096 L
.30712 .46095 L
.30714 .46095 L
.30717 .46095 L
.3072 .46096 L
.30723 .46098 L
.30726 .461 L
.30732 .46106 L
.30737 .46113 L
.30747 .46132 L
.30771 .4619 L
.30795 .46254 L
.30801 .46268 L
.30809 .46282 L
.30815 .46291 L
.30821 .46298 L
.30824 .463 L
.30826 .46301 L
.30827 .46302 L
.3083 .46303 L
.30833 .46303 L
.30835 .46303 L
.30836 .46303 L
.30839 .46302 L
.30841 .46301 L
.30843 .463 L
.30846 .46297 L
.30852 .46291 L
.30857 .46283 L
.3087 .46259 L
.30894 .46197 L
.30907 .46161 L
.3092 .46133 L
.30931 .46114 L
.30937 .46106 L
.30939 .46103 L
.30942 .46101 L
.30945 .46099 L
.30948 .46098 L
.30951 .46097 L
.30953 .46097 L
.30954 .46097 L
.30957 .46098 L
.3096 .46099 L
Mistroke
.30963 .46101 L
.30966 .46104 L
.30972 .46111 L
.30977 .46118 L
.30989 .46142 L
.31011 .46196 L
.31023 .46228 L
.31036 .46259 L
.31047 .4628 L
.31053 .46289 L
.31059 .46296 L
.31062 .46298 L
.31065 .463 L
.31068 .46301 L
.31071 .46301 L
.31073 .46301 L
.31076 .463 L
.31079 .46299 L
.31081 .46298 L
.31084 .46295 L
.31087 .46292 L
.31093 .46285 L
.31105 .46263 L
.31129 .46204 L
.31143 .46169 L
.31155 .46139 L
.31167 .46117 L
.31171 .46113 L
.31174 .46108 L
.31177 .46105 L
.3118 .46103 L
.31183 .46101 L
.31186 .461 L
.31188 .46099 L
.31191 .46099 L
.31194 .46099 L
.31197 .461 L
.312 .46102 L
.31203 .46104 L
.31208 .4611 L
.31214 .46117 L
.31224 .46135 L
.31247 .46191 L
.31259 .46223 L
.31272 .46254 L
.31278 .46267 L
.31284 .46278 L
.31289 .46286 L
.31295 .46292 L
.31298 .46295 L
Mistroke
.31301 .46297 L
.31304 .46298 L
.31307 .46299 L
.3131 .46299 L
.31313 .46299 L
.31314 .46299 L
.31316 .46298 L
.31318 .46297 L
.31319 .46296 L
.31323 .46293 L
.31326 .4629 L
.31332 .46282 L
.31346 .46257 L
.31367 .46205 L
.3139 .46148 L
.31397 .46134 L
.31403 .46122 L
.31409 .46113 L
.31412 .4611 L
.31415 .46107 L
.31418 .46105 L
.3142 .46103 L
.31423 .46101 L
.31426 .46101 L
.31429 .461 L
.31431 .46101 L
.31432 .46101 L
.31435 .46102 L
.31438 .46104 L
.31441 .46106 L
.31445 .46109 L
.3145 .46116 L
.31461 .46135 L
.31486 .46194 L
.3151 .46254 L
.31517 .46268 L
.31524 .4628 L
.31527 .46285 L
.31531 .46288 L
.31534 .46292 L
.31537 .46294 L
.3154 .46296 L
.31543 .46297 L
.31546 .46298 L
.31549 .46298 L
.31551 .46298 L
.31554 .46297 L
.31557 .46295 L
.3156 .46293 L
.31566 .46287 L
Mistroke
.31573 .46278 L
.31585 .46255 L
.31611 .4619 L
.31622 .46161 L
.31635 .46134 L
.31641 .46123 L
.31647 .46114 L
.3165 .4611 L
.31654 .46107 L
.31657 .46105 L
.3166 .46103 L
.31661 .46102 L
.31663 .46102 L
.31665 .46102 L
.31666 .46101 L
.31669 .46102 L
.31671 .46102 L
.31672 .46103 L
.31674 .46103 L
.31676 .46104 L
.31679 .46107 L
.31683 .4611 L
.31686 .46114 L
.31699 .46135 L
.31712 .46163 L
.31735 .46221 L
.31747 .4625 L
.31758 .46272 L
.31764 .46282 L
.31769 .46289 L
.31772 .46291 L
.31776 .46294 L
.31777 .46295 L
.31779 .46296 L
.31781 .46297 L
.31782 .46297 L
.31785 .46297 L
.31788 .46297 L
.31791 .46296 L
.31793 .46296 L
.31794 .46295 L
.31797 .46293 L
.318 .4629 L
.31806 .46284 L
.31817 .46267 L
.31827 .46246 L
.31849 .46191 L
.31861 .4616 L
.31872 .46136 L
.31879 .46124 L
Mistroke
.31886 .46114 L
.31889 .4611 L
.31892 .46107 L
.31895 .46105 L
.31898 .46103 L
.31901 .46102 L
.31904 .46102 L
.31906 .46102 L
.31907 .46102 L
.31911 .46103 L
.31913 .46105 L
.31917 .46107 L
.31922 .46112 L
.31928 .4612 L
.31934 .46129 L
.31945 .46151 L
.31969 .46211 L
.31981 .46241 L
.31992 .46265 L
.32002 .46281 L
.32008 .46288 L
.32013 .46293 L
.32016 .46295 L
.32018 .46296 L
.32021 .46297 L
.32024 .46297 L
.32027 .46297 L
.3203 .46296 L
.32033 .46294 L
.32036 .46292 L
.32042 .46286 L
.32049 .46277 L
.3206 .46255 L
.32083 .462 L
.32104 .46148 L
.32117 .46125 L
.32123 .46116 L
.32129 .46108 L
.32133 .46106 L
.32136 .46104 L
.32138 .46103 L
.3214 .46103 L
.32141 .46102 L
.32143 .46102 L
.32146 .46103 L
.32148 .46103 L
.32149 .46104 L
.32153 .46105 L
.32156 .46108 L
.32162 .46115 L
Mistroke
.32169 .46124 L
.32181 .46148 L
.32205 .46205 L
.32216 .46234 L
.32229 .46262 L
.32235 .46273 L
.32241 .46282 L
.32246 .46289 L
.32249 .46291 L
.32252 .46294 L
.32253 .46295 L
.32255 .46295 L
.32258 .46297 L
.3226 .46297 L
.32262 .46297 L
.32264 .46297 L
.32265 .46297 L
.32269 .46295 L
.3227 .46295 L
.32272 .46294 L
.32278 .46288 L
.32284 .46281 L
.3229 .46272 L
.32302 .46247 L
.32326 .46187 L
.32338 .46158 L
.32349 .46134 L
.32355 .46124 L
.32362 .46114 L
.32365 .4611 L
.32369 .46107 L
.3237 .46106 L
.32372 .46105 L
.32374 .46104 L
.32376 .46103 L
.32379 .46102 L
.32381 .46102 L
.32383 .46102 L
.32385 .46103 L
.32388 .46104 L
.32391 .46105 L
.32394 .46107 L
.324 .46114 L
.32406 .46122 L
.32411 .46131 L
.32423 .46156 L
.32445 .46211 L
.32457 .46241 L
.3247 .46269 L
.32476 .46279 L
Mistroke
.32483 .46288 L
.32488 .46293 L
.32492 .46295 L
.32495 .46296 L
.32497 .46297 L
.325 .46297 L
.32503 .46297 L
.32506 .46296 L
.32509 .46295 L
.32511 .46294 L
.32512 .46292 L
.32518 .46286 L
.32524 .46278 L
.3253 .46268 L
.32543 .46241 L
.32566 .46183 L
.32577 .46155 L
.32588 .46133 L
.32593 .46123 L
.32599 .46114 L
.32605 .46108 L
.32609 .46105 L
.3261 .46104 L
.32612 .46103 L
.32615 .46102 L
.32618 .46101 L
.3262 .46101 L
.32623 .46102 L
.32626 .46103 L
.32628 .46104 L
.32631 .46107 L
.32634 .46109 L
.3264 .46117 L
.32647 .46127 L
.32658 .4615 L
.32685 .46215 L
.32696 .46244 L
.32707 .46267 L
.32713 .46278 L
.3272 .46287 L
.32723 .4629 L
.32726 .46293 L
.32729 .46295 L
.32732 .46297 L
.32734 .46298 L
.32737 .46298 L
.3274 .46298 L
.32742 .46298 L
.32745 .46296 L
.32749 .46294 L
Mistroke
.32751 .46292 L
.32754 .46289 L
.32765 .46274 L
.32776 .46254 L
.32797 .46202 L
.32819 .46146 L
.32826 .46133 L
.32832 .46121 L
.32839 .46112 L
.32842 .46109 L
.32844 .46106 L
.32847 .46104 L
.3285 .46102 L
.32853 .46101 L
.32855 .46101 L
.32859 .46101 L
.3286 .46101 L
.32862 .46101 L
.32865 .46102 L
.32868 .46104 L
.32871 .46107 L
.32874 .4611 L
.3288 .46117 L
.32891 .46137 L
.32915 .46196 L
.32929 .46231 L
.32942 .46261 L
.32953 .46282 L
.32956 .46286 L
.3296 .4629 L
.32963 .46293 L
.32966 .46296 L
.32969 .46297 L
.32971 .46299 L
.32974 .46299 L
.32977 .46299 L
.3298 .46299 L
.32983 .46298 L
.32986 .46296 L
.32988 .46294 L
.32994 .46288 L
.33001 .46279 L
.33013 .46256 L
.33039 .4619 L
.33051 .4616 L
.33063 .46132 L
.3307 .46121 L
.33076 .46112 L
.33082 .46105 L
.33085 .46103 L
Mistroke
.33088 .46101 L
.33091 .461 L
.33094 .46099 L
.33096 .46099 L
.33097 .46099 L
.33099 .46099 L
.33101 .461 L
.33102 .46101 L
.33104 .46102 L
.33107 .46104 L
.3311 .46107 L
.33114 .46111 L
.33126 .46131 L
.33139 .46159 L
.33162 .4622 L
.33174 .46248 L
.33185 .46273 L
.33192 .46284 L
.33198 .46292 L
.33201 .46295 L
.33205 .46298 L
.33208 .46299 L
.33211 .463 L
.33213 .46301 L
.33217 .46301 L
.3322 .463 L
.33222 .46299 L
.33225 .46297 L
.33229 .46294 L
.33235 .46286 L
.33242 .46276 L
.33249 .46262 L
.33261 .46232 L
.33286 .46167 L
.33299 .46136 L
.33306 .46123 L
.33313 .46112 L
.33319 .46105 L
.33322 .46102 L
.33325 .461 L
.33326 .46099 L
.33328 .46098 L
.3333 .46098 L
.33332 .46097 L
.33335 .46097 L
.33336 .46098 L
.33338 .46098 L
.33341 .46099 L
.33344 .46101 L
.33346 .46103 L
Mistroke
.33349 .46106 L
.33355 .46114 L
.33361 .46124 L
.33406 .46236 L
.33419 .46265 L
.33425 .46278 L
.33432 .46288 L
.33437 .46295 L
.3344 .46297 L
.33443 .463 L
.33445 .46301 L
.33446 .46302 L
.33449 .46303 L
.33452 .46303 L
.33455 .46303 L
.33457 .46302 L
.33459 .46302 L
.3346 .46301 L
.33462 .463 L
.33465 .46297 L
.33469 .46293 L
.33475 .46285 L
.33482 .46273 L
.33506 .46214 L
.33519 .46181 L
.33532 .46147 L
.33544 .46122 L
.33549 .46112 L
.33555 .46105 L
.33558 .46102 L
.3356 .46099 L
.33564 .46097 L
.33567 .46096 L
.33568 .46095 L
.3357 .46095 L
.33572 .46095 L
.33573 .46095 L
.33576 .46096 L
.33578 .46096 L
.33579 .46097 L
.33583 .46099 L
.33586 .46102 L
.33592 .4611 L
.33599 .46121 L
.33606 .46136 L
.33631 .46201 L
.33654 .46261 L
.33666 .46285 L
.33672 .46294 L
.33676 .46298 L
Mistroke
.33679 .46301 L
.33682 .46303 L
.33684 .46304 L
.33685 .46305 L
.33687 .46305 L
.33689 .46306 L
.33691 .46306 L
.33693 .46306 L
.33696 .46305 L
.33698 .46304 L
.33699 .46303 L
.33702 .46301 L
.33705 .46298 L
.33711 .4629 L
.33717 .4628 L
.33728 .46257 L
.33754 .46189 L
.33766 .46156 L
.33778 .46127 L
.33785 .46113 L
.33792 .46103 L
.33795 .461 L
.33798 .46097 L
.338 .46095 L
.33802 .46094 L
.33805 .46093 L
.33808 .46092 L
.3381 .46092 L
.33814 .46093 L
.33817 .46094 L
.33819 .46096 L
.33822 .46098 L
.33828 .46104 L
.33833 .46113 L
.3384 .46125 L
.33853 .46155 L
.33876 .46219 L
.33888 .46252 L
.33899 .46278 L
.33906 .4629 L
.33912 .46299 L
.33915 .46302 L
.33919 .46305 L
.3392 .46306 L
.33922 .46307 L
.33924 .46308 L
.33926 .46309 L
.33929 .46309 L
.33932 .46309 L
.33934 .46308 L
Mistroke
.33937 .46306 L
.3394 .46304 L
.33944 .463 L
.3395 .46292 L
.33961 .46271 L
.33972 .46244 L
.33997 .46173 L
.34009 .46141 L
.34021 .46114 L
.34028 .46103 L
.34031 .46099 L
.34035 .46095 L
.34038 .46092 L
.34041 .4609 L
.34045 .46089 L
.34048 .46088 L
.3405 .46089 L
.34053 .4609 L
.34056 .46091 L
.34059 .46093 L
.34062 .46096 L
.34065 .461 L
.34071 .46109 L
.34084 .46135 L
.34096 .46166 L
.34117 .46229 L
.34128 .46259 L
.3414 .46286 L
.34146 .46297 L
.3415 .46301 L
.34153 .46306 L
.34156 .46309 L
.34159 .46311 L
.34162 .46312 L
.34165 .46313 L
.34168 .46313 L
.34171 .46312 L
.34174 .46311 L
.34177 .46309 L
.3418 .46306 L
.34183 .46302 L
.34189 .46293 L
.34201 .4627 L
.34213 .46239 L
.34234 .46176 L
.34246 .46143 L
.34257 .46116 L
.34263 .46104 L
.34266 .46099 L
.3427 .46094 L
Mistroke
.34273 .46091 L
.34276 .46088 L
.34279 .46086 L
.34281 .46085 L
.34284 .46084 L
.34287 .46084 L
.3429 .46085 L
.34292 .46086 L
.34295 .46088 L
.34297 .4609 L
.34303 .46096 L
.34308 .46104 L
.34314 .46116 L
.34325 .46142 L
.3435 .46216 L
.34362 .46252 L
.34374 .4628 L
.34379 .46291 L
.34385 .46302 L
.34389 .46307 L
.34392 .4631 L
.34395 .46313 L
.34398 .46315 L
.34401 .46317 L
.34403 .46317 L
.34404 .46317 L
.34407 .46317 L
.3441 .46316 L
.34412 .46315 L
.34414 .46314 L
.34417 .46311 L
.34421 .46307 L
.34424 .46302 L
.34436 .4628 L
.34448 .46248 L
.3447 .4618 L
.34482 .46145 L
.34494 .46114 L
.34501 .461 L
.34508 .4609 L
.34511 .46086 L
.34514 .46083 L
.34516 .46082 L
.34517 .46081 L
.3452 .4608 L
.34523 .46079 L
.34526 .46079 L
.34529 .4608 L
.34532 .46082 L
.34535 .46084 L
Mistroke
.34537 .46087 L
.34543 .46094 L
.34549 .46105 L
.34555 .46119 L
.34567 .4615 L
.3459 .46221 L
.34611 .46282 L
.34622 .46305 L
.34625 .4631 L
.34628 .46314 L
.34631 .46317 L
.34634 .46319 L
.34637 .46321 L
.34638 .46322 L
.3464 .46322 L
.34643 .46323 L
.34646 .46322 L
.34647 .46322 L
.34649 .46321 L
.34651 .4632 L
.34653 .46319 L
.34656 .46316 L
.34659 .46312 L
.34665 .46302 L
.34672 .46287 L
.34685 .46253 L
.34709 .46176 L
.3472 .46142 L
.34732 .46111 L
.34739 .46096 L
.34745 .46086 L
.34748 .46082 L
.34751 .46079 L
.34754 .46076 L
.34755 .46075 L
.34757 .46074 L
.34759 .46074 L
.3476 .46073 L
.34763 .46073 L
.34765 .46074 L
.34767 .46074 L
.34769 .46075 L
.34771 .46076 L
.34774 .4608 L
.34777 .46083 L
.34783 .46093 L
.34795 .46118 L
.34807 .46154 L
.34832 .46235 L
.34844 .46272 L
Mistroke
.34855 .463 L
.3486 .46311 L
.34866 .4632 L
.34869 .46323 L
.34872 .46326 L
.34875 .46328 L
.34877 .46329 L
.34879 .46329 L
.3488 .46329 L
.34882 .46329 L
.34885 .46329 L
.34887 .46328 L
.34889 .46327 L
.34892 .46323 L
.34896 .4632 L
.34899 .46316 L
.34905 .46303 L
.34929 .46237 L
.34955 .4615 L
.34967 .46113 L
.34973 .46098 L
.34979 .46086 L
.34984 .46078 L
.34987 .46074 L
.34989 .46071 L
.34992 .46069 L
.34995 .46067 L
.34998 .46066 L
.35001 .46066 L
.35003 .46067 L
.35006 .46068 L
.35009 .4607 L
.35012 .46073 L
.35018 .4608 L
.35023 .4609 L
.35036 .46122 L
.35048 .4616 L
.35069 .46236 L
.35081 .46275 L
.35092 .46305 L
.35098 .46317 L
.35101 .46323 L
.35105 .46328 L
.35108 .46331 L
.35111 .46334 L
.35113 .46336 L
.35116 .46337 L
.35119 .46337 L
.35122 .46337 L
.35124 .46336 L
Mistroke
.35127 .46335 L
.35129 .46332 L
.35132 .46329 L
.35138 .4632 L
.35144 .46307 L
.35151 .4629 L
.35164 .4625 L
.35188 .46165 L
.35199 .46127 L
.35211 .46093 L
.35217 .46078 L
.35224 .46068 L
.35227 .46064 L
.35228 .46062 L
.3523 .46061 L
.35233 .46059 L
.35236 .46058 L
.35239 .46057 L
.35242 .46058 L
.35243 .46059 L
.35245 .4606 L
.35248 .46062 L
.35251 .46066 L
.35254 .4607 L
.3526 .4608 L
.35267 .46097 L
.35274 .46116 L
.35286 .46159 L
.3531 .46247 L
.35323 .4629 L
.35329 .46308 L
.35334 .46321 L
.35339 .46331 L
.35345 .46339 L
.35348 .46342 L
.3535 .46344 L
.35353 .46346 L
.35356 .46347 L
.35358 .46347 L
.35361 .46346 L
.35364 .46344 L
.35367 .46342 L
.35369 .46339 L
.35373 .46335 L
.35379 .46323 L
.35385 .46309 L
.35392 .4629 L
.35403 .46249 L
.35426 .46162 L
.35439 .46115 L
Mistroke
.35446 .46094 L
.35452 .46077 L
.35458 .46064 L
.35464 .46055 L
.35467 .46052 L
.3547 .46049 L
.35473 .46047 L
.35475 .46047 L
.35476 .46047 L
.35479 .46047 L
.35481 .46048 L
.35483 .46049 L
.35486 .46052 L
.35488 .46055 L
.35495 .46065 L
.35502 .4608 L
.35514 .46118 L
.35526 .4616 L
.35547 .46248 L
.35559 .46292 L
.3557 .46325 L
.35576 .46338 L
.35582 .46348 L
.35585 .46352 L
.35587 .46354 L
.35588 .46356 L
.35591 .46357 L
.35594 .46358 L
.35597 .46358 L
.356 .46357 L
.35602 .46356 L
.35605 .46353 L
.35608 .4635 L
.35611 .46345 L
.35616 .46335 L
.35628 .46301 L
.3564 .46259 L
.35666 .4615 L
.35678 .46103 L
.35684 .46083 L
.35691 .46064 L
.35698 .4605 L
.35701 .46045 L
.35703 .46041 L
.35706 .46038 L
.35709 .46035 L
.35712 .46034 L
.35715 .46034 L
.35718 .46035 L
.3572 .46036 L
Mistroke
.35723 .46038 L
.35726 .46042 L
.35731 .46049 L
.35736 .46061 L
.35748 .46097 L
.35759 .46139 L
.35781 .46234 L
.35793 .46285 L
.35804 .46325 L
.35811 .46343 L
.35814 .46351 L
.35818 .46358 L
.35821 .46364 L
.35824 .46368 L
.35827 .4637 L
.3583 .46372 L
.35833 .46373 L
.35836 .46372 L
.35839 .46371 L
.35841 .46369 L
.35845 .46365 L
.35848 .4636 L
.35854 .46348 L
.3586 .46331 L
.35867 .4631 L
.35878 .46263 L
.35905 .46141 L
.35916 .46095 L
.35928 .46054 L
.35935 .46037 L
.35938 .46031 L
.35941 .46026 L
.35944 .46022 L
.35947 .4602 L
.3595 .46018 L
.35952 .46018 L
.35953 .46018 L
.35956 .46019 L
.35959 .46021 L
.35962 .46023 L
.35965 .46028 L
.35971 .4604 L
.35977 .46056 L
.35989 .46096 L
.35999 .46142 L
.36024 .46259 L
.36037 .46317 L
.36043 .46341 L
.36049 .46359 L
.36055 .46374 L
Mistroke
.36058 .46379 L
.36061 .46384 L
.36063 .46386 L
.36065 .46388 L
.36068 .4639 L
.36069 .4639 L
.36071 .46391 L
.36073 .46391 L
.36074 .4639 L
.36077 .46389 L
.3608 .46386 L
.36082 .46383 L
.36085 .46378 L
.36091 .46365 L
.36097 .46349 L
.36107 .4631 L
.36119 .46259 L
.36141 .46144 L
.36154 .46084 L
.3616 .46058 L
.36166 .46038 L
.36171 .46023 L
.36177 .46011 L
.3618 .46006 L
.36182 .46002 L
.36185 .45999 L
.36188 .45998 L
.3619 .45998 L
.36192 .45998 L
.36195 .45999 L
.36197 .46 L
.36198 .46002 L
.36202 .46007 L
.36205 .46013 L
.36208 .46019 L
.36215 .46038 L
.36226 .46083 L
.36239 .46143 L
.36262 .46267 L
.36274 .46328 L
.3628 .46354 L
.36286 .46375 L
.36291 .4639 L
.36297 .46403 L
.363 .46407 L
.36303 .46411 L
.36306 .46413 L
.36308 .46414 L
.36309 .46414 L
.36312 .46413 L
Mistroke
.36314 .46412 L
.36317 .4641 L
.3632 .46406 L
.36323 .46401 L
.36325 .46395 L
.3633 .46383 L
.36341 .46342 L
.36354 .46282 L
.36378 .4614 L
.3639 .4608 L
.36401 .46027 L
.36407 .46006 L
.36413 .45991 L
.36418 .45981 L
.3642 .45976 L
.36423 .45974 L
.36426 .45972 L
.36429 .45971 L
.36431 .45972 L
.36434 .45973 L
.36437 .45977 L
.36439 .45979 L
.3644 .45982 L
.36446 .45995 L
.36451 .46012 L
.36457 .46034 L
.36468 .46084 L
.36491 .46225 L
.36504 .463 L
.36517 .46371 L
.36524 .46398 L
.3653 .46419 L
.36536 .46433 L
.36539 .46438 L
.36542 .46442 L
.36545 .46444 L
.36548 .46445 L
.3655 .46444 L
.36553 .46442 L
.36556 .46438 L
.36558 .46436 L
.36559 .46433 L
.36565 .46419 L
.36572 .46397 L
.36578 .46371 L
.36591 .46297 L
.36616 .46137 L
.36627 .46064 L
.36639 .46 L
.36645 .45979 L
Mistroke
.3665 .45961 L
.36653 .45952 L
.36656 .45946 L
.36659 .45941 L
.36662 .45938 L
.36665 .45936 L
.36668 .45935 L
.36669 .45936 L
.36671 .45937 L
.36674 .4594 L
.36677 .45945 L
.3668 .45951 L
.36685 .45967 L
.36692 .45992 L
.36698 .46021 L
.36711 .46103 L
.36737 .46281 L
.36749 .46363 L
.36754 .46395 L
.3676 .46425 L
.36765 .46446 L
.36771 .46464 L
.36774 .46472 L
.36776 .46478 L
.36779 .46482 L
.36782 .46485 L
.36784 .46486 L
.36787 .46486 L
.3679 .46485 L
.36793 .46482 L
.36796 .46477 L
.36799 .46469 L
.36805 .4645 L
.36811 .46426 L
.36817 .46395 L
.36828 .46325 L
.36853 .46133 L
.36866 .46032 L
.36873 .45989 L
.36879 .45954 L
.36885 .45926 L
.36891 .45907 L
.36894 .45898 L
.36897 .45892 L
.369 .45888 L
.36902 .45886 L
.36903 .45885 L
.36906 .45885 L
.36909 .45887 L
.36912 .4589 L
Mistroke
.36914 .45895 L
.36917 .45903 L
.36921 .45913 L
.36927 .45936 L
.36937 .45994 L
.36948 .46076 L
.36974 .46297 L
.36986 .46389 L
.36992 .46432 L
.36998 .46472 L
.37004 .46503 L
.3701 .46524 L
.37013 .46533 L
.37015 .46539 L
.37018 .46544 L
.37021 .46547 L
.37024 .46548 L
.37026 .46547 L
.37029 .46544 L
.37032 .46539 L
.37034 .46535 L
.37036 .46531 L
.37039 .46521 L
.37045 .46496 L
.37051 .46463 L
.37057 .46418 L
.37071 .46307 L
.37095 .46076 L
.37107 .45972 L
.37113 .45923 L
.37119 .45884 L
.37124 .45854 L
.3713 .45833 L
.37132 .45824 L
.37135 .45817 L
.37138 .45812 L
.37141 .4581 L
.37144 .45809 L
.37147 .45812 L
.37149 .45814 L
.3715 .45817 L
.37154 .45825 L
.37157 .45837 L
.37161 .45852 L
.37167 .45888 L
.3718 .45984 L
.37191 .46096 L
.37217 .46371 L
.37229 .46491 L
.37235 .46535 L
Mistroke
.37241 .46576 L
.37246 .46606 L
.37251 .46626 L
.37254 .46634 L
.37256 .46639 L
.37259 .46643 L
.37262 .46644 L
.37265 .46643 L
.37268 .46639 L
.3727 .46633 L
.37273 .46625 L
.37276 .46613 L
.37279 .46597 L
.37285 .46561 L
.37297 .4646 L
.37308 .4634 L
.37333 .46027 L
.37346 .45883 L
.37358 .45774 L
.37364 .4573 L
.37368 .45712 L
.37372 .45698 L
.37374 .4569 L
.37378 .45685 L
.37379 .45683 L
.37381 .45683 L
.37384 .45684 L
.37386 .45687 L
.37387 .4569 L
.3739 .45698 L
.37393 .4571 L
.37397 .45727 L
.37403 .45768 L
.37408 .45816 L
.37421 .45961 L
.37435 .46149 L
.37458 .46491 L
.37471 .4665 L
.37477 .46712 L
.37483 .46758 L
.37486 .46777 L
.37489 .46791 L
.37492 .46803 L
.37493 .46808 L
.37495 .46812 L
.37497 .46815 L
.37498 .46817 L
.375 .46817 L
.37502 .46817 L
.37505 .46812 L
Mistroke
.37506 .46808 L
.37508 .46804 L
.37511 .46792 L
.37514 .46777 L
.3752 .46734 L
.37525 .46684 L
.3753 .4662 L
.37551 .46297 L
.37575 .45881 L
.37587 .45681 L
.37593 .45598 L
.37599 .45535 L
.37604 .45489 L
.37607 .45471 L
.3761 .45455 L
.37613 .45443 L
.37615 .45436 L
.37617 .45433 L
.37618 .45432 L
.37621 .45433 L
.37625 .4544 L
.37627 .45451 L
.37629 .45459 L
.37631 .45469 L
.37634 .45491 L
.3764 .45549 L
.37645 .45618 L
.37658 .45831 L
.37672 .46116 L
.37694 .4664 L
.37707 .46897 L
.37713 .47002 L
.37719 .47084 L
.37724 .47144 L
.37727 .47169 L
.3773 .47188 L
.37733 .47203 L
.37734 .47208 L
.37736 .47212 L
.37739 .47214 L
.37742 .47209 L
.37744 .47201 L
.37747 .47186 L
.37749 .47168 L
.37752 .47147 L
.37757 .4708 L
.37763 .46996 L
.37774 .46762 L
.37786 .46428 L
.3781 .45633 L
Mistroke
.37821 .45295 L
.37827 .45137 L
.37833 .44992 L
.37839 .44885 L
.37841 .44838 L
.37844 .44795 L
.37847 .44763 L
.3785 .44741 L
.37852 .44724 L
.37855 .44715 L
.37857 .44712 L
.3786 .44718 L
.37863 .44732 L
.37866 .44753 L
.37869 .44788 L
.37872 .44837 L
.37878 .44957 L
.37884 .45125 L
.37891 .45348 L
.37903 .45853 L
.37926 .47079 L
.37947 .4819 L
.37953 .48454 L
.37959 .48659 L
.37962 .48749 L
.37965 .48818 L
.37969 .48877 L
.3797 .48902 L
.37972 .48919 L
.37973 .4893 L
.37975 .48937 L
.37977 .48937 L
.37979 .48932 L
.37982 .48906 L
.37983 .48882 L
.37985 .48855 L
.37988 .48772 L
.37992 .48649 L
.37995 .48498 L
.37999 .48328 L
.38005 .47913 L
.38011 .47416 L
.38022 .46205 L
.38034 .44493 L
.38047 .42192 L
.38094 .31177 L
.38119 .24918 L
.38146 .19143 L
.38159 .16902 L
.38171 .15228 L
Mistroke
.38183 .14115 L
.38189 .13649 L
.38195 .13318 L
.38197 .13201 L
.382 .13096 L
.38203 .13021 L
.38205 .12957 L
.38208 .12906 L
.38211 .12875 L
.38214 .12865 L
.38217 .12873 L
.3822 .129 L
.38223 .12942 L
.38226 .12993 L
.38228 .13061 L
.38235 .1326 L
.38241 .13491 L
.38264 .147 L
.38277 .15416 L
.38289 .16033 L
.38301 .16503 L
.38307 .167 L
.38313 .16868 L
.38316 .16932 L
.38319 .16982 L
.38322 .17021 L
.38325 .1705 L
.38327 .1707 L
.3833 .17084 L
.38332 .17091 L
.38335 .1709 L
.38338 .17079 L
.3834 .1707 L
.38341 .17058 L
.38344 .17031 L
.38347 .16994 L
.38352 .16912 L
.38358 .16796 L
.38382 .16098 L
.38404 .15406 L
.38415 .1508 L
.38426 .1484 L
.38432 .14745 L
.38438 .14668 L
.38441 .14635 L
.38443 .14623 L
.38444 .14613 L
.38447 .14599 L
.3845 .14591 L
.38453 .1459 L
Mistroke
.38456 .14594 L
.38458 .14602 L
.38461 .14618 L
.38464 .1464 L
.38467 .14667 L
.38473 .1473 L
.38485 .14933 L
.38497 .15175 L
.38523 .15777 L
.38534 .16003 L
.3854 .16105 L
.38546 .16196 L
.38551 .16262 L
.38554 .16291 L
.38557 .16317 L
.3856 .16336 L
.38563 .16351 L
.38565 .16361 L
.38568 .16368 L
.3857 .16371 L
.38574 .1637 L
.38575 .16368 L
.38577 .16364 L
.3858 .16352 L
.38583 .16336 L
.38586 .16317 L
.38591 .1627 L
.38604 .16118 L
.38617 .15902 L
.38641 .15464 L
.38653 .15273 L
.38664 .15132 L
.38671 .15072 L
.38677 .15025 L
.3868 .15008 L
.38684 .14996 L
.38685 .14992 L
.38687 .14989 L
.38689 .14987 L
.38691 .14986 L
.38694 .14988 L
.38697 .14995 L
.38699 .15003 L
.38702 .15016 L
.38709 .15055 L
.38715 .15106 L
.38759 .15707 L
.38771 .1587 L
.38778 .15946 L
.38784 .16007 L
Mistroke
.3879 .16053 L
.38793 .16073 L
.38797 .1609 L
.38799 .16102 L
.38802 .16111 L
.38805 .16117 L
.38808 .1612 L
.38811 .1612 L
.38812 .16119 L
.38814 .16117 L
.38817 .16111 L
.3882 .16102 L
.38823 .16089 L
.38826 .16075 L
.38831 .16041 L
.38843 .15937 L
.38856 .15792 L
.3888 .1549 L
.38893 .15348 L
.389 .15284 L
.38907 .15234 L
.38913 .15198 L
.38916 .15182 L
.3892 .15172 L
.38922 .15165 L
.38925 .15161 L
.38928 .15159 L
.38931 .1516 L
.38934 .15164 L
.38937 .15171 L
.3894 .15178 L
.38943 .15189 L
.38949 .1522 L
.38955 .15258 L
.38967 .15368 L
.38979 .15488 L
.39005 .15767 L
.39017 .1587 L
.39023 .15915 L
.39029 .15949 L
.39034 .1597 L
.39037 .1598 L
.3904 .15986 L
.39043 .15991 L
.39046 .15994 L
.39049 .15994 L
.39051 .15992 L
.39054 .15988 L
.39057 .15981 L
.3906 .15973 L
Mistroke
.39063 .15963 L
.39069 .15934 L
.39076 .15894 L
.39101 .15673 L
.39124 .15457 L
.39137 .1536 L
.39143 .15322 L
.39149 .15294 L
.39154 .15274 L
.39157 .15267 L
.3916 .15261 L
.39163 .15257 L
.39165 .15256 L
.39166 .15256 L
.39169 .15256 L
.39172 .15259 L
.39174 .15263 L
.39177 .15269 L
.39182 .15283 L
.39188 .15307 L
.39193 .15335 L
.39217 .15516 L
.39243 .15735 L
.39254 .15811 L
.3926 .15845 L
.39265 .15872 L
.39268 .15885 L
.39272 .15897 L
.39274 .15905 L
.39278 .15911 L
.39281 .15915 L
.39284 .15918 L
.39287 .15918 L
.39289 .15917 L
.39292 .15914 L
.39295 .1591 L
.39298 .15903 L
.39301 .15895 L
.39307 .15871 L
.39313 .15844 L
.39334 .15702 L
.39359 .15507 L
.3937 .15432 L
.39376 .15398 L
.39382 .15368 L
.39388 .15345 L
.39394 .15329 L
.39396 .15324 L
.39399 .1532 L
.39402 .15318 L
Mistroke
.39404 .15317 L
.39407 .15318 L
.3941 .1532 L
.39413 .15324 L
.39416 .15329 L
.39419 .15337 L
.39422 .15347 L
.39428 .15369 L
.3944 .15433 L
.39452 .15508 L
.39478 .15694 L
.3949 .15769 L
.39497 .15802 L
.39503 .1583 L
.39509 .15848 L
.39513 .15856 L
.39516 .15862 L
.39519 .15865 L
.39521 .15867 L
.39524 .15868 L
.39527 .15867 L
.3953 .15865 L
.39532 .15861 L
.39535 .15856 L
.39538 .15849 L
.39543 .15835 L
.39548 .15815 L
.39561 .15755 L
.39572 .15687 L
.39594 .15542 L
.39606 .1547 L
.39617 .15415 L
.39623 .15391 L
.39627 .15381 L
.3963 .15372 L
.39633 .15367 L
.39635 .15364 L
.39637 .15362 L
.3964 .1536 L
.39643 .15359 L
.39646 .15359 L
.39647 .1536 L
.39649 .15362 L
.39652 .15366 L
.39654 .15369 L
.39655 .15372 L
.39661 .15386 L
.39667 .15405 L
.39711 .15649 L
.39723 .15719 L
Mistroke
.39729 .15752 L
.39736 .15779 L
.39741 .158 L
.39745 .15809 L
.39748 .15817 L
.39751 .15823 L
.39754 .15827 L
.39756 .1583 L
.39759 .15832 L
.39762 .15832 L
.39765 .15832 L
.39768 .15829 L
.39771 .15826 L
.39774 .15821 L
.39776 .15816 L
.39782 .15801 L
.39788 .15781 L
.39795 .15753 L
.39807 .15692 L
.39831 .15554 L
.39844 .15487 L
.3985 .15457 L
.39857 .1543 L
.39863 .15412 L
.39867 .15405 L
.3987 .15398 L
.39872 .15396 L
.39873 .15394 L
.39876 .15391 L
.39879 .1539 L
.39882 .1539 L
.39885 .15391 L
.39888 .15393 L
.39889 .15395 L
.39891 .15397 L
.39894 .15402 L
.399 .15415 L
.39905 .15431 L
.39917 .1548 L
.39931 .15547 L
.39955 .15679 L
.39966 .1573 L
.39978 .15772 L
.39981 .15781 L
.39985 .15789 L
.39988 .15795 L
.39991 .158 L
.39994 .15803 L
.39997 .15805 L
.39998 .15806 L
Mistroke
.4 .15806 L
.40003 .15805 L
.40006 .15804 L
.40007 .15802 L
.40009 .158 L
.40012 .15796 L
.40015 .15789 L
.40021 .15774 L
.40027 .15757 L
.40053 .1564 L
.40075 .15528 L
.40087 .15476 L
.40093 .15455 L
.40099 .15439 L
.40105 .15425 L
.40109 .1542 L
.40111 .15417 L
.40112 .15416 L
.40115 .15413 L
.40118 .15413 L
.4012 .15413 L
.40122 .15413 L
.40125 .15415 L
.40128 .15418 L
.40131 .15422 L
.40136 .15432 L
.40142 .15447 L
.40149 .15468 L
.40173 .15575 L
.40187 .1564 L
.40199 .15697 L
.40211 .1574 L
.40216 .15755 L
.40221 .15768 L
.40224 .15774 L
.40227 .15778 L
.4023 .15781 L
.40233 .15784 L
.40236 .15785 L
.40239 .15785 L
.40242 .15785 L
.40244 .15783 L
.40245 .15782 L
.40248 .15779 L
.40251 .15775 L
.40257 .15763 L
.40263 .15748 L
.40268 .15732 L
.40293 .15628 L
.40315 .1553 L
Mistroke
.40327 .15483 L
.40333 .15465 L
.40338 .15452 L
.40341 .15446 L
.40344 .15441 L
.40347 .15437 L
.4035 .15434 L
.40353 .15432 L
.40354 .15431 L
.40356 .15431 L
.40359 .15431 L
.40362 .15432 L
.40365 .15434 L
.40367 .15436 L
.40368 .15438 L
.40375 .15449 L
.40381 .15462 L
.40387 .1548 L
.40431 .15664 L
.40443 .1571 L
.4045 .1573 L
.40456 .15746 L
.40462 .15759 L
.40466 .15763 L
.40468 .15765 L
.4047 .15767 L
.40473 .15769 L
.40475 .15769 L
.40476 .15769 L
.40479 .15769 L
.40481 .15768 L
.40483 .15767 L
.40486 .15764 L
.40489 .1576 L
.40495 .15751 L
.40501 .15736 L
.40507 .15716 L
.40531 .15626 L
.40543 .15577 L
.40555 .15527 L
.40566 .15489 L
.40572 .15473 L
.40578 .15461 L
.40581 .15455 L
.40585 .15451 L
.40586 .15449 L
.40588 .15448 L
.4059 .15447 L
.40592 .15446 L
.40595 .15445 L
Mistroke
.40597 .15445 L
.40598 .15446 L
.40601 .15447 L
.40604 .1545 L
.40607 .15453 L
.4061 .15458 L
.40616 .15468 L
.40628 .15502 L
.40653 .15594 L
.40665 .15643 L
.40676 .15685 L
.40686 .15716 L
.40691 .15729 L
.40697 .15741 L
.407 .15746 L
.40703 .15749 L
.40705 .15752 L
.40708 .15754 L
.40711 .15756 L
.40714 .15757 L
.40717 .15756 L
.4072 .15755 L
.40723 .15753 L
.40726 .1575 L
.40729 .15745 L
.40732 .1574 L
.40744 .15711 L
.40755 .15678 L
.40767 .15634 L
.4078 .15581 L
.40793 .15533 L
.40799 .15514 L
.40805 .15495 L
.40811 .15481 L
.40817 .1547 L
.40822 .15463 L
.40825 .1546 L
.40828 .15458 L
.4083 .15457 L
.40833 .15457 L
.40836 .15457 L
.40839 .15458 L
.40842 .15461 L
.40845 .15464 L
.40851 .15472 L
.40857 .15485 L
.40864 .15501 L
.40888 .15582 L
.409 .1563 L
.40914 .15678 L
Mistroke
.4092 .15698 L
.40927 .15715 L
.40933 .15727 L
.40936 .15733 L
.40938 .15737 L
.40941 .1574 L
.40944 .15742 L
.40947 .15744 L
.4095 .15746 L
.40953 .15746 L
.40954 .15746 L
.40956 .15745 L
.40959 .15744 L
.40962 .15742 L
.40965 .15739 L
.40968 .15734 L
.40974 .15723 L
.40986 .15694 L
.41012 .15605 L
.41024 .15562 L
.41037 .15521 L
.41042 .15505 L
.41049 .15491 L
.41054 .15481 L
.4106 .15473 L
.41063 .1547 L
.41066 .15468 L
.41067 .15467 L
.41069 .15466 L
.41072 .15466 L
.41075 .15467 L
.41078 .15468 L
.41081 .1547 L
.41084 .15473 L
.4109 .15483 L
.41097 .15497 L
.4111 .15531 L
.41133 .1561 L
.41146 .15654 L
.41158 .1569 L
.41164 .15707 L
.41172 .15721 L
.41175 .15726 L
.41178 .1573 L
.41181 .15733 L
.41183 .15735 L
.41184 .15736 L
.41186 .15736 L
.41188 .15737 L
.41191 .15737 L
Mistroke
.41192 .15737 L
.41194 .15737 L
.41196 .15736 L
.41197 .15735 L
.412 .15733 L
.41203 .1573 L
.41209 .15721 L
.41215 .1571 L
.41221 .15697 L
.41234 .15661 L
.41259 .15574 L
.4127 .15537 L
.41281 .15509 L
.41287 .15496 L
.4129 .15491 L
.41294 .15485 L
.41296 .15482 L
.41299 .15479 L
.41302 .15476 L
.41305 .15475 L
.41308 .15474 L
.41309 .15474 L
.41311 .15474 L
.41314 .15475 L
.41317 .15476 L
.41318 .15478 L
.4132 .15479 L
.41323 .15482 L
.4133 .15492 L
.41336 .15504 L
.41341 .15517 L
.41354 .15552 L
.41375 .15623 L
.41386 .15659 L
.41398 .15691 L
.41404 .15705 L
.41408 .15711 L
.41411 .15717 L
.41415 .15722 L
.41418 .15725 L
.41421 .15727 L
.41423 .15729 L
.41426 .1573 L
.41429 .1573 L
.41432 .1573 L
.41435 .15728 L
.41438 .15726 L
.41441 .15723 L
.41447 .15715 L
.41453 .15706 L
Mistroke
.41459 .15693 L
.41471 .15661 L
.41492 .15592 L
.41503 .15556 L
.41516 .15521 L
.41522 .15508 L
.41528 .15497 L
.41533 .1549 L
.41536 .15486 L
.41539 .15484 L
.4154 .15483 L
.41542 .15482 L
.41544 .15481 L
.41545 .15481 L
.41548 .15481 L
.41551 .15481 L
.41553 .15482 L
.41555 .15483 L
.41559 .15486 L
.41562 .15489 L
.41565 .15493 L
.41577 .15515 L
.41589 .15547 L
.41614 .15623 L
.41626 .1566 L
.41637 .15688 L
.41647 .15708 L
.4165 .15712 L
.41652 .15716 L
.41655 .15718 L
.41657 .15721 L
.4166 .15722 L
.41663 .15724 L
.41666 .15724 L
.41668 .15724 L
.41671 .15723 L
.41674 .15722 L
.41677 .1572 L
.4168 .15717 L
.41686 .15709 L
.41692 .15699 L
.41703 .15674 L
.41727 .15602 L
.41751 .15532 L
.41758 .15516 L
.41765 .15504 L
.41771 .15495 L
.41774 .15492 L
.41777 .15489 L
.4178 .15487 L
Mistroke
.41782 .15487 L
.41783 .15486 L
.41786 .15486 L
.41789 .15487 L
.41792 .15488 L
.41794 .15489 L
.41797 .15491 L
.418 .15494 L
.41806 .15503 L
.41812 .15514 L
.41824 .15541 L
.41845 .15602 L
.41868 .15669 L
.41874 .15683 L
.4188 .15695 L
.41885 .15704 L
.41891 .15712 L
.41894 .15715 L
.41897 .15717 L
.41899 .15718 L
.41901 .15718 L
.41902 .15719 L
.41904 .15719 L
.41907 .15719 L
.4191 .15718 L
.41913 .15717 L
.41916 .15714 L
.41919 .15712 L
.41921 .15709 L
.41927 .157 L
.41937 .1568 L
.4196 .15617 L
.41982 .15553 L
.41994 .15523 L
.42 .15512 L
.42006 .15503 L
.42009 .15499 L
.42012 .15496 L
.42016 .15493 L
.42018 .15492 L
.42019 .15491 L
.42022 .15491 L
.42025 .15491 L
.42027 .15491 L
.42029 .15492 L
.42032 .15493 L
.42034 .15495 L
.42038 .15498 L
.42044 .15506 L
.4205 .15517 L
Mistroke
.42056 .15528 L
.421 .15651 L
.42112 .1568 L
.42119 .15693 L
.42125 .15703 L
.42128 .15707 L
.42131 .1571 L
.42133 .15711 L
.42134 .15712 L
.42137 .15714 L
.4214 .15715 L
.42143 .15715 L
.42146 .15715 L
.42149 .15714 L
.42152 .15712 L
.42155 .1571 L
.4216 .15703 L
.42167 .15694 L
.42173 .15681 L
.42197 .1562 L
.4221 .15583 L
.42223 .15547 L
.42235 .15521 L
.42241 .1551 L
.42244 .15506 L
.42248 .15502 L
.42251 .15499 L
.42254 .15497 L
.42256 .15496 L
.42259 .15495 L
.42262 .15495 L
.42264 .15495 L
.42267 .15496 L
.4227 .15497 L
.42273 .15499 L
.42276 .15502 L
.42283 .1551 L
.42288 .1552 L
.42294 .15531 L
.4232 .15599 L
.42332 .15634 L
.42344 .15664 L
.42356 .15688 L
.42361 .15697 L
.42368 .15705 L
.42371 .15708 L
.42374 .1571 L
.42376 .1571 L
.42378 .15711 L
.42379 .15711 L
Mistroke
.42381 .15711 L
.42384 .15711 L
.42387 .1571 L
.42389 .15709 L
.4239 .15708 L
.42393 .15706 L
.42399 .157 L
.42405 .15691 L
.42417 .15667 L
.42438 .15611 L
.4245 .15579 L
.42462 .15546 L
.42468 .15533 L
.42474 .15521 L
.4248 .15513 L
.42485 .15506 L
.42489 .15502 L
.42492 .155 L
.42495 .15499 L
.42498 .15498 L
.42499 .15498 L
.42501 .15498 L
.42503 .15498 L
.42504 .15498 L
.42506 .15499 L
.42508 .155 L
.42512 .15503 L
.42514 .15505 L
.42518 .15509 L
.42524 .15518 L
.42536 .15541 L
.42562 .15609 L
.42575 .15644 L
.42586 .15672 L
.42597 .15692 L
.42603 .15699 L
.42606 .15702 L
.42609 .15705 L
.42612 .15707 L
.42615 .15708 L
.42618 .15709 L
.4262 .15709 L
.42621 .15708 L
.42624 .15708 L
.42627 .15706 L
.4263 .15704 L
.42633 .15702 L
.42638 .15695 L
.42644 .15686 L
.42656 .15662 L
Mistroke
.42678 .15606 L
.42691 .15571 L
.42703 .15541 L
.42714 .1552 L
.42721 .15511 L
.42723 .15508 L
.42726 .15505 L
.42729 .15503 L
.42732 .15502 L
.42735 .15501 L
.42737 .155 L
.4274 .155 L
.42743 .15501 L
.42746 .15503 L
.42748 .15504 L
.42749 .15505 L
.42755 .15511 L
.42762 .1552 L
.42773 .15542 L
.42797 .15602 L
.4281 .15636 L
.42824 .15668 L
.4283 .15681 L
.42836 .15691 L
.42842 .15698 L
.42845 .15701 L
.42848 .15703 L
.42851 .15705 L
.42854 .15706 L
.42857 .15706 L
.42859 .15706 L
.42862 .15705 L
.42864 .15705 L
.42866 .15704 L
.42868 .15702 L
.42871 .15699 L
.42878 .15691 L
.42884 .15682 L
.42896 .15658 L
.42922 .1559 L
.42934 .1556 L
.42945 .15535 L
.42951 .15524 L
.42957 .15516 L
.42963 .15509 L
.42966 .15506 L
.42968 .15505 L
.4297 .15504 L
.42972 .15503 L
.42975 .15502 L
Mistroke
.42978 .15503 L
.42981 .15503 L
.42983 .15504 L
.42986 .15506 L
.42988 .15508 L
.42991 .1551 L
.42997 .15517 L
.43003 .15526 L
.43014 .15549 L
.43037 .15607 L
.4305 .1564 L
.43061 .15667 L
.43068 .1568 L
.43076 .15691 L
.43079 .15695 L
.43082 .15698 L
.43085 .15701 L
.43088 .15703 L
.4309 .15703 L
.43092 .15704 L
.43095 .15704 L
.43096 .15704 L
.43098 .15704 L
.43099 .15704 L
.43101 .15703 L
.43104 .15702 L
.43107 .157 L
.43113 .15693 L
.43119 .15685 L
.43126 .15674 L
.43137 .15649 L
.43159 .15592 L
.43172 .15561 L
.43185 .15533 L
.43191 .15522 L
.43197 .15514 L
.43203 .15509 L
.43206 .15506 L
.43209 .15505 L
.43212 .15504 L
.43215 .15504 L
.43217 .15504 L
.4322 .15505 L
.43223 .15507 L
.43225 .15508 L
.43226 .15509 L
.43232 .15515 L
.43238 .15522 L
.43243 .15532 L
.43254 .15554 L
Mistroke
.43278 .15614 L
.4329 .15645 L
.43297 .15661 L
.43304 .15674 L
.4331 .15685 L
.43313 .15689 L
.43317 .15694 L
.4332 .15697 L
.43323 .15699 L
.43326 .15701 L
.43329 .15702 L
.43332 .15703 L
.43334 .15703 L
.43337 .15703 L
.4334 .15702 L
.43343 .157 L
.43346 .15697 L
.43352 .15691 L
.43358 .15682 L
.43365 .15669 L
.43378 .15641 L
.43402 .15579 L
.43414 .15553 L
.43425 .15529 L
.43432 .15519 L
.43438 .15512 L
.43441 .15509 L
.43443 .15508 L
.43445 .15507 L
.43448 .15506 L
.4345 .15505 L
.43454 .15505 L
.43456 .15506 L
.4346 .15507 L
.43461 .15508 L
.43463 .15509 L
.43469 .15514 L
.43475 .15522 L
.43487 .15544 L
.43501 .15576 L
.43526 .15639 L
.43539 .15668 L
.43546 .1568 L
.43552 .1569 L
.43558 .15696 L
.43562 .15699 L
.43564 .157 L
.43566 .15701 L
.43568 .15702 L
.43569 .15702 L
Mistroke
.43571 .15702 L
.43574 .15702 L
.43576 .15701 L
.43578 .15701 L
.43581 .15699 L
.43584 .15697 L
.43589 .15692 L
.43595 .15684 L
.43601 .15674 L
.43627 .15614 L
.4364 .15581 L
.43652 .15552 L
.43662 .15532 L
.43668 .15523 L
.43674 .15515 L
.43677 .15512 L
.4368 .1551 L
.43683 .15508 L
.43686 .15507 L
.43689 .15506 L
.43692 .15506 L
.43695 .15507 L
.43697 .15507 L
.43698 .15508 L
.43701 .1551 L
.43704 .15512 L
.4371 .15519 L
.43716 .15528 L
.43721 .15537 L
.43747 .15595 L
.43768 .15649 L
.4378 .15673 L
.43786 .15683 L
.43792 .15691 L
.43795 .15695 L
.43798 .15697 L
.43802 .15699 L
.43803 .157 L
.43805 .15701 L
.43808 .15701 L
.43811 .15701 L
.43814 .15701 L
.43816 .157 L
.43817 .15699 L
.4382 .15698 L
.43823 .15695 L
.43829 .15688 L
.43835 .1568 L
.43841 .1567 L
.43886 .15563 L
Mistroke
.43897 .15538 L
.43903 .15528 L
.43908 .1552 L
.43914 .15513 L
.43918 .15511 L
.43919 .15509 L
.43921 .15508 L
.43924 .15507 L
.43927 .15506 L
.4393 .15506 L
.43933 .15507 L
.43935 .15508 L
.43938 .15509 L
.4394 .15511 L
.43943 .15513 L
.43949 .1552 L
.43954 .15528 L
.43965 .15548 L
.43977 .15575 L
.44001 .15637 L
.44013 .15664 L
.44024 .15683 L
.4403 .15691 L
.44036 .15697 L
.44039 .15699 L
.44042 .157 L
.44045 .15701 L
.44047 .15701 L
.44048 .15701 L
.4405 .15701 L
.44052 .15701 L
.44055 .15699 L
.44057 .15699 L
.44058 .15697 L
.44062 .15694 L
.44068 .15687 L
.44075 .15677 L
.44122 .15566 L
.44135 .15538 L
.44142 .15526 L
.44149 .15517 L
.44155 .15511 L
.44156 .1551 L
.44158 .15509 L
.44161 .15507 L
.44163 .15507 L
.44164 .15507 L
.44167 .15506 L
.44169 .15507 L
.44171 .15507 L
Mistroke
.44172 .15508 L
.44174 .15508 L
.44177 .1551 L
.4418 .15512 L
.44186 .15518 L
.44192 .15528 L
.44198 .15538 L
.44224 .15598 L
.44235 .15627 L
.44248 .15656 L
.44258 .15677 L
.44264 .15686 L
.4427 .15693 L
.44273 .15696 L
.44276 .15698 L
.44279 .157 L
.44282 .15701 L
.44285 .15701 L
.44288 .15701 L
.44291 .15701 L
.44294 .15699 L
.44296 .15698 L
.44299 .15695 L
.44304 .1569 L
.4431 .15683 L
.44315 .15673 L
.44341 .15613 L
.44353 .15584 L
.44365 .15554 L
.44376 .15532 L
.44382 .15523 L
.44388 .15515 L
.44391 .15512 L
.44394 .1551 L
.44397 .15508 L
.444 .15507 L
.44403 .15506 L
.44406 .15506 L
.44409 .15507 L
.44412 .15508 L
.44415 .1551 L
.44418 .15512 L
.44424 .15519 L
.4443 .15528 L
.44436 .15537 L
.44462 .15598 L
.44483 .15651 L
.44496 .15676 L
.44501 .15685 L
.44507 .15692 L
Mistroke
.4451 .15695 L
.44513 .15698 L
.44516 .157 L
.44517 .15701 L
.44519 .15701 L
.44521 .15702 L
.44522 .15702 L
.44525 .15702 L
.44527 .15702 L
.44529 .15701 L
.4453 .15701 L
.44532 .157 L
.44535 .15698 L
.44539 .15695 L
.44545 .15687 L
.44556 .15668 L
.44583 .15606 L
.44595 .15573 L
.44607 .15545 L
.44618 .15525 L
.44624 .15518 L
.4463 .15511 L
.44633 .15509 L
.44636 .15507 L
.44637 .15506 L
.44639 .15506 L
.44642 .15505 L
.44645 .15505 L
.44648 .15506 L
.44651 .15507 L
.44654 .15509 L
.44657 .15512 L
.4466 .15515 L
.44666 .15523 L
.44677 .15543 L
.44702 .15604 L
.44714 .15633 L
.44726 .15661 L
.44731 .15672 L
.44737 .15683 L
.44742 .1569 L
.44748 .15696 L
.44751 .15699 L
.44754 .15701 L
.44757 .15702 L
.4476 .15703 L
.44761 .15703 L
.44763 .15703 L
.44766 .15702 L
.44768 .15702 L
Mistroke
.44769 .15701 L
.44773 .15699 L
.44775 .15697 L
.44778 .15694 L
.44783 .15688 L
.44795 .15667 L
.44819 .15609 L
.44833 .15575 L
.44845 .15545 L
.44857 .15523 L
.4486 .15518 L
.44864 .15514 L
.44867 .15511 L
.4487 .15508 L
.44873 .15506 L
.44876 .15505 L
.44878 .15504 L
.44881 .15504 L
.44884 .15504 L
.44886 .15505 L
.44889 .15507 L
.44891 .15508 L
.44893 .15509 L
.44898 .15514 L
.44904 .15521 L
.44915 .15542 L
.44937 .15594 L
.44958 .1565 L
.4497 .15675 L
.44976 .15686 L
.44982 .15693 L
.44985 .15697 L
.44988 .157 L
.44992 .15702 L
.44994 .15703 L
.44995 .15704 L
.44998 .15704 L
.45001 .15704 L
.45004 .15704 L
.45006 .15703 L
.45008 .15702 L
.45011 .157 L
.45014 .15698 L
.4502 .15691 L
.45026 .15682 L
.45031 .15672 L
.45075 .15562 L
.45087 .15536 L
.45094 .15524 L
.451 .15514 L
Mistroke
.45106 .15508 L
.4511 .15506 L
.45113 .15504 L
.45116 .15503 L
.45118 .15502 L
.45121 .15503 L
.45124 .15503 L
.45127 .15504 L
.4513 .15506 L
.45133 .15509 L
.45136 .15512 L
.45147 .15528 L
.45159 .15553 L
.45172 .15585 L
.45184 .15619 L
.45198 .15654 L
.45204 .15667 L
.4521 .1568 L
.45216 .1569 L
.45222 .15697 L
.45225 .157 L
.45228 .15702 L
.45231 .15704 L
.45234 .15706 L
.45235 .15706 L
.45237 .15706 L
.4524 .15706 L
.45242 .15706 L
.45243 .15705 L
.45245 .15705 L
.45247 .15704 L
.4525 .15701 L
.45253 .15698 L
.45259 .15691 L
.45267 .15679 L
.45273 .15665 L
.45298 .15602 L
.4531 .15569 L
.45322 .15543 L
.45327 .15531 L
.45333 .15521 L
.45338 .15513 L
.45344 .15507 L
.45347 .15504 L
.4535 .15502 L
.45353 .15501 L
.45354 .15501 L
.45356 .155 L
.45359 .155 L
.45362 .15501 L
Mistroke
.45365 .15502 L
.45367 .15504 L
.4537 .15506 L
.45373 .1551 L
.45379 .15517 L
.45391 .1554 L
.45417 .15605 L
.45441 .15667 L
.45448 .15681 L
.45455 .15693 L
.45459 .15697 L
.45462 .15701 L
.45465 .15704 L
.45468 .15706 L
.45471 .15708 L
.45474 .15708 L
.45477 .15709 L
.45478 .15708 L
.4548 .15708 L
.45483 .15707 L
.45486 .15705 L
.45488 .15703 L
.45491 .15701 L
.45497 .15693 L
.45503 .15683 L
.45516 .15655 L
.45541 .1559 L
.45554 .15554 L
.45567 .15527 L
.45572 .15517 L
.45577 .1551 L
.4558 .15506 L
.45583 .15503 L
.45586 .15501 L
.45589 .15499 L
.45591 .15498 L
.45594 .15498 L
.45597 .15498 L
.45599 .15498 L
.456 .15499 L
.45603 .155 L
.45605 .15501 L
.45607 .15503 L
.45613 .15509 L
.45619 .15517 L
.45625 .15529 L
.45636 .15554 L
.45658 .15613 L
.4567 .15645 L
.45683 .15676 L
Mistroke
.45689 .15688 L
.45695 .15697 L
.457 .15704 L
.45703 .15707 L
.45706 .15709 L
.45708 .1571 L
.45711 .15711 L
.45714 .15711 L
.45717 .15711 L
.4572 .1571 L
.45723 .15709 L
.45726 .15707 L
.45729 .15704 L
.45735 .15696 L
.45742 .15685 L
.45754 .15658 L
.4578 .15586 L
.45792 .15554 L
.45804 .15525 L
.4581 .15515 L
.45816 .15505 L
.4582 .15502 L
.45823 .15499 L
.45826 .15497 L
.45829 .15495 L
.4583 .15495 L
.45832 .15495 L
.45834 .15495 L
.45836 .15495 L
.45839 .15496 L
.4584 .15496 L
.45842 .15497 L
.45845 .155 L
.45848 .15503 L
.45856 .15513 L
.45862 .15524 L
.45868 .15537 L
.45881 .1557 L
.45904 .15637 L
.45916 .15667 L
.45922 .15681 L
.45928 .15693 L
.45933 .15701 L
.45939 .15708 L
.45941 .1571 L
.45944 .15712 L
.45947 .15714 L
.4595 .15715 L
.45952 .15715 L
.45953 .15715 L
Mistroke
.45955 .15715 L
.45957 .15714 L
.4596 .15713 L
.45963 .15711 L
.45966 .15708 L
.45969 .15704 L
.45976 .15694 L
.45988 .1567 L
.46 .15638 L
.46024 .15567 L
.46037 .15533 L
.46044 .15518 L
.46051 .15507 L
.46057 .15499 L
.4606 .15496 L
.46063 .15493 L
.46066 .15492 L
.46068 .15491 L
.46069 .15491 L
.46071 .15491 L
.46073 .15491 L
.46075 .15491 L
.46076 .15492 L
.46079 .15493 L
.46082 .15495 L
.46085 .15497 L
.46087 .15501 L
.46094 .1551 L
.46099 .1552 L
.46144 .15643 L
.46156 .15676 L
.46163 .1569 L
.46169 .15702 L
.46175 .1571 L
.46179 .15714 L
.46182 .15716 L
.46184 .15718 L
.46187 .15719 L
.4619 .15719 L
.46193 .15719 L
.46196 .15718 L
.46198 .15717 L
.46199 .15716 L
.46202 .15713 L
.46206 .1571 L
.46211 .15702 L
.46217 .15691 L
.46231 .15659 L
.46244 .15623 L
.46267 .15553 L
Mistroke
.4628 .1552 L
.46286 .15508 L
.46292 .15499 L
.46295 .15495 L
.46298 .15491 L
.46301 .15489 L
.46304 .15487 L
.46307 .15486 L
.46309 .15486 L
.4631 .15486 L
.46312 .15486 L
.46313 .15487 L
.46315 .15487 L
.46317 .15488 L
.4632 .1549 L
.46323 .15493 L
.46328 .155 L
.46334 .1551 L
.46341 .15524 L
.46385 .15653 L
.46397 .15685 L
.46403 .15698 L
.46409 .15709 L
.46414 .15716 L
.46417 .15719 L
.4642 .15721 L
.46423 .15723 L
.46426 .15724 L
.46429 .15724 L
.46431 .15724 L
.46434 .15723 L
.46437 .15721 L
.4644 .15718 L
.46443 .15715 L
.4645 .15706 L
.46456 .15694 L
.46468 .15664 L
.46482 .15624 L
.46506 .15548 L
.46518 .15516 L
.46523 .15505 L
.46529 .15495 L
.46535 .15487 L
.46538 .15484 L
.46542 .15482 L
.46543 .15481 L
.46545 .15481 L
.46548 .15481 L
.4655 .15481 L
.46552 .15481 L
Mistroke
.46553 .15482 L
.46555 .15483 L
.46558 .15485 L
.46561 .15488 L
.46567 .15496 L
.46573 .15508 L
.46579 .15521 L
.46603 .15592 L
.46616 .15635 L
.46629 .15672 L
.4664 .15701 L
.46647 .15713 L
.4665 .15718 L
.46653 .15722 L
.46655 .15725 L
.46658 .15727 L
.4666 .15729 L
.46663 .1573 L
.46666 .1573 L
.46669 .1573 L
.46672 .15729 L
.46675 .15727 L
.46677 .15725 L
.4668 .15723 L
.46685 .15715 L
.4669 .15706 L
.46696 .15695 L
.46719 .15627 L
.46744 .15545 L
.46755 .15515 L
.4676 .15502 L
.46766 .15491 L
.46769 .15486 L
.46772 .15482 L
.46775 .15479 L
.46778 .15477 L
.46781 .15475 L
.46784 .15474 L
.46786 .15474 L
.46789 .15475 L
.46792 .15476 L
.46795 .15478 L
.46798 .15481 L
.46801 .15484 L
.46807 .15495 L
.46814 .15508 L
.46835 .15569 L
.46858 .15647 L
.46869 .15682 L
.4688 .15711 L
Mistroke
.46887 .15723 L
.4689 .15728 L
.46893 .15731 L
.46896 .15734 L
.46898 .15735 L
.469 .15736 L
.46902 .15737 L
.46906 .15737 L
.46907 .15737 L
.46909 .15737 L
.4691 .15736 L
.46912 .15735 L
.46915 .15733 L
.46918 .15729 L
.46925 .15718 L
.46932 .15705 L
.46944 .15671 L
.46956 .15631 L
.4698 .15549 L
.46992 .15511 L
.46999 .15496 L
.47004 .15484 L
.47009 .15476 L
.47012 .15473 L
.47014 .1547 L
.47017 .15468 L
.4702 .15467 L
.47023 .15466 L
.47025 .15466 L
.47028 .15467 L
.47031 .15469 L
.47034 .15471 L
.47037 .15475 L
.47043 .15483 L
.47049 .15495 L
.47075 .15574 L
.47099 .15663 L
.4711 .15697 L
.47122 .15725 L
.47128 .15735 L
.47131 .15739 L
.47134 .15742 L
.47137 .15744 L
.4714 .15746 L
.47143 .15746 L
.47146 .15746 L
.47149 .15744 L
.47152 .15742 L
.47154 .1574 L
.47157 .15736 L
Mistroke
.47163 .15726 L
.47169 .15713 L
.47191 .15647 L
.47216 .15552 L
.47228 .15511 L
.47234 .15496 L
.47239 .15482 L
.47245 .15471 L
.47248 .15467 L
.47251 .15463 L
.47253 .1546 L
.47256 .15459 L
.47258 .15457 L
.47261 .15457 L
.47264 .15457 L
.47267 .15458 L
.47269 .15459 L
.4727 .1546 L
.47273 .15463 L
.47276 .15467 L
.47279 .15472 L
.47285 .15482 L
.47297 .15516 L
.47308 .15555 L
.47334 .15655 L
.47345 .15695 L
.47352 .15713 L
.47357 .15728 L
.47363 .1574 L
.47366 .15745 L
.47369 .15749 L
.47372 .15752 L
.47374 .15754 L
.47377 .15756 L
.47379 .15756 L
.47382 .15756 L
.47385 .15756 L
.47387 .15755 L
.47389 .15753 L
.47392 .1575 L
.47395 .15747 L
.47398 .15742 L
.47403 .15731 L
.47415 .15697 L
.47429 .15649 L
.47453 .1555 L
.47465 .15506 L
.47476 .15475 L
.47482 .15463 L
.47488 .15453 L
Mistroke
.47491 .15449 L
.47494 .15447 L
.47497 .15445 L
.47499 .15445 L
.475 .15445 L
.47502 .15445 L
.47504 .15446 L
.47507 .15448 L
.47509 .15449 L
.4751 .15451 L
.47514 .15456 L
.4752 .15467 L
.47527 .15483 L
.47574 .15668 L
.47587 .15715 L
.47594 .15736 L
.47601 .15751 L
.47604 .15757 L
.47607 .15762 L
.47609 .15764 L
.47611 .15766 L
.47613 .15767 L
.47614 .15768 L
.47617 .15769 L
.4762 .15769 L
.47623 .15768 L
.47626 .15767 L
.47629 .15764 L
.47632 .1576 L
.47638 .1575 L
.47644 .15736 L
.4765 .15717 L
.47672 .15631 L
.47684 .15576 L
.47698 .15519 L
.4771 .15476 L
.47716 .15459 L
.47722 .15447 L
.47725 .15442 L
.47728 .15437 L
.47731 .15434 L
.47733 .15432 L
.47734 .15431 L
.47737 .15431 L
.4774 .15431 L
.47743 .15432 L
.47746 .15434 L
.47747 .15436 L
.47749 .15438 L
.47752 .15443 L
Mistroke
.47759 .15456 L
.47766 .15475 L
.47772 .15498 L
.47795 .15596 L
.47809 .15657 L
.47821 .15708 L
.47832 .15747 L
.47838 .15764 L
.47844 .15775 L
.47847 .1578 L
.4785 .15783 L
.47852 .15784 L
.47854 .15785 L
.47855 .15785 L
.47857 .15785 L
.4786 .15785 L
.47863 .15783 L
.47864 .15782 L
.47866 .1578 L
.47869 .15776 L
.47875 .15766 L
.4788 .15752 L
.47892 .15712 L
.47914 .15616 L
.47936 .15509 L
.47947 .15465 L
.47954 .15444 L
.4796 .1543 L
.47963 .15424 L
.47966 .15419 L
.47968 .15417 L
.4797 .15415 L
.47972 .15414 L
.47973 .15413 L
.47976 .15413 L
.47979 .15413 L
.47983 .15415 L
.47984 .15417 L
.47986 .15419 L
.47992 .15428 L
.47995 .15435 L
.47998 .15443 L
.4801 .15484 L
.48055 .15704 L
.48067 .15754 L
.48074 .15774 L
.48077 .15783 L
.4808 .15791 L
.48083 .15796 L
.48086 .158 L
Mistroke
.48088 .15802 L
.48089 .15804 L
.48093 .15805 L
.48095 .15806 L
.48098 .15805 L
.48101 .15803 L
.48104 .15801 L
.48107 .15796 L
.4811 .1579 L
.48117 .15774 L
.48123 .15754 L
.48129 .15732 L
.48155 .15597 L
.48178 .15478 L
.48185 .15451 L
.48192 .15427 L
.48197 .15411 L
.48201 .15403 L
.48204 .15398 L
.48205 .15396 L
.48207 .15394 L
.4821 .15391 L
.48212 .1539 L
.48213 .1539 L
.48215 .1539 L
.48217 .1539 L
.4822 .15392 L
.48221 .15393 L
.48223 .15395 L
.48226 .15399 L
.48229 .15405 L
.48235 .1542 L
.4824 .15438 L
.48253 .15492 L
.48274 .1561 L
.48297 .15738 L
.48304 .15766 L
.4831 .15792 L
.48316 .15809 L
.48319 .15817 L
.48322 .15823 L
.48325 .15827 L
.48328 .1583 L
.48331 .15832 L
.48333 .15832 L
.48335 .15832 L
.48338 .15831 L
.4834 .15828 L
.48343 .15824 L
.48346 .15819 L
Mistroke
.48352 .15806 L
.48357 .15787 L
.48368 .15744 L
.48391 .15611 L
.48414 .15475 L
.4842 .15442 L
.48426 .15414 L
.48432 .15394 L
.48435 .15384 L
.48438 .15377 L
.48441 .15371 L
.48444 .15365 L
.48446 .15362 L
.48449 .1536 L
.48451 .15359 L
.48454 .15359 L
.48456 .1536 L
.48459 .15363 L
.48462 .15367 L
.48465 .15372 L
.4847 .15385 L
.48476 .15404 L
.48482 .1543 L
.48529 .15719 L
.48541 .1579 L
.48548 .15821 L
.48552 .15834 L
.48555 .15844 L
.48558 .15853 L
.48561 .15859 L
.48565 .15864 L
.48566 .15866 L
.48568 .15867 L
.48571 .15868 L
.48574 .15867 L
.48577 .15865 L
.4858 .15861 L
.48583 .15856 L
.48586 .15849 L
.48591 .15832 L
.48597 .15809 L
.48603 .15779 L
.48625 .15639 L
.48649 .15473 L
.48661 .15398 L
.48668 .15365 L
.48671 .15352 L
.48674 .15342 L
.48677 .15333 L
.4868 .15327 L
Mistroke
.48683 .15322 L
.48685 .1532 L
.48686 .15318 L
.4869 .15317 L
.48692 .15317 L
.48696 .15319 L
.48697 .15321 L
.48699 .15324 L
.48702 .1533 L
.48705 .15337 L
.48711 .15358 L
.48717 .15383 L
.48722 .15412 L
.48746 .15584 L
.4876 .1569 L
.48772 .15782 L
.48784 .15853 L
.48791 .15883 L
.48794 .15894 L
.48797 .15902 L
.488 .15909 L
.48803 .15913 L
.48805 .15917 L
.48808 .15918 L
.48811 .15918 L
.48814 .15916 L
.48817 .15912 L
.4882 .15906 L
.48823 .159 L
.48825 .15891 L
.4883 .15872 L
.48841 .15811 L
.48853 .15725 L
.48864 .15635 L
.48886 .15447 L
.48898 .15359 L
.48904 .15324 L
.4891 .15297 L
.48913 .15285 L
.48916 .15274 L
.4892 .15265 L
.48922 .15262 L
.48923 .15259 L
.48926 .15256 L
.48929 .15256 L
.48931 .15256 L
.48932 .15257 L
.48936 .15262 L
.48939 .15268 L
.48942 .15276 L
Mistroke
.48948 .15301 L
.48954 .15332 L
.4896 .15368 L
.49004 .15767 L
.49016 .15868 L
.49023 .15913 L
.49029 .15948 L
.49035 .15972 L
.49038 .15982 L
.49041 .15989 L
.49044 .15992 L
.49047 .15994 L
.4905 .15994 L
.49052 .15991 L
.49055 .15986 L
.49057 .15982 L
.49059 .15978 L
.49064 .15956 L
.4907 .15928 L
.49075 .15891 L
.49089 .15782 L
.491 .15661 L
.49113 .1552 L
.49127 .15378 L
.49133 .15322 L
.49139 .15268 L
.49145 .15227 L
.49151 .15196 L
.49154 .15185 L
.49157 .15175 L
.4916 .15167 L
.49163 .15162 L
.49165 .1516 L
.49168 .15159 L
.4917 .15161 L
.49173 .15166 L
.49176 .15173 L
.49179 .15184 L
.49183 .15198 L
.49186 .15215 L
.49197 .153 L
.4921 .15429 L
.49221 .15567 L
.49234 .15725 L
.49247 .15884 L
.49259 .15997 L
.49265 .16048 L
.49268 .16068 L
.49271 .16084 L
.49274 .16096 L
Mistroke
.49277 .16107 L
.49279 .16114 L
.49282 .16118 L
.49285 .16121 L
.49287 .1612 L
.4929 .16117 L
.49293 .1611 L
.49296 .16101 L
.49299 .16087 L
.49306 .16048 L
.49312 .15999 L
.49317 .15945 L
.49343 .15601 L
.49355 .15421 L
.49368 .1524 L
.49374 .15168 L
.49381 .15103 L
.49386 .15056 L
.49389 .15037 L
.49392 .15019 L
.49395 .15006 L
.49398 .14996 L
.49401 .1499 L
.49403 .14987 L
.49406 .14986 L
.49408 .14989 L
.49411 .14994 L
.49414 .15003 L
.49416 .15015 L
.49419 .15033 L
.49425 .15073 L
.49431 .15129 L
.49437 .15205 L
.49463 .15627 L
.49476 .1586 L
.49488 .16059 L
.49498 .16209 L
.49504 .16269 L
.49507 .16298 L
.4951 .1632 L
.49513 .16339 L
.49516 .16355 L
.49519 .16365 L
.49521 .16369 L
.49522 .16371 L
.49525 .16371 L
.49528 .16367 L
.49531 .16358 L
.49534 .16344 L
.49537 .16326 L
Mistroke
.49539 .16306 L
.49545 .16247 L
.49551 .16172 L
.49557 .16075 L
.49579 .15634 L
.49604 .15056 L
.49616 .14824 L
.49622 .14743 L
.49627 .14673 L
.4963 .14643 L
.49633 .14621 L
.49636 .14606 L
.49639 .14595 L
.49642 .1459 L
.49645 .14592 L
.49648 .146 L
.4965 .14608 L
.49652 .14618 L
.49655 .14644 L
.49658 .14675 L
.49665 .14773 L
.49672 .14888 L
.49678 .15036 L
.49701 .15717 L
.49714 .16118 L
.49726 .16515 L
.49738 .16813 L
.49745 .16941 L
.49748 .1699 L
.49751 .17028 L
.49754 .17055 L
.49757 .17076 L
.49759 .17088 L
.49762 .17091 L
.49764 .17088 L
.49767 .17076 L
.4977 .17052 L
.49773 .1702 L
.49776 .16982 L
.49779 .1693 L
.49784 .16811 L
.49794 .16501 L
.49806 .16014 L
.49817 .15468 L
.49843 .14072 L
.49855 .13473 L
.49861 .13258 L
.49867 .13069 L
.49869 .13004 L
.49872 .12947 L
Mistroke
.49875 .12907 L
.49877 .12881 L
.4988 .12867 L
.49883 .12869 L
.49886 .12888 L
.49888 .12923 L
.49891 .12977 L
.49893 .13045 L
.49897 .13149 L
.49899 .13266 L
.49905 .13572 L
.49911 .14006 L
.49923 .15101 L
.49935 .16692 L
.49957 .20594 L
.50007 .32618 L
.50031 .38666 L
.50044 .41472 L
.50058 .44016 L
.5007 .45828 L
.50076 .46619 L
.50083 .47334 L
.5009 .4787 L
.50095 .4826 L
.50101 .48558 L
.50107 .48758 L
.50109 .4883 L
.50112 .48886 L
.50115 .4892 L
.50118 .48936 L
.5012 .48936 L
.50123 .48917 L
.50125 .48901 L
.50127 .48877 L
.5013 .48823 L
.50133 .48748 L
.50136 .48648 L
.50143 .48423 L
.50154 .47887 L
.50177 .4664 L
.50199 .45576 L
.5021 .45168 L
.50216 .44993 L
.50221 .44869 L
.50225 .44815 L
.50227 .44775 L
.50231 .44742 L
.50233 .44729 L
.50234 .4472 L
.50237 .44712 L
Mistroke
.50239 .44712 L
.5024 .44715 L
.50243 .44726 L
.50246 .44748 L
.50249 .44779 L
.50252 .44816 L
.50259 .44926 L
.5027 .452 L
.50297 .46029 L
.50319 .46699 L
.5033 .46953 L
.50337 .47062 L
.50343 .47138 L
.50346 .47168 L
.50348 .47181 L
.50349 .47191 L
.50352 .47205 L
.50355 .47212 L
.50357 .47214 L
.50359 .47213 L
.50362 .47206 L
.50364 .47199 L
.50365 .47191 L
.50369 .47167 L
.50372 .47141 L
.50374 .47113 L
.5038 .47033 L
.50393 .46816 L
.50414 .46331 L
.50437 .45826 L
.50449 .45625 L
.50456 .4554 L
.50459 .45509 L
.50463 .45482 L
.50465 .45463 L
.50469 .45448 L
.50471 .45438 L
.50474 .45433 L
.50477 .45432 L
.5048 .45435 L
.50481 .45439 L
.50483 .45444 L
.50486 .45457 L
.50489 .45476 L
.50492 .45498 L
.50499 .45563 L
.50513 .45747 L
.50537 .46176 L
.5056 .46558 L
.50566 .4664 L
Mistroke
.50573 .46712 L
.50576 .46741 L
.5058 .46764 L
.50582 .46781 L
.50585 .46796 L
.50588 .46807 L
.5059 .46811 L
.50592 .46814 L
.50594 .46817 L
.50597 .46816 L
.50599 .46814 L
.50601 .46811 L
.50602 .46806 L
.50604 .46801 L
.50607 .46788 L
.5061 .4677 L
.50616 .46728 L
.50622 .46678 L
.50634 .46532 L
.50655 .46225 L
.50678 .45905 L
.50684 .45841 L
.50691 .45782 L
.50697 .45739 L
.50702 .4571 L
.50705 .45697 L
.50708 .45689 L
.5071 .45686 L
.50711 .45684 L
.50713 .45683 L
.50715 .45683 L
.50718 .45685 L
.50721 .4569 L
.50722 .45694 L
.50724 .45699 L
.50727 .45711 L
.50733 .45743 L
.50738 .4578 L
.5075 .45891 L
.50771 .46146 L
.50794 .46417 L
.50805 .46525 L
.50812 .46573 L
.50818 .46607 L
.50821 .46621 L
.50824 .46632 L
.50827 .46638 L
.5083 .46643 L
.50832 .46644 L
.50834 .46644 L
Mistroke
.50836 .46643 L
.50837 .46642 L
.5084 .46636 L
.50842 .46632 L
.50844 .46627 L
.50849 .46605 L
.50856 .46571 L
.50868 .46476 L
.50894 .46203 L
.50907 .46065 L
.50919 .45955 L
.5093 .45878 L
.50935 .45849 L
.50938 .45836 L
.50941 .45826 L
.50944 .45818 L
.50947 .45813 L
.5095 .4581 L
.50952 .45809 L
.50954 .45809 L
.50956 .45811 L
.50959 .45816 L
.50962 .45823 L
.50965 .45832 L
.50971 .45854 L
.50977 .45887 L
.50989 .45974 L
.51011 .46173 L
.51024 .46299 L
.51036 .46404 L
.51047 .46478 L
.51054 .46509 L
.51056 .4652 L
.51059 .4653 L
.51062 .46538 L
.51065 .46543 L
.51068 .46546 L
.5107 .46548 L
.51073 .46547 L
.51076 .46545 L
.51079 .46541 L
.51081 .46538 L
.51082 .46534 L
.51088 .46515 L
.51095 .46485 L
.51106 .46412 L
.5113 .46215 L
.51143 .46106 L
.51157 .46004 L
.51163 .45963 L
Mistroke
.5117 .45932 L
.51175 .4591 L
.51179 .45901 L
.51182 .45894 L
.51184 .45889 L
.51187 .45886 L
.5119 .45885 L
.51193 .45886 L
.51196 .45888 L
.51197 .4589 L
.51199 .45893 L
.51202 .45899 L
.51205 .45907 L
.51211 .45931 L
.51217 .45961 L
.51229 .46032 L
.51255 .46233 L
.51267 .46323 L
.51279 .46395 L
.51285 .46427 L
.5129 .46451 L
.51297 .4647 L
.51298 .46474 L
.513 .46478 L
.51302 .46481 L
.51303 .46483 L
.51306 .46486 L
.51309 .46487 L
.51312 .46486 L
.51315 .46484 L
.51317 .46481 L
.5132 .46475 L
.51323 .46467 L
.51326 .46459 L
.51337 .46417 L
.51348 .46355 L
.51372 .46183 L
.51385 .46093 L
.51399 .46013 L
.51405 .45987 L
.51411 .45964 L
.51414 .45954 L
.51418 .45946 L
.51419 .45943 L
.51421 .45941 L
.51424 .45937 L
.51427 .45936 L
.5143 .45936 L
.51431 .45936 L
.51433 .45937 L
Mistroke
.51436 .45941 L
.51439 .45945 L
.51442 .45952 L
.51447 .45967 L
.51453 .4599 L
.51459 .46016 L
.5147 .46076 L
.51494 .46236 L
.51505 .46301 L
.51516 .46361 L
.51521 .46387 L
.51527 .4641 L
.5153 .46419 L
.51533 .46427 L
.51536 .46433 L
.51539 .46437 L
.51542 .46441 L
.51544 .46444 L
.51547 .46444 L
.51549 .46444 L
.5155 .46444 L
.51553 .46442 L
.51556 .46439 L
.51559 .46434 L
.51562 .46428 L
.51568 .46411 L
.51574 .4639 L
.51587 .46327 L
.51613 .46169 L
.51626 .46094 L
.51637 .46037 L
.51643 .46015 L
.51649 .45996 L
.51651 .45989 L
.51654 .45983 L
.51657 .45978 L
.51659 .45975 L
.51662 .45973 L
.51665 .45971 L
.51668 .45971 L
.51671 .45972 L
.51674 .45975 L
.51677 .45979 L
.5168 .45984 L
.51683 .45992 L
.51689 .46009 L
.51695 .46032 L
.51707 .46086 L
.51733 .46234 L
.51744 .46295 L
Mistroke
.51756 .4635 L
.51763 .46375 L
.51769 .46393 L
.51772 .464 L
.51775 .46406 L
.51778 .4641 L
.51781 .46412 L
.51784 .46414 L
.51787 .46414 L
.5179 .46412 L
.51793 .4641 L
.51796 .46406 L
.51799 .464 L
.51806 .46385 L
.51812 .46364 L
.51819 .46336 L
.51832 .46276 L
.51854 .46155 L
.51866 .46095 L
.51872 .46067 L
.51878 .46045 L
.51884 .46027 L
.51889 .46014 L
.51892 .46009 L
.51895 .46004 L
.51897 .46002 L
.51898 .46 L
.51901 .45998 L
.51904 .45998 L
.51906 .45998 L
.51909 .45999 L
.51912 .46001 L
.51914 .46004 L
.51917 .46008 L
.51922 .46019 L
.51929 .46036 L
.51934 .46056 L
.51945 .46102 L
.5197 .46226 L
.51991 .46323 L
.51997 .46344 L
.52003 .46362 L
.52006 .4637 L
.52009 .46376 L
.52011 .46381 L
.52014 .46385 L
.52017 .46388 L
.5202 .4639 L
.52023 .46391 L
.52025 .46391 L
Mistroke
.52028 .46389 L
.52031 .46387 L
.52034 .46383 L
.52038 .46378 L
.52044 .46365 L
.52049 .46349 L
.52062 .46301 L
.52084 .46201 L
.52107 .46095 L
.52113 .46071 L
.5212 .4605 L
.52126 .46036 L
.52129 .4603 L
.52132 .46025 L
.52135 .46022 L
.52138 .46019 L
.52141 .46018 L
.52143 .46018 L
.52144 .46018 L
.52147 .46019 L
.5215 .46021 L
.52153 .46025 L
.52156 .46029 L
.52161 .46039 L
.52167 .46054 L
.52177 .46088 L
.52201 .46189 L
.52223 .4629 L
.5223 .46315 L
.52236 .46334 L
.52242 .46349 L
.52245 .46356 L
.52248 .46361 L
.52251 .46365 L
.52253 .46368 L
.52256 .46371 L
.52259 .46372 L
.52261 .46373 L
.52264 .46372 L
.52267 .46371 L
.52269 .4637 L
.52272 .46367 L
.52275 .46363 L
.5228 .46353 L
.52286 .46339 L
.52292 .46321 L
.52339 .46127 L
.52352 .46081 L
.52359 .46061 L
.52362 .46053 L
Mistroke
.52366 .46047 L
.52369 .46043 L
.52372 .46039 L
.52373 .46037 L
.52375 .46036 L
.52377 .46035 L
.52378 .46034 L
.52381 .46034 L
.52383 .46034 L
.52385 .46035 L
.52388 .46037 L
.5239 .46039 L
.52394 .46043 L
.52396 .46048 L
.52403 .46061 L
.52414 .46094 L
.52436 .4618 L
.52449 .46232 L
.52462 .46283 L
.52468 .46305 L
.52474 .46322 L
.52479 .46336 L
.52485 .46347 L
.52488 .46351 L
.52491 .46354 L
.52494 .46356 L
.52496 .46358 L
.52499 .46358 L
.52502 .46358 L
.52504 .46357 L
.52507 .46356 L
.5251 .46353 L
.52513 .4635 L
.52519 .46339 L
.52525 .46326 L
.5253 .4631 L
.52554 .46223 L
.52568 .46169 L
.5258 .46122 L
.52592 .46085 L
.52597 .46072 L
.52603 .46061 L
.52606 .46056 L
.52609 .46053 L
.5261 .46051 L
.52612 .4605 L
.52615 .46048 L
.52616 .46047 L
.52618 .46047 L
.5262 .46047 L
Mistroke
.52621 .46047 L
.52625 .46048 L
.52626 .4605 L
.52628 .46051 L
.52631 .46054 L
.52634 .46058 L
.52639 .46067 L
.52649 .46092 L
.52661 .46131 L
.52672 .46172 L
.52694 .46256 L
.52705 .46293 L
.52711 .46311 L
.52717 .46324 L
.52723 .46335 L
.52727 .4634 L
.52728 .46342 L
.5273 .46344 L
.52732 .46345 L
.52733 .46346 L
.52737 .46347 L
.52739 .46347 L
.52742 .46346 L
.52745 .46344 L
.52748 .46342 L
.52751 .46338 L
.52754 .46334 L
.5276 .46323 L
.52766 .46308 L
.52791 .46226 L
.52814 .46139 L
.52825 .46107 L
.52835 .4608 L
.52841 .4607 L
.52844 .46066 L
.52847 .46062 L
.5285 .4606 L
.52852 .46058 L
.52855 .46058 L
.52858 .46057 L
.52861 .46058 L
.52864 .4606 L
.52867 .46062 L
.5287 .46065 L
.52875 .46073 L
.52881 .46084 L
.52894 .46118 L
.52905 .46157 L
.52931 .46251 L
.52944 .46291 L
Mistroke
.5295 .46305 L
.52956 .46318 L
.52959 .46323 L
.52962 .46327 L
.52964 .46331 L
.52967 .46333 L
.52969 .46335 L
.52972 .46336 L
.52975 .46337 L
.52978 .46337 L
.52981 .46336 L
.52983 .46335 L
.52986 .46332 L
.5299 .46329 L
.52996 .46319 L
.53001 .46309 L
.53013 .46276 L
.53027 .46233 L
.53051 .46148 L
.53062 .46115 L
.53068 .46099 L
.53074 .46087 L
.53077 .46081 L
.53081 .46076 L
.53084 .46072 L
.53085 .46071 L
.53087 .46069 L
.5309 .46067 L
.53091 .46067 L
.53093 .46066 L
.53096 .46066 L
.53099 .46067 L
.53102 .46068 L
.53105 .4607 L
.53108 .46073 L
.53111 .46077 L
.53117 .46088 L
.53124 .46101 L
.5315 .4618 L
.53173 .46259 L
.53185 .46292 L
.53192 .46307 L
.53198 .46317 L
.532 .46321 L
.53203 .46324 L
.53206 .46326 L
.53209 .46328 L
.53212 .46329 L
.53215 .46329 L
.53218 .46329 L
Mistroke
.53221 .46328 L
.53223 .46326 L
.53226 .46323 L
.53231 .46317 L
.53236 .46308 L
.53242 .46296 L
.53268 .46219 L
.53293 .46138 L
.53304 .4611 L
.5331 .46097 L
.53315 .46087 L
.53321 .4608 L
.53324 .46077 L
.53326 .46075 L
.53328 .46075 L
.53331 .46074 L
.53334 .46073 L
.53337 .46074 L
.53339 .46075 L
.53343 .46077 L
.53345 .46079 L
.53352 .46088 L
.53357 .46098 L
.53363 .4611 L
.53385 .46172 L
.53408 .46248 L
.53421 .46283 L
.53427 .46297 L
.53433 .46307 L
.53439 .46315 L
.53442 .46318 L
.53443 .46319 L
.53445 .4632 L
.53447 .46321 L
.53448 .46322 L
.5345 .46323 L
.53452 .46323 L
.53453 .46323 L
.53455 .46323 L
.53458 .46322 L
.53461 .4632 L
.53464 .46317 L
.53467 .46314 L
.5347 .4631 L
.5348 .46291 L
.53491 .46266 L
.53502 .46233 L
.53524 .46161 L
.53537 .46126 L
.53543 .46111 L
Mistroke
.53549 .461 L
.53554 .46092 L
.5356 .46085 L
.53563 .46082 L
.53566 .46081 L
.53568 .4608 L
.53571 .46079 L
.53574 .4608 L
.53577 .46081 L
.53579 .46082 L
.5358 .46083 L
.53584 .46086 L
.53587 .4609 L
.53591 .46095 L
.53597 .46106 L
.5361 .46136 L
.53621 .46169 L
.53643 .46236 L
.53655 .46269 L
.53666 .46294 L
.53673 .46305 L
.53676 .46309 L
.5368 .46313 L
.53683 .46315 L
.53686 .46316 L
.53687 .46317 L
.53689 .46317 L
.53692 .46317 L
.53695 .46317 L
.53698 .46315 L
.537 .46314 L
.53701 .46313 L
.53704 .46309 L
.5371 .46301 L
.53716 .46292 L
.5374 .46231 L
.53766 .46154 L
.53776 .46126 L
.53787 .46103 L
.53791 .46098 L
.53794 .46094 L
.53797 .4609 L
.538 .46088 L
.53803 .46086 L
.53805 .46085 L
.53807 .46084 L
.53809 .46084 L
.53812 .46084 L
.53814 .46085 L
.53817 .46086 L
Mistroke
.5382 .46088 L
.53823 .46091 L
.53829 .46099 L
.53835 .46108 L
.53845 .46132 L
.53856 .4616 L
.53879 .46228 L
.53891 .46261 L
.53904 .46289 L
.5391 .463 L
.53913 .46304 L
.53917 .46307 L
.5392 .4631 L
.53922 .46311 L
.53925 .46312 L
.53927 .46313 L
.53929 .46313 L
.53932 .46312 L
.53934 .46311 L
.53937 .4631 L
.5394 .46307 L
.53946 .46302 L
.53951 .46293 L
.53962 .46271 L
.53974 .46241 L
.53996 .46178 L
.54007 .46148 L
.54019 .4612 L
.54025 .46107 L
.54032 .46098 L
.54035 .46095 L
.54038 .46092 L
.54041 .4609 L
.54044 .46089 L
.54047 .46088 L
.5405 .46089 L
.54053 .46089 L
.54055 .46091 L
.54059 .46093 L
.54062 .46096 L
.54068 .46105 L
.54075 .46116 L
.54082 .46131 L
.54094 .46163 L
.54117 .46227 L
.54129 .46258 L
.54135 .46273 L
.54141 .46285 L
.54147 .46294 L
.54152 .46301 L
Mistroke
.54155 .46304 L
.54158 .46306 L
.54161 .46308 L
.54162 .46308 L
.54164 .46309 L
.54167 .46309 L
.54169 .46309 L
.54171 .46308 L
.54174 .46307 L
.54177 .46305 L
.5418 .46302 L
.54185 .46296 L
.54191 .46287 L
.54197 .46276 L
.54208 .4625 L
.54233 .46182 L
.54254 .46128 L
.54259 .46117 L
.54266 .46107 L
.54269 .46103 L
.54271 .46099 L
.54274 .46097 L
.54277 .46095 L
.5428 .46093 L
.54283 .46092 L
.54285 .46092 L
.54288 .46092 L
.54291 .46093 L
.54294 .46094 L
.54297 .46097 L
.543 .461 L
.54306 .46108 L
.54312 .46117 L
.54325 .46145 L
.54346 .46202 L
.54369 .46263 L
.54376 .46276 L
.54383 .46288 L
.54388 .46296 L
.54392 .46299 L
.54395 .46302 L
.54398 .46304 L
.54401 .46305 L
.54403 .46306 L
.54406 .46306 L
.54409 .46305 L
.54411 .46304 L
.54413 .46303 L
.54416 .46301 L
.54419 .46299 L
Mistroke
.54424 .46292 L
.5443 .46283 L
.5444 .46263 L
.54463 .46203 L
.54486 .46143 L
.54493 .46128 L
.54499 .46117 L
.54505 .46108 L
.54508 .46104 L
.54511 .46101 L
.54513 .46099 L
.54516 .46097 L
.54519 .46096 L
.54522 .46095 L
.54524 .46095 L
.54527 .46095 L
.54529 .46096 L
.54532 .46097 L
.54535 .46099 L
.54538 .46102 L
.54543 .46108 L
.54548 .46116 L
.54555 .46128 L
.54602 .46247 L
.54614 .46275 L
.54622 .46287 L
.54625 .46292 L
.54628 .46295 L
.54631 .46298 L
.54634 .463 L
.54636 .46301 L
.54638 .46302 L
.54639 .46303 L
.54641 .46303 L
.54644 .46303 L
.54646 .46303 L
.54647 .46302 L
.5465 .46301 L
.54653 .46299 L
.54656 .46297 L
.54659 .46294 L
.54665 .46285 L
.54677 .46264 L
.54699 .46209 L
.54711 .46176 L
.54724 .46144 L
.54731 .4613 L
.54737 .46119 L
.54742 .46111 L
.54748 .46104 L
Mistroke
.54751 .46101 L
.54754 .461 L
.54756 .46098 L
.54759 .46097 L
.54762 .46097 L
.54764 .46097 L
.54767 .46098 L
.54769 .46099 L
.54773 .46101 L
.54775 .46104 L
.54782 .46111 L
.54787 .46119 L
.54793 .4613 L
.54817 .46187 L
.5483 .46222 L
.54842 .46253 L
.54853 .46275 L
.54859 .46285 L
.54865 .46292 L
.54869 .46296 L
.54872 .46298 L
.54873 .46299 L
.54875 .463 L
.54877 .463 L
.54878 .46301 L
.54881 .46301 L
.54884 .46301 L
.54887 .463 L
.54889 .46299 L
.5489 .46298 L
.54896 .46293 L
.54901 .46287 L
.54913 .46266 L
.54935 .46215 L
.54957 .46158 L
.54969 .46131 L
.54975 .4612 L
.5498 .46112 L
.54987 .46105 L
.5499 .46102 L
.54992 .46101 L
.54994 .461 L
.54997 .46099 L
.54999 .46099 L
.55 .46099 L
.55003 .46099 L
.55006 .461 L
.55009 .46102 L
.55012 .46104 L
.55018 .4611 L
Mistroke
.55024 .46118 L
.5503 .46129 L
.55056 .4619 L
.55069 .46224 L
.55081 .46253 L
.55092 .46276 L
.55097 .46284 L
.55103 .4629 L
.55106 .46294 L
.55109 .46296 L
.55112 .46297 L
.55115 .46299 L
.55118 .46299 L
.5512 .46299 L
.55124 .46299 L
.55125 .46298 L
.55127 .46297 L
.5513 .46295 L
.55133 .46293 L
.55139 .46286 L
.55145 .46278 L
.5515 .46268 L
.55175 .4621 L
.55196 .46155 L
.55209 .46129 L
.55215 .46119 L
.5522 .46111 L
.55223 .46108 L
.55226 .46105 L
.55229 .46103 L
.55232 .46102 L
.55234 .46101 L
.55237 .461 L
.55239 .461 L
.55241 .46101 L
.55244 .46102 L
.55245 .46102 L
.55247 .46103 L
.5525 .46106 L
.55253 .46109 L
.55257 .46112 L
.55269 .46131 L
.55281 .46157 L
.55292 .46185 L
.55313 .46239 L
.55325 .46265 L
.55337 .46284 L
.55342 .46291 L
.55346 .46294 L
.55348 .46296 L
Mistroke
.5535 .46296 L
.55352 .46297 L
.55353 .46298 L
.55355 .46298 L
.55358 .46298 L
.5536 .46298 L
.55361 .46298 L
.55364 .46297 L
.55367 .46295 L
.5537 .46293 L
.55373 .4629 L
.55383 .46276 L
.55389 .46266 L
.55394 .46255 L
.55406 .46228 L
.55428 .4617 L
.55441 .46142 L
.55452 .46121 L
.55458 .46113 L
.55461 .46109 L
.55464 .46106 L
.55466 .46105 L
.55468 .46104 L
.5547 .46103 L
.55472 .46102 L
.55475 .46101 L
.55476 .46101 L
.55478 .46102 L
.55481 .46102 L
.55484 .46104 L
.55487 .46105 L
.5549 .46107 L
.55496 .46115 L
.55502 .46123 L
.55547 .46228 L
.55559 .46256 L
.55566 .4627 L
.55572 .4628 L
.55578 .46287 L
.5558 .4629 L
.55583 .46293 L
.55585 .46294 L
.55587 .46295 L
.5559 .46296 L
.55593 .46297 L
.55596 .46297 L
.55597 .46297 L
.55599 .46297 L
.55601 .46296 L
.55602 .46296 L
Mistroke
.55606 .46293 L
.5561 .46291 L
.55616 .46283 L
.55623 .46273 L
.55635 .46248 L
.55647 .4622 L
.55672 .46157 L
.55683 .46133 L
.55689 .46123 L
.55695 .46114 L
.55698 .46111 L
.55701 .46108 L
.55704 .46105 L
.55707 .46104 L
.55709 .46103 L
.55712 .46102 L
.55715 .46102 L
.55718 .46102 L
.55721 .46103 L
.55723 .46105 L
.55726 .46107 L
.5573 .4611 L
.55735 .46116 L
.55741 .46126 L
.55754 .4615 L
.55767 .46182 L
.55791 .46242 L
.55803 .46267 L
.55809 .46278 L
.55815 .46286 L
.55819 .4629 L
.55823 .46293 L
.55824 .46294 L
.55826 .46295 L
.55829 .46296 L
.55832 .46297 L
.55835 .46297 L
.55837 .46297 L
.55839 .46296 L
.5584 .46295 L
.55842 .46294 L
.55845 .46293 L
.55848 .4629 L
.55854 .46283 L
.5586 .46274 L
.55865 .46265 L
.5589 .46206 L
.55902 .46176 L
.55915 .46145 L
.55921 .46133 L
Mistroke
.55927 .46122 L
.55933 .46114 L
.55939 .46108 L
.55942 .46106 L
.55945 .46104 L
.55948 .46103 L
.55949 .46103 L
.55951 .46102 L
.55954 .46102 L
.55956 .46103 L
.55959 .46104 L
.55962 .46105 L
.55965 .46107 L
.55967 .4611 L
.55972 .46115 L
.55983 .46133 L
.56006 .46186 L
.56031 .46246 L
.56041 .46267 L
.56046 .46276 L
.56051 .46284 L
.56054 .46287 L
.56058 .46291 L
.5606 .46293 L
.56063 .46295 L
.56066 .46296 L
.56069 .46297 L
.56071 .46297 L
.56074 .46297 L
.56077 .46296 L
.5608 .46294 L
.56083 .46292 L
.56086 .4629 L
.56091 .46284 L
.56096 .46277 L
.56109 .46253 L
.5612 .46226 L
.56147 .4616 L
.56158 .46136 L
.56164 .46125 L
.56171 .46115 L
.56174 .46111 L
.56177 .46108 L
.5618 .46106 L
.56182 .46104 L
.56185 .46103 L
.56187 .46102 L
.5619 .46102 L
.56193 .46102 L
.56196 .46103 L
Mistroke
.56199 .46104 L
.56202 .46107 L
.56205 .46109 L
.56211 .46116 L
.56217 .46125 L
.56229 .46149 L
.56243 .46181 L
.56267 .46242 L
.56279 .46267 L
.56285 .46278 L
.56292 .46287 L
.56295 .4629 L
.56298 .46293 L
.56302 .46295 L
.56304 .46296 L
.56305 .46297 L
.56307 .46297 L
.56309 .46297 L
.56312 .46297 L
.56315 .46296 L
.56317 .46296 L
.56318 .46295 L
.56321 .46293 L
.56324 .4629 L
.5633 .46283 L
.56342 .46264 L
.56367 .46206 L
.56378 .46176 L
.56391 .46146 L
.56397 .46134 L
.56403 .46123 L
.56408 .46115 L
.56414 .46109 L
.56417 .46106 L
.5642 .46104 L
.56423 .46102 L
.56426 .46102 L
.56428 .46101 L
.5643 .46101 L
.56433 .46102 L
.56435 .46103 L
.56437 .46104 L
.5644 .46106 L
.56443 .46108 L
.56446 .46112 L
.56452 .46119 L
.56464 .46141 L
.56489 .46201 L
.56501 .46232 L
.56512 .46257 L
Mistroke
.56522 .46276 L
.56527 .46284 L
.5653 .46288 L
.56533 .46291 L
.56535 .46293 L
.56538 .46295 L
.56541 .46296 L
.56543 .46298 L
.56546 .46298 L
.56548 .46298 L
.5655 .46298 L
.56552 .46297 L
.56555 .46296 L
.56558 .46295 L
.56561 .46292 L
.56567 .46286 L
.56573 .46278 L
.56578 .46269 L
.56602 .46212 L
.56614 .4618 L
.56628 .46148 L
.56634 .46135 L
.56641 .46123 L
.56647 .46114 L
.56652 .46107 L
.56655 .46105 L
.56659 .46103 L
.5666 .46102 L
.56662 .46101 L
.56664 .46101 L
.56666 .461 L
.56667 .461 L
.56669 .46101 L
.56672 .46101 L
.56675 .46103 L
.56678 .46105 L
.56683 .4611 L
.56689 .46117 L
.56701 .46139 L
.56723 .46191 L
.56746 .46249 L
.56757 .46273 L
.56764 .46283 L
.56767 .46287 L
.5677 .46291 L
.56773 .46294 L
.56776 .46296 L
.56778 .46297 L
.56781 .46298 L
.56783 .46299 L
Mistroke
.56786 .46299 L
.56789 .46299 L
.56792 .46298 L
.56795 .46296 L
.56799 .46294 L
.56805 .46287 L
.56811 .46278 L
.56816 .46268 L
.56842 .46207 L
.56864 .46152 L
.56875 .46128 L
.56881 .46117 L
.56887 .4611 L
.5689 .46106 L
.56894 .46103 L
.56897 .46101 L
.56899 .461 L
.569 .461 L
.56904 .46099 L
.56906 .46099 L
.56909 .461 L
.56911 .461 L
.56913 .46101 L
.56916 .46103 L
.56919 .46106 L
.56925 .46113 L
.56931 .46122 L
.56937 .46133 L
.56961 .46192 L
.56985 .46252 L
.56995 .46273 L
.57001 .46283 L
.57006 .4629 L
.57011 .46296 L
.57014 .46298 L
.57016 .46299 L
.57018 .463 L
.57021 .46301 L
.57023 .46301 L
.57026 .46301 L
.57028 .463 L
.57031 .46299 L
.57034 .46297 L
.57037 .46295 L
.57039 .46293 L
.57045 .46285 L
.57051 .46275 L
.57076 .46219 L
.571 .46156 L
.57107 .46141 L
Mistroke
.57114 .46126 L
.5712 .46116 L
.57123 .46111 L
.57126 .46107 L
.57129 .46104 L
.57132 .46101 L
.57136 .46099 L
.57137 .46098 L
.57139 .46098 L
.57142 .46097 L
.57145 .46097 L
.57148 .46098 L
.5715 .46099 L
.57151 .461 L
.57154 .46102 L
.57157 .46104 L
.57163 .46111 L
.57168 .46119 L
.57174 .46129 L
.57218 .46241 L
.5723 .46268 L
.57241 .46287 L
.57247 .46295 L
.5725 .46298 L
.57253 .463 L
.57256 .46302 L
.57259 .46303 L
.57262 .46303 L
.57265 .46303 L
.57268 .46302 L
.57271 .463 L
.57274 .46298 L
.57276 .46296 L
.57281 .4629 L
.57286 .46282 L
.57298 .46259 L
.57309 .46232 L
.57332 .46171 L
.57344 .46141 L
.57355 .46118 L
.57361 .46108 L
.57368 .46101 L
.5737 .461 L
.57371 .46098 L
.57373 .46097 L
.57375 .46096 L
.57377 .46096 L
.57378 .46095 L
.57381 .46095 L
.57385 .46095 L
Mistroke
.57387 .46096 L
.57391 .46098 L
.57394 .46101 L
.57399 .46107 L
.57405 .46116 L
.57432 .46176 L
.57456 .46243 L
.57467 .46269 L
.57479 .46289 L
.57485 .46297 L
.57488 .463 L
.57491 .46303 L
.57494 .46304 L
.57497 .46305 L
.575 .46306 L
.57503 .46305 L
.57506 .46304 L
.57509 .46303 L
.57511 .46301 L
.57514 .46298 L
.5752 .46291 L
.57526 .46281 L
.57548 .46232 L
.57573 .46162 L
.57585 .46132 L
.57591 .46121 L
.57597 .4611 L
.57602 .46102 L
.57605 .46099 L
.57608 .46097 L
.57611 .46095 L
.57613 .46093 L
.57616 .46092 L
.57618 .46092 L
.57621 .46092 L
.57624 .46093 L
.57626 .46094 L
.57628 .46095 L
.57631 .46097 L
.57637 .46103 L
.57642 .46111 L
.57654 .46135 L
.57667 .46169 L
.57692 .46237 L
.57703 .46264 L
.57714 .46288 L
.57718 .46294 L
.57721 .46298 L
.57724 .46302 L
.57727 .46304 L
Mistroke
.5773 .46306 L
.57733 .46308 L
.57736 .46309 L
.57738 .46309 L
.57739 .46309 L
.57742 .46308 L
.57744 .46308 L
.57746 .46307 L
.57749 .46305 L
.57752 .46301 L
.57758 .46294 L
.57764 .46285 L
.57777 .46255 L
.5779 .46221 L
.57813 .46155 L
.57826 .46124 L
.57832 .46111 L
.57838 .46102 L
.57843 .46096 L
.57846 .46094 L
.57848 .46092 L
.57851 .4609 L
.57853 .46089 L
.57856 .46088 L
.57859 .46089 L
.57862 .46089 L
.57865 .46091 L
.57868 .46093 L
.57871 .46096 L
.57876 .46103 L
.57882 .46112 L
.57908 .46176 L
.57933 .46247 L
.57944 .46274 L
.57955 .46296 L
.57961 .46304 L
.57965 .46308 L
.57966 .46309 L
.57968 .4631 L
.57971 .46312 L
.57973 .46312 L
.57976 .46313 L
.57979 .46312 L
.57982 .46311 L
.57984 .4631 L
.57986 .46309 L
.57989 .46307 L
.57992 .46303 L
.57997 .46296 L
.58003 .46286 L
Mistroke
.58016 .46256 L
.58028 .46222 L
.58049 .46158 L
.58061 .46128 L
.58073 .46104 L
.58076 .46098 L
.5808 .46094 L
.58083 .4609 L
.58086 .46088 L
.58089 .46086 L
.58092 .46085 L
.58095 .46084 L
.58096 .46084 L
.58098 .46085 L
.58101 .46086 L
.58104 .46087 L
.58107 .46089 L
.58109 .46092 L
.58116 .46101 L
.58122 .46111 L
.58143 .46166 L
.58166 .46235 L
.58178 .46267 L
.58189 .46292 L
.58195 .46302 L
.58198 .46307 L
.58202 .46311 L
.58205 .46314 L
.58208 .46315 L
.5821 .46317 L
.58213 .46317 L
.58216 .46317 L
.58218 .46317 L
.58221 .46315 L
.58224 .46313 L
.58227 .46311 L
.58229 .46308 L
.58234 .46301 L
.5824 .46291 L
.58246 .46278 L
.58257 .46249 L
.58282 .46174 L
.58294 .46139 L
.58305 .46112 L
.5831 .46101 L
.58316 .46091 L
.58319 .46088 L
.58322 .46084 L
.58324 .46083 L
.58325 .46082 L
Mistroke
.58329 .4608 L
.5833 .4608 L
.58332 .46079 L
.58335 .46079 L
.58337 .4608 L
.58338 .4608 L
.5834 .46081 L
.58342 .46082 L
.58346 .46085 L
.58349 .46089 L
.58355 .46098 L
.58367 .46124 L
.58378 .46154 L
.58403 .46232 L
.58414 .46264 L
.58419 .46279 L
.58425 .46293 L
.58431 .46303 L
.58437 .46312 L
.58439 .46315 L
.58442 .46318 L
.58444 .4632 L
.58447 .46321 L
.5845 .46322 L
.58452 .46323 L
.58455 .46322 L
.58458 .46321 L
.58462 .46319 L
.58465 .46316 L
.58471 .46309 L
.58476 .46299 L
.58481 .46289 L
.58493 .46259 L
.58518 .46177 L
.58531 .46138 L
.58543 .46108 L
.58549 .46095 L
.58554 .46086 L
.58557 .46082 L
.5856 .46079 L
.58563 .46076 L
.58565 .46075 L
.58566 .46074 L
.58569 .46073 L
.58571 .46073 L
.58573 .46073 L
.58576 .46074 L
.58579 .46075 L
.5858 .46077 L
.58582 .46078 L
Mistroke
.58585 .46081 L
.58592 .46091 L
.58597 .46101 L
.58603 .46115 L
.58613 .46143 L
.58637 .46219 L
.58648 .46258 L
.58661 .46292 L
.58668 .46307 L
.58671 .46313 L
.58675 .46319 L
.58678 .46323 L
.58682 .46326 L
.58685 .46328 L
.58688 .46329 L
.58691 .46329 L
.58694 .46329 L
.58695 .46328 L
.58697 .46328 L
.587 .46326 L
.58703 .46323 L
.58706 .46319 L
.58711 .46311 L
.58717 .46299 L
.58723 .46284 L
.58736 .46246 L
.58761 .4616 L
.58774 .46121 L
.58779 .46107 L
.58785 .46093 L
.5879 .46083 L
.58795 .46075 L
.58798 .46072 L
.58801 .46069 L
.58804 .46068 L
.58806 .46066 L
.58809 .46066 L
.58812 .46066 L
.58815 .46067 L
.58817 .46069 L
.5882 .46072 L
.58824 .46075 L
.5883 .46084 L
.58835 .46096 L
.58841 .46111 L
.58852 .46143 L
.58877 .4623 L
.58891 .46275 L
.58898 .46294 L
.58904 .46309 L
Mistroke
.5891 .46321 L
.58915 .46329 L
.58918 .46332 L
.58921 .46335 L
.58924 .46336 L
.58926 .46337 L
.58928 .46337 L
.58931 .46337 L
.58934 .46336 L
.58936 .46334 L
.58939 .46332 L
.58942 .46328 L
.58945 .46324 L
.58951 .46313 L
.58962 .46288 L
.58973 .46252 L
.58999 .46158 L
.5901 .4612 L
.59016 .46103 L
.59023 .46087 L
.59029 .46074 L
.59035 .46066 L
.59037 .46063 L
.5904 .4606 L
.59043 .46058 L
.59046 .46058 L
.59048 .46057 L
.59051 .46058 L
.59054 .46059 L
.59057 .46062 L
.5906 .46065 L
.59064 .4607 L
.59069 .4608 L
.59082 .46112 L
.59093 .4615 L
.5912 .46248 L
.59131 .46286 L
.59137 .46303 L
.59143 .46318 L
.59148 .46329 L
.59151 .46334 L
.59154 .46339 L
.59157 .46342 L
.59159 .46344 L
.59162 .46346 L
.59164 .46347 L
.59167 .46347 L
.5917 .46346 L
.59172 .46345 L
.59174 .46344 L
Mistroke
.59177 .46342 L
.5918 .46338 L
.59183 .46334 L
.59188 .46324 L
.592 .46292 L
.59214 .46246 L
.59238 .46151 L
.5925 .46109 L
.59261 .46078 L
.59267 .46064 L
.5927 .46059 L
.59274 .46054 L
.59276 .46052 L
.59277 .46051 L
.5928 .46048 L
.59282 .46048 L
.59284 .46047 L
.59286 .46047 L
.59288 .46047 L
.5929 .46048 L
.59293 .4605 L
.59296 .46052 L
.59299 .46056 L
.59306 .46068 L
.59312 .46081 L
.59335 .46161 L
.59361 .46264 L
.59373 .46307 L
.59379 .46324 L
.59385 .46337 L
.5939 .46347 L
.59393 .4635 L
.59395 .46354 L
.59398 .46356 L
.59401 .46358 L
.59404 .46358 L
.59407 .46358 L
.5941 .46357 L
.59412 .46355 L
.59416 .46352 L
.59418 .46348 L
.59424 .46339 L
.59429 .46326 L
.59442 .46287 L
.59454 .46242 L
.59475 .46151 L
.59487 .46105 L
.59498 .4607 L
.59504 .46055 L
.59507 .46049 L
Mistroke
.59511 .46044 L
.59513 .4604 L
.59516 .46037 L
.59519 .46035 L
.59522 .46034 L
.59525 .46034 L
.59527 .46035 L
.5953 .46036 L
.59532 .46038 L
.59535 .46041 L
.59538 .46046 L
.59544 .46056 L
.5955 .46073 L
.59557 .46094 L
.5957 .46143 L
.59593 .46246 L
.59604 .46292 L
.59616 .46332 L
.59623 .4635 L
.59629 .46362 L
.59632 .46366 L
.59634 .46368 L
.59635 .46369 L
.59638 .46372 L
.59641 .46373 L
.59644 .46373 L
.59647 .46372 L
.5965 .46369 L
.59652 .46368 L
.59654 .46366 L
.5966 .46356 L
.59665 .46343 L
.59678 .46302 L
.59692 .46245 L
.59716 .46132 L
.59729 .4608 L
.59736 .46057 L
.59743 .4604 L
.59749 .46028 L
.59752 .46024 L
.59755 .46021 L
.59757 .4602 L
.59758 .46019 L
.5976 .46018 L
.59762 .46018 L
.59764 .46018 L
.59765 .46019 L
.59768 .46021 L
.59771 .46023 L
.59774 .46027 L
Mistroke
.59779 .46037 L
.59785 .46051 L
.59792 .46071 L
.59818 .46184 L
.59831 .46247 L
.59842 .46301 L
.59853 .46341 L
.59859 .46359 L
.59865 .46373 L
.59868 .46379 L
.59871 .46384 L
.59873 .46387 L
.59876 .46389 L
.59879 .46391 L
.59882 .46391 L
.59885 .46389 L
.59887 .46388 L
.59889 .46387 L
.59892 .46383 L
.59895 .46378 L
.59901 .46365 L
.59906 .46349 L
.59912 .4633 L
.59937 .46215 L
.59959 .46105 L
.5997 .46057 L
.59976 .46035 L
.59982 .46019 L
.59986 .46012 L
.59988 .46007 L
.59992 .46002 L
.59993 .46001 L
.59995 .45999 L
.59998 .45998 L
.60001 .45998 L
.60004 .45999 L
.60006 .46 L
.60007 .46001 L
.6001 .46005 L
.60013 .4601 L
.6002 .46024 L
.60025 .46041 L
.60031 .46063 L
.60076 .4629 L
.60087 .46343 L
.60098 .46383 L
.60104 .46398 L
.60108 .46405 L
.60109 .46407 L
.60111 .46409 L
Mistroke
.60114 .46412 L
.60117 .46413 L
.60119 .46414 L
.60123 .46413 L
.60125 .46411 L
.60128 .46408 L
.60131 .46404 L
.60134 .46398 L
.6014 .46382 L
.60146 .46363 L
.60167 .46264 L
.60189 .46136 L
.60201 .46071 L
.60212 .46021 L
.60218 .46001 L
.60225 .45985 L
.60228 .45979 L
.6023 .45976 L
.60232 .45974 L
.60233 .45973 L
.60235 .45972 L
.60238 .45971 L
.60241 .45972 L
.60243 .45973 L
.60245 .45975 L
.60248 .45979 L
.60251 .45984 L
.60256 .45997 L
.60262 .46017 L
.60288 .46147 L
.60313 .46298 L
.60324 .46356 L
.60335 .46405 L
.60338 .46416 L
.60342 .46424 L
.60345 .46432 L
.60348 .46437 L
.6035 .46441 L
.60353 .46443 L
.60356 .46444 L
.60359 .46444 L
.60362 .46442 L
.60364 .46441 L
.60366 .46439 L
.60368 .46434 L
.60371 .46427 L
.60377 .46412 L
.60383 .46391 L
.60395 .46328 L
.60408 .46254 L
Mistroke
.60429 .46112 L
.6044 .46043 L
.60453 .45985 L
.60456 .45972 L
.60459 .45961 L
.60462 .45952 L
.60465 .45946 L
.60468 .45941 L
.60471 .45938 L
.60474 .45936 L
.60476 .45935 L
.60477 .45936 L
.6048 .45937 L
.60483 .4594 L
.60486 .45944 L
.60489 .4595 L
.60495 .45968 L
.60501 .45991 L
.60511 .46043 L
.60523 .46114 L
.60546 .46278 L
.60557 .46357 L
.60564 .46395 L
.6057 .46425 L
.60575 .46448 L
.6058 .46465 L
.60583 .46472 L
.60586 .46478 L
.60589 .46483 L
.60592 .46486 L
.60595 .46487 L
.60598 .46486 L
.606 .46485 L
.60601 .46483 L
.60603 .46481 L
.60605 .46478 L
.60608 .4647 L
.60611 .46462 L
.60618 .46435 L
.6063 .46374 L
.60642 .46289 L
.60667 .46096 L
.6068 .46004 L
.60687 .45962 L
.60694 .4593 L
.60699 .45909 L
.60703 .459 L
.60706 .45893 L
.60707 .4589 L
.60709 .45888 L
Mistroke
.60711 .45886 L
.60712 .45885 L
.60716 .45885 L
.60717 .45886 L
.60719 .45887 L
.60722 .45891 L
.60725 .45897 L
.60727 .45903 L
.6073 .45912 L
.60736 .45937 L
.60742 .45967 L
.60787 .46325 L
.60799 .4642 L
.60806 .46464 L
.60813 .46497 L
.60818 .4652 L
.60821 .46529 L
.60824 .46537 L
.60825 .4654 L
.60827 .46543 L
.6083 .46547 L
.60833 .46548 L
.60836 .46547 L
.60838 .46546 L
.60839 .46543 L
.60841 .46541 L
.60843 .46537 L
.60846 .46527 L
.6085 .46515 L
.60856 .46486 L
.60863 .46445 L
.60887 .4624 L
.60912 .46002 L
.60924 .45915 L
.6093 .45876 L
.60936 .45846 L
.60939 .45834 L
.60941 .45825 L
.60943 .45821 L
.60945 .45817 L
.60948 .45812 L
.60951 .4581 L
.60953 .45809 L
.60954 .4581 L
.60957 .45812 L
.6096 .45818 L
.60962 .45821 L
.60963 .45826 L
.60967 .45838 L
.60973 .45867 L
Mistroke
.6098 .45912 L
.60987 .45964 L
.6101 .46197 L
.61023 .4634 L
.61035 .46461 L
.61047 .46559 L
.61054 .46596 L
.61057 .46613 L
.6106 .46626 L
.61063 .46634 L
.61066 .4664 L
.61069 .46644 L
.61071 .46644 L
.61073 .46644 L
.61076 .46642 L
.61078 .46637 L
.61081 .46629 L
.61084 .46619 L
.6109 .46593 L
.61095 .46557 L
.61106 .46471 L
.61129 .46205 L
.61151 .45927 L
.61158 .45858 L
.61164 .45801 L
.6117 .45757 L
.61173 .45737 L
.61176 .45721 L
.61179 .45708 L
.61181 .45697 L
.61184 .4569 L
.61187 .45685 L
.61189 .45683 L
.61192 .45683 L
.61194 .45685 L
.61197 .4569 L
.612 .45698 L
.61203 .45709 L
.61208 .45737 L
.61214 .45778 L
.6122 .45834 L
.61266 .46472 L
.61279 .46634 L
.61286 .46703 L
.6129 .46735 L
.61293 .4676 L
.61296 .4678 L
.61299 .46794 L
.61302 .46807 L
.61304 .46811 L
Mistroke
.61306 .46815 L
.61309 .46817 L
.61312 .46816 L
.61315 .46812 L
.61316 .46808 L
.61318 .46802 L
.61321 .46789 L
.61324 .46771 L
.6133 .46725 L
.61336 .46667 L
.61341 .46602 L
.61367 .46196 L
.6139 .4578 L
.61402 .45612 L
.61407 .45553 L
.61412 .45501 L
.61415 .45481 L
.61418 .45463 L
.6142 .4545 L
.61423 .45441 L
.61425 .45434 L
.61428 .45432 L
.61431 .45434 L
.61434 .45439 L
.61437 .45449 L
.61439 .45462 L
.61442 .45481 L
.61445 .45506 L
.61451 .45572 L
.61457 .4565 L
.61469 .45861 L
.61482 .46145 L
.61507 .467 L
.61519 .46951 L
.61526 .4705 L
.61531 .47122 L
.61537 .47171 L
.61539 .47189 L
.61542 .47203 L
.61545 .47211 L
.61548 .47214 L
.61551 .47209 L
.61554 .472 L
.61557 .47182 L
.6156 .47155 L
.61566 .47087 L
.61573 .46986 L
.6158 .46843 L
.61604 .4615 L
.61627 .45416 L
Mistroke
.61639 .45074 L
.61645 .4494 L
.61651 .44842 L
.61654 .448 L
.61657 .44763 L
.61658 .44747 L
.6166 .44735 L
.61663 .44718 L
.61666 .44712 L
.61668 .44713 L
.6167 .44717 L
.61672 .44725 L
.61673 .44735 L
.61675 .44751 L
.61677 .44769 L
.6168 .44807 L
.61683 .44857 L
.61688 .44974 L
.61695 .45157 L
.61701 .45362 L
.61725 .46516 L
.61751 .4792 L
.61762 .48406 L
.61768 .48621 L
.61773 .48779 L
.61776 .48846 L
.61778 .48875 L
.6178 .489 L
.61783 .48929 L
.61786 .48938 L
.61788 .4893 L
.61791 .48906 L
.61794 .48859 L
.61797 .48786 L
.618 .48694 L
.61803 .4857 L
.61809 .48279 L
.61816 .47813 L
.61822 .47274 L
.61834 .45884 L
.61846 .44181 L
.61867 .40095 L
.6189 .34662 L
.61937 .22957 L
.6195 .20199 L
.61964 .17668 L
.61977 .15763 L
.61988 .14434 L
.61994 .13933 L
.62001 .13511 L
Mistroke
.62007 .13198 L
.62011 .13068 L
.62014 .12976 L
.62017 .12919 L
.6202 .12881 L
.62023 .12867 L
.62026 .12868 L
.62029 .1289 L
.6203 .12911 L
.62032 .12935 L
.62035 .12994 L
.62038 .13066 L
.62044 .13236 L
.62049 .1346 L
.6206 .13949 L
.62083 .15236 L
.62095 .15841 L
.62106 .16334 L
.62112 .1656 L
.62119 .16764 L
.62125 .16907 L
.6213 .17004 L
.62133 .17038 L
.62136 .17066 L
.62139 .17083 L
.62141 .1709 L
.62144 .17091 L
.62146 .17085 L
.62149 .17071 L
.62152 .17051 L
.62155 .17021 L
.62157 .16984 L
.62163 .16898 L
.62174 .16628 L
.62195 .15981 L
.62218 .15262 L
.62231 .14933 L
.62237 .14819 L
.62243 .1472 L
.62246 .14684 L
.62249 .14651 L
.62252 .14629 L
.62254 .1461 L
.62256 .14602 L
.62258 .14596 L
.62261 .1459 L
.62263 .14591 L
.62266 .14597 L
.62269 .1461 L
.62272 .14626 L
Mistroke
.62275 .14651 L
.62278 .14681 L
.62289 .14833 L
.62301 .1506 L
.62314 .15352 L
.62338 .15895 L
.62345 .16022 L
.62352 .16141 L
.62358 .16226 L
.62361 .16264 L
.62364 .16298 L
.62368 .16324 L
.62371 .16343 L
.62374 .16357 L
.62377 .16366 L
.6238 .16371 L
.62383 .16371 L
.62384 .16369 L
.62386 .16365 L
.62388 .1636 L
.62389 .16354 L
.62392 .16339 L
.62395 .1632 L
.624 .16277 L
.62412 .16137 L
.62436 .15727 L
.6245 .15486 L
.62462 .15281 L
.62474 .15128 L
.62481 .15064 L
.62484 .1504 L
.62487 .15021 L
.6249 .15008 L
.62493 .14998 L
.62495 .14991 L
.62498 .14987 L
.62501 .14986 L
.62504 .1499 L
.62507 .14997 L
.6251 .15007 L
.62512 .15019 L
.62515 .15035 L
.6252 .1507 L
.62531 .15181 L
.62554 .15491 L
.62566 .1567 L
.62579 .15847 L
.62585 .15922 L
.62591 .15983 L
.62597 .1603 L
Mistroke
.62602 .1607 L
.62605 .16086 L
.62608 .161 L
.62611 .16109 L
.62614 .16116 L
.62617 .1612 L
.6262 .16121 L
.62622 .1612 L
.62623 .16118 L
.62626 .16111 L
.62628 .16106 L
.6263 .161 L
.62633 .16086 L
.6264 .16043 L
.62646 .15995 L
.62653 .15932 L
.62676 .15664 L
.627 .15373 L
.62707 .15303 L
.62714 .15248 L
.6272 .15209 L
.62723 .15194 L
.62727 .15179 L
.62728 .15174 L
.6273 .1517 L
.62733 .15163 L
.62735 .15161 L
.62736 .1516 L
.62738 .15159 L
.6274 .1516 L
.62743 .15162 L
.62744 .15165 L
.62746 .15168 L
.62749 .15177 L
.62752 .15187 L
.62757 .15213 L
.62763 .15251 L
.62775 .15352 L
.62797 .15582 L
.6281 .15724 L
.62823 .15842 L
.62834 .15924 L
.62837 .15941 L
.62841 .15957 L
.62844 .1597 L
.62847 .15979 L
.62849 .15986 L
.62852 .15991 L
.62855 .15994 L
.62858 .15994 L
Mistroke
.62861 .15992 L
.62864 .15989 L
.62866 .15983 L
.62869 .15976 L
.62875 .15953 L
.62881 .15918 L
.62893 .15832 L
.62917 .15611 L
.6293 .15491 L
.62944 .15379 L
.6295 .15336 L
.62956 .15302 L
.62962 .1528 L
.62965 .1527 L
.62968 .15263 L
.62971 .15259 L
.62974 .15256 L
.62977 .15256 L
.62979 .15257 L
.62982 .1526 L
.62984 .15263 L
.62986 .15266 L
.62991 .15283 L
.62995 .15296 L
.62998 .15311 L
.63004 .15344 L
.63017 .15438 L
.63042 .15646 L
.63054 .15744 L
.63065 .15822 L
.63071 .15856 L
.63077 .15881 L
.6308 .15892 L
.63083 .15902 L
.63086 .1591 L
.63088 .15913 L
.6309 .15915 L
.63092 .15918 L
.63095 .15918 L
.63098 .15917 L
.63101 .15915 L
.63103 .15911 L
.63106 .15906 L
.63111 .15891 L
.63117 .15869 L
.63123 .15839 L
.63134 .15771 L
.63158 .15584 L
.63171 .15487 L
.63178 .15439 L
Mistroke
.63185 .154 L
.63191 .15369 L
.63195 .15355 L
.63198 .15343 L
.63201 .15334 L
.63204 .15327 L
.63207 .15322 L
.6321 .15319 L
.63213 .15317 L
.63216 .15317 L
.63218 .15318 L
.63221 .15322 L
.63224 .15327 L
.63227 .15334 L
.63233 .15352 L
.63239 .15376 L
.63245 .15405 L
.63256 .1547 L
.6328 .15642 L
.63301 .15777 L
.63307 .15805 L
.63313 .15831 L
.63316 .15841 L
.63319 .15849 L
.63322 .15855 L
.63324 .1586 L
.63327 .15864 L
.6333 .15867 L
.63333 .15868 L
.63335 .15868 L
.63338 .15866 L
.63341 .15862 L
.63344 .15857 L
.63348 .1585 L
.63354 .15831 L
.63359 .15809 L
.63372 .15742 L
.63393 .15606 L
.63417 .15461 L
.63423 .15432 L
.63429 .15405 L
.63435 .15385 L
.6344 .15371 L
.63443 .15366 L
.63446 .15362 L
.63448 .15361 L
.6345 .1536 L
.63451 .15359 L
.63453 .15359 L
.63456 .1536 L
Mistroke
.63459 .15362 L
.6346 .15364 L
.63462 .15367 L
.63465 .15373 L
.63471 .15388 L
.63476 .15406 L
.63488 .15459 L
.6351 .15584 L
.63532 .15718 L
.63543 .15772 L
.6355 .15796 L
.63556 .15813 L
.63559 .15821 L
.63562 .15826 L
.63565 .15829 L
.63568 .15832 L
.6357 .15832 L
.63572 .15832 L
.63574 .15832 L
.63575 .15831 L
.63579 .15828 L
.6358 .15826 L
.63582 .15824 L
.63588 .15812 L
.63594 .15794 L
.63606 .15745 L
.63632 .15601 L
.63645 .15528 L
.63657 .15469 L
.63668 .15427 L
.63673 .15411 L
.63676 .15404 L
.63679 .15399 L
.63682 .15394 L
.63685 .15391 L
.63688 .1539 L
.6369 .1539 L
.63692 .1539 L
.63695 .15391 L
.63697 .15393 L
.63701 .15397 L
.63703 .15402 L
.63709 .15414 L
.63715 .15432 L
.63727 .15481 L
.63749 .15592 L
.63762 .15663 L
.63774 .15723 L
.63785 .15766 L
.63792 .15783 L
Mistroke
.63794 .1579 L
.63797 .15795 L
.638 .158 L
.63803 .15803 L
.63806 .15805 L
.63808 .15806 L
.63811 .15806 L
.63814 .15804 L
.63817 .15802 L
.63819 .158 L
.6382 .15798 L
.63826 .15787 L
.63833 .1577 L
.63844 .15727 L
.63868 .15611 L
.63881 .15546 L
.63895 .15485 L
.63901 .1546 L
.63908 .15441 L
.63913 .15428 L
.63917 .15422 L
.6392 .15418 L
.63922 .15415 L
.63925 .15414 L
.63928 .15413 L
.63931 .15413 L
.63934 .15414 L
.63935 .15416 L
.63937 .15417 L
.6394 .15421 L
.63943 .15426 L
.63949 .1544 L
.63955 .15458 L
.63967 .15502 L
.63993 .15626 L
.64005 .15682 L
.64017 .15727 L
.64023 .15748 L
.64028 .15762 L
.64035 .15775 L
.64038 .1578 L
.6404 .15782 L
.64041 .15783 L
.64044 .15785 L
.64047 .15785 L
.64049 .15785 L
.64052 .15784 L
.64055 .15782 L
.64058 .15779 L
.6406 .15776 L
Mistroke
.64063 .15772 L
.64068 .15759 L
.64075 .15742 L
.64086 .15702 L
.64109 .15599 L
.64122 .15541 L
.64133 .15494 L
.6414 .15472 L
.64146 .15455 L
.64149 .15448 L
.64153 .15442 L
.64155 .15439 L
.64157 .15437 L
.64158 .15435 L
.6416 .15433 L
.64162 .15432 L
.64164 .15431 L
.64167 .15431 L
.64169 .15431 L
.64172 .15433 L
.64176 .15435 L
.64178 .15439 L
.64182 .15444 L
.64185 .15451 L
.64198 .15485 L
.64211 .15535 L
.64235 .15642 L
.64247 .15689 L
.64253 .15712 L
.64259 .1573 L
.64265 .15744 L
.6427 .15755 L
.64272 .15759 L
.64275 .15763 L
.64278 .15766 L
.64281 .15768 L
.64284 .15769 L
.64287 .15769 L
.64289 .15769 L
.6429 .15768 L
.64292 .15767 L
.64294 .15766 L
.64297 .15762 L
.643 .15759 L
.64306 .15747 L
.64311 .15734 L
.64317 .15716 L
.64328 .15677 L
.64355 .15567 L
.64367 .15518 L
Mistroke
.64378 .15482 L
.64384 .15468 L
.6439 .15457 L
.64393 .15452 L
.64396 .15449 L
.64398 .15448 L
.64399 .15447 L
.64401 .15446 L
.64403 .15445 L
.64406 .15445 L
.64409 .15446 L
.64411 .15447 L
.64414 .1545 L
.64417 .15453 L
.6442 .15458 L
.64426 .15469 L
.64432 .15484 L
.64439 .15504 L
.64452 .15552 L
.64476 .1565 L
.64489 .15696 L
.64495 .15715 L
.64501 .15729 L
.64506 .1574 L
.64512 .15749 L
.64515 .15752 L
.64517 .15754 L
.6452 .15756 L
.64523 .15757 L
.64525 .15756 L
.64527 .15756 L
.6453 .15755 L
.64532 .15753 L
.64534 .15752 L
.64537 .15748 L
.64543 .15737 L
.6455 .15723 L
.64562 .15685 L
.64574 .15643 L
.64596 .15558 L
.64608 .15516 L
.64619 .15485 L
.64626 .15472 L
.64629 .15466 L
.64633 .15462 L
.64635 .15459 L
.64638 .15458 L
.6464 .15457 L
.64642 .15457 L
.64645 .15457 L
Mistroke
.64648 .15458 L
.6465 .15459 L
.64651 .1546 L
.64654 .15463 L
.64657 .15467 L
.64663 .15477 L
.64669 .1549 L
.64693 .15567 L
.64719 .15663 L
.64729 .15697 L
.64735 .15712 L
.64741 .15725 L
.64744 .1573 L
.64747 .15736 L
.6475 .15739 L
.64753 .15742 L
.64756 .15744 L
.64759 .15746 L
.64762 .15746 L
.64765 .15746 L
.64768 .15744 L
.6477 .15742 L
.64773 .1574 L
.64776 .15736 L
.64783 .15725 L
.64788 .15713 L
.6481 .15648 L
.64835 .15558 L
.64846 .15522 L
.64851 .15506 L
.64858 .15492 L
.64864 .1548 L
.64869 .15473 L
.64872 .1547 L
.64875 .15468 L
.64877 .15467 L
.6488 .15466 L
.64883 .15466 L
.64886 .15467 L
.64889 .15469 L
.64891 .15471 L
.64895 .15475 L
.64898 .1548 L
.64904 .1549 L
.64916 .15521 L
.64928 .15557 L
.64954 .15649 L
.64966 .15686 L
.64972 .15703 L
.64979 .15717 L
Mistroke
.64985 .15727 L
.64988 .15731 L
.64991 .15734 L
.64994 .15736 L
.64997 .15737 L
.65 .15737 L
.65003 .15737 L
.65005 .15736 L
.65008 .15734 L
.65011 .15732 L
.65014 .15729 L
.65019 .15722 L
.65024 .15712 L
.65036 .15682 L
.65047 .15647 L
.65069 .15572 L
.65081 .15534 L
.65092 .15505 L
.65099 .15492 L
.65102 .15487 L
.65106 .15482 L
.65109 .15479 L
.6511 .15477 L
.65112 .15476 L
.65115 .15475 L
.65118 .15474 L
.65121 .15474 L
.65123 .15475 L
.65124 .15475 L
.65127 .15477 L
.65129 .15478 L
.65131 .1548 L
.65136 .15487 L
.65142 .15497 L
.65153 .15523 L
.65165 .15559 L
.6519 .15641 L
.65201 .15674 L
.65207 .1569 L
.65213 .15703 L
.65218 .15713 L
.65221 .15718 L
.65224 .15722 L
.65227 .15725 L
.65229 .15727 L
.65232 .15729 L
.65234 .1573 L
.65237 .1573 L
.6524 .1573 L
.65243 .15729 L
Mistroke
.65246 .15728 L
.65249 .15725 L
.65252 .15722 L
.65258 .15713 L
.65264 .15702 L
.65271 .15686 L
.65283 .15653 L
.65306 .15578 L
.65316 .15547 L
.65327 .15518 L
.65332 .15506 L
.65338 .15496 L
.65341 .15491 L
.65344 .15488 L
.65347 .15485 L
.6535 .15483 L
.65353 .15481 L
.65356 .15481 L
.65359 .15481 L
.6536 .15481 L
.65362 .15482 L
.65365 .15483 L
.65368 .15485 L
.65371 .15489 L
.65374 .15492 L
.65385 .15512 L
.65395 .15536 L
.65418 .15606 L
.6543 .15645 L
.65443 .15681 L
.65449 .15695 L
.65456 .15707 L
.65461 .15715 L
.65464 .15718 L
.65467 .15721 L
.6547 .15723 L
.65473 .15724 L
.65476 .15724 L
.65478 .15724 L
.65481 .15723 L
.65483 .15722 L
.65486 .1572 L
.65489 .15718 L
.65495 .1571 L
.655 .15701 L
.65512 .15675 L
.65536 .15604 L
.65549 .15564 L
.65561 .1553 L
.65573 .15506 L
Mistroke
.65576 .15501 L
.65579 .15496 L
.65582 .15493 L
.65585 .1549 L
.65588 .15488 L
.65591 .15487 L
.65593 .15486 L
.65596 .15486 L
.65599 .15487 L
.65601 .15488 L
.65604 .15489 L
.65607 .15492 L
.65613 .15499 L
.65618 .15507 L
.6563 .15531 L
.65651 .15591 L
.65663 .15628 L
.65676 .15664 L
.65682 .1568 L
.65688 .15692 L
.65693 .15702 L
.65696 .15706 L
.65699 .1571 L
.65702 .15713 L
.65705 .15715 L
.65707 .15717 L
.6571 .15719 L
.65713 .15719 L
.65716 .15719 L
.65718 .15718 L
.65721 .15717 L
.65724 .15715 L
.65727 .15713 L
.65732 .15706 L
.65738 .15697 L
.65744 .15685 L
.65768 .15622 L
.65781 .15584 L
.65794 .15546 L
.65801 .1553 L
.65807 .15517 L
.65813 .15506 L
.65816 .15502 L
.65819 .15499 L
.65822 .15496 L
.65824 .15494 L
.65827 .15492 L
.6583 .15491 L
.65833 .15491 L
.65835 .15491 L
Mistroke
.65836 .15491 L
.65839 .15492 L
.65842 .15494 L
.65845 .15496 L
.65849 .155 L
.65855 .15509 L
.65867 .15531 L
.65893 .15603 L
.65905 .15638 L
.65917 .15671 L
.65924 .15684 L
.6593 .15695 L
.65935 .15703 L
.65941 .1571 L
.65943 .15712 L
.65945 .15713 L
.65947 .15714 L
.65948 .15714 L
.6595 .15715 L
.65953 .15715 L
.65956 .15715 L
.65959 .15713 L
.65962 .15712 L
.65965 .15709 L
.65971 .15701 L
.65977 .15692 L
.65991 .15662 L
.66015 .15594 L
.66029 .15557 L
.66041 .15528 L
.66046 .15518 L
.66052 .15509 L
.66054 .15505 L
.66058 .15502 L
.6606 .15499 L
.66063 .15497 L
.66064 .15496 L
.66066 .15496 L
.66069 .15495 L
.66071 .15495 L
.66072 .15495 L
.66075 .15495 L
.66078 .15496 L
.66081 .15498 L
.66084 .155 L
.66087 .15504 L
.66093 .15512 L
.66099 .15522 L
.66112 .15551 L
.66135 .15616 L
Mistroke
.66157 .15671 L
.66162 .15683 L
.66168 .15694 L
.66174 .15701 L
.66177 .15704 L
.66179 .15707 L
.66182 .15709 L
.66185 .1571 L
.66188 .15711 L
.6619 .15711 L
.66191 .15711 L
.66194 .15711 L
.66197 .1571 L
.662 .15708 L
.66203 .15706 L
.66208 .157 L
.66213 .15693 L
.66224 .15672 L
.6625 .15605 L
.66262 .1557 L
.66274 .15542 L
.66279 .1553 L
.66285 .15519 L
.6629 .15511 L
.66296 .15505 L
.66299 .15502 L
.66302 .155 L
.66305 .15499 L
.66307 .15498 L
.66308 .15498 L
.66311 .15498 L
.66314 .15498 L
.66317 .155 L
.66319 .15501 L
.66322 .15504 L
.66325 .15507 L
.66331 .15514 L
.66344 .15538 L
.66369 .15604 L
.66381 .15637 L
.66394 .15668 L
.66401 .15681 L
.66406 .15691 L
.66412 .15698 L
.66415 .15702 L
.66418 .15704 L
.6642 .15706 L
.66422 .15707 L
.66424 .15708 L
.66425 .15708 L
Mistroke
.66427 .15708 L
.6643 .15708 L
.66433 .15708 L
.66436 .15707 L
.66439 .15705 L
.66442 .15702 L
.66448 .15695 L
.66454 .15685 L
.66468 .15656 L
.6649 .156 L
.66513 .15542 L
.66519 .15528 L
.66526 .15517 L
.66531 .1551 L
.66535 .15506 L
.66538 .15504 L
.6654 .15502 L
.66543 .15501 L
.66546 .155 L
.66549 .155 L
.66551 .15501 L
.66552 .15501 L
.66555 .15502 L
.66558 .15504 L
.66561 .15507 L
.66567 .15514 L
.66573 .15523 L
.66584 .15545 L
.66609 .15609 L
.66634 .1567 L
.6664 .15682 L
.66646 .15692 L
.6665 .15696 L
.66653 .157 L
.66657 .15703 L
.66658 .15704 L
.6666 .15705 L
.66663 .15706 L
.66666 .15706 L
.66669 .15706 L
.6667 .15706 L
.66672 .15705 L
.66674 .15704 L
.66677 .15702 L
.6668 .157 L
.66683 .15697 L
.66689 .15688 L
.66695 .15679 L
.66708 .15651 L
.6673 .15595 L
Mistroke
.66753 .15539 L
.66764 .15519 L
.66767 .15514 L
.6677 .15511 L
.66773 .15508 L
.66777 .15505 L
.6678 .15504 L
.66782 .15503 L
.66785 .15502 L
.66788 .15503 L
.66791 .15503 L
.66794 .15505 L
.66796 .15506 L
.66799 .15508 L
.66805 .15515 L
.66811 .15525 L
.66825 .15552 L
.66849 .15613 L
.6686 .15642 L
.66873 .15671 L
.66879 .15681 L
.66885 .15691 L
.6689 .15697 L
.66893 .15699 L
.66896 .15701 L
.66897 .15702 L
.66899 .15703 L
.66901 .15704 L
.66902 .15704 L
.66905 .15704 L
.66908 .15704 L
.6691 .15703 L
.66912 .15703 L
.66916 .157 L
.66919 .15697 L
.66922 .15694 L
.66934 .15677 L
.66946 .15651 L
.6697 .15588 L
.66983 .15558 L
.66994 .15534 L
.67004 .15518 L
.67009 .15512 L
.67012 .15509 L
.67014 .15507 L
.67017 .15506 L
.6702 .15505 L
.67023 .15504 L
.67026 .15504 L
.67029 .15505 L
Mistroke
.67032 .15506 L
.67035 .15508 L
.67037 .1551 L
.67043 .15517 L
.67049 .15525 L
.67061 .15549 L
.67084 .15605 L
.67097 .15638 L
.6711 .15668 L
.67116 .1568 L
.67123 .15689 L
.67128 .15696 L
.67131 .15698 L
.67134 .157 L
.67137 .15702 L
.6714 .15703 L
.67143 .15703 L
.67146 .15703 L
.67148 .15702 L
.67151 .15701 L
.67154 .15699 L
.67156 .15697 L
.67162 .15691 L
.67167 .15683 L
.67179 .15661 L
.67205 .15597 L
.67216 .15568 L
.67229 .1554 L
.67234 .1553 L
.6724 .15521 L
.67246 .15514 L
.67251 .15509 L
.67254 .15507 L
.67257 .15506 L
.6726 .15505 L
.67263 .15505 L
.67264 .15505 L
.67266 .15506 L
.67269 .15507 L
.67272 .15509 L
.67275 .15511 L
.67281 .15517 L
.67286 .15525 L
.67299 .15549 L
.67325 .15612 L
.67337 .15642 L
.6735 .15671 L
.67356 .15681 L
.67362 .1569 L
.67368 .15696 L
Mistroke
.67371 .15698 L
.67374 .157 L
.67376 .15701 L
.67379 .15702 L
.67382 .15702 L
.67385 .15701 L
.67387 .15701 L
.6739 .15699 L
.67392 .15698 L
.67395 .15695 L
.67401 .15689 L
.67406 .15681 L
.67418 .15658 L
.67442 .15601 L
.67455 .15568 L
.67467 .15541 L
.67478 .15522 L
.67482 .15517 L
.67485 .15514 L
.67488 .15511 L
.67491 .15509 L
.67494 .15507 L
.67497 .15506 L
.67499 .15506 L
.67502 .15506 L
.67505 .15507 L
.67507 .15508 L
.6751 .15509 L
.67513 .15511 L
.67519 .15518 L
.67524 .15526 L
.67537 .15549 L
.6756 .15606 L
.67581 .15656 L
.67587 .15668 L
.67593 .15679 L
.67598 .15687 L
.67604 .15693 L
.67607 .15696 L
.67609 .15698 L
.67612 .157 L
.67615 .15701 L
.67618 .15701 L
.6762 .15701 L
.67624 .15701 L
.67625 .157 L
.67627 .15699 L
.6763 .15698 L
.67632 .15696 L
.67638 .15689 L
Mistroke
.67643 .15682 L
.67648 .15673 L
.67672 .1562 L
.67686 .15586 L
.67698 .15556 L
.6771 .15532 L
.67717 .15521 L
.6772 .15517 L
.67723 .15514 L
.67726 .15512 L
.67728 .1551 L
.67731 .15508 L
.67734 .15507 L
.67737 .15506 L
.6774 .15507 L
.67743 .15507 L
.67746 .15508 L
.67748 .1551 L
.67751 .15512 L
.67756 .15517 L
.67762 .15525 L
.67767 .15534 L
.6779 .15584 L
.67812 .1564 L
.67824 .15666 L
.67835 .15686 L
.67842 .15693 L
.67846 .15697 L
.67847 .15698 L
.67849 .15699 L
.67852 .157 L
.67855 .15701 L
.67858 .15701 L
.6786 .15701 L
.67861 .15701 L
.67864 .15699 L
.67867 .15698 L
.6787 .15695 L
.67874 .15692 L
.67879 .15685 L
.67885 .15676 L
.6791 .15621 L
.67936 .15557 L
.67946 .15535 L
.67952 .15525 L
.67958 .15518 L
.67961 .15514 L
.67964 .15511 L
.67967 .15509 L
.6797 .15508 L
Mistroke
.67973 .15507 L
.67976 .15506 L
.67979 .15507 L
.67982 .15507 L
.67985 .15509 L
.67988 .15511 L
.67991 .15513 L
.67994 .15517 L
.68005 .15534 L
.68016 .15556 L
.68027 .15581 L
.68052 .15644 L
.68063 .15667 L
.68068 .15678 L
.68075 .15687 L
.68078 .15691 L
.68081 .15694 L
.68084 .15697 L
.68086 .15699 L
.68089 .157 L
.68092 .15701 L
.68094 .15701 L
.68097 .15701 L
.681 .15701 L
.68103 .15699 L
.68106 .15697 L
.68109 .15695 L
.68115 .15688 L
.68121 .1568 L
.68134 .15656 L
.68147 .15624 L
.68171 .15563 L
.68183 .15538 L
.6819 .15526 L
.68196 .15518 L
.68199 .15514 L
.68202 .15511 L
.68206 .15508 L
.68208 .15507 L
.6821 .15507 L
.68211 .15506 L
.68213 .15506 L
.68216 .15506 L
.68219 .15507 L
.68221 .15507 L
.68222 .15508 L
.68225 .1551 L
.68228 .15513 L
.68234 .1552 L
.6824 .15528 L
Mistroke
.68246 .15538 L
.68271 .15596 L
.68283 .15627 L
.68296 .15658 L
.68302 .1567 L
.68308 .15681 L
.68314 .15689 L
.68317 .15693 L
.6832 .15696 L
.68323 .15698 L
.68326 .157 L
.68328 .15701 L
.68331 .15702 L
.68333 .15702 L
.68336 .15702 L
.68338 .15701 L
.68341 .157 L
.68344 .15698 L
.68347 .15696 L
.68352 .1569 L
.68358 .15682 L
.68364 .15671 L
.68391 .1561 L
.68403 .15577 L
.68415 .15549 L
.68426 .15528 L
.68431 .1552 L
.68435 .15516 L
.68437 .15513 L
.6844 .1551 L
.68443 .15508 L
.68447 .15506 L
.68448 .15506 L
.6845 .15505 L
.68453 .15505 L
.68456 .15506 L
.68459 .15507 L
.68462 .15508 L
.68464 .1551 L
.68467 .15512 L
.68473 .15519 L
.68479 .15528 L
.68485 .15539 L
.68506 .1559 L
.68519 .15621 L
.68532 .15653 L
.68544 .15678 L
.6855 .15687 L
.68555 .15694 L
.68558 .15697 L
Mistroke
.68561 .15699 L
.68564 .15701 L
.68566 .15702 L
.68568 .15703 L
.68571 .15703 L
.68573 .15703 L
.68576 .15702 L
.68579 .15701 L
.68581 .157 L
.68583 .15699 L
.68586 .15696 L
.68592 .15689 L
.68599 .15677 L
.68606 .15665 L
.68629 .15609 L
.68642 .15575 L
.68654 .15546 L
.68666 .15525 L
.68672 .15516 L
.68678 .1551 L
.68681 .15507 L
.68684 .15505 L
.68686 .15505 L
.68687 .15504 L
.68689 .15504 L
.68691 .15504 L
.68694 .15504 L
.68697 .15505 L
.68698 .15506 L
.687 .15507 L
.68703 .15509 L
.68708 .15515 L
.68714 .15523 L
.68726 .15545 L
.68747 .15597 L
.6877 .15654 L
.68781 .15678 L
.68788 .15688 L
.68794 .15696 L
.68797 .15699 L
.688 .15701 L
.68803 .15703 L
.68806 .15704 L
.68808 .15704 L
.6881 .15704 L
.68812 .15704 L
.68813 .15704 L
.68816 .15703 L
.68818 .15702 L
.6882 .15701 L
Mistroke
.68826 .15695 L
.68829 .15691 L
.68832 .15687 L
.68844 .15666 L
.68866 .15612 L
.68889 .15553 L
.68901 .15528 L
.68908 .15517 L
.68911 .15513 L
.68914 .15509 L
.68917 .15507 L
.6892 .15505 L
.68923 .15503 L
.68926 .15503 L
.68929 .15502 L
.68932 .15503 L
.68933 .15503 L
.68935 .15504 L
.68938 .15505 L
.68941 .15508 L
.68944 .15511 L
.68951 .1552 L
.68958 .15531 L
.68965 .15545 L
.68989 .15607 L
.69002 .1564 L
.69015 .1567 L
.69026 .15689 L
.69029 .15694 L
.69032 .15698 L
.69035 .15701 L
.69038 .15703 L
.69041 .15705 L
.69043 .15705 L
.69044 .15706 L
.69046 .15706 L
.69048 .15706 L
.69051 .15706 L
.69054 .15705 L
.69056 .15704 L
.69059 .15701 L
.69062 .15699 L
.69069 .1569 L
.69075 .1568 L
.69089 .15651 L
.69112 .15589 L
.69125 .15556 L
.69138 .15529 L
.69144 .15519 L
.6915 .1551 L
Mistroke
.69153 .15507 L
.69156 .15504 L
.69159 .15502 L
.69161 .15501 L
.69163 .15501 L
.69166 .155 L
.69169 .155 L
.69172 .15501 L
.69174 .15502 L
.69177 .15504 L
.69181 .15507 L
.69187 .15514 L
.69192 .15523 L
.69198 .15533 L
.6921 .15561 L
.69231 .15618 L
.69243 .15648 L
.69255 .15677 L
.69261 .15687 L
.69267 .15696 L
.69272 .15702 L
.69275 .15705 L
.69278 .15706 L
.6928 .15707 L
.69281 .15708 L
.69283 .15708 L
.69285 .15709 L
.69288 .15708 L
.69291 .15708 L
.69292 .15707 L
.69294 .15706 L
.69298 .15703 L
.69301 .157 L
.69304 .15696 L
.69316 .15677 L
.69328 .15649 L
.69351 .15588 L
.69363 .15555 L
.69375 .15528 L
.69381 .15519 L
.69386 .1551 L
.6939 .15506 L
.69392 .15503 L
.69395 .15501 L
.69398 .15499 L
.69401 .15498 L
.69403 .15498 L
.69406 .15498 L
.69408 .15498 L
.69411 .15499 L
Mistroke
.69414 .15501 L
.69417 .15503 L
.69419 .15505 L
.69425 .15512 L
.69431 .15522 L
.69443 .15548 L
.69465 .15607 L
.69478 .15642 L
.69491 .15674 L
.69497 .15685 L
.69503 .15695 L
.69506 .157 L
.69509 .15703 L
.69512 .15706 L
.69515 .15709 L
.69518 .1571 L
.69521 .15711 L
.69524 .15711 L
.69527 .15711 L
.6953 .1571 L
.69533 .15709 L
.69536 .15706 L
.69539 .15703 L
.69545 .15696 L
.6955 .15687 L
.69562 .15662 L
.69587 .15592 L
.696 .15557 L
.69612 .15529 L
.69622 .1551 L
.69627 .15503 L
.6963 .155 L
.69633 .15498 L
.69636 .15496 L
.69639 .15495 L
.69642 .15495 L
.69644 .15495 L
.69645 .15495 L
.69648 .15496 L
.69651 .15497 L
.69654 .15499 L
.69657 .15502 L
.69663 .15509 L
.69669 .1552 L
.6968 .15544 L
.69706 .15615 L
.69729 .15676 L
.69736 .15689 L
.69742 .157 L
.69748 .15707 L
Mistroke
.69751 .1571 L
.69754 .15712 L
.69756 .15714 L
.69759 .15715 L
.69761 .15715 L
.69764 .15715 L
.69767 .15714 L
.6977 .15713 L
.69772 .15711 L
.69775 .15708 L
.6978 .15702 L
.69786 .15693 L
.69798 .15669 L
.69822 .15601 L
.69836 .15562 L
.69848 .1553 L
.69859 .15509 L
.69865 .15501 L
.69867 .15498 L
.6987 .15495 L
.69873 .15493 L
.69876 .15492 L
.69879 .15491 L
.69881 .15491 L
.69883 .15491 L
.69886 .15492 L
.69888 .15493 L
.69891 .15495 L
.69894 .15498 L
.699 .15505 L
.69906 .15514 L
.69917 .15539 L
.69939 .156 L
.69951 .15636 L
.69964 .15671 L
.69975 .15695 L
.69981 .15706 L
.69987 .15713 L
.6999 .15715 L
.69993 .15717 L
.69996 .15719 L
.69999 .15719 L
.70001 .15719 L
.70004 .15718 L
.70007 .15717 L
.7001 .15715 L
.70013 .15713 L
.70016 .15709 L
.70021 .15701 L
.70034 .15676 L
Mistroke
.70058 .15608 L
.70071 .15568 L
.70084 .15534 L
.70096 .15508 L
.70099 .15502 L
.70102 .15497 L
.70105 .15494 L
.70109 .15491 L
.70112 .15488 L
.70114 .15487 L
.70117 .15486 L
.70119 .15486 L
.70122 .15487 L
.70125 .15488 L
.70128 .15489 L
.70131 .15492 L
.70136 .15498 L
.70142 .15507 L
.70152 .15529 L
.70175 .15595 L
.70187 .15632 L
.702 .15669 L
.70207 .15685 L
.70212 .15698 L
.70218 .15707 L
.70224 .15715 L
.70226 .15718 L
.7023 .15721 L
.70232 .15723 L
.70235 .15724 L
.70238 .15724 L
.70241 .15724 L
.70243 .15723 L
.70245 .15722 L
.70248 .1572 L
.70251 .15717 L
.70254 .15713 L
.70261 .15702 L
.70274 .15673 L
.70299 .156 L
.70312 .15558 L
.70324 .15524 L
.70335 .15501 L
.70341 .15492 L
.70344 .15488 L
.70346 .15486 L
.70349 .15483 L
.70352 .15482 L
.70355 .15481 L
.70357 .15481 L
Mistroke
.70359 .15481 L
.70362 .15481 L
.70364 .15483 L
.70367 .15485 L
.70371 .15488 L
.70376 .15496 L
.70382 .15505 L
.70393 .15533 L
.70415 .15599 L
.70427 .15639 L
.7044 .15677 L
.70451 .15703 L
.70457 .15715 L
.70463 .15723 L
.70466 .15726 L
.70469 .15728 L
.70472 .15729 L
.70475 .1573 L
.70478 .1573 L
.7048 .1573 L
.70483 .15728 L
.70485 .15726 L
.70488 .15724 L
.70491 .1572 L
.70497 .15712 L
.70503 .157 L
.70509 .15685 L
.70535 .15603 L
.70559 .15528 L
.70571 .155 L
.70577 .15488 L
.70581 .15484 L
.70583 .1548 L
.70586 .15478 L
.70589 .15476 L
.70592 .15475 L
.70595 .15474 L
.70597 .15474 L
.70601 .15475 L
.70604 .15477 L
.70606 .1548 L
.70609 .15483 L
.70613 .15488 L
.70619 .15499 L
.70631 .15527 L
.70657 .15611 L
.70669 .15652 L
.70681 .1569 L
.70688 .15706 L
.70693 .15718 L
Mistroke
.70699 .15726 L
.70702 .1573 L
.70705 .15733 L
.70707 .15735 L
.70709 .15736 L
.70711 .15737 L
.70712 .15737 L
.70714 .15737 L
.70717 .15737 L
.7072 .15736 L
.70723 .15734 L
.70725 .15732 L
.70729 .15728 L
.70736 .15716 L
.70742 .15702 L
.70755 .15667 L
.70776 .15594 L
.70799 .15518 L
.70806 .15501 L
.70812 .15487 L
.70818 .15477 L
.70821 .15473 L
.70824 .1547 L
.70827 .15468 L
.7083 .15467 L
.70833 .15466 L
.70835 .15466 L
.70839 .15467 L
.7084 .15468 L
.70842 .1547 L
.70845 .15472 L
.70848 .15476 L
.70854 .15486 L
.7086 .15498 L
.70871 .15528 L
.70895 .15614 L
.7092 .15697 L
.70926 .15712 L
.70932 .15726 L
.70936 .15733 L
.70939 .15738 L
.70942 .15741 L
.70944 .15743 L
.70946 .15744 L
.70949 .15745 L
.70952 .15746 L
.70954 .15746 L
.70956 .15745 L
.70958 .15745 L
.7096 .15743 L
Mistroke
.70963 .1574 L
.70966 .15737 L
.70969 .15733 L
.70975 .15721 L
.70981 .15708 L
.70994 .15669 L
.71015 .1559 L
.71038 .1551 L
.71049 .15481 L
.71052 .15475 L
.71056 .15469 L
.71059 .15465 L
.71062 .15461 L
.71065 .15459 L
.71067 .15457 L
.7107 .15457 L
.71073 .15457 L
.71076 .15458 L
.71079 .15459 L
.71081 .15461 L
.71084 .15464 L
.7109 .15474 L
.71096 .15488 L
.7111 .15526 L
.71134 .15616 L
.71145 .1566 L
.71158 .15703 L
.71163 .15719 L
.71169 .15734 L
.71175 .15744 L
.71178 .15748 L
.7118 .15751 L
.71182 .15753 L
.71184 .15754 L
.71187 .15756 L
.71189 .15756 L
.7119 .15757 L
.71192 .15756 L
.71194 .15756 L
.71197 .15754 L
.71199 .15753 L
.712 .15751 L
.71203 .15748 L
.71206 .15743 L
.71212 .15732 L
.71218 .15717 L
.7123 .15678 L
.71252 .15594 L
.71275 .15506 L
.71282 .15486 L
Mistroke
.71288 .1547 L
.71294 .15458 L
.71297 .15454 L
.713 .1545 L
.71303 .15447 L
.71305 .15446 L
.71308 .15445 L
.71311 .15445 L
.71313 .15446 L
.71315 .15446 L
.71318 .15449 L
.71321 .15452 L
.71323 .15456 L
.7133 .15467 L
.71336 .15482 L
.71347 .15516 L
.71372 .15617 L
.71384 .1567 L
.71396 .15713 L
.71403 .15733 L
.71409 .15747 L
.71415 .15759 L
.71417 .15762 L
.71419 .15764 L
.71421 .15766 L
.71422 .15767 L
.71425 .15769 L
.71428 .15769 L
.7143 .15769 L
.71431 .15769 L
.71435 .15767 L
.71436 .15766 L
.71438 .15765 L
.71441 .15761 L
.71444 .15755 L
.71447 .15749 L
.71459 .15717 L
.71471 .15676 L
.71492 .15585 L
.71515 .1549 L
.71521 .15472 L
.71527 .15455 L
.7153 .15448 L
.71533 .15443 L
.71536 .15439 L
.71539 .15436 L
.71542 .15433 L
.71545 .15431 L
.71548 .15431 L
.7155 .15431 L
Mistroke
.71552 .15432 L
.71554 .15433 L
.71557 .15436 L
.7156 .1544 L
.71563 .15445 L
.71569 .15458 L
.71574 .15472 L
.71586 .15514 L
.71608 .15609 L
.7163 .15708 L
.71641 .15747 L
.71648 .15763 L
.71654 .15775 L
.71657 .1578 L
.71659 .15782 L
.7166 .15783 L
.71663 .15785 L
.71666 .15785 L
.71668 .15785 L
.7167 .15785 L
.71673 .15783 L
.71674 .15782 L
.71676 .1578 L
.7168 .15775 L
.71685 .15764 L
.71691 .15748 L
.71704 .15705 L
.7173 .15583 L
.71743 .15522 L
.71755 .15473 L
.71765 .1544 L
.71771 .15427 L
.71774 .15422 L
.71777 .15418 L
.7178 .15415 L
.71783 .15413 L
.71785 .15413 L
.71788 .15413 L
.71791 .15415 L
.71793 .15416 L
.71795 .15418 L
.71798 .15423 L
.71801 .15428 L
.71806 .1544 L
.71812 .15458 L
.71824 .15504 L
.71846 .1561 L
.71859 .15677 L
.71871 .15732 L
.71882 .15772 L
Mistroke
.71889 .15788 L
.71891 .15793 L
.71894 .15798 L
.71897 .15802 L
.719 .15804 L
.71903 .15805 L
.71905 .15806 L
.71908 .15805 L
.71911 .15803 L
.71914 .158 L
.71917 .15795 L
.7192 .15789 L
.71924 .15781 L
.7193 .15763 L
.71941 .15718 L
.71965 .15595 L
.71978 .15527 L
.71991 .15462 L
.71998 .15437 L
.72004 .15417 L
.7201 .15404 L
.72013 .15398 L
.72016 .15394 L
.72019 .15391 L
.72022 .1539 L
.72024 .1539 L
.72027 .1539 L
.7203 .15393 L
.72032 .15394 L
.72033 .15396 L
.72039 .15407 L
.72042 .15415 L
.72046 .15425 L
.72052 .15446 L
.72065 .15507 L
.7209 .15645 L
.72102 .15711 L
.72113 .15765 L
.72119 .15789 L
.72125 .15806 L
.72127 .15814 L
.72131 .15821 L
.72134 .15826 L
.72136 .15828 L
.72137 .1583 L
.7214 .15832 L
.72143 .15832 L
.72146 .15832 L
.72149 .1583 L
.72151 .15827 L
Mistroke
.72154 .15823 L
.72159 .15812 L
.72165 .15796 L
.72171 .15773 L
.72182 .15721 L
.72205 .15584 L
.72217 .15507 L
.72229 .15444 L
.72236 .15414 L
.72243 .15388 L
.72246 .15379 L
.7225 .15371 L
.72253 .15366 L
.72254 .15364 L
.72256 .15362 L
.72258 .1536 L
.72259 .15359 L
.72262 .15359 L
.72264 .15359 L
.72266 .1536 L
.72267 .15361 L
.72269 .15363 L
.72272 .15367 L
.72275 .15374 L
.72281 .15389 L
.72287 .15411 L
.72292 .15435 L
.72305 .15505 L
.72331 .15672 L
.72342 .15743 L
.72353 .15799 L
.72359 .15824 L
.72362 .15836 L
.72365 .15846 L
.72368 .15853 L
.72371 .15859 L
.72374 .15863 L
.72376 .15866 L
.72379 .15868 L
.72381 .15868 L
.72383 .15868 L
.72386 .15866 L
.72388 .15863 L
.7239 .1586 L
.72392 .15857 L
.72395 .15851 L
.72401 .1583 L
.72407 .15806 L
.72413 .15779 L
.72425 .15704 L
Mistroke
.72447 .15552 L
.72458 .15474 L
.7247 .15402 L
.72476 .15372 L
.72479 .15358 L
.72483 .15345 L
.72486 .15336 L
.72489 .15328 L
.72492 .15323 L
.72495 .15319 L
.72498 .15317 L
.72501 .15317 L
.72504 .15318 L
.72506 .15321 L
.7251 .15326 L
.72513 .15333 L
.72519 .15352 L
.72524 .15375 L
.7253 .15405 L
.72542 .1548 L
.72564 .15644 L
.72575 .15733 L
.72588 .15818 L
.72593 .1585 L
.72599 .15878 L
.72605 .15896 L
.72608 .15904 L
.7261 .1591 L
.72612 .15913 L
.72614 .15915 L
.72615 .15917 L
.72617 .15918 L
.7262 .15918 L
.72623 .15917 L
.72625 .15915 L
.72627 .15912 L
.7263 .15905 L
.72634 .15895 L
.72637 .15884 L
.72648 .15827 L
.72661 .15742 L
.72685 .15536 L
.72697 .15436 L
.72708 .15356 L
.72718 .15301 L
.72721 .15289 L
.72724 .15279 L
.72726 .15272 L
.72729 .15265 L
.72732 .1526 L
Mistroke
.72735 .15257 L
.72738 .15256 L
.7274 .15256 L
.72743 .15259 L
.72746 .15263 L
.72749 .1527 L
.72752 .15278 L
.72757 .15301 L
.72763 .15332 L
.72774 .15406 L
.72799 .15626 L
.72823 .15847 L
.7283 .15898 L
.72836 .15937 L
.72842 .15965 L
.72846 .15976 L
.72849 .15985 L
.72852 .1599 L
.72853 .15992 L
.72855 .15994 L
.72858 .15994 L
.72861 .15993 L
.72863 .15989 L
.72866 .15984 L
.72869 .15977 L
.72871 .15966 L
.72878 .15936 L
.72884 .15897 L
.72896 .15804 L
.72917 .15588 L
.7294 .15346 L
.72945 .15296 L
.72952 .15248 L
.72957 .15215 L
.72963 .15186 L
.72966 .15175 L
.72969 .15167 L
.72971 .15164 L
.72972 .15162 L
.72974 .1516 L
.72976 .15159 L
.72979 .1516 L
.72981 .15163 L
.72984 .15169 L
.72987 .15179 L
.7299 .1519 L
.72993 .15201 L
.72998 .15234 L
.73009 .15316 L
.73032 .15576 L
Mistroke
.73054 .1585 L
.73066 .15977 L
.73072 .16027 L
.73077 .16065 L
.7308 .16082 L
.73084 .16098 L
.73087 .1611 L
.73089 .16114 L
.73091 .16117 L
.73094 .1612 L
.73097 .1612 L
.73098 .16119 L
.731 .16116 L
.73103 .16109 L
.73106 .16099 L
.73109 .16085 L
.73116 .16046 L
.73122 .15997 L
.73127 .15941 L
.73172 .15325 L
.73184 .1517 L
.73191 .15102 L
.73197 .1505 L
.732 .15031 L
.73203 .15014 L
.73204 .15007 L
.73206 .15001 L
.73209 .14992 L
.73212 .14987 L
.73215 .14986 L
.73218 .14989 L
.7322 .14994 L
.73223 .15003 L
.73226 .15018 L
.73232 .15055 L
.73238 .15109 L
.73245 .15186 L
.73268 .15554 L
.73281 .15788 L
.73295 .16023 L
.73306 .16191 L
.73313 .16266 L
.73316 .16294 L
.73319 .16319 L
.73322 .1634 L
.73325 .16354 L
.73328 .16364 L
.73331 .1637 L
.73334 .16372 L
.73336 .1637 L
Mistroke
.73339 .16364 L
.73342 .16353 L
.73345 .16337 L
.73348 .16313 L
.73354 .16254 L
.7336 .16179 L
.73366 .16095 L
.73391 .15562 L
.73404 .15266 L
.73416 .15011 L
.73427 .14801 L
.73433 .14718 L
.73439 .14649 L
.73443 .14623 L
.73446 .14605 L
.73447 .14599 L
.73449 .14593 L
.73451 .1459 L
.73453 .1459 L
.73455 .14593 L
.73459 .14604 L
.7346 .14612 L
.73462 .14623 L
.73465 .14648 L
.7347 .14709 L
.73476 .14799 L
.73488 .15052 L
.7351 .15677 L
.73534 .16457 L
.73546 .16773 L
.73551 .16885 L
.73557 .16982 L
.7356 .17024 L
.73563 .17054 L
.73566 .17076 L
.73568 .17085 L
.73569 .17089 L
.73571 .17091 L
.73573 .1709 L
.73575 .17086 L
.73577 .17077 L
.73578 .17065 L
.7358 .17051 L
.73583 .17015 L
.73586 .16971 L
.73589 .16915 L
.73595 .16788 L
.73607 .16381 L
.73632 .15195 L
.73655 .13926 L
Mistroke
.73665 .13453 L
.73671 .13239 L
.73676 .13076 L
.73679 .13003 L
.73681 .12948 L
.73684 .12903 L
.73686 .12886 L
.73688 .12874 L
.7369 .12865 L
.73693 .12871 L
.73696 .12894 L
.73699 .12938 L
.73702 .13009 L
.73705 .13097 L
.73711 .13378 L
.73717 .13725 L
.73723 .14196 L
.73734 .15276 L
.73746 .16845 L
.73772 .21662 L
.73796 .27399 L
.73841 .3858 L
.73853 .41246 L
.73866 .43708 L
.73877 .45475 L
.73889 .46971 L
.73896 .47594 L
.73902 .48057 L
.73907 .48404 L
.73913 .48672 L
.73917 .48775 L
.73918 .4882 L
.7392 .48856 L
.73922 .48884 L
.73923 .48907 L
.73926 .48932 L
.73928 .48938 L
.7393 .48937 L
.73932 .48928 L
.73933 .48913 L
.73935 .48893 L
.73937 .4887 L
.7394 .48802 L
.73946 .48633 L
.73952 .48427 L
.73965 .4783 L
.73989 .46542 L
.74001 .4591 L
.74014 .45344 L
.7402 .45138 L
Mistroke
.74026 .44963 L
.74032 .4485 L
.74035 .448 L
.74038 .44764 L
.74041 .44738 L
.74044 .4472 L
.74047 .44713 L
.74049 .44713 L
.74052 .4472 L
.74054 .44735 L
.74057 .44757 L
.74059 .44785 L
.74065 .4487 L
.74071 .44972 L
.74083 .45274 L
.74106 .46033 L
.7412 .46447 L
.74132 .46782 L
.74144 .47018 L
.74147 .47068 L
.7415 .47112 L
.74153 .47145 L
.74156 .47172 L
.74159 .47191 L
.74161 .47204 L
.74164 .47211 L
.74166 .47214 L
.74169 .47211 L
.74172 .47204 L
.74175 .4719 L
.74178 .4717 L
.74181 .47143 L
.74184 .47109 L
.7419 .47034 L
.74203 .46807 L
.74226 .46281 L
.74238 .46015 L
.74249 .45791 L
.74259 .45628 L
.74264 .45561 L
.7427 .45503 L
.74272 .45481 L
.74275 .45461 L
.74278 .45446 L
.74281 .45437 L
.74284 .45432 L
.74287 .45432 L
.7429 .45436 L
.74292 .45444 L
.74294 .4545 L
Mistroke
.74296 .45458 L
.74299 .45475 L
.74305 .45528 L
.74311 .45589 L
.74317 .45669 L
.74361 .46426 L
.74372 .4659 L
.74378 .46664 L
.74384 .46722 L
.74387 .46749 L
.74391 .46773 L
.74394 .46791 L
.74397 .46803 L
.744 .46811 L
.74403 .46816 L
.74404 .46817 L
.74406 .46817 L
.74409 .46814 L
.7441 .46811 L
.74412 .46806 L
.74415 .46795 L
.74418 .46778 L
.74422 .46757 L
.74429 .46701 L
.74435 .46633 L
.74459 .46304 L
.74483 .45969 L
.74495 .45834 L
.74501 .45774 L
.74504 .45752 L
.74508 .45731 L
.7451 .45715 L
.74513 .45703 L
.74516 .45694 L
.74519 .45687 L
.74521 .45684 L
.74524 .45683 L
.74526 .45684 L
.74529 .45687 L
.74532 .45694 L
.74535 .45704 L
.74538 .45718 L
.74541 .45733 L
.74552 .45815 L
.74597 .46341 L
.74609 .46473 L
.74616 .46532 L
.74622 .46577 L
.74627 .46607 L
.7463 .4662 L
Mistroke
.74633 .4663 L
.74636 .46637 L
.74639 .46642 L
.74641 .46644 L
.74642 .46644 L
.74645 .46643 L
.74647 .46641 L
.74649 .46639 L
.74652 .46631 L
.74655 .4662 L
.74659 .46604 L
.74666 .46565 L
.74672 .4652 L
.74697 .46281 L
.7472 .46034 L
.74726 .45976 L
.74733 .45921 L
.74739 .45879 L
.74745 .45848 L
.74748 .45837 L
.74751 .45826 L
.74752 .45822 L
.74754 .45818 L
.74757 .45813 L
.74759 .45811 L
.7476 .4581 L
.74762 .45809 L
.74764 .4581 L
.74767 .45812 L
.74768 .45815 L
.7477 .45818 L
.74773 .45825 L
.74775 .45834 L
.74782 .4586 L
.74787 .45893 L
.74794 .45937 L
.74838 .46344 L
.7485 .46436 L
.74857 .46477 L
.74863 .46507 L
.74866 .46521 L
.7487 .46533 L
.74871 .46537 L
.74873 .46541 L
.74876 .46545 L
.7488 .46548 L
.74882 .46548 L
.74884 .46547 L
.74886 .46545 L
.74887 .46543 L
Mistroke
.74889 .4654 L
.74892 .46533 L
.74895 .46524 L
.74901 .465 L
.74907 .46471 L
.74912 .46437 L
.74937 .46237 L
.74961 .46041 L
.74973 .45963 L
.7498 .4593 L
.74983 .45918 L
.74986 .45907 L
.74989 .45898 L
.74992 .45893 L
.74994 .45889 L
.74997 .45886 L
.75 .45885 L
.75002 .45885 L
.75005 .45887 L
.75007 .45891 L
.7501 .45897 L
.75014 .45905 L
.75019 .45925 L
.75025 .45951 L
.7503 .45979 L
.75076 .46314 L
.75088 .46394 L
.75095 .46429 L
.75101 .46455 L
.75107 .46471 L
.7511 .46478 L
.75112 .46482 L
.75115 .46485 L
.75117 .46486 L
.75119 .46487 L
.75121 .46486 L
.75125 .46484 L
.75126 .46482 L
.75128 .46479 L
.75131 .46473 L
.75134 .46465 L
.75137 .46454 L
.75149 .46402 L
.75163 .46317 L
.75176 .46225 L
.75199 .46064 L
.75206 .46027 L
.75213 .45994 L
.75218 .45971 L
.75225 .45952 L
Mistroke
.75228 .45945 L
.75231 .4594 L
.75234 .45937 L
.75237 .45936 L
.75238 .45935 L
.7524 .45936 L
.75243 .45938 L
.75245 .45939 L
.75246 .45942 L
.7525 .45948 L
.75253 .45955 L
.75256 .45964 L
.75261 .45984 L
.75274 .46043 L
.75297 .46191 L
.75319 .46326 L
.75324 .46357 L
.7533 .46385 L
.75336 .46406 L
.75342 .46424 L
.75345 .46431 L
.75348 .46437 L
.75351 .46441 L
.75353 .46443 L
.75354 .46444 L
.75357 .46445 L
.7536 .46444 L
.75363 .46441 L
.75366 .46438 L
.75369 .46433 L
.75372 .46427 L
.75377 .46411 L
.75387 .46371 L
.7541 .46246 L
.75435 .46096 L
.75447 .46036 L
.75452 .46015 L
.75458 .45997 L
.75461 .45989 L
.75464 .45983 L
.75467 .45978 L
.7547 .45974 L
.75473 .45972 L
.75476 .45971 L
.75479 .45972 L
.75481 .45973 L
.75482 .45974 L
.75484 .45976 L
.75485 .45978 L
.75488 .45983 L
Mistroke
.75492 .4599 L
.75495 .45999 L
.75509 .46049 L
.75533 .46179 L
.75546 .46256 L
.75559 .46321 L
.75569 .46365 L
.75575 .46385 L
.75581 .46398 L
.75584 .46404 L
.75587 .46408 L
.7559 .46412 L
.75591 .46413 L
.75593 .46414 L
.75596 .46414 L
.75599 .46413 L
.75602 .4641 L
.75605 .46407 L
.75608 .46403 L
.7561 .46397 L
.75616 .46383 L
.75626 .46346 L
.7565 .4623 L
.75662 .46165 L
.75675 .461 L
.75686 .46051 L
.75692 .46032 L
.75697 .46018 L
.757 .46012 L
.75703 .46007 L
.75705 .46003 L
.75708 .46 L
.75711 .45998 L
.75713 .45998 L
.75716 .45998 L
.75719 .45999 L
.75722 .46002 L
.75725 .46006 L
.75728 .4601 L
.75731 .46016 L
.75737 .46034 L
.75743 .46054 L
.75767 .46163 L
.75781 .46233 L
.75793 .46292 L
.75805 .4634 L
.75811 .46359 L
.75815 .46368 L
.75818 .46375 L
.75821 .46381 L
Mistroke
.75824 .46385 L
.75826 .46387 L
.75828 .46389 L
.7583 .4639 L
.75831 .46391 L
.75833 .46391 L
.75835 .46391 L
.75837 .4639 L
.75838 .46389 L
.75841 .46387 L
.75844 .46383 L
.75847 .46378 L
.7585 .46372 L
.75856 .46357 L
.75867 .46319 L
.75893 .46203 L
.75915 .46101 L
.75921 .46077 L
.75927 .46057 L
.75933 .46042 L
.75938 .4603 L
.75941 .46025 L
.75943 .46023 L
.75945 .46021 L
.75948 .46019 L
.75951 .46018 L
.75953 .46018 L
.75954 .46018 L
.75956 .46019 L
.75958 .4602 L
.75961 .46023 L
.75963 .46024 L
.75964 .46027 L
.7597 .46038 L
.75977 .46054 L
.75988 .46093 L
.76011 .46193 L
.76036 .463 L
.76043 .46325 L
.7605 .46345 L
.76056 .46358 L
.76059 .46364 L
.76062 .46368 L
.76065 .4637 L
.76068 .46372 L
.76071 .46373 L
.76073 .46373 L
.76074 .46372 L
.76078 .4637 L
.76079 .46369 L
Mistroke
.76081 .46367 L
.76084 .46363 L
.76087 .46358 L
.76093 .46345 L
.76098 .46331 L
.76111 .46289 L
.76132 .46195 L
.76145 .46141 L
.76158 .4609 L
.76165 .46071 L
.76171 .46055 L
.76177 .46045 L
.7618 .46041 L
.76183 .46038 L
.76185 .46036 L
.76188 .46034 L
.76191 .46034 L
.76193 .46034 L
.76196 .46036 L
.76199 .46038 L
.76202 .46041 L
.76205 .46045 L
.76211 .46056 L
.76216 .4607 L
.76228 .46108 L
.76254 .46214 L
.76265 .46261 L
.76278 .46305 L
.76283 .46322 L
.76289 .46336 L
.76292 .46342 L
.76295 .46347 L
.76297 .4635 L
.763 .46354 L
.76303 .46356 L
.76306 .46358 L
.76309 .46358 L
.76312 .46358 L
.76315 .46357 L
.76318 .46355 L
.76321 .46352 L
.76324 .46347 L
.7633 .46336 L
.76336 .46321 L
.76348 .46284 L
.76374 .46181 L
.76386 .46135 L
.76399 .46092 L
.76405 .46075 L
.76409 .46067 L
Mistroke
.76412 .4606 L
.76416 .46055 L
.76419 .46052 L
.76422 .46049 L
.76425 .46047 L
.76428 .46047 L
.76431 .46047 L
.76433 .46048 L
.76434 .46049 L
.76437 .46051 L
.7644 .46054 L
.76443 .46058 L
.76448 .46067 L
.76455 .46082 L
.76461 .46098 L
.76474 .46142 L
.76499 .4624 L
.76511 .46284 L
.76517 .463 L
.76523 .46316 L
.76528 .46327 L
.76533 .46336 L
.76536 .4634 L
.76539 .46343 L
.76542 .46345 L
.76544 .46346 L
.76547 .46347 L
.7655 .46347 L
.76553 .46345 L
.76555 .46344 L
.76558 .46341 L
.76562 .46337 L
.76567 .46327 L
.76573 .46315 L
.76579 .46299 L
.7659 .46264 L
.76615 .4617 L
.76629 .46123 L
.76636 .46103 L
.76642 .46087 L
.76647 .46076 L
.76653 .46066 L
.76656 .46063 L
.76659 .4606 L
.76663 .46058 L
.76664 .46058 L
.76666 .46057 L
.76669 .46058 L
.76672 .46059 L
.76674 .4606 L
Mistroke
.76677 .46063 L
.7668 .46066 L
.76684 .46071 L
.76689 .46082 L
.767 .46108 L
.76711 .46145 L
.76737 .46239 L
.7675 .46279 L
.76761 .46309 L
.76767 .4632 L
.76773 .46329 L
.76776 .46333 L
.76778 .46334 L
.76779 .46335 L
.76782 .46337 L
.76785 .46337 L
.76788 .46337 L
.7679 .46336 L
.76793 .46335 L
.76796 .46332 L
.76799 .46329 L
.76802 .46324 L
.76808 .46315 L
.7682 .46284 L
.76832 .46248 L
.76858 .46156 L
.76869 .46121 L
.76875 .46105 L
.76881 .46091 L
.76887 .46081 L
.76889 .46077 L
.76892 .46073 L
.76895 .4607 L
.76898 .46068 L
.769 .46067 L
.76903 .46066 L
.76906 .46066 L
.76909 .46067 L
.7691 .46068 L
.76912 .46069 L
.76915 .46071 L
.76918 .46074 L
.76921 .46078 L
.76927 .46088 L
.76939 .46117 L
.76952 .46158 L
.76977 .46241 L
.76989 .46278 L
.77 .46304 L
.77005 .46314 L
Mistroke
.77011 .46322 L
.77014 .46325 L
.77017 .46327 L
.7702 .46329 L
.77022 .46329 L
.77024 .46329 L
.77025 .46329 L
.77027 .46329 L
.7703 .46327 L
.77032 .46326 L
.77034 .46325 L
.77037 .46321 L
.77044 .46312 L
.7705 .46299 L
.77098 .46153 L
.77111 .46116 L
.77118 .461 L
.77124 .46088 L
.77128 .46083 L
.77131 .4608 L
.77132 .46078 L
.77134 .46076 L
.77136 .46075 L
.77138 .46074 L
.7714 .46073 L
.77144 .46073 L
.77147 .46074 L
.77149 .46075 L
.77152 .46077 L
.77155 .46079 L
.77161 .46087 L
.77167 .46097 L
.77173 .46111 L
.77195 .46175 L
.77219 .46251 L
.77231 .46285 L
.77238 .463 L
.77242 .46306 L
.77245 .4631 L
.77248 .46314 L
.77251 .46318 L
.77254 .4632 L
.77256 .46321 L
.77258 .46322 L
.77261 .46323 L
.77264 .46323 L
.77267 .46322 L
.7727 .4632 L
.77273 .46318 L
.77276 .46315 L
Mistroke
.77281 .46308 L
.77287 .46296 L
.77293 .46284 L
.77319 .46207 L
.77331 .4617 L
.77344 .46133 L
.77349 .46119 L
.77355 .46106 L
.77361 .46096 L
.77366 .46088 L
.7737 .46085 L
.77373 .46082 L
.77376 .4608 L
.77379 .46079 L
.77381 .46079 L
.77384 .4608 L
.77387 .46081 L
.7739 .46083 L
.77393 .46086 L
.77396 .46089 L
.77403 .461 L
.7741 .46112 L
.77416 .46127 L
.7744 .46197 L
.77465 .4627 L
.77472 .46285 L
.77479 .46299 L
.77485 .46308 L
.77488 .46312 L
.7749 .46313 L
.77491 .46314 L
.77494 .46316 L
.77496 .46317 L
.77498 .46317 L
.77501 .46317 L
.77504 .46317 L
.77506 .46316 L
.77509 .46314 L
.77512 .46311 L
.77515 .46308 L
.77521 .463 L
.77527 .46289 L
.7754 .46258 L
.77564 .46186 L
.77576 .46151 L
.77587 .46123 L
.77593 .4611 L
.776 .46099 L
.77603 .46095 L
.77606 .46091 L
Mistroke
.77608 .46089 L
.7761 .46088 L
.77612 .46086 L
.77613 .46086 L
.77616 .46085 L
.77619 .46084 L
.77621 .46084 L
.77623 .46085 L
.77626 .46086 L
.77629 .46088 L
.77631 .4609 L
.77637 .46097 L
.77643 .46107 L
.77649 .46118 L
.77661 .46147 L
.77683 .46211 L
.77695 .46246 L
.77708 .46279 L
.77714 .46291 L
.77721 .46301 L
.77726 .46307 L
.77729 .4631 L
.77732 .46311 L
.77735 .46312 L
.77738 .46313 L
.77741 .46312 L
.77744 .46312 L
.77747 .4631 L
.77748 .46309 L
.7775 .46307 L
.77756 .463 L
.77762 .46292 L
.77768 .46279 L
.77781 .46248 L
.77804 .46183 L
.77825 .46126 L
.77831 .46114 L
.77837 .46104 L
.7784 .46099 L
.77844 .46095 L
.77847 .46093 L
.7785 .46091 L
.77852 .46089 L
.77855 .46089 L
.77858 .46088 L
.7786 .46089 L
.77863 .4609 L
.77866 .46092 L
.77869 .46094 L
.77872 .46097 L
Mistroke
.77878 .46106 L
.77884 .46116 L
.77898 .46146 L
.77922 .46215 L
.77944 .46272 L
.7795 .46284 L
.77956 .46294 L
.77961 .46301 L
.77964 .46304 L
.77967 .46306 L
.77969 .46307 L
.77971 .46308 L
.77974 .46309 L
.77977 .46309 L
.7798 .46308 L
.77983 .46307 L
.77984 .46306 L
.77986 .46305 L
.77989 .46302 L
.77993 .46298 L
.77999 .46289 L
.78005 .46278 L
.78017 .46252 L
.78038 .46194 L
.78061 .46134 L
.78067 .46121 L
.78074 .46109 L
.78079 .46101 L
.78083 .46098 L
.78086 .46095 L
.78089 .46094 L
.78091 .46092 L
.78094 .46092 L
.78097 .46092 L
.781 .46093 L
.78101 .46093 L
.78103 .46094 L
.78106 .46096 L
.78109 .46099 L
.78115 .46106 L
.78121 .46116 L
.78132 .46138 L
.78156 .46204 L
.78169 .46238 L
.78181 .46267 L
.78187 .4628 L
.78195 .46292 L
.78198 .46296 L
.78201 .46299 L
.78204 .46302 L
Mistroke
.78207 .46304 L
.78208 .46304 L
.7821 .46305 L
.78213 .46306 L
.78216 .46306 L
.78219 .46305 L
.78222 .46304 L
.78223 .46303 L
.78225 .46301 L
.78232 .46295 L
.78237 .46287 L
.78243 .46277 L
.78255 .46251 L
.78276 .46194 L
.78299 .46136 L
.78305 .46123 L
.78311 .46112 L
.78317 .46105 L
.78319 .46102 L
.78322 .46099 L
.78325 .46097 L
.78328 .46096 L
.78331 .46095 L
.78334 .46095 L
.78337 .46095 L
.78339 .46096 L
.78342 .46097 L
.78344 .46099 L
.78347 .46102 L
.7835 .46105 L
.78357 .46114 L
.7837 .4614 L
.78394 .46203 L
.78418 .46262 L
.7843 .46285 L
.78433 .4629 L
.78436 .46294 L
.7844 .46297 L
.78443 .463 L
.78445 .46301 L
.78448 .46302 L
.78451 .46303 L
.78453 .46303 L
.78454 .46303 L
.78457 .46302 L
.7846 .46301 L
.78463 .46299 L
.78466 .46297 L
.78471 .46291 L
.78476 .46284 L
Mistroke
.78487 .46263 L
.78509 .46208 L
.78532 .46148 L
.78544 .46122 L
.78551 .46111 L
.78554 .46107 L
.78558 .46104 L
.7856 .46101 L
.78564 .46099 L
.78566 .46098 L
.78569 .46097 L
.78572 .46097 L
.78575 .46098 L
.78576 .46098 L
.78578 .46099 L
.78581 .461 L
.78584 .46103 L
.78587 .46106 L
.78594 .46115 L
.78601 .46126 L
.78608 .46141 L
.78632 .46203 L
.78645 .46235 L
.78658 .46265 L
.78669 .46285 L
.78672 .46289 L
.78675 .46293 L
.78678 .46296 L
.78681 .46298 L
.78684 .463 L
.78686 .463 L
.78688 .46301 L
.78689 .46301 L
.78691 .46301 L
.78694 .46301 L
.78697 .463 L
.78699 .46298 L
.78702 .46296 L
.78706 .46293 L
.78712 .46285 L
.78718 .46275 L
.78732 .46245 L
.78755 .46185 L
.78769 .46152 L
.78781 .46127 L
.78787 .46116 L
.78793 .46109 L
.78796 .46105 L
.78799 .46103 L
.78802 .46101 L
Mistroke
.78804 .461 L
.78806 .46099 L
.78809 .46099 L
.78812 .46099 L
.78815 .461 L
.78817 .46101 L
.7882 .46103 L
.78824 .46106 L
.7883 .46113 L
.78835 .46121 L
.78841 .46132 L
.78853 .46158 L
.78874 .46213 L
.78887 .46245 L
.78899 .4627 L
.78904 .46279 L
.7891 .46287 L
.78912 .4629 L
.78916 .46294 L
.78918 .46296 L
.78921 .46297 L
.78924 .46299 L
.78926 .46299 L
.78928 .46299 L
.78931 .46299 L
.78934 .46298 L
.78935 .46298 L
.78937 .46297 L
.78941 .46294 L
.78944 .46291 L
.78947 .46288 L
.78959 .46269 L
.78971 .46242 L
.78994 .46184 L
.79007 .46153 L
.79018 .46128 L
.79024 .46119 L
.79029 .46112 L
.79033 .46108 L
.79036 .46105 L
.79039 .46103 L
.79041 .46102 L
.79044 .46101 L
.79047 .461 L
.79049 .46101 L
.79052 .46101 L
.79054 .46102 L
.79057 .46104 L
.7906 .46106 L
.79062 .46108 L
Mistroke
.79068 .46114 L
.79074 .46124 L
.79086 .46148 L
.79108 .46203 L
.79121 .46235 L
.79134 .46264 L
.7914 .46275 L
.79146 .46284 L
.79149 .46288 L
.79152 .46291 L
.79155 .46294 L
.79158 .46296 L
.79161 .46297 L
.79164 .46298 L
.79167 .46298 L
.7917 .46298 L
.79173 .46297 L
.79176 .46295 L
.79179 .46293 L
.79182 .4629 L
.79188 .46283 L
.79193 .46275 L
.79205 .46252 L
.79231 .46188 L
.79243 .46157 L
.79255 .46132 L
.79265 .46115 L
.79271 .46109 L
.79274 .46106 L
.79276 .46104 L
.79279 .46103 L
.79282 .46102 L
.79285 .46101 L
.79288 .46102 L
.79291 .46102 L
.79292 .46103 L
.79294 .46104 L
.79297 .46106 L
.793 .46108 L
.79306 .46115 L
.79312 .46124 L
.79324 .46146 L
.79349 .4621 L
.79361 .46239 L
.79372 .46263 L
.79378 .46275 L
.79385 .46284 L
.79388 .46288 L
.79391 .46291 L
.79394 .46294 L
Mistroke
.79397 .46295 L
.79399 .46296 L
.79402 .46297 L
.79405 .46297 L
.79408 .46297 L
.7941 .46296 L
.79413 .46295 L
.79415 .46294 L
.79418 .46292 L
.79424 .46286 L
.7943 .46277 L
.79441 .46256 L
.79464 .46201 L
.79488 .46142 L
.79495 .46128 L
.79502 .46117 L
.79508 .4611 L
.79512 .46107 L
.79515 .46105 L
.79518 .46103 L
.79521 .46102 L
.79524 .46102 L
.79525 .46102 L
.79527 .46102 L
.7953 .46103 L
.79532 .46104 L
.79534 .46105 L
.79537 .46107 L
.7954 .46111 L
.79546 .46119 L
.79552 .46128 L
.79566 .46155 L
.7959 .46216 L
.79612 .46266 L
.79617 .46275 L
.79623 .46284 L
.79626 .46288 L
.79629 .46291 L
.79632 .46293 L
.79635 .46295 L
.79638 .46296 L
.79641 .46297 L
.79644 .46297 L
.79647 .46297 L
.7965 .46295 L
.79651 .46295 L
.79653 .46294 L
.79659 .46288 L
.79665 .46282 L
.7967 .46274 L
Mistroke
.79681 .46252 L
.79707 .46188 L
.79718 .4616 L
.79731 .46133 L
.79736 .46123 L
.79742 .46115 L
.79745 .46111 L
.79748 .46109 L
.79751 .46106 L
.79753 .46105 L
.79756 .46103 L
.79759 .46102 L
.79762 .46102 L
.79765 .46102 L
.79768 .46103 L
.79771 .46105 L
.79774 .46107 L
.79777 .4611 L
.79783 .46117 L
.79789 .46127 L
.79801 .46149 L
.79827 .46214 L
.79839 .46243 L
.79852 .46269 L
.79858 .4628 L
.79862 .46285 L
.79866 .46289 L
.79869 .46292 L
.79872 .46294 L
.79875 .46296 L
.79878 .46297 L
.79881 .46297 L
.79884 .46297 L
.79886 .46296 L
.79887 .46296 L
.7989 .46294 L
.79893 .46292 L
.79896 .46289 L
.79901 .46283 L
.79914 .46263 L
.79927 .46234 L
.79951 .46173 L
.79963 .46146 L
.79974 .46125 L
.7998 .46116 L
.79986 .46108 L
.7999 .46106 L
.79993 .46104 L
.79995 .46103 L
.79996 .46102 L
Mistroke
.79998 .46102 L
.8 .46102 L
.80003 .46102 L
.80006 .46103 L
.80009 .46105 L
.80011 .46106 L
.80014 .46109 L
.80018 .46113 L
.80024 .46121 L
.80071 .46228 L
.80084 .46258 L
.80091 .46271 L
.80097 .46282 L
.80104 .46289 L
.80107 .46293 L
.80109 .46294 L
.8011 .46295 L
.80113 .46296 L
.80116 .46297 L
.80119 .46297 L
.80121 .46297 L
.80122 .46297 L
.80125 .46296 L
.80128 .46295 L
.80131 .46293 L
.80134 .4629 L
.80139 .46284 L
.80144 .46276 L
.80157 .46253 L
.80168 .46225 L
.80193 .46162 L
.80206 .46135 L
.80211 .46125 L
.80217 .46116 L
.80223 .46109 L
.80226 .46107 L
.80228 .46105 L
.80231 .46103 L
.80233 .46102 L
.80236 .46102 L
.80239 .46101 L
.80241 .46102 L
.80245 .46103 L
.80246 .46104 L
.80248 .46105 L
.80251 .46107 L
.80257 .46113 L
.80262 .4612 L
.80274 .46143 L
.80287 .46174 L
Mistroke
.80312 .46235 L
.80322 .4626 L
.80334 .46281 L
.80337 .46285 L
.80341 .46289 L
.80344 .46292 L
.80347 .46295 L
.8035 .46296 L
.80353 .46297 L
.80354 .46298 L
.80356 .46298 L
.80359 .46298 L
.80362 .46297 L
.80364 .46297 L
.80365 .46296 L
.80368 .46294 L
.80372 .46291 L
.80378 .46284 L
.80383 .46276 L
.80397 .46249 L
.8041 .46218 L
.80433 .46159 L
.80445 .46132 L
.80451 .46121 L
.80457 .46113 L
.80463 .46107 L
.80465 .46104 L
.80468 .46103 L
.80471 .46101 L
.80473 .46101 L
.80475 .46101 L
.80478 .461 L
.8048 .46101 L
.80483 .46102 L
.80486 .46103 L
.80488 .46105 L
.8049 .46107 L
.80496 .46114 L
.80501 .46122 L
.80546 .46226 L
.80558 .46255 L
.80565 .46269 L
.80571 .4628 L
.80577 .46288 L
.8058 .46291 L
.80583 .46294 L
.80586 .46296 L
.80589 .46298 L
.80592 .46299 L
.80594 .46299 L
Mistroke
.80597 .46299 L
.80599 .46299 L
.80601 .46298 L
.80604 .46297 L
.80607 .46295 L
.80612 .4629 L
.80618 .46282 L
.80631 .46259 L
.80643 .46231 L
.80667 .46167 L
.80681 .46136 L
.80687 .46123 L
.80693 .46114 L
.80699 .46107 L
.80702 .46104 L
.80705 .46102 L
.80708 .46101 L
.8071 .461 L
.80713 .46099 L
.80715 .46099 L
.80717 .46099 L
.80718 .461 L
.8072 .461 L
.80723 .46102 L
.80726 .46104 L
.80729 .46106 L
.80735 .46114 L
.80742 .46124 L
.80754 .46149 L
.80765 .46177 L
.80786 .46232 L
.80798 .46261 L
.8081 .46282 L
.80815 .4629 L
.80818 .46293 L
.80822 .46296 L
.80823 .46297 L
.80825 .46299 L
.80827 .46299 L
.80828 .463 L
.80831 .46301 L
.80833 .46301 L
.80835 .46301 L
.80837 .463 L
.8084 .46299 L
.80843 .46298 L
.80846 .46296 L
.80851 .46291 L
.80856 .46284 L
.80868 .46261 L
Mistroke
.80879 .46236 L
.80901 .46177 L
.80914 .46146 L
.80925 .46123 L
.80931 .46113 L
.80937 .46105 L
.80941 .46102 L
.80943 .461 L
.80945 .46099 L
.80948 .46098 L
.80949 .46098 L
.80951 .46097 L
.80954 .46097 L
.80956 .46098 L
.80958 .46098 L
.8096 .461 L
.80964 .46102 L
.80966 .46104 L
.80969 .46107 L
.80975 .46115 L
.80987 .46137 L
.81 .46169 L
.81024 .46232 L
.81035 .4626 L
.81041 .46272 L
.81047 .46283 L
.81053 .4629 L
.81057 .46296 L
.8106 .46299 L
.81063 .463 L
.81066 .46302 L
.81069 .46303 L
.8107 .46303 L
.81072 .46303 L
.81075 .46303 L
.81078 .46302 L
.8108 .46301 L
.81081 .463 L
.81087 .46294 L
.8109 .4629 L
.81093 .46286 L
.81105 .46265 L
.81116 .4624 L
.8114 .46174 L
.81154 .4614 L
.8116 .46126 L
.81166 .46116 L
.81171 .46108 L
.81177 .46101 L
.8118 .46099 L
Mistroke
.81183 .46097 L
.81186 .46096 L
.81189 .46095 L
.81191 .46095 L
.81192 .46095 L
.81194 .46095 L
.81196 .46096 L
.81199 .46097 L
.812 .46098 L
.81202 .461 L
.81208 .46106 L
.81214 .46114 L
.81226 .46137 L
.81237 .46165 L
.81258 .46223 L
.8127 .46254 L
.81281 .46278 L
.81288 .46288 L
.81291 .46293 L
.81294 .46297 L
.81297 .463 L
.813 .46303 L
.81303 .46304 L
.81306 .46305 L
.81309 .46306 L
.81312 .46306 L
.81314 .46305 L
.81317 .46304 L
.81319 .46302 L
.81322 .463 L
.81327 .46294 L
.81333 .46286 L
.81339 .46275 L
.8135 .4625 L
.81375 .46182 L
.81387 .4615 L
.81398 .46124 L
.81404 .46114 L
.8141 .46105 L
.81413 .461 L
.81416 .46097 L
.81419 .46095 L
.81423 .46093 L
.81426 .46092 L
.81427 .46092 L
.81429 .46092 L
.81432 .46092 L
.81435 .46094 L
.81437 .46095 L
.81439 .46096 L
Mistroke
.81442 .46098 L
.81449 .46107 L
.81455 .46117 L
.81461 .46129 L
.81472 .46154 L
.81496 .46222 L
.81506 .46249 L
.81517 .46275 L
.81523 .46286 L
.81529 .46295 L
.81531 .46299 L
.81534 .46302 L
.81537 .46305 L
.8154 .46306 L
.81543 .46308 L
.81545 .46309 L
.81548 .46309 L
.81551 .46308 L
.81554 .46307 L
.81557 .46306 L
.8156 .46303 L
.81562 .46301 L
.81568 .46293 L
.81575 .46281 L
.81587 .46254 L
.81611 .46187 L
.81624 .46151 L
.81631 .46134 L
.81638 .46119 L
.81644 .46108 L
.81647 .46103 L
.81651 .46098 L
.81654 .46095 L
.81657 .46092 L
.8166 .4609 L
.81663 .46089 L
.81665 .46089 L
.81668 .46089 L
.81671 .46089 L
.81674 .4609 L
.81677 .46092 L
.8168 .46095 L
.81686 .46102 L
.81692 .46113 L
.81699 .46127 L
.81712 .4616 L
.81736 .4623 L
.81747 .4626 L
.81759 .46286 L
.81766 .46298 L
Mistroke
.81772 .46305 L
.81775 .46308 L
.81777 .46309 L
.81778 .4631 L
.81781 .46312 L
.81784 .46313 L
.81786 .46313 L
.81788 .46313 L
.81791 .46312 L
.81792 .46311 L
.81794 .4631 L
.81798 .46307 L
.81801 .46304 L
.81804 .463 L
.81811 .46289 L
.81823 .46262 L
.81835 .4623 L
.81858 .46161 L
.81871 .46128 L
.81877 .46114 L
.81883 .46103 L
.81887 .46096 L
.81893 .4609 L
.81895 .46088 L
.81898 .46086 L
.81901 .46085 L
.81904 .46084 L
.81907 .46084 L
.81908 .46085 L
.8191 .46085 L
.81913 .46087 L
.81916 .46089 L
.81921 .46095 L
.81927 .46103 L
.81939 .46129 L
.81951 .46161 L
.81974 .46229 L
.81985 .46262 L
.81998 .46291 L
.82004 .46302 L
.82008 .46307 L
.82011 .46311 L
.82015 .46314 L
.82018 .46316 L
.82021 .46317 L
.82024 .46317 L
.82027 .46317 L
.82029 .46316 L
.8203 .46316 L
.82033 .46314 L
Mistroke
.82036 .46311 L
.82041 .46305 L
.82047 .46296 L
.82059 .46269 L
.82071 .46236 L
.82092 .46171 L
.82104 .46138 L
.82115 .46109 L
.82122 .46097 L
.82128 .46088 L
.82131 .46085 L
.82133 .46083 L
.82135 .46082 L
.82138 .4608 L
.8214 .46079 L
.82143 .46079 L
.82146 .4608 L
.82149 .46081 L
.82152 .46082 L
.82155 .46085 L
.82158 .46089 L
.82164 .46098 L
.82175 .46121 L
.82187 .46153 L
.82209 .4622 L
.8222 .46254 L
.82231 .46285 L
.82237 .46298 L
.82244 .46309 L
.82247 .46313 L
.8225 .46317 L
.82253 .46319 L
.82255 .46321 L
.82258 .46322 L
.82261 .46323 L
.82264 .46323 L
.82266 .46322 L
.82269 .46321 L
.82272 .46318 L
.82275 .46315 L
.82278 .46312 L
.82289 .46293 L
.82299 .46267 L
.82324 .46189 L
.82336 .4615 L
.82348 .46119 L
.82358 .46096 L
.82363 .46087 L
.82369 .4608 L
.82372 .46077 L
Mistroke
.82374 .46075 L
.82377 .46074 L
.8238 .46073 L
.82383 .46073 L
.82386 .46074 L
.82388 .46076 L
.82391 .46078 L
.82394 .46081 L
.82397 .46084 L
.82403 .46094 L
.82414 .46118 L
.82439 .46195 L
.82451 .46237 L
.82465 .46278 L
.82471 .46294 L
.82478 .46307 L
.82483 .46317 L
.82486 .46321 L
.82489 .46324 L
.82492 .46326 L
.82495 .46328 L
.82498 .46329 L
.82501 .46329 L
.82504 .46329 L
.82505 .46328 L
.82507 .46327 L
.8251 .46325 L
.82513 .46322 L
.82518 .46315 L
.82523 .46306 L
.82535 .46278 L
.82559 .462 L
.82572 .46155 L
.82584 .46118 L
.82596 .46091 L
.82602 .46079 L
.82605 .46075 L
.82608 .46072 L
.82609 .4607 L
.82611 .46069 L
.82614 .46067 L
.82616 .46067 L
.82617 .46066 L
.82619 .46066 L
.82621 .46066 L
.82624 .46067 L
.82625 .46068 L
.82627 .46069 L
.8263 .46071 L
.82633 .46075 L
Mistroke
.82639 .46084 L
.82645 .46096 L
.82656 .46126 L
.82677 .46197 L
.82689 .46239 L
.82702 .4628 L
.82708 .46297 L
.82714 .46311 L
.8272 .46321 L
.82725 .4633 L
.82728 .46333 L
.82731 .46335 L
.82734 .46337 L
.82737 .46337 L
.8274 .46337 L
.82743 .46336 L
.82745 .46335 L
.82746 .46334 L
.8275 .46331 L
.82753 .46327 L
.82756 .46322 L
.82763 .46308 L
.82776 .46273 L
.828 .46188 L
.82814 .46141 L
.82826 .46102 L
.82837 .46078 L
.8284 .46072 L
.82843 .46068 L
.82845 .46064 L
.82848 .46061 L
.82851 .46059 L
.82854 .46058 L
.82857 .46057 L
.8286 .46058 L
.82863 .46059 L
.82866 .46061 L
.82867 .46062 L
.82869 .46064 L
.82872 .46068 L
.82878 .46079 L
.82884 .46093 L
.82895 .46124 L
.8292 .46214 L
.82941 .46289 L
.82947 .46306 L
.82953 .46321 L
.82959 .46332 L
.82965 .4634 L
.82968 .46343 L
Mistroke
.8297 .46345 L
.82973 .46346 L
.82975 .46347 L
.82977 .46347 L
.82979 .46346 L
.82983 .46345 L
.82985 .46342 L
.82988 .4634 L
.82994 .46331 L
.83 .46318 L
.83013 .46283 L
.83035 .46199 L
.83057 .46118 L
.83069 .46082 L
.83075 .46067 L
.83079 .46061 L
.83082 .46057 L
.83084 .46053 L
.83087 .46051 L
.83089 .46049 L
.83092 .46047 L
.83095 .46047 L
.83098 .46047 L
.83101 .46049 L
.83104 .46051 L
.83107 .46054 L
.8311 .46059 L
.83117 .46071 L
.83128 .46102 L
.83154 .46199 L
.83166 .46247 L
.83179 .46294 L
.83185 .46314 L
.83191 .46329 L
.83196 .46341 L
.83202 .4635 L
.83205 .46354 L
.83208 .46356 L
.83211 .46358 L
.83213 .46358 L
.83217 .46358 L
.83219 .46357 L
.83223 .46355 L
.83224 .46353 L
.83226 .46351 L
.83233 .4634 L
.8324 .46324 L
.83252 .46284 L
.83276 .4619 L
.833 .46093 L
Mistroke
.83306 .46074 L
.83313 .46057 L
.83317 .46049 L
.8332 .46044 L
.83322 .46041 L
.83324 .46039 L
.83326 .46037 L
.83327 .46036 L
.83329 .46035 L
.8333 .46034 L
.83333 .46034 L
.83335 .46034 L
.83337 .46035 L
.83338 .46035 L
.8334 .46037 L
.83343 .46039 L
.83346 .46043 L
.83352 .46054 L
.83358 .46069 L
.83364 .46087 L
.83378 .46136 L
.83402 .46243 L
.83414 .4629 L
.83424 .46328 L
.8343 .46344 L
.83436 .46356 L
.83438 .46361 L
.83441 .46366 L
.83445 .46369 L
.83446 .46371 L
.83448 .46372 L
.83451 .46373 L
.83452 .46373 L
.83454 .46373 L
.83457 .46371 L
.8346 .46369 L
.83462 .46368 L
.83463 .46366 L
.83466 .46361 L
.83473 .46347 L
.83479 .46331 L
.83485 .46313 L
.83497 .46265 L
.83518 .46166 L
.8353 .46116 L
.83542 .46071 L
.83548 .46051 L
.83551 .46043 L
.83555 .46035 L
.83558 .46029 L
Mistroke
.83561 .46024 L
.83564 .46021 L
.83567 .46019 L
.8357 .46018 L
.83573 .46018 L
.83576 .46019 L
.83579 .46021 L
.83582 .46025 L
.83585 .46029 L
.83591 .46042 L
.83596 .46056 L
.83602 .46076 L
.83614 .46124 L
.83636 .46226 L
.83647 .46281 L
.8366 .46333 L
.83666 .46352 L
.83672 .46368 L
.83677 .46379 L
.8368 .46384 L
.83683 .46387 L
.83685 .46388 L
.83686 .4639 L
.83688 .4639 L
.8369 .46391 L
.83692 .4639 L
.83696 .46389 L
.83697 .46388 L
.83699 .46386 L
.83703 .46381 L
.83706 .46374 L
.83709 .46368 L
.83721 .46332 L
.83733 .4628 L
.83756 .46164 L
.83769 .46103 L
.83781 .46053 L
.83786 .46035 L
.83792 .4602 L
.83795 .46013 L
.83798 .46007 L
.83801 .46003 L
.83804 .46 L
.83806 .45998 L
.83809 .45998 L
.83811 .45998 L
.83814 .45999 L
.83817 .46001 L
.83819 .46004 L
.83822 .46009 L
Mistroke
.83825 .46014 L
.8383 .46027 L
.83836 .46047 L
.83849 .46098 L
.83871 .46214 L
.83884 .46286 L
.83897 .46345 L
.83903 .46366 L
.83908 .46385 L
.83912 .46393 L
.83915 .464 L
.83918 .46405 L
.83921 .4641 L
.83924 .46412 L
.83927 .46414 L
.8393 .46414 L
.83933 .46413 L
.83936 .4641 L
.83939 .46406 L
.83942 .46401 L
.83945 .46394 L
.83951 .46378 L
.83956 .4636 L
.83968 .46307 L
.83994 .46162 L
.84006 .46091 L
.84018 .46037 L
.84023 .46016 L
.84029 .45997 L
.84032 .4599 L
.84035 .45984 L
.84037 .45979 L
.8404 .45976 L
.84043 .45973 L
.84044 .45972 L
.84046 .45971 L
.84049 .45971 L
.84052 .45973 L
.84055 .45975 L
.84058 .45979 L
.84061 .45984 L
.84063 .4599 L
.84069 .46008 L
.84075 .4603 L
.84089 .46094 L
.84113 .46239 L
.84134 .46362 L
.8414 .46388 L
.84146 .46411 L
.84152 .46426 L
Mistroke
.84155 .46433 L
.84158 .46438 L
.84159 .4644 L
.84161 .46442 L
.84164 .46444 L
.84167 .46444 L
.8417 .46444 L
.84173 .46441 L
.84175 .46439 L
.84176 .46436 L
.8418 .4643 L
.84183 .46421 L
.8419 .464 L
.84196 .46375 L
.84207 .46315 L
.84228 .4618 L
.84251 .46038 L
.84257 .46006 L
.84264 .45978 L
.8427 .45959 L
.84273 .4595 L
.84276 .45944 L
.84279 .4594 L
.84282 .45937 L
.84285 .45935 L
.84286 .45935 L
.84288 .45936 L
.8429 .45937 L
.84293 .45941 L
.84296 .45946 L
.84299 .45952 L
.84305 .4597 L
.84311 .45993 L
.84322 .4605 L
.84347 .46217 L
.84371 .46382 L
.84378 .46419 L
.84385 .46448 L
.84391 .46467 L
.84394 .46475 L
.84397 .46481 L
.844 .46484 L
.84403 .46486 L
.84406 .46487 L
.84408 .46485 L
.84411 .46483 L
.84413 .4648 L
.84414 .46477 L
.84417 .46471 L
.8442 .46463 L
Mistroke
.84426 .46443 L
.84432 .46414 L
.84445 .46338 L
.84466 .46179 L
.84489 .46008 L
.84495 .45972 L
.84501 .45939 L
.84507 .45915 L
.84513 .45899 L
.84514 .45895 L
.84516 .45892 L
.84519 .45888 L
.84522 .45885 L
.84524 .45885 L
.84525 .45885 L
.84528 .45887 L
.84531 .45891 L
.84533 .45894 L
.84534 .45897 L
.84537 .45905 L
.84543 .45926 L
.84549 .45951 L
.8456 .46024 L
.84582 .46197 L
.84604 .46387 L
.84616 .46464 L
.84622 .46498 L
.84628 .46522 L
.84632 .46533 L
.84633 .46537 L
.84635 .4654 L
.84638 .46545 L
.84641 .46547 L
.84644 .46548 L
.84646 .46547 L
.84647 .46545 L
.84649 .46543 L
.84651 .4654 L
.84654 .46532 L
.84657 .46522 L
.8466 .46512 L
.84667 .46481 L
.84678 .46403 L
.847 .46207 L
.84723 .4599 L
.84736 .45899 L
.84742 .45859 L
.84746 .45844 L
.84749 .45832 L
.84752 .45823 L
Mistroke
.84755 .45816 L
.84758 .45812 L
.8476 .4581 L
.84763 .45809 L
.84766 .45811 L
.84768 .45814 L
.84769 .45817 L
.84772 .45824 L
.84775 .45834 L
.84778 .45847 L
.84785 .45883 L
.84792 .45929 L
.84799 .45987 L
.84824 .46241 L
.84836 .46374 L
.84849 .46497 L
.8486 .46578 L
.84863 .46596 L
.84866 .46611 L
.84869 .46623 L
.84872 .46632 L
.84875 .46639 L
.84877 .46642 L
.84879 .46643 L
.8488 .46644 L
.84882 .46644 L
.84885 .46642 L
.84888 .46637 L
.84891 .4663 L
.84894 .46619 L
.84897 .46606 L
.84903 .46568 L
.84909 .46521 L
.84923 .46384 L
.84947 .46099 L
.8496 .45941 L
.84972 .45817 L
.84978 .45766 L
.84984 .45728 L
.84987 .45713 L
.8499 .457 L
.84992 .45694 L
.84994 .4569 L
.84995 .45687 L
.84997 .45684 L
.85 .45683 L
.85003 .45684 L
.85004 .45686 L
.85006 .4569 L
.85009 .45698 L
Mistroke
.85012 .4571 L
.85015 .45725 L
.85021 .4576 L
.85032 .4586 L
.85042 .45982 L
.85065 .46319 L
.85077 .46492 L
.8509 .46653 L
.85096 .46712 L
.85103 .46762 L
.85105 .46778 L
.85108 .46792 L
.85111 .46804 L
.85114 .46812 L
.85117 .46816 L
.8512 .46817 L
.85122 .46815 L
.85125 .46808 L
.85127 .46803 L
.85129 .46797 L
.85132 .46782 L
.85137 .46744 L
.85143 .46696 L
.85148 .46633 L
.85159 .46492 L
.85183 .4607 L
.85195 .45857 L
.85206 .4568 L
.85216 .45554 L
.85222 .455 L
.85227 .45464 L
.8523 .4545 L
.85233 .4544 L
.85236 .45433 L
.85239 .45432 L
.85241 .45435 L
.85244 .45441 L
.85247 .45452 L
.8525 .45468 L
.85253 .4549 L
.85256 .45515 L
.85262 .45588 L
.85274 .45773 L
.85296 .46245 L
.85309 .46536 L
.85322 .46827 L
.85328 .46943 L
.85335 .47046 L
.8534 .47117 L
.85343 .47149 L
Mistroke
.85346 .47173 L
.85349 .47192 L
.85352 .47205 L
.85355 .47212 L
.85358 .47214 L
.8536 .4721 L
.85364 .47199 L
.85365 .47191 L
.85367 .4718 L
.8537 .47156 L
.85375 .47091 L
.85381 .47007 L
.85391 .46795 L
.85415 .46109 L
.85428 .45672 L
.85441 .45286 L
.85453 .44982 L
.85459 .44854 L
.85463 .44806 L
.85466 .4477 L
.85468 .44746 L
.85471 .44727 L
.85474 .44715 L
.85477 .44712 L
.85479 .44718 L
.85483 .44734 L
.85485 .44759 L
.85488 .44791 L
.85494 .44892 L
.855 .45024 L
.85506 .45208 L
.85513 .4545 L
.85539 .46723 L
.85563 .4803 L
.85569 .48333 L
.85577 .48603 L
.8558 .4871 L
.85583 .48793 L
.85586 .48854 L
.85589 .48901 L
.85592 .48929 L
.85595 .48938 L
.85598 .48928 L
.856 .48914 L
.85602 .48894 L
.85605 .48837 L
.85606 .48793 L
.85608 .48746 L
.85614 .48502 L
.8562 .48211 L
Mistroke
.85626 .47796 L
.85638 .46646 L
.85649 .45097 L
.85662 .43039 L
.85684 .38418 L
.85734 .25892 L
.85757 .20675 L
.8577 .18271 L
.85781 .16382 L
.85793 .14987 L
.85798 .14398 L
.85805 .13883 L
.8581 .13536 L
.85815 .13241 L
.85818 .1314 L
.85821 .13049 L
.85823 .12982 L
.85826 .12933 L
.85827 .12909 L
.85829 .12888 L
.85832 .12868 L
.85833 .12865 L
.85835 .12868 L
.85838 .1289 L
.85841 .12927 L
.85844 .12975 L
.8585 .13132 L
.85857 .13366 L
.85863 .13628 L
.85876 .14326 L
.85901 .15693 L
.85913 .16211 L
.85918 .16446 L
.85925 .16661 L
.85931 .16828 L
.85936 .16945 L
.85941 .17025 L
.85944 .17053 L
.85947 .17075 L
.8595 .17088 L
.85953 .17091 L
.85954 .17089 L
.85956 .17084 L
.85959 .17067 L
.85962 .17042 L
.85965 .17008 L
.85971 .16925 L
.85976 .16807 L
.85983 .16653 L
.85994 .16321 L
Mistroke
.8602 .15475 L
.86032 .15134 L
.86045 .14847 L
.86052 .14727 L
.86055 .14683 L
.86059 .1465 L
.86062 .14624 L
.86063 .14613 L
.86065 .14604 L
.86068 .14594 L
.86071 .1459 L
.86073 .14591 L
.86075 .14593 L
.86078 .14604 L
.86081 .1462 L
.86083 .1464 L
.8609 .14704 L
.86096 .14797 L
.86107 .14997 L
.8612 .15263 L
.86144 .15813 L
.86155 .16046 L
.86166 .16214 L
.86172 .16282 L
.86175 .1631 L
.86179 .16335 L
.86181 .16346 L
.86183 .16354 L
.86184 .16361 L
.86186 .16366 L
.86189 .16371 L
.86191 .16372 L
.86192 .16371 L
.86196 .16365 L
.86199 .16354 L
.86201 .16341 L
.86204 .16323 L
.86211 .16269 L
.86216 .16202 L
.8624 .15835 L
.86265 .15386 L
.86277 .15213 L
.86283 .15136 L
.86289 .15078 L
.86294 .15039 L
.86297 .15023 L
.86299 .15009 L
.86302 .14997 L
.86305 .1499 L
.86308 .14986 L
Mistroke
.86311 .14986 L
.86314 .1499 L
.86316 .14995 L
.86319 .15005 L
.86322 .15017 L
.86326 .15046 L
.86332 .15088 L
.86344 .15214 L
.86355 .15362 L
.86377 .15693 L
.86389 .15853 L
.86401 .1599 L
.86408 .16043 L
.86411 .16066 L
.86415 .16086 L
.86418 .16101 L
.86421 .1611 L
.86424 .16117 L
.86427 .1612 L
.8643 .1612 L
.86433 .16117 L
.86435 .16112 L
.86438 .16104 L
.86441 .16091 L
.86445 .16074 L
.86451 .16035 L
.86462 .15935 L
.86474 .158 L
.86496 .15533 L
.86507 .15395 L
.86519 .15287 L
.86525 .1524 L
.86528 .15219 L
.86531 .152 L
.86534 .15187 L
.86537 .15175 L
.8654 .15167 L
.86543 .15162 L
.86546 .1516 L
.86549 .15159 L
.86552 .15162 L
.86554 .15166 L
.86557 .15171 L
.86559 .1518 L
.86564 .15202 L
.8657 .15234 L
.86576 .15277 L
.86587 .15375 L
.86612 .15641 L
.86624 .15767 L
Mistroke
.86635 .15865 L
.86641 .15906 L
.86647 .15942 L
.8665 .15958 L
.86653 .1597 L
.86656 .1598 L
.8666 .15987 L
.86663 .15992 L
.86664 .15994 L
.86666 .15994 L
.86669 .15993 L
.86672 .1599 L
.86674 .15987 L
.86676 .15984 L
.86679 .15975 L
.86683 .15961 L
.86686 .15945 L
.86698 .15873 L
.8671 .15771 L
.86732 .15559 L
.86744 .15453 L
.86756 .15359 L
.86763 .15316 L
.8677 .15287 L
.86773 .15276 L
.86776 .15267 L
.86778 .15263 L
.86779 .15261 L
.86782 .15257 L
.86785 .15256 L
.86788 .15256 L
.86791 .15259 L
.86794 .15264 L
.86797 .1527 L
.86799 .15277 L
.86805 .15298 L
.86811 .15328 L
.86817 .15368 L
.86829 .15455 L
.86852 .1565 L
.86873 .15812 L
.86879 .15845 L
.86884 .15872 L
.86887 .15884 L
.8689 .15895 L
.86893 .15903 L
.86896 .15909 L
.86897 .15912 L
.86899 .15915 L
.86902 .15918 L
Mistroke
.86904 .15918 L
.86906 .15918 L
.86907 .15918 L
.86909 .15917 L
.86912 .15913 L
.86913 .1591 L
.86915 .15907 L
.86921 .15891 L
.86924 .15879 L
.86927 .15865 L
.86933 .15835 L
.86947 .15748 L
.86971 .15557 L
.86983 .15472 L
.86994 .15403 L
.87 .15372 L
.87007 .15346 L
.8701 .15337 L
.87013 .15329 L
.87016 .15324 L
.87018 .1532 L
.87021 .15318 L
.87024 .15317 L
.87026 .15317 L
.87029 .1532 L
.87032 .15324 L
.87035 .1533 L
.87038 .15337 L
.87041 .15345 L
.87052 .15391 L
.87062 .1545 L
.87083 .15596 L
.87106 .1575 L
.87112 .15785 L
.87119 .15816 L
.87125 .15838 L
.87128 .15847 L
.87131 .15855 L
.87134 .15861 L
.87137 .15865 L
.8714 .15867 L
.87141 .15868 L
.87143 .15868 L
.87146 .15867 L
.87148 .15865 L
.87151 .15861 L
.87154 .15856 L
.87157 .15849 L
.8716 .1584 L
.87166 .1582 L
Mistroke
.87177 .15769 L
.87202 .15614 L
.87215 .15525 L
.87228 .15451 L
.8724 .154 L
.87243 .15389 L
.87246 .1538 L
.87249 .15372 L
.87252 .15367 L
.87255 .15363 L
.87258 .1536 L
.87261 .15359 L
.87264 .15359 L
.87267 .15361 L
.8727 .15364 L
.87272 .15368 L
.87275 .15373 L
.87281 .15389 L
.87288 .15412 L
.87299 .15468 L
.87324 .15612 L
.87336 .15689 L
.8735 .15759 L
.87357 .15786 L
.87363 .15807 L
.87369 .1582 L
.87372 .15826 L
.87375 .15829 L
.87378 .15831 L
.8738 .15832 L
.87383 .15832 L
.87386 .1583 L
.87388 .15829 L
.87389 .15827 L
.87392 .15822 L
.87398 .15809 L
.87404 .15791 L
.87411 .15765 L
.87424 .157 L
.87449 .1556 L
.87461 .15497 L
.87467 .15467 L
.87473 .15442 L
.87479 .15423 L
.87484 .15409 L
.87486 .15403 L
.87489 .15398 L
.87492 .15394 L
.87495 .15391 L
.87498 .1539 L
Mistroke
.87501 .1539 L
.87503 .1539 L
.87504 .15391 L
.87506 .15392 L
.87508 .15394 L
.87511 .15399 L
.87514 .15404 L
.87521 .15422 L
.87527 .15442 L
.87533 .15464 L
.87545 .15523 L
.87568 .15645 L
.8758 .15707 L
.87592 .15754 L
.87598 .15774 L
.87604 .1579 L
.87608 .15797 L
.87609 .15799 L
.87611 .15801 L
.87614 .15804 L
.87616 .15805 L
.87618 .15806 L
.8762 .15806 L
.87623 .15804 L
.87626 .15802 L
.87629 .15799 L
.87632 .15794 L
.87635 .15788 L
.87642 .15771 L
.87654 .15726 L
.87666 .1567 L
.87689 .15556 L
.877 .15501 L
.87713 .15454 L
.87719 .15436 L
.87723 .15428 L
.87726 .15422 L
.87728 .15419 L
.8773 .15417 L
.87733 .15414 L
.87736 .15413 L
.87739 .15413 L
.87741 .15413 L
.87742 .15414 L
.87745 .15416 L
.87748 .1542 L
.87752 .15425 L
.87758 .15438 L
.87764 .15455 L
.87775 .15494 L
Mistroke
.87786 .15546 L
.87813 .15672 L
.87824 .1572 L
.87831 .15742 L
.87837 .1576 L
.87842 .15772 L
.87846 .15777 L
.87849 .15781 L
.87852 .15784 L
.87853 .15785 L
.87855 .15785 L
.87858 .15785 L
.8786 .15785 L
.87861 .15784 L
.87863 .15783 L
.87865 .15782 L
.87868 .15778 L
.87871 .15773 L
.87875 .15766 L
.87882 .15749 L
.87888 .15729 L
.87911 .15633 L
.87924 .15572 L
.87936 .15519 L
.87948 .15475 L
.87955 .15458 L
.87958 .1545 L
.87961 .15444 L
.87964 .15439 L
.87967 .15435 L
.8797 .15433 L
.87972 .15432 L
.87974 .15431 L
.87977 .15431 L
.87979 .15431 L
.87982 .15433 L
.87985 .15435 L
.87988 .15439 L
.87991 .15443 L
.87996 .15454 L
.88006 .15483 L
.88018 .15527 L
.8803 .15575 L
.88042 .15628 L
.88055 .15682 L
.88066 .15723 L
.88072 .1574 L
.88078 .15753 L
.88081 .15758 L
.88084 .15762 L
Mistroke
.88086 .15764 L
.88087 .15766 L
.8809 .15768 L
.88093 .15769 L
.88096 .15769 L
.88099 .15769 L
.88101 .15767 L
.88104 .15765 L
.88107 .15762 L
.88112 .15753 L
.88118 .15742 L
.88123 .15728 L
.88146 .15643 L
.8817 .15542 L
.8818 .15505 L
.88191 .15474 L
.88197 .15461 L
.88203 .15452 L
.88205 .15449 L
.88208 .15447 L
.88211 .15446 L
.88214 .15445 L
.88216 .15445 L
.88219 .15446 L
.88222 .15448 L
.88224 .15451 L
.88227 .15454 L
.8823 .15459 L
.88236 .15471 L
.88249 .15505 L
.8826 .15547 L
.88286 .15651 L
.88299 .15696 L
.88304 .15713 L
.8831 .15729 L
.88316 .15741 L
.88322 .1575 L
.88325 .15753 L
.88328 .15755 L
.88329 .15756 L
.88331 .15756 L
.88334 .15757 L
.88337 .15756 L
.88339 .15755 L
.88341 .15754 L
.88344 .15751 L
.88347 .15746 L
.88354 .15735 L
.8836 .15721 L
.88383 .15646 L
Mistroke
.88404 .15561 L
.88416 .15519 L
.88427 .15487 L
.88434 .15474 L
.88437 .15469 L
.8844 .15464 L
.88443 .15461 L
.88445 .1546 L
.88446 .15458 L
.88449 .15457 L
.88452 .15457 L
.88455 .15457 L
.88458 .15458 L
.88461 .1546 L
.88462 .15462 L
.88464 .15463 L
.8847 .15472 L
.88475 .15482 L
.88485 .15508 L
.88496 .15544 L
.88521 .15637 L
.88533 .15679 L
.88544 .15711 L
.8855 .15724 L
.88556 .15734 L
.88559 .15739 L
.88562 .15742 L
.88565 .15744 L
.88567 .15745 L
.88569 .15746 L
.8857 .15746 L
.88572 .15746 L
.88575 .15745 L
.88577 .15745 L
.88578 .15744 L
.88582 .1574 L
.88585 .15736 L
.88588 .15732 L
.88595 .1572 L
.88619 .15647 L
.88645 .15554 L
.88656 .1552 L
.88667 .15491 L
.88674 .15479 L
.88677 .15475 L
.8868 .15472 L
.88683 .15469 L
.88686 .15467 L
.88688 .15466 L
.88691 .15466 L
Mistroke
.88694 .15467 L
.88697 .15468 L
.887 .1547 L
.88702 .15473 L
.88708 .15481 L
.88714 .15492 L
.88724 .15517 L
.88735 .15552 L
.88761 .1564 L
.88772 .15676 L
.88778 .15694 L
.88784 .15708 L
.8879 .15721 L
.88796 .15729 L
.88799 .15732 L
.88802 .15735 L
.88805 .15737 L
.88807 .15737 L
.88809 .15737 L
.88812 .15737 L
.88815 .15736 L
.88817 .15735 L
.88818 .15734 L
.88822 .15731 L
.88825 .15727 L
.88828 .15721 L
.88835 .15708 L
.88848 .15676 L
.8886 .15635 L
.88884 .15555 L
.88896 .1552 L
.88902 .15504 L
.88908 .15492 L
.88915 .15482 L
.88918 .15479 L
.8892 .15477 L
.88922 .15476 L
.88925 .15474 L
.88927 .15474 L
.88929 .15474 L
.88932 .15475 L
.88934 .15475 L
.88935 .15476 L
.88938 .15478 L
.88941 .15481 L
.88947 .15489 L
.88953 .155 L
.8896 .15516 L
.88983 .15587 L
.88995 .15626 L
Mistroke
.89008 .15665 L
.89019 .15695 L
.89025 .15708 L
.8903 .15717 L
.89034 .15722 L
.89037 .15725 L
.8904 .15728 L
.89042 .15729 L
.89044 .1573 L
.89047 .1573 L
.8905 .1573 L
.89052 .15729 L
.89053 .15729 L
.89055 .15728 L
.89057 .15727 L
.8906 .15724 L
.89063 .1572 L
.89068 .15712 L
.89074 .15701 L
.89081 .15686 L
.89107 .15607 L
.89119 .15565 L
.89131 .15531 L
.89142 .15506 L
.89148 .15495 L
.89153 .15488 L
.89157 .15485 L
.89159 .15483 L
.89163 .15481 L
.89164 .15481 L
.89166 .15481 L
.89169 .15481 L
.89172 .15482 L
.89175 .15483 L
.89178 .15486 L
.8918 .15488 L
.89183 .15492 L
.89189 .15502 L
.89201 .15526 L
.89225 .15601 L
.89237 .15636 L
.89249 .15671 L
.89254 .15685 L
.8926 .15698 L
.89265 .15707 L
.89271 .15715 L
.89274 .15719 L
.89277 .15721 L
.8928 .15723 L
.89282 .15724 L
Mistroke
.89284 .15724 L
.89286 .15724 L
.8929 .15724 L
.89292 .15722 L
.89295 .1572 L
.89298 .15718 L
.89301 .15715 L
.89307 .15706 L
.89317 .15685 L
.89342 .15616 L
.89355 .15574 L
.89368 .15539 L
.89378 .15513 L
.89384 .15503 L
.8939 .15495 L
.89393 .15492 L
.89396 .15489 L
.89398 .15488 L
.89399 .15487 L
.89403 .15486 L
.89406 .15486 L
.89409 .15487 L
.89411 .15488 L
.89414 .1549 L
.89417 .15492 L
.8942 .15495 L
.89425 .15503 L
.89437 .15526 L
.89458 .15584 L
.89481 .15653 L
.89494 .15685 L
.895 .15697 L
.89506 .15706 L
.89511 .15713 L
.89514 .15715 L
.89517 .15717 L
.8952 .15719 L
.89522 .15719 L
.89523 .15719 L
.89526 .15719 L
.89529 .15718 L
.89532 .15717 L
.89534 .15715 L
.89539 .1571 L
.89544 .15703 L
.8955 .15693 L
.89575 .15631 L
.896 .15555 L
.89611 .15528 L
.89617 .15516 L
Mistroke
.89623 .15507 L
.89626 .15502 L
.89629 .15498 L
.89632 .15495 L
.89635 .15493 L
.89638 .15492 L
.89641 .15491 L
.89644 .15491 L
.89647 .15491 L
.8965 .15493 L
.89652 .15494 L
.89655 .15497 L
.89659 .155 L
.89665 .15509 L
.8967 .15519 L
.89692 .15571 L
.89717 .15644 L
.89728 .15672 L
.89733 .15685 L
.8974 .15696 L
.89746 .15705 L
.89749 .15708 L
.89751 .15711 L
.89754 .15713 L
.89757 .15714 L
.8976 .15715 L
.89762 .15715 L
.89765 .15715 L
.89768 .15713 L
.89771 .15712 L
.89774 .1571 L
.8978 .15703 L
.89786 .15693 L
.89798 .15667 L
.8981 .15637 L
.89836 .15563 L
.89848 .15533 L
.89855 .1552 L
.89862 .15509 L
.89867 .15501 L
.89871 .15498 L
.89874 .15496 L
.89877 .15495 L
.8988 .15495 L
.89883 .15495 L
.89885 .15495 L
.89888 .15496 L
.89891 .15498 L
.89894 .15501 L
.89897 .15504 L
Mistroke
.89907 .15519 L
.89918 .15543 L
.8993 .15574 L
.89955 .15644 L
.89967 .15674 L
.89978 .15694 L
.89981 .15698 L
.89984 .15702 L
.89987 .15705 L
.8999 .15708 L
.89993 .1571 L
.89995 .1571 L
.89996 .15711 L
.89999 .15711 L
.90002 .15711 L
.90004 .15711 L
.90006 .1571 L
.90008 .15709 L
.9001 .15708 L
.90013 .15705 L
.90016 .15702 L
.90023 .15693 L
.90029 .15682 L
.90073 .15567 L
.90085 .15537 L
.90092 .15524 L
.90098 .15513 L
.90104 .15506 L
.90107 .15503 L
.90111 .155 L
.90113 .15499 L
.90116 .15498 L
.90119 .15498 L
.90122 .15498 L
.90125 .15499 L
.90128 .155 L
.90129 .15501 L
.90131 .15503 L
.90134 .15506 L
.9014 .15513 L
.90145 .15521 L
.90158 .15548 L
.9017 .15579 L
.90194 .15646 L
.90208 .15677 L
.90214 .15689 L
.9022 .15697 L
.90223 .157 L
.90226 .15703 L
.90229 .15705 L
Mistroke
.90231 .15707 L
.90234 .15708 L
.90237 .15709 L
.9024 .15708 L
.90243 .15708 L
.90246 .15706 L
.90248 .15705 L
.9025 .15704 L
.90255 .15698 L
.90262 .15688 L
.90268 .15677 L
.90313 .15564 L
.90325 .15536 L
.90331 .15523 L
.90338 .15513 L
.90344 .15507 L
.90347 .15504 L
.9035 .15502 L
.90353 .15501 L
.90356 .155 L
.90359 .155 L
.90362 .15501 L
.90365 .15502 L
.90367 .15504 L
.9037 .15506 L
.90373 .15509 L
.90383 .15524 L
.90394 .15547 L
.90407 .15576 L
.90431 .15642 L
.90443 .1567 L
.90455 .1569 L
.90457 .15694 L
.9046 .15698 L
.90463 .157 L
.90466 .15703 L
.90469 .15705 L
.90471 .15705 L
.90473 .15706 L
.90476 .15706 L
.90479 .15706 L
.9048 .15706 L
.90482 .15705 L
.90484 .15704 L
.90485 .15703 L
.90489 .157 L
.90492 .15697 L
.90499 .15688 L
.90505 .15678 L
.90549 .15569 L
Mistroke
.90561 .15541 L
.90568 .15528 L
.90574 .15518 L
.9058 .1551 L
.90583 .15507 L
.90586 .15505 L
.90589 .15504 L
.90592 .15503 L
.90595 .15502 L
.90598 .15503 L
.906 .15503 L
.90603 .15505 L
.90605 .15506 L
.90607 .15507 L
.9061 .1551 L
.90615 .15516 L
.90621 .15524 L
.90633 .15549 L
.90645 .15579 L
.9067 .15643 L
.90683 .15673 L
.9069 .15684 L
.90696 .15693 L
.90699 .15696 L
.90702 .15699 L
.90704 .15701 L
.90707 .15702 L
.9071 .15704 L
.90713 .15704 L
.90716 .15704 L
.90719 .15704 L
.90722 .15702 L
.90723 .15702 L
.90725 .157 L
.90731 .15695 L
.90734 .15691 L
.90738 .15686 L
.90744 .15675 L
.90767 .15622 L
.90788 .15567 L
.908 .15541 L
.90806 .15529 L
.90812 .15519 L
.90817 .15513 L
.9082 .15511 L
.90822 .15508 L
.90825 .15506 L
.90828 .15505 L
.90831 .15504 L
.90834 .15504 L
Mistroke
.90837 .15505 L
.90839 .15505 L
.9084 .15506 L
.90843 .15508 L
.90847 .1551 L
.90852 .15516 L
.90858 .15525 L
.90871 .1555 L
.90884 .1558 L
.90909 .15644 L
.90921 .15671 L
.90927 .15682 L
.90933 .1569 L
.90938 .15696 L
.9094 .15698 L
.90943 .157 L
.90946 .15701 L
.90948 .15702 L
.90951 .15703 L
.90954 .15703 L
.90957 .15702 L
.9096 .15701 L
.90961 .157 L
.90963 .15699 L
.90966 .15697 L
.90972 .1569 L
.90977 .15683 L
.91001 .15633 L
.91026 .15569 L
.91037 .15542 L
.91044 .1553 L
.9105 .15521 L
.91055 .15515 L
.9106 .1551 L
.91063 .15508 L
.91066 .15506 L
.91069 .15505 L
.91072 .15505 L
.91074 .15506 L
.91077 .15506 L
.9108 .15508 L
.91082 .15509 L
.91085 .15512 L
.91089 .15515 L
.91094 .15523 L
.91107 .15546 L
.91119 .15573 L
.9114 .15626 L
.91151 .15653 L
.91162 .15676 L
Mistroke
.91168 .15685 L
.91174 .15693 L
.91177 .15696 L
.9118 .15698 L
.91183 .157 L
.91185 .15701 L
.91188 .15702 L
.91191 .15702 L
.91194 .15702 L
.91197 .15701 L
.91199 .15699 L
.91202 .15698 L
.91207 .15693 L
.91213 .15685 L
.9122 .15675 L
.91231 .15651 L
.91257 .15587 L
.91268 .15558 L
.9128 .15535 L
.91286 .15525 L
.91292 .15516 L
.91295 .15513 L
.91299 .1551 L
.91301 .15508 L
.91304 .15507 L
.91307 .15506 L
.9131 .15506 L
.91312 .15506 L
.91315 .15507 L
.91318 .15509 L
.91321 .15511 L
.91327 .15516 L
.91332 .15523 L
.91337 .15531 L
.91348 .15553 L
.9137 .15606 L
.91393 .15661 L
.91399 .15674 L
.91406 .15684 L
.91412 .15692 L
.91415 .15695 L
.91418 .15698 L
.91421 .15699 L
.91424 .15701 L
.91427 .15701 L
.91428 .15701 L
.9143 .15701 L
.91433 .15701 L
.91436 .157 L
.91439 .15698 L
Mistroke
.91441 .15696 L
.91448 .15689 L
.91453 .15681 L
.91465 .15661 L
.91489 .15601 L
.91514 .15542 L
.9152 .15531 L
.91526 .15521 L
.9153 .15517 L
.91534 .15513 L
.91537 .1551 L
.91539 .15509 L
.9154 .15508 L
.91543 .15507 L
.91546 .15506 L
.91549 .15506 L
.91551 .15507 L
.91552 .15507 L
.91555 .15508 L
.91558 .1551 L
.91561 .15512 L
.91563 .15515 L
.9157 .15522 L
.91575 .15532 L
.91588 .15558 L
.9161 .15611 L
.91633 .15665 L
.91644 .15685 L
.91647 .15689 L
.91651 .15693 L
.91654 .15696 L
.91657 .15698 L
.9166 .157 L
.91663 .15701 L
.91666 .15701 L
.91668 .15701 L
.91671 .15701 L
.91673 .157 L
.91676 .15698 L
.91679 .15696 L
.91685 .1569 L
.91692 .15681 L
.91705 .15655 L
.91729 .15596 L
.91741 .15568 L
.91753 .1554 L
.91759 .1553 L
.91765 .1552 L
.9177 .15514 L
.91773 .15512 L
Mistroke
.91776 .1551 L
.91778 .15509 L
.9178 .15508 L
.91783 .15507 L
.91784 .15506 L
.91786 .15506 L
.91788 .15507 L
.9179 .15507 L
.91793 .15508 L
.91795 .15509 L
.91796 .1551 L
.91802 .15516 L
.91808 .15523 L
.91814 .15533 L
.91826 .15557 L
.91851 .15617 L
.91862 .15646 L
.91873 .1567 L
.91879 .1568 L
.91886 .1569 L
.91889 .15693 L
.91893 .15696 L
.91894 .15698 L
.91896 .15699 L
.91898 .157 L
.919 .15701 L
.91903 .15701 L
.91905 .15701 L
.91907 .15701 L
.91908 .15701 L
.91911 .157 L
.91914 .15698 L
.91917 .15696 L
.91924 .1569 L
.91929 .15681 L
.91935 .15672 L
.91947 .15647 L
.91969 .15592 L
.91981 .15562 L
.91994 .15534 L
.92 .15524 L
.92007 .15516 L
.9201 .15513 L
.92013 .1551 L
.92015 .15508 L
.92018 .15507 L
.92021 .15506 L
.92024 .15506 L
.92027 .15506 L
.9203 .15507 L
Mistroke
.92033 .15509 L
.92035 .15511 L
.92041 .15516 L
.92047 .15524 L
.92053 .15534 L
.92066 .15562 L
.92093 .15628 L
.92104 .15656 L
.9211 .15668 L
.92117 .1568 L
.92124 .15689 L
.92129 .15696 L
.92132 .15698 L
.92135 .157 L
.92138 .15701 L
.92141 .15702 L
.92144 .15702 L
.92146 .15702 L
.92149 .15701 L
.92152 .15699 L
.92155 .15697 L
.92158 .15694 L
.92164 .15688 L
.9217 .15678 L
.92176 .15667 L
.92188 .15641 L
.92214 .15575 L
.92225 .15549 L
.92236 .15527 L
.92242 .15518 L
.92246 .15514 L
.92249 .15511 L
.92252 .15509 L
.92255 .15507 L
.92258 .15506 L
.92261 .15505 L
.92263 .15505 L
.92266 .15506 L
.92269 .15507 L
.92272 .15508 L
.92274 .1551 L
.92276 .15512 L
.92282 .15518 L
.92287 .15526 L
.92293 .15537 L
.92304 .15561 L
.92329 .15623 L
.92341 .15652 L
.92352 .15675 L
.92358 .15685 L
Mistroke
.92365 .15694 L
.92368 .15697 L
.92371 .157 L
.92373 .15701 L
.92375 .15702 L
.92377 .15702 L
.92378 .15703 L
.92381 .15703 L
.92384 .15703 L
.92387 .15702 L
.9239 .157 L
.92393 .15698 L
.92396 .15695 L
.92402 .15688 L
.92414 .15667 L
.92425 .15642 L
.9245 .15578 L
.92463 .15548 L
.92475 .15525 L
.92482 .15516 L
.92485 .15512 L
.92489 .15508 L
.92492 .15506 L
.92494 .15505 L
.92495 .15505 L
.92498 .15504 L
.92501 .15504 L
.92504 .15505 L
.92506 .15505 L
.92507 .15506 L
.9251 .15508 L
.92514 .15511 L
.9252 .15518 L
.92526 .15526 L
.92538 .15551 L
.92552 .15585 L
.92575 .15645 L
.92588 .15673 L
.92595 .15684 L
.926 .15692 L
.92606 .15699 L
.92609 .15701 L
.92612 .15703 L
.92614 .15703 L
.92616 .15704 L
.92617 .15704 L
.92619 .15704 L
.92622 .15704 L
.92624 .15704 L
.92625 .15703 L
Mistroke
.92628 .15701 L
.92631 .15699 L
.92636 .15694 L
.92642 .15687 L
.92648 .15677 L
.92671 .15624 L
.92692 .15569 L
.92703 .15542 L
.92709 .1553 L
.92715 .1552 L
.92721 .15513 L
.92724 .1551 L
.92727 .15507 L
.92729 .15505 L
.92732 .15504 L
.92735 .15503 L
.92737 .15502 L
.9274 .15503 L
.92743 .15503 L
.92745 .15504 L
.92747 .15505 L
.9275 .15507 L
.92753 .1551 L
.92756 .15513 L
.92761 .1552 L
.92773 .15543 L
.92787 .15575 L
.92811 .15641 L
.92824 .15669 L
.92835 .15689 L
.92841 .15697 L
.92843 .15699 L
.92846 .15702 L
.92849 .15704 L
.92852 .15705 L
.92854 .15706 L
.92856 .15706 L
.92859 .15706 L
.9286 .15706 L
.92862 .15705 L
.92864 .15705 L
.92865 .15704 L
.92868 .15702 L
.92871 .15699 L
.92879 .1569 L
.92885 .1568 L
.92909 .15623 L
.92935 .15556 L
.92946 .15532 L
.92951 .15522 L
Mistroke
.92957 .15513 L
.9296 .1551 L
.92963 .15506 L
.92966 .15504 L
.92969 .15502 L
.92972 .15501 L
.92975 .155 L
.92978 .155 L
.92981 .15501 L
.92984 .15502 L
.92986 .15504 L
.92989 .15506 L
.92992 .15509 L
.92998 .15518 L
.93004 .15527 L
.93025 .15576 L
.9305 .15643 L
.93061 .15669 L
.93067 .15681 L
.93073 .15691 L
.93079 .15699 L
.93082 .15702 L
.93085 .15705 L
.93087 .15706 L
.9309 .15708 L
.93093 .15708 L
.93095 .15709 L
.93098 .15708 L
.931 .15708 L
.93102 .15707 L
.93105 .15705 L
.93108 .15703 L
.93113 .15697 L
.93119 .15689 L
.93131 .15664 L
.93145 .15631 L
.93169 .15565 L
.93181 .15537 L
.93187 .15524 L
.93193 .15514 L
.93197 .15509 L
.932 .15505 L
.93204 .15502 L
.93207 .155 L
.9321 .15498 L
.93212 .15498 L
.93213 .15498 L
.93216 .15498 L
.93218 .15498 L
.9322 .15499 L
Mistroke
.93223 .155 L
.93224 .15501 L
.93226 .15503 L
.93232 .15509 L
.93238 .15518 L
.93245 .1553 L
.93268 .15588 L
.93292 .15653 L
.93305 .15682 L
.93311 .15693 L
.93317 .15701 L
.93319 .15704 L
.93322 .15707 L
.93324 .15708 L
.93327 .1571 L
.9333 .15711 L
.93333 .15711 L
.93335 .15711 L
.93338 .15711 L
.93341 .15709 L
.93344 .15707 L
.93346 .15705 L
.93349 .15702 L
.93355 .15694 L
.93361 .15684 L
.93384 .15627 L
.9341 .15557 L
.93421 .15529 L
.93428 .15517 L
.93433 .15508 L
.93438 .15502 L
.93441 .15499 L
.93444 .15497 L
.93447 .15496 L
.9345 .15495 L
.93453 .15495 L
.93455 .15495 L
.93458 .15496 L
.9346 .15497 L
.93463 .15499 L
.93466 .15502 L
.93471 .15507 L
.93476 .15515 L
.93488 .1554 L
.93499 .15568 L
.93522 .15632 L
.93533 .15664 L
.93546 .15691 L
.93552 .15701 L
.93555 .15705 L
Mistroke
.93559 .15709 L
.93562 .15712 L
.93565 .15714 L
.93568 .15715 L
.93571 .15715 L
.93574 .15715 L
.93577 .15714 L
.9358 .15712 L
.93583 .1571 L
.93586 .15707 L
.93589 .15703 L
.93595 .15694 L
.93606 .15671 L
.93618 .15639 L
.9364 .15577 L
.93652 .15545 L
.93663 .1552 L
.93669 .15508 L
.93672 .15504 L
.93676 .15499 L
.93678 .15496 L
.93682 .15494 L
.93685 .15492 L
.93687 .15491 L
.9369 .15491 L
.93693 .15491 L
.93696 .15492 L
.93698 .15493 L
.93701 .15495 L
.93703 .15497 L
.93709 .15503 L
.93714 .15512 L
.9372 .15524 L
.93731 .15551 L
.93756 .15623 L
.93768 .15658 L
.93779 .15685 L
.93785 .15696 L
.93791 .15706 L
.93794 .1571 L
.93797 .15713 L
.938 .15716 L
.93804 .15718 L
.93807 .15719 L
.93808 .15719 L
.9381 .15719 L
.93813 .15719 L
.93816 .15717 L
.93818 .15716 L
.9382 .15715 L
Mistroke
.93823 .15712 L
.93827 .15708 L
.9383 .15703 L
.93842 .1568 L
.93854 .15648 L
.93876 .15581 L
.93888 .15548 L
.939 .15518 L
.93907 .15504 L
.93914 .15495 L
.93917 .15492 L
.93918 .1549 L
.9392 .15489 L
.93922 .15488 L
.93923 .15487 L
.93926 .15486 L
.93929 .15486 L
.93932 .15487 L
.93935 .15488 L
.93936 .15489 L
.93938 .1549 L
.93941 .15492 L
.93944 .15496 L
.9395 .15505 L
.93962 .15529 L
.93973 .15557 L
.93998 .15637 L
.94011 .15673 L
.94017 .15686 L
.94023 .15699 L
.94028 .15709 L
.94031 .15713 L
.94034 .15716 L
.94036 .15719 L
.94039 .15721 L
.94042 .15723 L
.94044 .15724 L
.94047 .15724 L
.9405 .15724 L
.94052 .15723 L
.94054 .15723 L
.94057 .15721 L
.9406 .15718 L
.94062 .15715 L
.94068 .15708 L
.94074 .15697 L
.9408 .15683 L
.94091 .15652 L
.94117 .15571 L
.94128 .15538 L
Mistroke
.9414 .1551 L
.94146 .15499 L
.94149 .15494 L
.94152 .15489 L
.94156 .15486 L
.94159 .15483 L
.94161 .15482 L
.94164 .15481 L
.94167 .15481 L
.94169 .15481 L
.94172 .15482 L
.94175 .15484 L
.94178 .15486 L
.9418 .15488 L
.94185 .15495 L
.94191 .15505 L
.94197 .15518 L
.94208 .15547 L
.94232 .15625 L
.94244 .15663 L
.94255 .15692 L
.94262 .15705 L
.94268 .15717 L
.94272 .15722 L
.94275 .15725 L
.94278 .15728 L
.9428 .15729 L
.94282 .1573 L
.94285 .1573 L
.94288 .1573 L
.94291 .15729 L
.94292 .15728 L
.94294 .15727 L
.94297 .15725 L
.943 .15721 L
.94306 .15713 L
.94312 .15701 L
.94318 .15686 L
.9433 .15652 L
.94357 .15565 L
.9437 .15526 L
.94376 .15509 L
.94382 .15497 L
.94387 .15488 L
.94393 .1548 L
.94396 .15478 L
.94399 .15476 L
.94402 .15474 L
.94403 .15474 L
.94405 .15474 L
Mistroke
.94408 .15474 L
.9441 .15475 L
.94413 .15477 L
.94416 .1548 L
.9442 .15484 L
.94423 .15489 L
.94429 .15499 L
.94439 .15524 L
.94451 .15559 L
.94477 .15648 L
.94489 .15686 L
.94501 .15713 L
.94506 .15723 L
.94509 .15727 L
.94512 .15731 L
.94515 .15734 L
.94518 .15736 L
.9452 .15737 L
.94522 .15737 L
.94525 .15737 L
.94528 .15737 L
.9453 .15735 L
.94533 .15733 L
.94536 .15731 L
.94542 .15722 L
.94548 .15712 L
.9456 .1568 L
.94572 .15643 L
.94598 .15551 L
.94609 .15516 L
.94616 .155 L
.94621 .15488 L
.94627 .15478 L
.9463 .15474 L
.94633 .15471 L
.94635 .15469 L
.94638 .15467 L
.94641 .15466 L
.94643 .15466 L
.94646 .15467 L
.94649 .15468 L
.94651 .15469 L
.94653 .15471 L
.94656 .15474 L
.94662 .15483 L
.94667 .15494 L
.9468 .15529 L
.94693 .15571 L
.94716 .15656 L
.94729 .15696 L
Mistroke
.94735 .15713 L
.94741 .15725 L
.94746 .15734 L
.94751 .15741 L
.94754 .15743 L
.94757 .15745 L
.94759 .15746 L
.94762 .15746 L
.94765 .15746 L
.94768 .15744 L
.94771 .15742 L
.94773 .1574 L
.94779 .15731 L
.94785 .15719 L
.94797 .15688 L
.94808 .15651 L
.94833 .15559 L
.94844 .15522 L
.94849 .15504 L
.94855 .15489 L
.94861 .15477 L
.94864 .15472 L
.94867 .15467 L
.94869 .15463 L
.94872 .15461 L
.94874 .15459 L
.94877 .15457 L
.9488 .15457 L
.94882 .15457 L
.94883 .15457 L
.94886 .15458 L
.94889 .1546 L
.94892 .15462 L
.94894 .15466 L
.949 .15475 L
.94906 .15488 L
.94912 .15503 L
.94924 .15544 L
.94946 .15627 L
.94969 .15708 L
.94974 .15722 L
.9498 .15736 L
.94983 .15742 L
.94986 .15747 L
.9499 .15751 L
.94992 .15754 L
.94995 .15755 L
.94998 .15756 L
.95001 .15757 L
.95003 .15756 L
Mistroke
.95006 .15755 L
.95009 .15752 L
.95012 .15749 L
.95015 .15745 L
.9502 .15735 L
.95026 .15722 L
.95039 .15683 L
.95064 .15582 L
.95076 .15535 L
.95089 .15491 L
.95095 .15475 L
.95102 .15461 L
.95105 .15456 L
.95108 .15452 L
.9511 .15449 L
.95113 .15447 L
.95116 .15446 L
.95119 .15445 L
.95121 .15445 L
.95124 .15447 L
.95126 .15448 L
.95128 .15449 L
.95131 .15452 L
.95136 .15461 L
.95142 .15473 L
.95147 .15488 L
.95158 .15521 L
.95182 .15621 L
.95194 .1567 L
.95205 .15711 L
.95215 .1574 L
.95221 .15753 L
.95226 .15761 L
.95229 .15764 L
.95231 .15767 L
.95234 .15769 L
.95238 .15769 L
.9524 .15769 L
.95243 .15768 L
.95246 .15766 L
.95249 .15763 L
.95252 .15759 L
.95255 .15754 L
.95261 .1574 L
.95273 .15704 L
.95295 .15613 L
.95308 .15557 L
.95321 .15503 L
.95327 .15482 L
.95334 .15463 L
Mistroke
.95339 .1545 L
.95342 .15444 L
.95345 .15439 L
.95348 .15436 L
.95351 .15433 L
.95354 .15431 L
.95356 .15431 L
.95359 .15431 L
.95362 .15432 L
.95364 .15433 L
.95365 .15435 L
.95368 .15438 L
.95371 .15443 L
.95374 .15448 L
.9538 .15461 L
.9539 .15493 L
.95416 .15604 L
.9544 .15708 L
.95451 .15748 L
.95458 .15765 L
.95461 .15771 L
.95464 .15776 L
.95467 .1578 L
.95469 .15782 L
.95472 .15784 L
.95475 .15785 L
.95478 .15785 L
.95481 .15784 L
.95484 .15782 L
.95487 .15778 L
.9549 .15774 L
.95493 .15768 L
.95498 .15755 L
.95511 .15712 L
.95537 .15593 L
.95549 .15535 L
.95562 .1548 L
.95568 .15458 L
.95574 .15441 L
.9558 .15428 L
.95583 .15423 L
.95585 .15419 L
.95588 .15416 L
.9559 .15415 L
.95592 .15414 L
.95593 .15413 L
.95595 .15413 L
.95598 .15413 L
.95601 .15415 L
.95604 .15417 L
Mistroke
.95607 .15421 L
.9561 .15426 L
.95617 .15443 L
.95624 .15464 L
.95636 .15515 L
.95658 .15622 L
.9568 .15731 L
.95687 .15757 L
.95694 .15777 L
.95699 .1579 L
.95703 .15796 L
.95706 .15801 L
.95708 .15803 L
.95711 .15805 L
.95714 .15806 L
.95717 .15805 L
.95718 .15805 L
.9572 .15803 L
.95723 .158 L
.95726 .15796 L
.95729 .15791 L
.95735 .15775 L
.95741 .15757 L
.95752 .15712 L
.95777 .15582 L
.9579 .15515 L
.95802 .15459 L
.95808 .15435 L
.95814 .15416 L
.95817 .15409 L
.95821 .15401 L
.95823 .15398 L
.95824 .15396 L
.95826 .15393 L
.95828 .15392 L
.9583 .1539 L
.95833 .15389 L
.95836 .1539 L
.95839 .15392 L
.95842 .15395 L
.95845 .15399 L
.95848 .15405 L
.95851 .15413 L
.95858 .15433 L
.95864 .15457 L
.95876 .15513 L
.95897 .15633 L
.9592 .15756 L
.95926 .1578 L
.95932 .15801 L
Mistroke
.95935 .1581 L
.95938 .15817 L
.95941 .15822 L
.95944 .15826 L
.95947 .1583 L
.9595 .15832 L
.95953 .15832 L
.95955 .15832 L
.95957 .15831 L
.95959 .15829 L
.95962 .15825 L
.95965 .1582 L
.95968 .15812 L
.95974 .15795 L
.95979 .15776 L
.95991 .1572 L
.96013 .15594 L
.96035 .15462 L
.96046 .15411 L
.96053 .15388 L
.96059 .15373 L
.96062 .15367 L
.96064 .15364 L
.96065 .15362 L
.96068 .1536 L
.96071 .15359 L
.96073 .15359 L
.96075 .1536 L
.96078 .15362 L
.96079 .15364 L
.96081 .15367 L
.96085 .15374 L
.9609 .15388 L
.96096 .1541 L
.96109 .15469 L
.96135 .15634 L
.96147 .15717 L
.96159 .15784 L
.9617 .15831 L
.96175 .15848 L
.96179 .15855 L
.96181 .15861 L
.96184 .15865 L
.96187 .15867 L
.9619 .15868 L
.96193 .15867 L
.96196 .15865 L
.96198 .15863 L
.962 .15861 L
.96203 .15855 L
Mistroke
.96206 .15847 L
.96211 .1583 L
.96217 .15806 L
.96229 .15742 L
.9625 .15594 L
.96263 .15501 L
.96276 .15422 L
.96287 .15366 L
.96293 .15343 L
.96296 .15334 L
.96299 .15328 L
.96302 .15323 L
.96305 .15319 L
.96308 .15317 L
.96311 .15317 L
.96313 .15318 L
.96316 .15321 L
.96319 .15325 L
.96322 .15331 L
.96325 .15339 L
.96328 .15351 L
.96334 .15376 L
.96346 .1544 L
.96369 .15616 L
.96382 .15715 L
.96396 .15809 L
.96402 .15845 L
.96409 .15876 L
.96414 .15896 L
.96417 .15905 L
.9642 .15911 L
.96423 .15915 L
.96426 .15918 L
.96429 .15918 L
.96431 .15917 L
.96434 .15915 L
.96436 .15912 L
.96438 .15909 L
.96441 .15903 L
.96443 .15895 L
.9645 .1587 L
.96456 .15838 L
.96468 .15762 L
.96494 .15544 L
.96506 .15444 L
.96517 .15362 L
.96523 .15325 L
.9653 .15293 L
.96533 .15282 L
.96536 .15272 L
Mistroke
.96539 .15265 L
.96541 .1526 L
.96544 .15257 L
.96547 .15256 L
.9655 .15256 L
.96553 .15259 L
.96556 .15263 L
.96559 .1527 L
.96561 .15279 L
.96564 .15289 L
.96575 .15347 L
.96586 .15421 L
.96607 .15618 L
.9663 .1583 L
.96637 .15882 L
.96643 .15924 L
.96649 .15954 L
.96652 .15966 L
.96655 .15977 L
.96658 .15985 L
.96661 .1599 L
.96664 .15993 L
.96666 .15994 L
.96668 .15994 L
.9667 .15992 L
.96673 .15988 L
.96676 .15982 L
.96679 .15974 L
.96685 .1595 L
.9669 .15918 L
.96703 .1582 L
.9673 .1555 L
.96753 .15315 L
.96759 .15264 L
.96766 .15219 L
.96769 .15202 L
.96772 .15188 L
.96775 .15178 L
.96778 .15169 L
.96781 .15163 L
.96784 .1516 L
.96786 .15159 L
.96789 .15161 L
.96792 .15166 L
.96795 .15173 L
.96798 .15184 L
.96801 .15197 L
.96808 .15233 L
.96813 .15275 L
.96826 .15399 L
Mistroke
.96848 .15657 L
.96871 .1593 L
.96877 .15992 L
.96884 .16046 L
.9689 .16081 L
.96893 .16096 L
.96896 .16107 L
.96899 .16115 L
.96902 .1612 L
.96905 .16121 L
.96908 .16119 L
.96911 .16114 L
.96912 .1611 L
.96914 .16105 L
.96917 .16093 L
.9692 .16078 L
.96926 .16043 L
.96931 .15995 L
.96942 .15886 L
.96965 .15565 L
.96988 .15237 L
.96994 .15159 L
.97001 .15096 L
.97006 .15051 L
.97009 .1503 L
.97012 .15014 L
.97015 .15003 L
.97018 .14994 L
.97021 .14988 L
.97023 .14986 L
.97026 .14987 L
.9703 .14993 L
.97032 .15003 L
.97035 .15015 L
.9704 .15044 L
.97046 .15088 L
.97056 .15211 L
.97081 .15607 L
.97094 .1585 L
.97107 .1606 L
.97117 .16208 L
.97123 .16273 L
.97129 .1632 L
.97132 .1634 L
.97135 .16354 L
.97138 .16365 L
.97139 .16369 L
.97141 .16371 L
.97144 .16371 L
.97147 .16367 L
Mistroke
.9715 .16357 L
.97153 .16344 L
.97156 .16325 L
.97159 .16304 L
.97165 .16242 L
.97176 .16086 L
.97188 .15841 L
.972 .15571 L
.97222 .15076 L
.97234 .1484 L
.9724 .14748 L
.97246 .1468 L
.97249 .14652 L
.97252 .14628 L
.97254 .1461 L
.97257 .14598 L
.9726 .14591 L
.97263 .1459 L
.97264 .14592 L
.97266 .14596 L
.97269 .14609 L
.97272 .14628 L
.97275 .14657 L
.97282 .14739 L
.97288 .14842 L
.97294 .1496 L
.97315 .15555 L
.97338 .16301 L
.9735 .16648 L
.97357 .16807 L
.97363 .16928 L
.97366 .16983 L
.9737 .17024 L
.97373 .17059 L
.97375 .17073 L
.97377 .17082 L
.9738 .17091 L
.97383 .17089 L
.97385 .17084 L
.97386 .17076 L
.97388 .17064 L
.9739 .1705 L
.97392 .17018 L
.97396 .16973 L
.97402 .16849 L
.97408 .16696 L
.97413 .16521 L
.97438 .1537 L
.97463 .13992 L
.97476 .13413 L
Mistroke
.97481 .13209 L
.97484 .13118 L
.97487 .13033 L
.9749 .1297 L
.97492 .12925 L
.97495 .12893 L
.97497 .12872 L
.975 .12865 L
.97503 .12873 L
.97505 .12898 L
.97508 .12945 L
.97511 .13015 L
.97515 .13116 L
.97521 .13371 L
.97526 .13712 L
.97532 .14109 L
.97542 .15126 L
.97553 .1657 L
.97573 .20055 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 147.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000Tb000`400?l00000o`00003ooooooooe
ooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00;?ooool5
o`0002_ooooo0ol0000Zooooo`;o0000;Oooool3o`0002_ooooo1Ol0000hooooo`Go0000;?ooool3
o`0002[ooooo0_l0000/ooooo`?o0000;?ooool5o`00017ooooo000]ooooo`04o`000?oooooooooo
o`0002cooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`00017ooooo000Vooooo`Go00000oooool00ol0003oooooooooo`0Toooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0booooo`Go00000oooool00ol0003oooooooooo`0U
ooooo`Go00000oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`00;oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0@ooooo`00;?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`00000hooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo0000017ooooo000/ooooo`05o`000?ooooooooooooooool00000:oooool2o`0002[ooooo
00Co0000oooooooooooo0000;?ooool2o`0002cooooo00Go0000ooooooooooooooooo`00000hoooo
o`05o`000?ooooooooooooooool00000;?ooool2o`0002[ooooo00Co0000oooooooooooo0000:ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00000Aooooo`00;Oooool3o`0002gooooo00?o
0000ooooooooool0:Oooool2o`0002kooooo00?o0000ooooooooool0:oooool3o`0003[ooooo0ol0
000^ooooo`03o`000?oooooooooo02Wooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo0ol0
000Booooo`00oooooooeooooo`00oooooooeooooo`008?ooool3o`000?Cooooo0ol0003Jooooo`00
8Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo0=Wooooo000Iooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooolSo00008Oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ooo7o`0000kooooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qoooo
o`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00cooooo000Wooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool2o`00067ooooo00?o0000ooooooooool0
H?ooool2o`00033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0
001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`03o`000?oooooooooo01Wooooo00?o
o`00ooooooooool05?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000W
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05?ooool2ool001Kooooo0_oo000E
ooooo`;oo`005_ooool2ool001Kooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool06Oooool00ooo003oooooooooo`0Dooooo`;oo`005oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`005Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooooooo
ool05?ooool2ool001Oooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool06Oooool2ool001Gooooo0_oo
000Gooooo`03ool00?oooooooooo01?ooooo0_oo000Gooooo`03ool00?oooooooooo01?ooooo0_oo
000Gooooo`;oo`005?ooool2ool000Cooooo00?o0000ooooooooool03?ooool000gooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00001Rooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool04oooool5o`0000;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo1Ooo000?ooooo`Go
o`005oooool4ool000oooooo1Ooo000Gooooo`Coo`004?ooool4ool001Oooooo1?oo000@ooooo`Co
o`001?ooool00ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool0000;ooooo`04
o`000?ooooooooooooooo`;o00006_oooolIo`00oaOooooo6?l00?lGoooooaWo003o5_oooolIo`00
o`;ooooo0ol0000Looooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2
o`0001[ooooo6Ooo000GoooooaSoo`005ooooolHool001Oooooo6?oo0003ooooo`;o00003_ooool0
01Cooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001ooo
ool4o`0000Gooooo00?o0000ooooooooool06OoooolIool001Kooooo6Ooo000GoooooaSoo`005ooo
oolHool000Cooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Iooooo`;oo`005?ooool3ool001Kooooo0_oo000Eooooo`;oo`00
5oooool00ooo003oooooooooo`0Cooooo`;oo`005oooool00ooo003oooooooooo`0Cooooo`;oo`00
1?ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`0000Sooooo1Ol00003ooooo`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Kooooo`;o00002?oo
ool5o`0000Cooooo00?o0000ooooooooool06Oooool2ool001Gooooo0_oo000Fooooo`;oo`005Ooo
ool2ool001Oooooo00?oo`00ooooooooool04oooool2ool001Oooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Iooooo`;o0000<?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003ooooo
ooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003ooooo
ooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0I
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03
ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`00
9oooool2o`0001[ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool0
6Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
5Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
5Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Oooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0
000`ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00
ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooooooooooo
000000kooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo
003ooooooooooooooooo000000kooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05Oooool01Ooo003ooooooooooooooooo000000kooooo000Wooooo`03o`000?oooooooooo
01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooooooooooo000000kooooo000Woooo
o`;o00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooo`00000>ooooo`009oooool00ol0
003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooo`00000>
ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00Goo`00oooo
ooooooooooooo`00000>ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Gooooo00Goo`00ooooooooooooooooo`00000>ooooo`008Oooool2o`0000Cooooo00?o0000oooo
ooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo0_l00005oooo
o`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool01Ooo003ooooooooooooooooo
000000kooooo000Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00Goo`00oooooooooooooooo
o`00000>ooooo`008?ooool01?l0003oooooooooool00003oooooaco000000?o003oo`000?l00000
5Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o000001Co000000?o003oo`000?l00000
5Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o000001Co000000?o003oo`000?l00000
6ol0000Xooooo`04o`000?ooooooooooo`0000Cooooo1?l000000ooo003o0000o`00000Eo`000003
ool00?l0003o000001Go000000?oo`00o`000?l000005?l000000ooo003o0000o`00000Eo`000003
ool00?l0003o000001Go000000?oo`00o`000?l000005?l000000ooo003o0000o`00000Eo`000003
ool00?l0003o000001Go000000?oo`00o`000?l000000_l0000>ooooo`008?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooool0000G
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0023ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool09_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooooooo0000
5oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
5Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
5Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Pooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`00
0?oooooooooo02Kooooo00Co0000oooooooooooo00001?ooool01Ol0003oooooooooooooooooo`00
01Oooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`008Oooool2o`0000Co
oooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02Oo
oooo0_l00005ooooo`05o`000?oooooooooooooooooo00005oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Ioooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool06_ooool00ol0003oooooooooo`0^ooooo`05o`000?oooooooooooooooooo00005oooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`;o00006_ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Iooooo`;o0000<?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?o
o`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0I
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<
ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`00
9oooool2o`0001[ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06Oooool2o`00033ooooo00?o0000ooooooooool0
0_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oo
oooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool0
02Oooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Gooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Jooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03?ooool002Oooooo
00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Wooooo
00?o0000ooooooooool03?ooool002Oooooo0_l0000Jooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Wooooo0_l0
000`ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool05Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Ioooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooooooo
ool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooooooo
ool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00oooooooo
ool05Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Iooooo`03o`00
0?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooo
oooo00cooooo000Wooooo`;o00006_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Iooooo`;o0000<?ooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01[o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`0Iooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool06Oooool00ol0003ooooo
ooooo`0<ooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`04o`000?ooooooooooooooo`;oo`00
5Oooool2ool001Oooooo00?oo`00ooooooooool04oooool2ool001Oooooo0_oo000Eooooo`;oo`00
5_ooool2ool001Gooooo0_oo000Kooooo`03o`000?oooooooooo00cooooo000Dooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool04oooool2ool001Oooooo0_oo000Dooooo`;oo`005oooool2ool001Gooooo00?oo`00
ooooooooool05Oooool2ool001Gooooo0_oo000Kooooo`03o`000?oooooooooo00cooooo000Doooo
o`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01[ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_oooolHool001Oooooo6?oo000GoooooaSoo`00
5ooooolIool001_ooooo00?o0000ooooooooool03?ooool001Cooooo00Co0000oooooooooooo0000
2oooool01?l0003oooooooooooooool2o`0000?ooooo6?l00?lGoooooaWo003o5_oooolIo`00oaOo
oooo6?l00?lJooooo`?o00007?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
00;ooooo0_l00003oooooaSoo`005ooooolHool001Oooooo6?oo000GoooooaWoo`006_ooool2o`00
00kooooo000Dooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo0ooo000Aooooo`Coo`005oooool3
ool0017ooooo1?oo000Gooooo`Coo`004?ooool4ool001Oooooo1?oo000@ooooo`Goo`006oooool0
0ol0003oooooooooo`0<ooooo`005?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool04oooool2ool001Oooooo00?oo`00ooooooooool04ooo
ool2ool001Oooooo0_oo000Dooooo`;oo`005oooool2ool001Gooooo0_oo000Kooooo`03o`000?oo
oooooooo00cooooo000Eooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01_ooooo0_l00008ooooo`Go00001?ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Eooooo`;oo`005_ooool00ooo003oooooooooo`0Iooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo0_oo000Fooooo`03ool00?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooooooo0_oo000Eoooo
o`;oo`005oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`0Eooooo`;oo`005Oooool2ool001_ooooo00?o0000oooo
ooooool03?ooool002Oooooo0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`05
o`000?oooooooooooooooooo0000G_ooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo
037ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Woooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<oooo
o`009oooool2o`00067ooooo00?o0000ooooooooool0H?ooool2o`00033ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`009ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?oo
ool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool03?ooool002Oooooo0_l0001Qooooo`03o`000?oooooooooo063ooooo
0_l0000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`;o0000HOoo
ool00ol0003oooooooooo`1Pooooo`;o0000<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool3o`0000Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Ko
oooo0ol00005ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0<ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00cooooo
000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000ko
oooo000Qooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0002Wooooo00?o0000ooooooooool0
1?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;o00003_ooool0027ooooo00?o0000ooooooooool00oooooo8o`0002Wooooo00?o
0000ooooooooool01?ooooo7o`0000kooooo000Pooooo`;o0000mOooool2o`000=_ooooo000Qoooo
o`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0fOooool00?oooooomOooool00?oooooo
mOooool00?oooooomOooool00?oooooomOooool00?oooooomOooool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {146.125, 0}} -> {-0.0552611, -0.0147182, \
0.00422951, 0.00422951}, {{13.0625, 238.188}, {142.625, 3.4375}} -> \
{-2.93665, -1.26592, 0.0211569, 0.0164643}, {{260.75, 485.875}, {142.625, \
3.4375}} -> {-8.17696, -1.26592, 0.0211569, 0.0164643}}],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \(sin(2\ \[Pi]\ t)\)\)\/\[Pi] + \(2\ \(sin(6\ \
\[Pi]\ t)\)\)\/\(3\ \[Pi]\) + \(2\ \(sin(10\ \[Pi]\ t)\)\)\/\(5\ \[Pi]\) + \
\(2\ \(sin(14\ \[Pi]\ t)\)\)\/\(7\ \[Pi]\) + \(2\ \(sin(18\ \[Pi]\ \
t)\)\)\/\(9\ \[Pi]\) + \(2\ \(sin(22\ \[Pi]\ t)\)\)\/\(11\ \[Pi]\) + \(2\ \
\(sin(26\ \[Pi]\ t)\)\)\/\(13\ \[Pi]\) + \(2\ \(sin(30\ \[Pi]\ t)\)\)\/\(15\ \
\[Pi]\) + \(2\ \(sin(34\ \[Pi]\ t)\)\)\/\(17\ \[Pi]\) + \(2\ \(sin(38\ \[Pi]\ \
t)\)\)\/\(19\ \[Pi]\) + \(2\ \(sin(42\ \[Pi]\ t)\)\)\/\(21\ \[Pi]\) + \(2\ \
\(sin(46\ \[Pi]\ t)\)\)\/\(23\ \[Pi]\) + \(2\ \(sin(50\ \[Pi]\ t)\)\)\/\(25\ \
\[Pi]\) + \(2\ \(sin(54\ \[Pi]\ t)\)\)\/\(27\ \[Pi]\) + \(2\ \(sin(58\ \[Pi]\ \
t)\)\)\/\(29\ \[Pi]\) + \(2\ \(sin(62\ \[Pi]\ t)\)\)\/\(31\ \[Pi]\) + \(2\ \
\(sin(66\ \[Pi]\ t)\)\)\/\(33\ \[Pi]\) + \(2\ \(sin(70\ \[Pi]\ t)\)\)\/\(35\ \
\[Pi]\) + \(2\ \(sin(74\ \[Pi]\ t)\)\)\/\(37\ \[Pi]\) + \(2\ \(sin(78\ \[Pi]\ \
t)\)\)\/\(39\ \[Pi]\) + \(2\ \(sin(82\ \[Pi]\ t)\)\)\/\(41\ \[Pi]\) + \(2\ \
\(sin(86\ \[Pi]\ t)\)\)\/\(43\ \[Pi]\) + \(2\ \(sin(90\ \[Pi]\ t)\)\)\/\(45\ \
\[Pi]\) + \(2\ \(sin(94\ \[Pi]\ t)\)\)\/\(47\ \[Pi]\) + \(2\ \(sin(98\ \[Pi]\ \
t)\)\)\/\(49\ \[Pi]\) + \(2\ \(sin(102\ \[Pi]\ t)\)\)\/\(51\ \[Pi]\) + \(2\ \
\(sin(106\ \[Pi]\ t)\)\)\/\(53\ \[Pi]\) + \(2\ \(sin(110\ \[Pi]\ t)\)\)\/\(55\
\ \[Pi]\) + \(2\ \(sin(114\ \[Pi]\ t)\)\)\/\(57\ \[Pi]\) + \(2\ \(sin(118\ \
\[Pi]\ t)\)\)\/\(59\ \[Pi]\) + \(2\ \(sin(122\ \[Pi]\ t)\)\)\/\(61\ \[Pi]\) + \
\(2\ \(sin(126\ \[Pi]\ t)\)\)\/\(63\ \[Pi]\) + \(2\ \(sin(130\ \[Pi]\ \
t)\)\)\/\(65\ \[Pi]\) + \(2\ \(sin(134\ \[Pi]\ t)\)\)\/\(67\ \[Pi]\) + \(2\ \
\(sin(138\ \[Pi]\ t)\)\)\/\(69\ \[Pi]\) + \(2\ \(sin(142\ \[Pi]\ t)\)\)\/\(71\
\ \[Pi]\) + \(2\ \(sin(146\ \[Pi]\ t)\)\)\/\(73\ \[Pi]\) + \(2\ \(sin(150\ \
\[Pi]\ t)\)\)\/\(75\ \[Pi]\) + \(2\ \(sin(154\ \[Pi]\ t)\)\)\/\(77\ \[Pi]\) + \
\(2\ \(sin(158\ \[Pi]\ t)\)\)\/\(79\ \[Pi]\) + \(2\ \(sin(162\ \[Pi]\ \
t)\)\)\/\(81\ \[Pi]\) + \(2\ \(sin(166\ \[Pi]\ t)\)\)\/\(83\ \[Pi]\) + \(2\ \
\(sin(170\ \[Pi]\ t)\)\)\/\(85\ \[Pi]\) + \(2\ \(sin(174\ \[Pi]\ t)\)\)\/\(87\
\ \[Pi]\) + \(2\ \(sin(178\ \[Pi]\ t)\)\)\/\(89\ \[Pi]\) + \(2\ \(sin(182\ \
\[Pi]\ t)\)\)\/\(91\ \[Pi]\) + \(2\ \(sin(186\ \[Pi]\ t)\)\)\/\(93\ \[Pi]\) + \
\(2\ \(sin(190\ \[Pi]\ t)\)\)\/\(95\ \[Pi]\) + \(2\ \(sin(194\ \[Pi]\ \
t)\)\)\/\(97\ \[Pi]\) + \(2\ \(sin(198\ \[Pi]\ t)\)\)\/\(99\ \[Pi]\)\)], \
"Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency domain plots", "Subsubsection"],

Cell[BoxData[
    \(\(ftbl\  = \ 
        Table[{k, 
            FourierCoefficient[Pulse1[t], t, k, \ 
              FourierParameters \[Rule] {1, \(-1\)}]}, {k, \(-50\), 
            50}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[\({#[\([1]\)], Abs[#[\([2]\)]]} &\)\  /@ \ ftbl, \ 
        Red, \ Frame \[Rule] True, \ PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.0147151 1.84915 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10717 -24 -4.5 ]
[-0.0125 .10717 0 4.5 ]
[-0.0125 .19963 -18 -4.5 ]
[-0.0125 .19963 0 4.5 ]
[-0.0125 .29209 -24 -4.5 ]
[-0.0125 .29209 0 4.5 ]
[-0.0125 .38455 -18 -4.5 ]
[-0.0125 .38455 0 4.5 ]
[-0.0125 .477 -24 -4.5 ]
[-0.0125 .477 0 4.5 ]
[-0.0125 .56946 -18 -4.5 ]
[-0.0125 .56946 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-40)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-20)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(20)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(40)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10717 m
.00625 .10717 L
s
[(0.05)] -0.0125 .10717 1 0 Mshowa
0 .19963 m
.00625 .19963 L
s
[(0.1)] -0.0125 .19963 1 0 Mshowa
0 .29209 m
.00625 .29209 L
s
[(0.15)] -0.0125 .29209 1 0 Mshowa
0 .38455 m
.00625 .38455 L
s
[(0.2)] -0.0125 .38455 1 0 Mshowa
0 .477 m
.00625 .477 L
s
[(0.25)] -0.0125 .477 1 0 Mshowa
0 .56946 m
.00625 .56946 L
s
[(0.3)] -0.0125 .56946 1 0 Mshowa
.125 Mabswid
0 .03321 m
.00375 .03321 L
s
0 .0517 m
.00375 .0517 L
s
0 .07019 m
.00375 .07019 L
s
0 .08868 m
.00375 .08868 L
s
0 .12566 m
.00375 .12566 L
s
0 .14416 m
.00375 .14416 L
s
0 .16265 m
.00375 .16265 L
s
0 .18114 m
.00375 .18114 L
s
0 .21812 m
.00375 .21812 L
s
0 .23661 m
.00375 .23661 L
s
0 .25511 m
.00375 .25511 L
s
0 .2736 m
.00375 .2736 L
s
0 .31058 m
.00375 .31058 L
s
0 .32907 m
.00375 .32907 L
s
0 .34756 m
.00375 .34756 L
s
0 .36605 m
.00375 .36605 L
s
0 .40304 m
.00375 .40304 L
s
0 .42153 m
.00375 .42153 L
s
0 .44002 m
.00375 .44002 L
s
0 .45851 m
.00375 .45851 L
s
0 .49549 m
.00375 .49549 L
s
0 .51399 m
.00375 .51399 L
s
0 .53248 m
.00375 .53248 L
s
0 .55097 m
.00375 .55097 L
s
0 .58795 m
.00375 .58795 L
s
0 .60644 m
.00375 .60644 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10717 m
1 .10717 L
s
.99375 .19963 m
1 .19963 L
s
.99375 .29209 m
1 .29209 L
s
.99375 .38455 m
1 .38455 L
s
.99375 .477 m
1 .477 L
s
.99375 .56946 m
1 .56946 L
s
.125 Mabswid
.99625 .03321 m
1 .03321 L
s
.99625 .0517 m
1 .0517 L
s
.99625 .07019 m
1 .07019 L
s
.99625 .08868 m
1 .08868 L
s
.99625 .12566 m
1 .12566 L
s
.99625 .14416 m
1 .14416 L
s
.99625 .16265 m
1 .16265 L
s
.99625 .18114 m
1 .18114 L
s
.99625 .21812 m
1 .21812 L
s
.99625 .23661 m
1 .23661 L
s
.99625 .25511 m
1 .25511 L
s
.99625 .2736 m
1 .2736 L
s
.99625 .31058 m
1 .31058 L
s
.99625 .32907 m
1 .32907 L
s
.99625 .34756 m
1 .34756 L
s
.99625 .36605 m
1 .36605 L
s
.99625 .40304 m
1 .40304 L
s
.99625 .42153 m
1 .42153 L
s
.99625 .44002 m
1 .44002 L
s
.99625 .45851 m
1 .45851 L
s
.99625 .49549 m
1 .49549 L
s
.99625 .51399 m
1 .51399 L
s
.99625 .53248 m
1 .53248 L
s
.99625 .55097 m
1 .55097 L
s
.99625 .58795 m
1 .58795 L
s
.99625 .60644 m
1 .60644 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.03333 .01472 m
.03333 .02673 L
s
.04286 .01472 m
.04286 .01472 L
s
.05238 .01472 m
.05238 .02724 L
s
.0619 .01472 m
.0619 .01472 L
s
.07143 .01472 m
.07143 .0278 L
s
.08095 .01472 m
.08095 .01472 L
s
.09048 .01472 m
.09048 .0284 L
s
.1 .01472 m
.1 .01472 L
s
.10952 .01472 m
.10952 .02907 L
s
.11905 .01472 m
.11905 .01472 L
s
.12857 .01472 m
.12857 .02981 L
s
.1381 .01472 m
.1381 .01472 L
s
.14762 .01472 m
.14762 .03062 L
s
.15714 .01472 m
.15714 .01472 L
s
.16667 .01472 m
.16667 .03153 L
s
.17619 .01472 m
.17619 .01472 L
s
.18571 .01472 m
.18571 .03255 L
s
.19524 .01472 m
.19524 .01472 L
s
.20476 .01472 m
.20476 .0337 L
s
.21429 .01472 m
.21429 .01472 L
s
.22381 .01472 m
.22381 .03501 L
s
.23333 .01472 m
.23333 .01472 L
s
.24286 .01472 m
.24286 .03652 L
s
.25238 .01472 m
.25238 .01472 L
s
.2619 .01472 m
.2619 .03826 L
s
.27143 .01472 m
.27143 .01472 L
s
.28095 .01472 m
.28095 .04031 L
s
.29048 .01472 m
.29048 .01472 L
s
.3 .01472 m
.3 .04274 L
s
.30952 .01472 m
.30952 .01472 L
s
.31905 .01472 m
.31905 .04569 L
s
.32857 .01472 m
.32857 .01472 L
s
.3381 .01472 m
.3381 .04934 L
s
.34762 .01472 m
.34762 .01472 L
s
.35714 .01472 m
.35714 .05396 L
s
.36667 .01472 m
.36667 .01472 L
s
.37619 .01472 m
.37619 .05999 L
s
.38571 .01472 m
.38571 .01472 L
s
.39524 .01472 m
.39524 .06822 L
s
.40476 .01472 m
.40476 .01472 L
s
.41429 .01472 m
.41429 .08012 L
s
.42381 .01472 m
.42381 .01472 L
s
.43333 .01472 m
.43333 .0988 L
s
.44286 .01472 m
.44286 .01472 L
s
.45238 .01472 m
.45238 .13244 L
s
.4619 .01472 m
.4619 .01472 L
s
.47143 .01472 m
.47143 .21092 L
s
.48095 .01472 m
.48095 .01472 L
s
.49048 .01472 m
.49048 .60332 L
s
.5 .01472 m
.5 .01472 L
s
.50952 .01472 m
.50952 .60332 L
s
.51905 .01472 m
.51905 .01472 L
s
.52857 .01472 m
.52857 .21092 L
s
.5381 .01472 m
.5381 .01472 L
s
.54762 .01472 m
.54762 .13244 L
s
.55714 .01472 m
.55714 .01472 L
s
.56667 .01472 m
.56667 .0988 L
s
.57619 .01472 m
.57619 .01472 L
s
.58571 .01472 m
.58571 .08012 L
s
.59524 .01472 m
.59524 .01472 L
s
.60476 .01472 m
.60476 .06822 L
s
.61429 .01472 m
.61429 .01472 L
s
.62381 .01472 m
.62381 .05999 L
s
.63333 .01472 m
.63333 .01472 L
s
.64286 .01472 m
.64286 .05396 L
s
.65238 .01472 m
.65238 .01472 L
s
.6619 .01472 m
.6619 .04934 L
s
.67143 .01472 m
.67143 .01472 L
s
.68095 .01472 m
.68095 .04569 L
s
.69048 .01472 m
.69048 .01472 L
s
.7 .01472 m
.7 .04274 L
s
.70952 .01472 m
.70952 .01472 L
s
.71905 .01472 m
.71905 .04031 L
s
.72857 .01472 m
.72857 .01472 L
s
.7381 .01472 m
.7381 .03826 L
s
.74762 .01472 m
.74762 .01472 L
s
.75714 .01472 m
.75714 .03652 L
s
.76667 .01472 m
.76667 .01472 L
s
.77619 .01472 m
.77619 .03501 L
s
.78571 .01472 m
.78571 .01472 L
s
.79524 .01472 m
.79524 .0337 L
s
.80476 .01472 m
.80476 .01472 L
s
.81429 .01472 m
.81429 .03255 L
s
.82381 .01472 m
.82381 .01472 L
s
.83333 .01472 m
.83333 .03153 L
s
.84286 .01472 m
.84286 .01472 L
s
.85238 .01472 m
.85238 .03062 L
s
.8619 .01472 m
.8619 .01472 L
s
.87143 .01472 m
.87143 .02981 L
s
.88095 .01472 m
.88095 .01472 L
s
.89048 .01472 m
.89048 .02907 L
s
.9 .01472 m
.9 .01472 L
s
.90952 .01472 m
.90952 .0284 L
s
.91905 .01472 m
.91905 .01472 L
s
.92857 .01472 m
.92857 .0278 L
s
.9381 .01472 m
.9381 .01472 L
s
.94762 .01472 m
.94762 .02724 L
s
.95714 .01472 m
.95714 .01472 L
s
.96667 .01472 m
.96667 .02673 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.03333 .02673 Mdot
.04286 .01472 Mdot
.05238 .02724 Mdot
.0619 .01472 Mdot
.07143 .0278 Mdot
.08095 .01472 Mdot
.09048 .0284 Mdot
.1 .01472 Mdot
.10952 .02907 Mdot
.11905 .01472 Mdot
.12857 .02981 Mdot
.1381 .01472 Mdot
.14762 .03062 Mdot
.15714 .01472 Mdot
.16667 .03153 Mdot
.17619 .01472 Mdot
.18571 .03255 Mdot
.19524 .01472 Mdot
.20476 .0337 Mdot
.21429 .01472 Mdot
.22381 .03501 Mdot
.23333 .01472 Mdot
.24286 .03652 Mdot
.25238 .01472 Mdot
.2619 .03826 Mdot
.27143 .01472 Mdot
.28095 .04031 Mdot
.29048 .01472 Mdot
.3 .04274 Mdot
.30952 .01472 Mdot
.31905 .04569 Mdot
.32857 .01472 Mdot
.3381 .04934 Mdot
.34762 .01472 Mdot
.35714 .05396 Mdot
.36667 .01472 Mdot
.37619 .05999 Mdot
.38571 .01472 Mdot
.39524 .06822 Mdot
.40476 .01472 Mdot
.41429 .08012 Mdot
.42381 .01472 Mdot
.43333 .0988 Mdot
.44286 .01472 Mdot
.45238 .13244 Mdot
.4619 .01472 Mdot
.47143 .21092 Mdot
.48095 .01472 Mdot
.49048 .60332 Mdot
.5 .01472 Mdot
.50952 .60332 Mdot
.51905 .01472 Mdot
.52857 .21092 Mdot
.5381 .01472 Mdot
.54762 .13244 Mdot
.55714 .01472 Mdot
.56667 .0988 Mdot
.57619 .01472 Mdot
.58571 .08012 Mdot
.59524 .01472 Mdot
.60476 .06822 Mdot
.61429 .01472 Mdot
.62381 .05999 Mdot
.63333 .01472 Mdot
.64286 .05396 Mdot
.65238 .01472 Mdot
.6619 .04934 Mdot
.67143 .01472 Mdot
.68095 .04569 Mdot
.69048 .01472 Mdot
.7 .04274 Mdot
.70952 .01472 Mdot
.71905 .04031 Mdot
.72857 .01472 Mdot
.7381 .03826 Mdot
.74762 .01472 Mdot
.75714 .03652 Mdot
.76667 .01472 Mdot
.77619 .03501 Mdot
.78571 .01472 Mdot
.79524 .0337 Mdot
.80476 .01472 Mdot
.81429 .03255 Mdot
.82381 .01472 Mdot
.83333 .03153 Mdot
.84286 .01472 Mdot
.85238 .03062 Mdot
.8619 .01472 Mdot
.87143 .02981 Mdot
.88095 .01472 Mdot
.89048 .02907 Mdot
.9 .01472 Mdot
.90952 .0284 Mdot
.91905 .01472 Mdot
.92857 .0278 Mdot
.9381 .01472 Mdot
.94762 .02724 Mdot
.95714 .01472 Mdot
.96667 .02673 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00>Oooool3o`0000?ooooo0_l0000Wooooo`Go0000
0oooool2o`0002[ooooo0_l0000Zooooo`Go00000oooool2o`0002Wooooo0ol00003ooooo`;o0000
7Oooool003[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Gooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`04o`000?oooooooooo
o`0002[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Yooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`00<Oooool5o`000003oooo
ool0003o000000?o00000_ooool01?l0003oooooooooool0000Pooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo0000:oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0001cooooo000gooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
0000:Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool09_ooool01?l0
003oooooooooool0000/ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Tooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007?ooool003Sooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Vooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Xooooo`04o`000?ooooooooooo`0002Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool0000Looooo`00>Oooool2o`0000?ooooo00Co0000oooooooo
oooo00009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?oo
ool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Xooooo`;o00000oooool01?l0003oooooooooool0000Looooo`00>_ooool00ol0
003oooooooooo`02ooooo`;o0000:?ooool3o`0000Cooooo0_l0000Zooooo`;o0000:oooool3o`00
00Cooooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooooooo`0000Go00000Oooool001Co
oooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Looooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool01?l0003o
ooooooooooooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000Cooooo0Ol0
0001ooooo`004oooool01?l0003oooooooooool00004ooooo`;o00000_ooool3ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00005ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000?oo`0000?oooooool00?oo00001Ooo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool000?ooooo0_l0
0001ooooo`004oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooooooo`?oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Goo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000ooo00000oooooooo`00ool00005ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
00?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000;oo`00
1?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1?ooool3ool000;ooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?oo`000_ooool3ool000Oooooo0Ol00001ooooo`005?ooool2o`0000Go
oooo00?o0000ooooooooool01?ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`04ool00?oooooo
ooooooooo`?oo`000_ooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0007ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01?oo
ool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_oo
ool3ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3ool000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0000
1?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0007ooooo`7o00000Ooo
ool001_ooooo0_l0000?ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00Coo`00oooooooooooooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo000@ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool09oooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000Cooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo000Yooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0>_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0004
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo000mooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0A?ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0017ooooo`7o00000Oooool0
01_ooooo0_l0001?ooooo`?oo`000_ooool3ool000;ooooo0ooo0003ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00ooo0002ooooo`?oo`000_ooool3ool0053ooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`1Cooooo`?oo`000_ooool3ool000?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ool000;ooooo0ooo001Fooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0F?ooool3ool000;ooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ool000;ooooo0ooo001Kooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0GOooool3ool000?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?oo`00H?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo05gooooo0ooo0002ooooo`?oo`000oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ool000;ooooo0ooo001Pooooo`7o00000Oooool001_ooooo0_l0001Sooooo`?oo`000oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ool006Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Rooooo`?o
o`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ool006Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1Wooooo`?oo`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?oo`00
J_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Oooooo0ooo0003ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00ooo001Zooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Ioooool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ool006[ooooo0Ol00001ooooo`006oooool2o`0006kooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`1/ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0KOooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo06gooooo0Ol00001ooooo`000_ooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo06cooooo
0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ool006oooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06cooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ool006oooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1/
ooooo`?oo`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00ooo001_ooooo`7o00000Oooool00005ooooool0003oooooooooool000002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0001cooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1aooooo`;o00000Ooo
ool00005ooooool0003oooooooooool000002?ooool01Ol0003oooooooooool0003ooooo00Co0000
1Oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`1booooo`7o00000Oooool00005ooooool0003oooooooooool00000
2?ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0L_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0L_ooool1o`00
007ooooo0002ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo07;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07;o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1booooo`7o00000Oooool001_ooooo0_l0
001cooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1aooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0LOooool3ool000?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00ooo001dooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool3ool0
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00ooo001dooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0LOooool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo001dooooo`7o00000Oooool001_ooooo
0_l0001hooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo07Kooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1g
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1goooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool2o`0007Sooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
M_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Mooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Moooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Moooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Moooool1o`00007o
oooo000Kooooo`;o0000N?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1fooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool0Moooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1gooooo`7o00000Oooool000Sooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo07Oooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0Moooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1gooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Oooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Moooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1gooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000N?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1f
ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Moooool1o`00007ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo07Kooooo0ooo0003
ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo001hooooo`7o00000Ooo
ool000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0M_ooool3
ool000?ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3ool007Sooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1fooooo`?oo`000oooool00ooo003oooooooooo`02
ooooo`04ool00?ooooooooooooooo`?oo`00N?ooool1o`00007ooooo000Kooooo`;o0000OOooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo07_ooooo0_l00001ooooo`006oooool00ol0
003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool2o`0007gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1kooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006ooo
ool2o`0007gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1kooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo07cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo
0Ol00001ooooo`006oooool2o`0007gooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1kooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`000_ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo07cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool00005ooooool0003ooooooooo
ool000002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1looooo`7o00000Oooool00005ooooool0003oooooooooool000002Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001mooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0Noooool2o`00007ooooo00001Ooooooo0000oooooooooooo
000000Wooooo00Co0000oooooooooooooooo1?l00005ooooo`03o`000?oooooooooo07cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool00005ooooool0003o
ooooooooool000002?ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo0002
ooooo`;o00002_ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0O?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1
o`00007ooooo000Kooooo`;o0000OOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol0
0001ooooo`006oooool2o`0007gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1k
ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1looooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo07cooooo0Ol00001ooooo`006oooool2o`0007gooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1kooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool2o`0007gooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1kooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool0
00Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool0
00Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`;o0000OOooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo07_ooooo0_l00001ooooo`001oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo0007
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o0000
0Oooool000Sooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1looooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool0
01_ooooo0_l0001mooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Noooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000K
ooooo`;o0000OOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07_ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?oo
ool1o`00007ooooo000Kooooo`;o0000OOooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo07_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`;o0000OOooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo07_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1loooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo0002ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool00005
ooooool0003oooooooooool000002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0O?ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool00005ooooool0003o
ooooooooool000002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
001mooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Noooool2o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Go
oooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07co
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`000?oooooooooooooo
ool0003oooooo`000008ooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1looooo`7o00000Oooool000;ooooo0_l00009ooooo`?o00000_ooool5o`00
00Cooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`;o0000OOooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo07_ooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1l
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool2o`0007gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1kooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006oooool2o`0007go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1kooooo`;o00000Oooool001_ooooo
00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001oooo
o`006oooool2o`0007gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1kooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo07cooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo07cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0O?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0O?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`;o0000OOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07_ooooo
0_l00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0O?ooool1o`00007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0
O?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0O?oo
ool1o`00007ooooo000Kooooo`;o0000OOooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo07_ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0O?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1looooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Noooool3ool000;ooooo0ooo001mooooo`7o00000Oooool001_ooooo0_l0
001looooo`?oo`000_ooool3ool007cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1k
ooooo`?oo`000_ooool3ool007gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`7o00000Oooool001_oooooool00005o`00007ooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-63.5193, -0.0378746, \
0.404426, 0.00208295}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[\({#[\([1]\)], 
              Arg[#[\([2]\)] +  .000001]} &\)\  /@ \ ftbl, \ Red, \ 
        Frame \[Rule] True, \ PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.309017 0.187359 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02798 -24 -4.5 ]
[-0.0125 .02798 0 4.5 ]
[-0.0125 .12166 -12 -4.5 ]
[-0.0125 .12166 0 4.5 ]
[-0.0125 .21534 -24 -4.5 ]
[-0.0125 .21534 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .4027 -18 -4.5 ]
[-0.0125 .4027 0 4.5 ]
[-0.0125 .49638 -6 -4.5 ]
[-0.0125 .49638 0 4.5 ]
[-0.0125 .59006 -18 -4.5 ]
[-0.0125 .59006 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-40)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-20)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(20)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(40)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02798 m
.00625 .02798 L
s
[(-1.5)] -0.0125 .02798 1 0 Mshowa
0 .12166 m
.00625 .12166 L
s
[(-1)] -0.0125 .12166 1 0 Mshowa
0 .21534 m
.00625 .21534 L
s
[(-0.5)] -0.0125 .21534 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .4027 m
.00625 .4027 L
s
[(0.5)] -0.0125 .4027 1 0 Mshowa
0 .49638 m
.00625 .49638 L
s
[(1)] -0.0125 .49638 1 0 Mshowa
0 .59006 m
.00625 .59006 L
s
[(1.5)] -0.0125 .59006 1 0 Mshowa
.125 Mabswid
0 .04671 m
.00375 .04671 L
s
0 .06545 m
.00375 .06545 L
s
0 .08419 m
.00375 .08419 L
s
0 .10292 m
.00375 .10292 L
s
0 .14039 m
.00375 .14039 L
s
0 .15913 m
.00375 .15913 L
s
0 .17787 m
.00375 .17787 L
s
0 .1966 m
.00375 .1966 L
s
0 .23407 m
.00375 .23407 L
s
0 .25281 m
.00375 .25281 L
s
0 .27155 m
.00375 .27155 L
s
0 .29028 m
.00375 .29028 L
s
0 .32775 m
.00375 .32775 L
s
0 .34649 m
.00375 .34649 L
s
0 .36522 m
.00375 .36522 L
s
0 .38396 m
.00375 .38396 L
s
0 .42143 m
.00375 .42143 L
s
0 .44017 m
.00375 .44017 L
s
0 .4589 m
.00375 .4589 L
s
0 .47764 m
.00375 .47764 L
s
0 .51511 m
.00375 .51511 L
s
0 .53385 m
.00375 .53385 L
s
0 .55258 m
.00375 .55258 L
s
0 .57132 m
.00375 .57132 L
s
0 .00924 m
.00375 .00924 L
s
0 .60879 m
.00375 .60879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02798 m
1 .02798 L
s
.99375 .12166 m
1 .12166 L
s
.99375 .21534 m
1 .21534 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .4027 m
1 .4027 L
s
.99375 .49638 m
1 .49638 L
s
.99375 .59006 m
1 .59006 L
s
.125 Mabswid
.99625 .04671 m
1 .04671 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08419 m
1 .08419 L
s
.99625 .10292 m
1 .10292 L
s
.99625 .14039 m
1 .14039 L
s
.99625 .15913 m
1 .15913 L
s
.99625 .17787 m
1 .17787 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .23407 m
1 .23407 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .27155 m
1 .27155 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .32775 m
1 .32775 L
s
.99625 .34649 m
1 .34649 L
s
.99625 .36522 m
1 .36522 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .42143 m
1 .42143 L
s
.99625 .44017 m
1 .44017 L
s
.99625 .4589 m
1 .4589 L
s
.99625 .47764 m
1 .47764 L
s
.99625 .51511 m
1 .51511 L
s
.99625 .53385 m
1 .53385 L
s
.99625 .55258 m
1 .55258 L
s
.99625 .57132 m
1 .57132 L
s
.99625 .00924 m
1 .00924 L
s
.99625 .60879 m
1 .60879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03333 .30902 m
.03333 .60329 L
s
.04286 .30902 m
.04286 .30902 L
s
.05238 .30902 m
.05238 .60329 L
s
.0619 .30902 m
.0619 .30902 L
s
.07143 .30902 m
.07143 .60329 L
s
.08095 .30902 m
.08095 .30902 L
s
.09048 .30902 m
.09048 .60329 L
s
.1 .30902 m
.1 .30902 L
s
.10952 .30902 m
.10952 .6033 L
s
.11905 .30902 m
.11905 .30902 L
s
.12857 .30902 m
.12857 .6033 L
s
.1381 .30902 m
.1381 .30902 L
s
.14762 .30902 m
.14762 .6033 L
s
.15714 .30902 m
.15714 .30902 L
s
.16667 .30902 m
.16667 .6033 L
s
.17619 .30902 m
.17619 .30902 L
s
.18571 .30902 m
.18571 .6033 L
s
.19524 .30902 m
.19524 .30902 L
s
.20476 .30902 m
.20476 .6033 L
s
.21429 .30902 m
.21429 .30902 L
s
.22381 .30902 m
.22381 .6033 L
s
.23333 .30902 m
.23333 .30902 L
s
.24286 .30902 m
.24286 .6033 L
s
.25238 .30902 m
.25238 .30902 L
s
.2619 .30902 m
.2619 .6033 L
s
.27143 .30902 m
.27143 .30902 L
s
.28095 .30902 m
.28095 .60331 L
s
.29048 .30902 m
.29048 .30902 L
s
.3 .30902 m
.3 .60331 L
s
.30952 .30902 m
.30952 .30902 L
s
.31905 .30902 m
.31905 .60331 L
s
.32857 .30902 m
.32857 .30902 L
s
.3381 .30902 m
.3381 .60331 L
s
.34762 .30902 m
.34762 .30902 L
s
.35714 .30902 m
.35714 .60331 L
s
.36667 .30902 m
.36667 .30902 L
s
.37619 .30902 m
.37619 .60331 L
s
.38571 .30902 m
.38571 .30902 L
s
.39524 .30902 m
.39524 .60331 L
s
.40476 .30902 m
.40476 .30902 L
s
.41429 .30902 m
.41429 .60331 L
s
.42381 .30902 m
.42381 .30902 L
s
.43333 .30902 m
.43333 .60332 L
s
.44286 .30902 m
.44286 .30902 L
s
.45238 .30902 m
.45238 .60332 L
s
.4619 .30902 m
.4619 .30902 L
s
.47143 .30902 m
.47143 .60332 L
s
.48095 .30902 m
.48095 .30902 L
s
.49048 .30902 m
.49048 .60332 L
s
.5 .30902 m
.5 .30902 L
s
.50952 .30902 m
.50952 .01472 L
s
.51905 .30902 m
.51905 .30902 L
s
.52857 .30902 m
.52857 .01472 L
s
.5381 .30902 m
.5381 .30902 L
s
.54762 .30902 m
.54762 .01472 L
s
.55714 .30902 m
.55714 .30902 L
s
.56667 .30902 m
.56667 .01472 L
s
.57619 .30902 m
.57619 .30902 L
s
.58571 .30902 m
.58571 .01472 L
s
.59524 .30902 m
.59524 .30902 L
s
.60476 .30902 m
.60476 .01472 L
s
.61429 .30902 m
.61429 .30902 L
s
.62381 .30902 m
.62381 .01472 L
s
.63333 .30902 m
.63333 .30902 L
s
.64286 .30902 m
.64286 .01472 L
s
.65238 .30902 m
.65238 .30902 L
s
.6619 .30902 m
.6619 .01472 L
s
.67143 .30902 m
.67143 .30902 L
s
.68095 .30902 m
.68095 .01473 L
s
.69048 .30902 m
.69048 .30902 L
s
.7 .30902 m
.7 .01473 L
s
.70952 .30902 m
.70952 .30902 L
s
.71905 .30902 m
.71905 .01473 L
s
.72857 .30902 m
.72857 .30902 L
s
.7381 .30902 m
.7381 .01473 L
s
.74762 .30902 m
.74762 .30902 L
s
.75714 .30902 m
.75714 .01473 L
s
.76667 .30902 m
.76667 .30902 L
s
.77619 .30902 m
.77619 .01473 L
s
.78571 .30902 m
.78571 .30902 L
s
.79524 .30902 m
.79524 .01473 L
s
.80476 .30902 m
.80476 .30902 L
s
.81429 .30902 m
.81429 .01473 L
s
.82381 .30902 m
.82381 .30902 L
s
.83333 .30902 m
.83333 .01474 L
s
.84286 .30902 m
.84286 .30902 L
s
.85238 .30902 m
.85238 .01474 L
s
.8619 .30902 m
.8619 .30902 L
s
.87143 .30902 m
.87143 .01474 L
s
.88095 .30902 m
.88095 .30902 L
s
.89048 .30902 m
.89048 .01474 L
s
.9 .30902 m
.9 .30902 L
s
.90952 .30902 m
.90952 .01474 L
s
.91905 .30902 m
.91905 .30902 L
s
.92857 .30902 m
.92857 .01474 L
s
.9381 .30902 m
.9381 .30902 L
s
.94762 .30902 m
.94762 .01474 L
s
.95714 .30902 m
.95714 .30902 L
s
.96667 .30902 m
.96667 .01474 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.03333 .60329 Mdot
.04286 .30902 Mdot
.05238 .60329 Mdot
.0619 .30902 Mdot
.07143 .60329 Mdot
.08095 .30902 Mdot
.09048 .60329 Mdot
.1 .30902 Mdot
.10952 .6033 Mdot
.11905 .30902 Mdot
.12857 .6033 Mdot
.1381 .30902 Mdot
.14762 .6033 Mdot
.15714 .30902 Mdot
.16667 .6033 Mdot
.17619 .30902 Mdot
.18571 .6033 Mdot
.19524 .30902 Mdot
.20476 .6033 Mdot
.21429 .30902 Mdot
.22381 .6033 Mdot
.23333 .30902 Mdot
.24286 .6033 Mdot
.25238 .30902 Mdot
.2619 .6033 Mdot
.27143 .30902 Mdot
.28095 .60331 Mdot
.29048 .30902 Mdot
.3 .60331 Mdot
.30952 .30902 Mdot
.31905 .60331 Mdot
.32857 .30902 Mdot
.3381 .60331 Mdot
.34762 .30902 Mdot
.35714 .60331 Mdot
.36667 .30902 Mdot
.37619 .60331 Mdot
.38571 .30902 Mdot
.39524 .60331 Mdot
.40476 .30902 Mdot
.41429 .60331 Mdot
.42381 .30902 Mdot
.43333 .60332 Mdot
.44286 .30902 Mdot
.45238 .60332 Mdot
.4619 .30902 Mdot
.47143 .60332 Mdot
.48095 .30902 Mdot
.49048 .60332 Mdot
.5 .30902 Mdot
.50952 .01472 Mdot
.51905 .30902 Mdot
.52857 .01472 Mdot
.5381 .30902 Mdot
.54762 .01472 Mdot
.55714 .30902 Mdot
.56667 .01472 Mdot
.57619 .30902 Mdot
.58571 .01472 Mdot
.59524 .30902 Mdot
.60476 .01472 Mdot
.61429 .30902 Mdot
.62381 .01472 Mdot
.63333 .30902 Mdot
.64286 .01472 Mdot
.65238 .30902 Mdot
.6619 .01472 Mdot
.67143 .30902 Mdot
.68095 .01473 Mdot
.69048 .30902 Mdot
.7 .01473 Mdot
.70952 .30902 Mdot
.71905 .01473 Mdot
.72857 .30902 Mdot
.7381 .01473 Mdot
.74762 .30902 Mdot
.75714 .01473 Mdot
.76667 .30902 Mdot
.77619 .01473 Mdot
.78571 .30902 Mdot
.79524 .01473 Mdot
.80476 .30902 Mdot
.81429 .01473 Mdot
.82381 .30902 Mdot
.83333 .01474 Mdot
.84286 .30902 Mdot
.85238 .01474 Mdot
.8619 .30902 Mdot
.87143 .01474 Mdot
.88095 .30902 Mdot
.89048 .01474 Mdot
.9 .30902 Mdot
.90952 .01474 Mdot
.91905 .30902 Mdot
.92857 .01474 Mdot
.9381 .30902 Mdot
.94762 .01474 Mdot
.95714 .30902 Mdot
.96667 .01474 Mdot
.97619 .30902 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00>Oooool3o`0000?ooooo0_l0000Wooooo`Go0000
0oooool2o`0002[ooooo0_l0000Zooooo`Go00000oooool2o`0002Wooooo0ol00003ooooo`;o0000
7Oooool003[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Gooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`04o`000?oooooooooo
o`0002[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Yooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`00<Oooool5o`000003oooo
ool0003o000000?o00000_ooool01?l0003oooooooooool0000Pooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo0000:oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0001cooooo000gooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
0000:Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool09_ooool01?l0
003oooooooooool0000/ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Tooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007?ooool003Sooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Vooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Xooooo`04o`000?ooooooooooo`0002Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool0000Looooo`00>Oooool2o`0000?ooooo00Co0000oooooooo
oooo00009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?oo
ool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Xooooo`;o00000oooool01?l0003oooooooooool0000Looooo`00>_ooool00ol0
003oooooooooo`02ooooo`;o0000:?ooool3o`0000Cooooo0_l0000Zooooo`;o0000:oooool3o`00
00Cooooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooooooo`0000Go00000Oooool001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool1o`00007ooooo000Kooooo`;o00007Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01_ooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`20ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;o
oooo0ooo0002ooooo`?oo`000_ooool3ool000Oooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`20ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?o
o`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?o
o`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?o
o`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool00004oooooooo003oo`00ool0
00;ooooo0ooo0002ooooo`?oo`000_ooool3ool000Oooooo0Ol00001ooooo`001oooool3o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0P?ooool3ool000;o
oooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0007ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool000Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00022
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Cooooo0_l00001ooooo`002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool000Sooooo00?o0000
ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool000Oooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0POooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`05ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000
ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo0_l00022ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`21
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol0
0001ooooo`006oooool2o`0008;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01?ooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`;o0000P_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0POooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`05ooooo`7o00000Oooool001_ooooo0_l00022ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`004oooool3o`0000Gooooo00?o0000
ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`003?ooool5o`0000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`005?ooool0
0ol0003oooooooooo`04ooooo`;o0000P_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`004oooool2
o`0000Kooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool2
o`0008;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool1o`00007ooooo000Kooooo`;o0000P_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0POooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Ooo
ool001_ooooo0_l00022ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`21
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0008;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`21
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`00
1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo00;ooooo0_l00022ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo0_l00001ooooo`001oooool01?l0
003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`21ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol0
0001ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?oo
ool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0008;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo
000Kooooo`;o0000P_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`04ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0POoo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0POooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0POooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`7o00000Oooool001_ooooo0_l0
0022ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo0Ol00001ooooo`006oooool2o`0008;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003ooooooooo
o`21ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Gooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo087ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01Oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo0_l00002ooooo`?oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00003ool00003
oooooooo003oo`0000Goo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00005ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000;oo`000oooool2o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo00Co0000oooooooooooooooo0ooo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00?oo`0000?oooooool00?oo00001Ooo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00000_oo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0004ooooo`7o00000Oooool0
01?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooooooool3ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00005ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool00003oooooooo
003oo`0000;oo`0000?oooooool00?oo00000_oo00000oooooooo`00ool00002ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo
0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00
0_ooool3ool000Cooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0POooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool2o`0000Kooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0P?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00007o
oooo000Kooooo`;o00001_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`20ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`21ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_ooooo0_l00006ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo083o
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087o
oooo0Ol00001ooooo`006oooool2o`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0P?ooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0POooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo083ooooo0_l00001ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`21ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool001_ooooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo083ooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
087ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool2o`0000Ko
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0P?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Kooooo`;o00001_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`20ooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`21ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_o
oooo0_l00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo083ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
087ooooo0Ol00001ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
087ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
083ooooo0_l00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
087ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo000Kooooo`;o00001_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`20ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`21ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`21ooooo`7o00000Oooool001_ooooo0_l00006ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
083ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo087ooooo0Ol00001ooooo`006oooool2o`0000Kooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0P?ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0POooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1o`00
007ooooo000Kooooo`;o00001_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`20ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`21ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`21oooo
o`7o00000Oooool000Oooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0POooool1o`00007ooooo0008ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0POooool1
o`00007ooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0P?ooool2o`00007ooooo0008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001ooooo`002?ooool00ol0
003oooooooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo087ooooo0Ol00001
ooooo`001oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0022ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool5o`00
00Cooooo00?o0000ooooooooool01?ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool0
00;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool0
0?oo003oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`00P_ooool1o`00007ooooo000Koooo
o`;o00001Oooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002oooo
o`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`0000Coooooool00?oo003oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`?oo`000_ooool3
ool000;ooooo0ooo0002ooooo`?oo`00POooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00?ooooo0Ol00001ooooo`006oooooooo`0000Go00000Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-63.5193, -1.9446, 0.404426, \
0.0205577}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 578}},
ScreenStyleEnvironment->"Working",
WindowSize->{745, 661},
WindowMargins->{{226, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 40, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1770, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1894, 62, 60, 0, 49, "Subsection"],
Cell[1957, 64, 127, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2121, 71, 37, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2183, 75, 59, 0, 43, "Subsubsection"],
Cell[2245, 77, 118, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2400, 84, 67, 0, 43, "Subsubsection"],
Cell[2470, 86, 820, 15, 143, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3339, 107, 45, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3409, 111, 62, 0, 43, "Subsubsection"],
Cell[3474, 113, 330, 6, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3841, 124, 67, 0, 43, "Subsubsection"],
Cell[3911, 126, 227, 4, 28, "Text"],
Cell[4141, 132, 551, 10, 143, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4729, 147, 48, 0, 43, "Subsubsection"],
Cell[4780, 149, 367, 8, 46, "Text"],
Cell[5150, 159, 302, 4, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5489, 168, 83, 1, 43, "Subsubsection"],
Cell[5575, 171, 683, 12, 191, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6307, 189, 39, 0, 33, "Subsection"],
Cell[6349, 191, 333, 7, 46, "Text"],
Cell[6685, 200, 541, 10, 127, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7263, 215, 41, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[7329, 219, 45, 0, 43, "Subsubsection"],
Cell[7377, 221, 67, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7481, 227, 43, 0, 43, "Subsubsection"],
Cell[7527, 229, 58, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7622, 235, 104, 4, 43, "Subsubsection"],
Cell[7729, 241, 74, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7852, 248, 109, 4, 33, "Subsection"],
Cell[7964, 254, 136, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8137, 262, 50, 0, 33, "Subsection"],
Cell[8190, 264, 181, 3, 63, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8420, 273, 56, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8501, 277, 47, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8573, 281, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8652, 285, 490, 11, 79, "Input"],
Cell[9145, 298, 33325, 849, 186, 6435, 512, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42519, 1153, 47, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[42591, 1157, 158, 3, 63, "Input"],
Cell[42752, 1162, 516, 7, 66, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43317, 1175, 44, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[43386, 1179, 143, 2, 63, "Input"],
Cell[43532, 1183, 195, 3, 63, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43776, 1192, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[43837, 1196, 308, 6, 79, "Input"],
Cell[44148, 1204, 52235, 1586, 157, 14311, 1115, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[96432, 2796, 96, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[96553, 2803, 187, 3, 47, "Input"],
Cell[96743, 2808, 63616, 2516, 186, 31140, 2111, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[160408, 5330, 47, 0, 43, "Subsubsection"],
Cell[160458, 5332, 139, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[160622, 5339, 123, 2, 47, "Input"],
Cell[160748, 5343, 27577, 740, 186, 5662, 465, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[188386, 6090, 47, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[188458, 6094, 52, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[188535, 6098, 395, 9, 79, "Input"],
Cell[188933, 6109, 38188, 891, 186, 6452, 495, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[227170, 7006, 47, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[227242, 7010, 176, 3, 63, "Input"],
Cell[227421, 7015, 811, 12, 79, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[228281, 7033, 44, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[228350, 7037, 143, 2, 63, "Input"],
Cell[228496, 7041, 231, 3, 76, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[228776, 7050, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[228837, 7054, 325, 6, 79, "Input"],
Cell[229165, 7062, 70478, 2051, 156, 19663, 1421, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[299692, 9119, 35, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[299752, 9123, 515, 10, 111, "Input"],
Cell[300270, 9135, 71531, 2112, 156, 20570, 1480, "GraphicsData", \
"PostScript", "Graphics"],
Cell[371804, 11249, 428, 6, 76, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[372281, 11261, 40, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[372346, 11265, 516, 10, 111, "Input"],
Cell[372865, 11277, 65845, 1711, 156, 14159, 1070, "GraphicsData", \
"PostScript", "Graphics"],
Cell[438713, 12990, 4084, 53, 356, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[442846, 13049, 47, 0, 43, "Subsubsection"],
Cell[442896, 13051, 208, 5, 47, "Input"],

Cell[CellGroupData[{
Cell[443129, 13060, 166, 2, 47, "Input"],
Cell[443298, 13064, 45120, 1264, 186, 10308, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[488455, 14333, 192, 3, 47, "Input"],
Cell[488650, 14338, 223916, 3472, 186, 10311, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[712627, 17817, 45, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[712697, 17821, 52, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[712774, 17825, 407, 9, 79, "Input"],
Cell[713184, 17836, 35541, 884, 186, 6745, 524, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[748774, 18726, 47, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[748846, 18730, 155, 3, 63, "Input"],
Cell[749004, 18735, 563, 8, 79, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[749616, 18749, 44, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[749685, 18753, 143, 2, 63, "Input"],
Cell[749831, 18757, 178, 3, 76, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[750058, 18766, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[750119, 18770, 325, 6, 79, "Input"],
Cell[750447, 18778, 73681, 2130, 156, 20197, 1467, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[824177, 20914, 35, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[824237, 20918, 512, 10, 111, "Input"],
Cell[824752, 20930, 76457, 2327, 156, 23345, 1668, "GraphicsData", \
"PostScript", "Graphics"],
Cell[901212, 23259, 270, 4, 76, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[901531, 23269, 40, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[901596, 23273, 551, 11, 111, "Input"],
Cell[902150, 23286, 313152, 17645, 156, 263649, 17031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1215305, 40933, 2421, 32, 203, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1217775, 40971, 47, 0, 43, "Subsubsection"],
Cell[1217825, 40973, 205, 5, 47, "Input"],

Cell[CellGroupData[{
Cell[1218055, 40982, 166, 2, 47, "Input"],
Cell[1218224, 40986, 46842, 1286, 186, 10311, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1265103, 42277, 192, 3, 47, "Input"],
Cell[1265298, 42282, 125578, 2258, 186, 10311, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

